/**
 * Copyright 2019 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { GaxiosPromise } from 'gaxios';
import { JWT, OAuth2Client, UserRefreshClient } from 'google-auth-library';
import { APIRequestContext, BodyResponseCallback, GlobalOptions, GoogleConfigurable, MethodOptions } from 'googleapis-common';
export declare namespace compute_v1 {
    interface Options extends GlobalOptions {
        version: 'v1';
    }
    interface StandardParameters {
        /**
         * Data format for the response.
         */
        alt?: string;
        /**
         * Selector specifying which fields to include in a partial response.
         */
        fields?: string;
        /**
         * API key. Your API key identifies your project and provides you with API
         * access, quota, and reports. Required unless you provide an OAuth 2.0
         * token.
         */
        key?: string;
        /**
         * OAuth 2.0 token for the current user.
         */
        oauth_token?: string;
        /**
         * Returns response with indentations and line breaks.
         */
        prettyPrint?: boolean;
        /**
         * An opaque string that represents a user for quota purposes. Must not
         * exceed 40 characters.
         */
        quotaUser?: string;
        /**
         * Deprecated. Please use quotaUser instead.
         */
        userIp?: string;
    }
    /**
     * Compute Engine API
     *
     * Creates and runs virtual machines on Google Cloud Platform.
     *
     * @example
     * const {google} = require('googleapis');
     * const compute = google.compute('v1');
     *
     * @namespace compute
     * @type {Function}
     * @version v1
     * @variation v1
     * @param {object=} options Options for Compute
     */
    class Compute {
        context: APIRequestContext;
        acceleratorTypes: Resource$Acceleratortypes;
        addresses: Resource$Addresses;
        autoscalers: Resource$Autoscalers;
        backendBuckets: Resource$Backendbuckets;
        backendServices: Resource$Backendservices;
        disks: Resource$Disks;
        diskTypes: Resource$Disktypes;
        firewalls: Resource$Firewalls;
        forwardingRules: Resource$Forwardingrules;
        globalAddresses: Resource$Globaladdresses;
        globalForwardingRules: Resource$Globalforwardingrules;
        globalOperations: Resource$Globaloperations;
        healthChecks: Resource$Healthchecks;
        httpHealthChecks: Resource$Httphealthchecks;
        httpsHealthChecks: Resource$Httpshealthchecks;
        images: Resource$Images;
        instanceGroupManagers: Resource$Instancegroupmanagers;
        instanceGroups: Resource$Instancegroups;
        instances: Resource$Instances;
        instanceTemplates: Resource$Instancetemplates;
        interconnectAttachments: Resource$Interconnectattachments;
        interconnectLocations: Resource$Interconnectlocations;
        interconnects: Resource$Interconnects;
        licenseCodes: Resource$Licensecodes;
        licenses: Resource$Licenses;
        machineTypes: Resource$Machinetypes;
        networkEndpointGroups: Resource$Networkendpointgroups;
        networks: Resource$Networks;
        nodeGroups: Resource$Nodegroups;
        nodeTemplates: Resource$Nodetemplates;
        nodeTypes: Resource$Nodetypes;
        projects: Resource$Projects;
        regionAutoscalers: Resource$Regionautoscalers;
        regionBackendServices: Resource$Regionbackendservices;
        regionCommitments: Resource$Regioncommitments;
        regionDisks: Resource$Regiondisks;
        regionDiskTypes: Resource$Regiondisktypes;
        regionInstanceGroupManagers: Resource$Regioninstancegroupmanagers;
        regionInstanceGroups: Resource$Regioninstancegroups;
        regionOperations: Resource$Regionoperations;
        regions: Resource$Regions;
        routers: Resource$Routers;
        routes: Resource$Routes;
        securityPolicies: Resource$Securitypolicies;
        snapshots: Resource$Snapshots;
        sslCertificates: Resource$Sslcertificates;
        sslPolicies: Resource$Sslpolicies;
        subnetworks: Resource$Subnetworks;
        targetHttpProxies: Resource$Targethttpproxies;
        targetHttpsProxies: Resource$Targethttpsproxies;
        targetInstances: Resource$Targetinstances;
        targetPools: Resource$Targetpools;
        targetSslProxies: Resource$Targetsslproxies;
        targetTcpProxies: Resource$Targettcpproxies;
        targetVpnGateways: Resource$Targetvpngateways;
        urlMaps: Resource$Urlmaps;
        vpnTunnels: Resource$Vpntunnels;
        zoneOperations: Resource$Zoneoperations;
        zones: Resource$Zones;
        constructor(options: GlobalOptions, google?: GoogleConfigurable);
    }
    /**
     * A specification of the type and number of accelerator cards attached to the
     * instance.
     */
    interface Schema$AcceleratorConfig {
        /**
         * The number of the guest accelerator cards exposed to this instance.
         */
        acceleratorCount?: number;
        /**
         * Full or partial URL of the accelerator type resource to attach to this
         * instance. For example:
         * projects/my-project/zones/us-central1-c/acceleratorTypes/nvidia-tesla-p100
         * If you are creating an instance template, specify only the accelerator
         * name. See GPUs on Compute Engine for a full list of accelerator types.
         */
        acceleratorType?: string;
    }
    /**
     * An Accelerator Type resource. (== resource_for beta.acceleratorTypes ==)
     * (== resource_for v1.acceleratorTypes ==)
     */
    interface Schema$AcceleratorType {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] The deprecation status associated with this accelerator
         * type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional textual description of the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] The type of the resource. Always compute#acceleratorType
         * for accelerator types.
         */
        kind?: string;
        /**
         * [Output Only] Maximum accelerator cards allowed per instance.
         */
        maximumCardsPerInstance?: number;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The name of the zone where the accelerator type resides,
         * such as us-central1-a. You must specify this field as part of the HTTP
         * request URL. It is not settable as a field in the request body.
         */
        zone?: string;
    }
    interface Schema$AcceleratorTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of AcceleratorTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$AcceleratorTypesScopedList;
        };
        /**
         * [Output Only] Type of resource. Always
         * compute#acceleratorTypeAggregatedList for aggregated lists of accelerator
         * types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of accelerator types.
     */
    interface Schema$AcceleratorTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of AcceleratorType resources.
         */
        items?: Schema$AcceleratorType[];
        /**
         * [Output Only] Type of resource. Always compute#acceleratorTypeList for
         * lists of accelerator types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$AcceleratorTypesScopedList {
        /**
         * [Output Only] A list of accelerator types contained in this scope.
         */
        acceleratorTypes?: Schema$AcceleratorType[];
        /**
         * [Output Only] An informational warning that appears when the accelerator
         * types list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * An access configuration attached to an instance&#39;s network interface.
     * Only one access config per instance is supported.
     */
    interface Schema$AccessConfig {
        /**
         * [Output Only] Type of the resource. Always compute#accessConfig for
         * access configs.
         */
        kind?: string;
        /**
         * The name of this access configuration. The default and recommended name
         * is External NAT but you can use any arbitrary string you would like. For
         * example, My external IP or Network Access.
         */
        name?: string;
        /**
         * An external IP address associated with this instance. Specify an unused
         * static external IP address available to the project or leave this field
         * undefined to use an IP from a shared ephemeral IP address pool. If you
         * specify a static external IP address, it must live in the same region as
         * the zone of the instance.
         */
        natIP?: string;
        /**
         * This signifies the networking tier used for configuring this access
         * configuration and can only take the following values: PREMIUM, STANDARD.
         * If an AccessConfig is specified without a valid external IP address, an
         * ephemeral IP will be created with this networkTier.  If an AccessConfig
         * with a valid external IP address is specified, it must match that of the
         * networkTier associated with the Address resource owning that IP.
         */
        networkTier?: string;
        /**
         * The DNS domain name for the public PTR record. This field can only be set
         * when the set_public_ptr field is enabled.
         */
        publicPtrDomainName?: string;
        /**
         * Specifies whether a public DNS ?PTR? record should be created to map the
         * external IP address of the instance to a DNS domain name.
         */
        setPublicPtr?: boolean;
        /**
         * The type of configuration. The default and only option is ONE_TO_ONE_NAT.
         */
        type?: string;
    }
    /**
     * A reserved address resource. (== resource_for beta.addresses ==) (==
     * resource_for v1.addresses ==) (== resource_for beta.globalAddresses ==) (==
     * resource_for v1.globalAddresses ==)
     */
    interface Schema$Address {
        /**
         * The static IP address represented by this resource.
         */
        address?: string;
        /**
         * The type of address to reserve, either INTERNAL or EXTERNAL. If
         * unspecified, defaults to EXTERNAL.
         */
        addressType?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * The IP Version that will be used by this address. Valid options are IPV4
         * or IPV6. This can only be specified for a global address.
         */
        ipVersion?: string;
        /**
         * [Output Only] Type of the resource. Always compute#address for addresses.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The URL of the network in which to reserve the address. This field can
         * only be used with INTERNAL type with VPC_PEERING purpose.
         */
        network?: string;
        /**
         * This signifies the networking tier used for configuring this Address and
         * can only take the following values: PREMIUM, STANDARD. Global forwarding
         * rules can only be Premium Tier. Regional forwarding rules can be either
         * Premium or Standard Tier. Standard Tier addresses applied to regional
         * forwarding rules can be used with any external load balancer. Regional
         * forwarding rules in Premium Tier can only be used with a Network load
         * balancer.  If this field is not specified, it is assumed to be PREMIUM.
         */
        networkTier?: string;
        /**
         * The prefix length if the resource reprensents an IP range.
         */
        prefixLength?: number;
        /**
         * The purpose of resource, only used with INTERNAL type.
         */
        purpose?: string;
        /**
         * [Output Only] URL of the region where the regional address resides. This
         * field is not applicable to global addresses. You must specify this field
         * as part of the HTTP request URL. You cannot set this field in the request
         * body.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The status of the address, which can be one of RESERVING,
         * RESERVED, or IN_USE. An address that is RESERVING is currently in the
         * process of being reserved. A RESERVED address is currently reserved and
         * available to use. An IN_USE address is currently being used by another
         * resource and is not available.
         */
        status?: string;
        /**
         * The URL of the subnetwork in which to reserve the address. If an IP
         * address is specified, it must be within the subnetwork&#39;s IP range.
         * This field can only be used with INTERNAL type with
         * GCE_ENDPOINT/DNS_RESOLVER purposes.
         */
        subnetwork?: string;
        /**
         * [Output Only] The URLs of the resources that are using this address.
         */
        users?: string[];
    }
    interface Schema$AddressAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of AddressesScopedList resources.
         */
        items?: {
            [key: string]: Schema$AddressesScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#addressAggregatedList for
         * aggregated lists of addresses.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$AddressesScopedList {
        /**
         * [Output Only] A list of addresses contained in this scope.
         */
        addresses?: Schema$Address[];
        /**
         * [Output Only] Informational warning which replaces the list of addresses
         * when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of addresses.
     */
    interface Schema$AddressList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Address resources.
         */
        items?: Schema$Address[];
        /**
         * [Output Only] Type of resource. Always compute#addressList for lists of
         * addresses.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * An alias IP range attached to an instance&#39;s network interface.
     */
    interface Schema$AliasIpRange {
        /**
         * The IP CIDR range represented by this alias IP range. This IP CIDR range
         * must belong to the specified subnetwork and cannot contain IP addresses
         * reserved by system or used by other network interfaces. This range may be
         * a single IP address (e.g. 10.2.3.4), a netmask (e.g. /24) or a CIDR
         * format string (e.g. 10.1.2.0/24).
         */
        ipCidrRange?: string;
        /**
         * Optional subnetwork secondary range name specifying the secondary range
         * from which to allocate the IP CIDR range for this alias IP range. If left
         * unspecified, the primary range of the subnetwork will be used.
         */
        subnetworkRangeName?: string;
    }
    /**
     * An instance-attached disk resource.
     */
    interface Schema$AttachedDisk {
        /**
         * Specifies whether the disk will be auto-deleted when the instance is
         * deleted (but not when the disk is detached from the instance).
         */
        autoDelete?: boolean;
        /**
         * Indicates that this is a boot disk. The virtual machine will use the
         * first partition of the disk for its root filesystem.
         */
        boot?: boolean;
        /**
         * Specifies a unique device name of your choice that is reflected into the
         * /dev/disk/by-id/google-* tree of a Linux operating system running within
         * the instance. This name can be used to reference the device for mounting,
         * resizing, and so on, from within the instance.  If not specified, the
         * server chooses a default device name to apply to this disk, in the form
         * persistent-disk-x, where x is a number assigned by Google Compute Engine.
         * This field is only applicable for persistent disks.
         */
        deviceName?: string;
        /**
         * Encrypts or decrypts a disk using a customer-supplied encryption key.  If
         * you are creating a new disk, this field encrypts the new disk using an
         * encryption key that you provide. If you are attaching an existing disk
         * that is already encrypted, this field decrypts the disk using the
         * customer-supplied encryption key.  If you encrypt a disk using a
         * customer-supplied key, you must provide the same key again when you
         * attempt to use this resource at a later time. For example, you must
         * provide the key when you create a snapshot or an image from the disk or
         * when you attach the disk to a virtual machine instance.  If you do not
         * provide an encryption key, then the disk will be encrypted using an
         * automatically generated key and you do not need to provide a key to use
         * the disk later.  Instance templates do not store customer-supplied
         * encryption keys, so you cannot use your own keys to encrypt disks in a
         * managed instance group.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * A list of features to enable on the guest operating system. Applicable
         * only for bootable images. Read  Enabling guest operating system features
         * to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] A zero-based index to this disk, where 0 is reserved for
         * the boot disk. If you have many disks attached to an instance, each disk
         * would have a unique index number.
         */
        index?: number;
        /**
         * [Input Only] Specifies the parameters for a new disk that will be created
         * alongside the new instance. Use initialization parameters to create boot
         * disks or local SSDs attached to the new instance.  This property is
         * mutually exclusive with the source property; you can only define one or
         * the other, but not both.
         */
        initializeParams?: Schema$AttachedDiskInitializeParams;
        /**
         * Specifies the disk interface to use for attaching this disk, which is
         * either SCSI or NVME. The default is SCSI. Persistent disks must always
         * use SCSI and the request will fail if you attempt to attach a persistent
         * disk in any other format than SCSI. Local SSDs can use either NVME or
         * SCSI. For performance characteristics of SCSI over NVMe, see Local SSD
         * performance.
         */
        interface?: string;
        /**
         * [Output Only] Type of the resource. Always compute#attachedDisk for
         * attached disks.
         */
        kind?: string;
        /**
         * [Output Only] Any valid publicly visible licenses.
         */
        licenses?: string[];
        /**
         * The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If
         * not specified, the default is to attach the disk in READ_WRITE mode.
         */
        mode?: string;
        /**
         * Specifies a valid partial or full URL to an existing Persistent Disk
         * resource. When creating a new instance, one of
         * initializeParams.sourceImage or disks.source is required except for local
         * SSD.  If desired, you can also attach existing non-root persistent disks
         * using this property. This field is only applicable for persistent disks.
         * Note that for InstanceTemplate, specify the disk name, not the URL for
         * the disk.
         */
        source?: string;
        /**
         * Specifies the type of the disk, either SCRATCH or PERSISTENT. If not
         * specified, the default is PERSISTENT.
         */
        type?: string;
    }
    /**
     * [Input Only] Specifies the parameters for a new disk that will be created
     * alongside the new instance. Use initialization parameters to create boot
     * disks or local SSDs attached to the new instance.  This property is
     * mutually exclusive with the source property; you can only define one or the
     * other, but not both.
     */
    interface Schema$AttachedDiskInitializeParams {
        /**
         * An optional description. Provide this property when creating the disk.
         */
        description?: string;
        /**
         * Specifies the disk name. If not specified, the default is to use the name
         * of the instance. If the disk with the instance name exists already in the
         * given zone/region, a new name will be automatically generated.
         */
        diskName?: string;
        /**
         * Specifies the size of the disk in base-2 GB.
         */
        diskSizeGb?: string;
        /**
         * Specifies the disk type to use to create the instance. If not specified,
         * the default is pd-standard, specified using the full URL. For example:
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/pd-standard
         * Other values include pd-ssd and local-ssd. If you define this field, you
         * can provide either the full or partial URL. For example, the following
         * are valid values:   -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/diskType
         * - projects/project/zones/zone/diskTypes/diskType  -
         * zones/zone/diskTypes/diskType  Note that for InstanceTemplate, this is
         * the name of the disk type, not URL.
         */
        diskType?: string;
        /**
         * Labels to apply to this disk. These can be later modified by the
         * disks.setLabels method. This field is only applicable for persistent
         * disks.
         */
        labels?: {
            [key: string]: string;
        };
        /**
         * The source image to create this disk. When creating a new instance, one
         * of initializeParams.sourceImage or disks.source is required except for
         * local SSD.  To create a disk with one of the public operating system
         * images, specify the image by its family name. For example, specify
         * family/debian-9 to use the latest Debian 9 image:
         * projects/debian-cloud/global/images/family/debian-9   Alternatively, use
         * a specific version of a public operating system image:
         * projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD   To
         * create a disk with a custom image that you created, specify the image
         * name in the following format: global/images/my-custom-image   You can
         * also specify a custom image by its image family, which returns the latest
         * version of the image in that family. Replace the image name with
         * family/family-name: global/images/family/my-image-family   If the source
         * image is deleted later, this field will not be set.
         */
        sourceImage?: string;
        /**
         * The customer-supplied encryption key of the source image. Required if the
         * source image is protected by a customer-supplied encryption key. Instance
         * templates do not store customer-supplied encryption keys, so you cannot
         * create disks for instances in a managed instance group if the source
         * images are encrypted with your own keys.
         */
        sourceImageEncryptionKey?: Schema$CustomerEncryptionKey;
    }
    /**
     * Specifies the audit configuration for a service. The configuration
     * determines which permission types are logged, and what identities, if any,
     * are exempted from logging. An AuditConfig must have one or more
     * AuditLogConfigs.  If there are AuditConfigs for both `allServices` and a
     * specific service, the union of the two AuditConfigs is used for that
     * service: the log_types specified in each AuditConfig are enabled, and the
     * exempted_members in each AuditLogConfig are exempted.  Example Policy with
     * multiple AuditConfigs:  { &quot;audit_configs&quot;: [ {
     * &quot;service&quot;: &quot;allServices&quot; &quot;audit_log_configs&quot;:
     * [ { &quot;log_type&quot;: &quot;DATA_READ&quot;,
     * &quot;exempted_members&quot;: [ &quot;user:foo@gmail.com&quot; ] }, {
     * &quot;log_type&quot;: &quot;DATA_WRITE&quot;, }, { &quot;log_type&quot;:
     * &quot;ADMIN_READ&quot;, } ] }, { &quot;service&quot;:
     * &quot;fooservice.googleapis.com&quot; &quot;audit_log_configs&quot;: [ {
     * &quot;log_type&quot;: &quot;DATA_READ&quot;, }, { &quot;log_type&quot;:
     * &quot;DATA_WRITE&quot;, &quot;exempted_members&quot;: [
     * &quot;user:bar@gmail.com&quot; ] } ] } ] }  For fooservice, this policy
     * enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts
     * foo@gmail.com from DATA_READ logging, and bar@gmail.com from DATA_WRITE
     * logging.
     */
    interface Schema$AuditConfig {
        /**
         * The configuration for logging of each type of permission.
         */
        auditLogConfigs?: Schema$AuditLogConfig[];
        exemptedMembers?: string[];
        /**
         * Specifies a service that will be enabled for audit logging. For example,
         * `storage.googleapis.com`, `cloudsql.googleapis.com`. `allServices` is a
         * special value that covers all services.
         */
        service?: string;
    }
    /**
     * Provides the configuration for logging a type of permissions. Example:  {
     * &quot;audit_log_configs&quot;: [ { &quot;log_type&quot;:
     * &quot;DATA_READ&quot;, &quot;exempted_members&quot;: [
     * &quot;user:foo@gmail.com&quot; ] }, { &quot;log_type&quot;:
     * &quot;DATA_WRITE&quot;, } ] }  This enables &#39;DATA_READ&#39; and
     * &#39;DATA_WRITE&#39; logging, while exempting foo@gmail.com from DATA_READ
     * logging.
     */
    interface Schema$AuditLogConfig {
        /**
         * Specifies the identities that do not cause logging for this type of
         * permission. Follows the same format of [Binding.members][].
         */
        exemptedMembers?: string[];
        /**
         * The log type that this config enables.
         */
        logType?: string;
    }
    /**
     * Authorization-related information used by Cloud Audit Logging.
     */
    interface Schema$AuthorizationLoggingOptions {
        /**
         * The type of the permission that was checked.
         */
        permissionType?: string;
    }
    /**
     * Represents an Autoscaler resource. Autoscalers allow you to automatically
     * scale virtual machine instances in managed instance groups according to an
     * autoscaling policy that you define. For more information, read Autoscaling
     * Groups of Instances. (== resource_for beta.autoscalers ==) (== resource_for
     * v1.autoscalers ==) (== resource_for beta.regionAutoscalers ==) (==
     * resource_for v1.regionAutoscalers ==)
     */
    interface Schema$Autoscaler {
        /**
         * The configuration parameters for the autoscaling algorithm. You can
         * define one or more of the policies for an autoscaler: cpuUtilization,
         * customMetricUtilizations, and loadBalancingUtilization.  If none of these
         * are specified, the default will be to autoscale based on cpuUtilization
         * to 0.6 or 60%.
         */
        autoscalingPolicy?: Schema$AutoscalingPolicy;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#autoscaler for
         * autoscalers.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] URL of the region where the instance group resides (for
         * autoscalers living in regional scope).
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The status of the autoscaler configuration.
         */
        status?: string;
        /**
         * [Output Only] Human-readable details about the current state of the
         * autoscaler. Read the documentation for Commonly returned status messages
         * for examples of status messages you might encounter.
         */
        statusDetails?: Schema$AutoscalerStatusDetails[];
        /**
         * URL of the managed instance group that this autoscaler will scale.
         */
        target?: string;
        /**
         * [Output Only] URL of the zone where the instance group resides (for
         * autoscalers living in zonal scope).
         */
        zone?: string;
    }
    interface Schema$AutoscalerAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of AutoscalersScopedList resources.
         */
        items?: {
            [key: string]: Schema$AutoscalersScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#autoscalerAggregatedList
         * for aggregated lists of autoscalers.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of Autoscaler resources.
     */
    interface Schema$AutoscalerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Autoscaler resources.
         */
        items?: Schema$Autoscaler[];
        /**
         * [Output Only] Type of resource. Always compute#autoscalerList for lists
         * of autoscalers.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$AutoscalersScopedList {
        /**
         * [Output Only] A list of autoscalers contained in this scope.
         */
        autoscalers?: Schema$Autoscaler[];
        /**
         * [Output Only] Informational warning which replaces the list of
         * autoscalers when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$AutoscalerStatusDetails {
        /**
         * The status message.
         */
        message?: string;
        /**
         * The type of error returned.
         */
        type?: string;
    }
    /**
     * Cloud Autoscaler policy.
     */
    interface Schema$AutoscalingPolicy {
        /**
         * The number of seconds that the autoscaler should wait before it starts
         * collecting information from a new instance. This prevents the autoscaler
         * from collecting information when the instance is initializing, during
         * which the collected usage would not be reliable. The default time
         * autoscaler waits is 60 seconds.  Virtual machine initialization times
         * might vary because of numerous factors. We recommend that you test how
         * long an instance may take to initialize. To do this, create an instance
         * and time the startup process.
         */
        coolDownPeriodSec?: number;
        /**
         * Defines the CPU utilization policy that allows the autoscaler to scale
         * based on the average CPU utilization of a managed instance group.
         */
        cpuUtilization?: Schema$AutoscalingPolicyCpuUtilization;
        /**
         * Configuration parameters of autoscaling based on a custom metric.
         */
        customMetricUtilizations?: Schema$AutoscalingPolicyCustomMetricUtilization[];
        /**
         * Configuration parameters of autoscaling based on load balancer.
         */
        loadBalancingUtilization?: Schema$AutoscalingPolicyLoadBalancingUtilization;
        /**
         * The maximum number of instances that the autoscaler can scale up to. This
         * is required when creating or updating an autoscaler. The maximum number
         * of replicas should not be lower than minimal number of replicas.
         */
        maxNumReplicas?: number;
        /**
         * The minimum number of replicas that the autoscaler can scale down to.
         * This cannot be less than 0. If not provided, autoscaler will choose a
         * default value depending on maximum number of instances allowed.
         */
        minNumReplicas?: number;
    }
    /**
     * CPU utilization policy.
     */
    interface Schema$AutoscalingPolicyCpuUtilization {
        /**
         * The target CPU utilization that the autoscaler should maintain. Must be a
         * float value in the range (0, 1]. If not specified, the default is 0.6. If
         * the CPU level is below the target utilization, the autoscaler scales down
         * the number of instances until it reaches the minimum number of instances
         * you specified or until the average CPU of your instances reaches the
         * target utilization.  If the average CPU is above the target utilization,
         * the autoscaler scales up until it reaches the maximum number of instances
         * you specified or until the average utilization reaches the target
         * utilization.
         */
        utilizationTarget?: number;
    }
    /**
     * Custom utilization metric policy.
     */
    interface Schema$AutoscalingPolicyCustomMetricUtilization {
        /**
         * The identifier (type) of the Stackdriver Monitoring metric. The metric
         * cannot have negative values.  The metric must have a value type of INT64
         * or DOUBLE.
         */
        metric?: string;
        /**
         * The target value of the metric that autoscaler should maintain. This must
         * be a positive value. A utilization metric scales number of virtual
         * machines handling requests to increase or decrease proportionally to the
         * metric.  For example, a good metric to use as a utilization_target is
         * compute.googleapis.com/instance/network/received_bytes_count. The
         * autoscaler will work to keep this value constant for each of the
         * instances.
         */
        utilizationTarget?: number;
        /**
         * Defines how target utilization value is expressed for a Stackdriver
         * Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.
         */
        utilizationTargetType?: string;
    }
    /**
     * Configuration parameters of autoscaling based on load balancing.
     */
    interface Schema$AutoscalingPolicyLoadBalancingUtilization {
        /**
         * Fraction of backend capacity utilization (set in HTTP(S) load balancing
         * configuration) that autoscaler should maintain. Must be a positive float
         * value. If not defined, the default is 0.8.
         */
        utilizationTarget?: number;
    }
    /**
     * Message containing information of one individual backend.
     */
    interface Schema$Backend {
        /**
         * Specifies the balancing mode for this backend. For global HTTP(S) or
         * TCP/SSL load balancing, the default is UTILIZATION. Valid values are
         * UTILIZATION, RATE (for HTTP(S)) and CONNECTION (for TCP/SSL).  For
         * Internal Load Balancing, the default and only supported mode is
         * CONNECTION.
         */
        balancingMode?: string;
        /**
         * A multiplier applied to the group&#39;s maximum servicing capacity (based
         * on UTILIZATION, RATE or CONNECTION). Default value is 1, which means the
         * group will serve up to 100% of its configured capacity (depending on
         * balancingMode). A setting of 0 means the group is completely drained,
         * offering 0% of its available Capacity. Valid range is [0.0,1.0].  This
         * cannot be used for internal load balancing.
         */
        capacityScaler?: number;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * The fully-qualified URL of an Instance Group or Network Endpoint Group
         * resource. In case of instance group this defines the list of instances
         * that serve traffic. Member virtual machine instances from each instance
         * group must live in the same zone as the instance group itself. No two
         * backends in a backend service are allowed to use same Instance Group
         * resource.  For Network Endpoint Groups this defines list of endpoints.
         * All endpoints of Network Endpoint Group must be hosted on instances
         * located in the same zone as the Network Endpoint Group.  Backend service
         * can not contain mix of Instance Group and Network Endpoint Group
         * backends.  Note that you must specify an Instance Group or Network
         * Endpoint Group resource using the fully-qualified URL, rather than a
         * partial URL.  When the BackendService has load balancing scheme INTERNAL,
         * the instance group must be within the same region as the BackendService.
         * Network Endpoint Groups are not supported for INTERNAL load balancing
         * scheme.
         */
        group?: string;
        /**
         * The max number of simultaneous connections for the group. Can be used
         * with either CONNECTION or UTILIZATION balancing modes. For CONNECTION
         * mode, either maxConnections or maxConnectionsPerInstance must be set.
         * This cannot be used for internal load balancing.
         */
        maxConnections?: number;
        /**
         * The max number of simultaneous connections that a single backend network
         * endpoint can handle. This is used to calculate the capacity of the group.
         * Can be used in either CONNECTION or UTILIZATION balancing modes. For
         * CONNECTION mode, either maxConnections or maxConnectionsPerEndpoint must
         * be set.  This cannot be used for internal load balancing.
         */
        maxConnectionsPerEndpoint?: number;
        /**
         * The max number of simultaneous connections that a single backend instance
         * can handle. This is used to calculate the capacity of the group. Can be
         * used in either CONNECTION or UTILIZATION balancing modes. For CONNECTION
         * mode, either maxConnections or maxConnectionsPerInstance must be set.
         * This cannot be used for internal load balancing.
         */
        maxConnectionsPerInstance?: number;
        /**
         * The max requests per second (RPS) of the group. Can be used with either
         * RATE or UTILIZATION balancing modes, but required if RATE mode. For RATE
         * mode, either maxRate or maxRatePerInstance must be set.  This cannot be
         * used for internal load balancing.
         */
        maxRate?: number;
        /**
         * The max requests per second (RPS) that a single backend network endpoint
         * can handle. This is used to calculate the capacity of the group. Can be
         * used in either balancing mode. For RATE mode, either maxRate or
         * maxRatePerEndpoint must be set.  This cannot be used for internal load
         * balancing.
         */
        maxRatePerEndpoint?: number;
        /**
         * The max requests per second (RPS) that a single backend instance can
         * handle. This is used to calculate the capacity of the group. Can be used
         * in either balancing mode. For RATE mode, either maxRate or
         * maxRatePerInstance must be set.  This cannot be used for internal load
         * balancing.
         */
        maxRatePerInstance?: number;
        /**
         * Used when balancingMode is UTILIZATION. This ratio defines the CPU
         * utilization target for the group. The default is 0.8. Valid range is
         * [0.0, 1.0].  This cannot be used for internal load balancing.
         */
        maxUtilization?: number;
    }
    /**
     * A BackendBucket resource. This resource defines a Cloud Storage bucket.
     */
    interface Schema$BackendBucket {
        /**
         * Cloud Storage bucket name.
         */
        bucketName?: string;
        /**
         * Cloud CDN configuration for this BackendBucket.
         */
        cdnPolicy?: Schema$BackendBucketCdnPolicy;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional textual description of the resource; provided by the client
         * when the resource is created.
         */
        description?: string;
        /**
         * If true, enable Cloud CDN for this BackendBucket.
         */
        enableCdn?: boolean;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * Type of the resource.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
    }
    /**
     * Message containing Cloud CDN configuration for a backend bucket.
     */
    interface Schema$BackendBucketCdnPolicy {
        /**
         * Maximum number of seconds the response to a signed URL request will be
         * considered fresh. After this time period, the response will be
         * revalidated before being served. Defaults to 1hr (3600s). When serving
         * responses to signed URL requests, Cloud CDN will internally behave as
         * though all responses from this backend had a &quot;Cache-Control: public,
         * max-age=[TTL]&quot; header, regardless of any existing Cache-Control
         * header. The actual headers served in responses will not be altered.
         */
        signedUrlCacheMaxAgeSec?: string;
        /**
         * [Output Only] Names of the keys for signing request URLs.
         */
        signedUrlKeyNames?: string[];
    }
    /**
     * Contains a list of BackendBucket resources.
     */
    interface Schema$BackendBucketList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of BackendBucket resources.
         */
        items?: Schema$BackendBucket[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A BackendService resource. This resource defines a group of backend virtual
     * machines and their serving capacity. (== resource_for v1.backendService ==)
     * (== resource_for beta.backendService ==)
     */
    interface Schema$BackendService {
        /**
         * Lifetime of cookies in seconds if session_affinity is GENERATED_COOKIE.
         * If set to 0, the cookie is non-persistent and lasts only until the end of
         * the browser session (or equivalent). The maximum allowed value for TTL is
         * one day.  When the load balancing scheme is INTERNAL, this field is not
         * used.
         */
        affinityCookieTtlSec?: number;
        /**
         * The list of backends that serve this BackendService.
         */
        backends?: Schema$Backend[];
        /**
         * Cloud CDN configuration for this BackendService.
         */
        cdnPolicy?: Schema$BackendServiceCdnPolicy;
        connectionDraining?: Schema$ConnectionDraining;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * Headers that the HTTP/S load balancer should add to proxied requests.
         */
        customRequestHeaders?: string[];
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * If true, enable Cloud CDN for this BackendService.  When the load
         * balancing scheme is INTERNAL, this field is not used.
         */
        enableCDN?: boolean;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this
         * object. This field is used in optimistic locking. This field will be
         * ignored when inserting a BackendService. An up-to-date fingerprint must
         * be provided in order to update the BackendService, otherwise the request
         * will fail with error 412 conditionNotMet.  To see the latest fingerprint,
         * make a get() request to retrieve a BackendService.
         */
        fingerprint?: string;
        /**
         * The list of URLs to the HttpHealthCheck or HttpsHealthCheck resource for
         * health checking this BackendService. Currently at most one health check
         * can be specified, and a health check is required for Compute Engine
         * backend services. A health check must not be specified for App Engine
         * backend and Cloud Function backend.  For internal load balancing, a URL
         * to a HealthCheck resource must be specified instead.
         */
        healthChecks?: string[];
        iap?: Schema$BackendServiceIAP;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#backendService for backend
         * services.
         */
        kind?: string;
        /**
         * Indicates whether the backend service will be used with internal or
         * external load balancing. A backend service created for one type of load
         * balancing cannot be used with the other. Possible values are INTERNAL and
         * EXTERNAL.
         */
        loadBalancingScheme?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Deprecated in favor of portName. The TCP port to connect on the backend.
         * The default value is 80.  This cannot be used for internal load
         * balancing.
         */
        port?: number;
        /**
         * Name of backend port. The same name should appear in the instance groups
         * referenced by this service. Required when the load balancing scheme is
         * EXTERNAL.  When the load balancing scheme is INTERNAL, this field is not
         * used.
         */
        portName?: string;
        /**
         * The protocol this BackendService uses to communicate with backends.
         * Possible values are HTTP, HTTPS, TCP, and SSL. The default is HTTP.  For
         * internal load balancing, the possible values are TCP and UDP, and the
         * default is TCP.
         */
        protocol?: string;
        /**
         * [Output Only] URL of the region where the regional backend service
         * resides. This field is not applicable to global backend services. You
         * must specify this field as part of the HTTP request URL. It is not
         * settable as a field in the request body.
         */
        region?: string;
        /**
         * [Output Only] The resource URL for the security policy associated with
         * this backend service.
         */
        securityPolicy?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * Type of session affinity to use. The default is NONE.  When the load
         * balancing scheme is EXTERNAL, can be NONE, CLIENT_IP, or
         * GENERATED_COOKIE.  When the load balancing scheme is INTERNAL, can be
         * NONE, CLIENT_IP, CLIENT_IP_PROTO, or CLIENT_IP_PORT_PROTO.  When the
         * protocol is UDP, this field is not used.
         */
        sessionAffinity?: string;
        /**
         * How many seconds to wait for the backend before considering it a failed
         * request. Default is 30 seconds.
         */
        timeoutSec?: number;
    }
    /**
     * Contains a list of BackendServicesScopedList.
     */
    interface Schema$BackendServiceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of BackendServicesScopedList resources.
         */
        items?: {
            [key: string]: Schema$BackendServicesScopedList;
        };
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Message containing Cloud CDN configuration for a backend service.
     */
    interface Schema$BackendServiceCdnPolicy {
        /**
         * The CacheKeyPolicy for this CdnPolicy.
         */
        cacheKeyPolicy?: Schema$CacheKeyPolicy;
        /**
         * Maximum number of seconds the response to a signed URL request will be
         * considered fresh. After this time period, the response will be
         * revalidated before being served. Defaults to 1hr (3600s). When serving
         * responses to signed URL requests, Cloud CDN will internally behave as
         * though all responses from this backend had a &quot;Cache-Control: public,
         * max-age=[TTL]&quot; header, regardless of any existing Cache-Control
         * header. The actual headers served in responses will not be altered.
         */
        signedUrlCacheMaxAgeSec?: string;
        /**
         * [Output Only] Names of the keys for signing request URLs.
         */
        signedUrlKeyNames?: string[];
    }
    interface Schema$BackendServiceGroupHealth {
        /**
         * Health state of the backend instances or endpoints in requested instance
         * or network endpoint group, determined based on configured health checks.
         */
        healthStatus?: Schema$HealthStatus[];
        /**
         * [Output Only] Type of resource. Always compute#backendServiceGroupHealth
         * for the health of backend services.
         */
        kind?: string;
    }
    /**
     * Identity-Aware Proxy
     */
    interface Schema$BackendServiceIAP {
        enabled?: boolean;
        oauth2ClientId?: string;
        oauth2ClientSecret?: string;
        /**
         * [Output Only] SHA256 hash value for the field oauth2_client_secret above.
         */
        oauth2ClientSecretSha256?: string;
    }
    /**
     * Contains a list of BackendService resources.
     */
    interface Schema$BackendServiceList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of BackendService resources.
         */
        items?: Schema$BackendService[];
        /**
         * [Output Only] Type of resource. Always compute#backendServiceList for
         * lists of backend services.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$BackendServiceReference {
        backendService?: string;
    }
    interface Schema$BackendServicesScopedList {
        /**
         * A list of BackendServices contained in this scope.
         */
        backendServices?: Schema$BackendService[];
        /**
         * Informational warning which replaces the list of backend services when
         * the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Associates `members` with a `role`.
     */
    interface Schema$Binding {
        /**
         * The condition that is associated with this binding. NOTE: an unsatisfied
         * condition will not allow user access via current binding. Different
         * bindings, including their conditions, are examined independently.
         */
        condition?: Schema$Expr;
        /**
         * Specifies the identities requesting access for a Cloud Platform resource.
         * `members` can have the following values:  * `allUsers`: A special
         * identifier that represents anyone who is on the internet; with or without
         * a Google account.  * `allAuthenticatedUsers`: A special identifier that
         * represents anyone who is authenticated with a Google account or a service
         * account.  * `user:{emailid}`: An email address that represents a specific
         * Google account. For example, `alice@gmail.com` .    *
         * `serviceAccount:{emailid}`: An email address that represents a service
         * account. For example, `my-other-app@appspot.gserviceaccount.com`.  *
         * `group:{emailid}`: An email address that represents a Google group. For
         * example, `admins@example.com`.    * `domain:{domain}`: The G Suite domain
         * (primary) that represents all the users of that domain. For example,
         * `google.com` or `example.com`.
         */
        members?: string[];
        /**
         * Role that is assigned to `members`. For example, `roles/viewer`,
         * `roles/editor`, or `roles/owner`.
         */
        role?: string;
    }
    interface Schema$CacheInvalidationRule {
        /**
         * If set, this invalidation rule will only apply to requests with a Host
         * header matching host.
         */
        host?: string;
        path?: string;
    }
    /**
     * Message containing what to include in the cache key for a request for Cloud
     * CDN.
     */
    interface Schema$CacheKeyPolicy {
        /**
         * If true, requests to different hosts will be cached separately.
         */
        includeHost?: boolean;
        /**
         * If true, http and https requests will be cached separately.
         */
        includeProtocol?: boolean;
        /**
         * If true, include query string parameters in the cache key according to
         * query_string_whitelist and query_string_blacklist. If neither is set, the
         * entire query string will be included. If false, the query string will be
         * excluded from the cache key entirely.
         */
        includeQueryString?: boolean;
        /**
         * Names of query string parameters to exclude in cache keys. All other
         * parameters will be included. Either specify query_string_whitelist or
         * query_string_blacklist, not both. &#39;&amp;&#39; and &#39;=&#39; will be
         * percent encoded and not treated as delimiters.
         */
        queryStringBlacklist?: string[];
        /**
         * Names of query string parameters to include in cache keys. All other
         * parameters will be excluded. Either specify query_string_whitelist or
         * query_string_blacklist, not both. &#39;&amp;&#39; and &#39;=&#39; will be
         * percent encoded and not treated as delimiters.
         */
        queryStringWhitelist?: string[];
    }
    /**
     * Represents a Commitment resource. Creating a Commitment resource means that
     * you are purchasing a committed use contract with an explicit start and end
     * time. You can create commitments based on vCPUs and memory usage and
     * receive discounted rates. For full details, read Signing Up for Committed
     * Use Discounts.  Committed use discounts are subject to Google Cloud
     * Platform&#39;s Service Specific Terms. By purchasing a committed use
     * discount, you agree to these terms. Committed use discounts will not renew,
     * so you must purchase a new commitment to continue receiving discounts. (==
     * resource_for beta.commitments ==) (== resource_for v1.commitments ==)
     */
    interface Schema$Commitment {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] Commitment end time in RFC3339 text format.
         */
        endTimestamp?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#commitment for
         * commitments.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The plan for this commitment, which determines duration and discount
         * rate. The currently supported plans are TWELVE_MONTH (1 year), and
         * THIRTY_SIX_MONTH (3 years).
         */
        plan?: string;
        /**
         * [Output Only] URL of the region where this commitment may be used.
         */
        region?: string;
        /**
         * A list of commitment amounts for particular resources. Note that VCPU and
         * MEMORY resource commitments must occur together.
         */
        resources?: Schema$ResourceCommitment[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Commitment start time in RFC3339 text format.
         */
        startTimestamp?: string;
        /**
         * [Output Only] Status of the commitment with regards to eventual
         * expiration (each commitment has an end date defined). One of the
         * following values: NOT_YET_ACTIVE, ACTIVE, EXPIRED.
         */
        status?: string;
        /**
         * [Output Only] An optional, human-readable explanation of the status.
         */
        statusMessage?: string;
    }
    interface Schema$CommitmentAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of CommitmentsScopedList resources.
         */
        items?: {
            [key: string]: Schema$CommitmentsScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#commitmentAggregatedList
         * for aggregated lists of commitments.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of Commitment resources.
     */
    interface Schema$CommitmentList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Commitment resources.
         */
        items?: Schema$Commitment[];
        /**
         * [Output Only] Type of resource. Always compute#commitmentList for lists
         * of commitments.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$CommitmentsScopedList {
        /**
         * [Output Only] A list of commitments contained in this scope.
         */
        commitments?: Schema$Commitment[];
        /**
         * [Output Only] Informational warning which replaces the list of
         * commitments when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A condition to be met.
     */
    interface Schema$Condition {
        /**
         * Trusted attributes supplied by the IAM system.
         */
        iam?: string;
        /**
         * An operator to apply the subject with.
         */
        op?: string;
        /**
         * Trusted attributes discharged by the service.
         */
        svc?: string;
        /**
         * Trusted attributes supplied by any service that owns resources and uses
         * the IAM system for access control.
         */
        sys?: string;
        /**
         * The objects of the condition.
         */
        values?: string[];
    }
    /**
     * Message containing connection draining configuration.
     */
    interface Schema$ConnectionDraining {
        /**
         * Time for which instance will be drained (not accept new connections, but
         * still work to finish started).
         */
        drainingTimeoutSec?: number;
    }
    /**
     * Represents a customer-supplied encryption key
     */
    interface Schema$CustomerEncryptionKey {
        /**
         * The name of the encryption key that is stored in Google Cloud KMS.
         */
        kmsKeyName?: string;
        /**
         * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648
         * base64 to either encrypt or decrypt this resource.
         */
        rawKey?: string;
        /**
         * [Output only] The RFC 4648 base64 encoded SHA-256 hash of the
         * customer-supplied encryption key that protects this resource.
         */
        sha256?: string;
    }
    interface Schema$CustomerEncryptionKeyProtectedDisk {
        /**
         * Decrypts data associated with the disk with a customer-supplied
         * encryption key.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * Specifies a valid partial or full URL to an existing Persistent Disk
         * resource. This field is only applicable for persistent disks.
         */
        source?: string;
    }
    /**
     * Deprecation status for a public resource.
     */
    interface Schema$DeprecationStatus {
        /**
         * An optional RFC3339 timestamp on or after which the state of this
         * resource is intended to change to DELETED. This is only informational and
         * the status will not change unless the client explicitly changes it.
         */
        deleted?: string;
        /**
         * An optional RFC3339 timestamp on or after which the state of this
         * resource is intended to change to DEPRECATED. This is only informational
         * and the status will not change unless the client explicitly changes it.
         */
        deprecated?: string;
        /**
         * An optional RFC3339 timestamp on or after which the state of this
         * resource is intended to change to OBSOLETE. This is only informational
         * and the status will not change unless the client explicitly changes it.
         */
        obsolete?: string;
        /**
         * The URL of the suggested replacement for a deprecated resource. The
         * suggested replacement resource must be the same kind of resource as the
         * deprecated resource.
         */
        replacement?: string;
        /**
         * The deprecation state of this resource. This can be ACTIVE, DEPRECATED,
         * OBSOLETE, or DELETED. Operations which communicate the end of life date
         * for an image, can use ACTIVE. Operations which create a new resource
         * using a DEPRECATED resource will return successfully, but with a warning
         * indicating the deprecated resource and recommending its replacement.
         * Operations which use OBSOLETE or DELETED resources will be rejected and
         * result in an error.
         */
        state?: string;
    }
    /**
     * A Disk resource. (== resource_for beta.disks ==) (== resource_for v1.disks
     * ==)
     */
    interface Schema$Disk {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * Encrypts the disk using a customer-supplied encryption key.  After you
         * encrypt a disk with a customer-supplied key, you must provide the same
         * key if you use the disk later (e.g. to create a disk snapshot or an
         * image, or to attach the disk to a virtual machine).  Customer-supplied
         * encryption keys do not protect access to metadata of the disk.  If you do
         * not provide an encryption key when creating the disk, then the disk will
         * be encrypted using an automatically generated key and you do not need to
         * provide a key to use the disk later.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * A list of features to enable on the guest operating system. Applicable
         * only for bootable images. Read  Enabling guest operating system features
         * to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#disk for disks.
         */
        kind?: string;
        /**
         * A fingerprint for the labels being applied to this disk, which is
         * essentially a hash of the labels set used for optimistic locking. The
         * fingerprint is initially generated by Compute Engine and changes after
         * every request to modify or update labels. You must always provide an
         * up-to-date fingerprint hash in order to update or change labels,
         * otherwise the request will fail with error 412 conditionNotMet.  To see
         * the latest fingerprint, make a get() request to retrieve a disk.
         */
        labelFingerprint?: string;
        /**
         * Labels to apply to this disk. These can be later modified by the
         * setLabels method.
         */
        labels?: {
            [key: string]: string;
        };
        /**
         * [Output Only] Last attach timestamp in RFC3339 text format.
         */
        lastAttachTimestamp?: string;
        /**
         * [Output Only] Last detach timestamp in RFC3339 text format.
         */
        lastDetachTimestamp?: string;
        /**
         * Integer license codes indicating which licenses are attached to this
         * disk.
         */
        licenseCodes?: string[];
        /**
         * A list of publicly visible licenses. Reserved for Google&#39;s use.
         */
        licenses?: string[];
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Internal use only.
         */
        options?: string;
        /**
         * Physical block size of the persistent disk, in bytes. If not present in a
         * request, a default value is used. Currently supported sizes are 4096 and
         * 16384, other sizes may be added in the future. If an unsupported value is
         * requested, the error message will list the supported values for the
         * caller&#39;s project.
         */
        physicalBlockSizeBytes?: string;
        /**
         * [Output Only] URL of the region where the disk resides. Only applicable
         * for regional resources. You must specify this field as part of the HTTP
         * request URL. It is not settable as a field in the request body.
         */
        region?: string;
        /**
         * URLs of the zones where the disk should be replicated to. Only applicable
         * for regional resources.
         */
        replicaZones?: string[];
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string;
        /**
         * Size of the persistent disk, specified in GB. You can specify this field
         * when creating a persistent disk using the sourceImage or sourceSnapshot
         * parameter, or specify it alone to create an empty persistent disk.  If
         * you specify this field along with sourceImage or sourceSnapshot, the
         * value of sizeGb must not be less than the size of the sourceImage or the
         * size of the snapshot. Acceptable values are 1 to 65536, inclusive.
         */
        sizeGb?: string;
        /**
         * The source image used to create this disk. If the source image is
         * deleted, this field will not be set.  To create a disk with one of the
         * public operating system images, specify the image by its family name. For
         * example, specify family/debian-9 to use the latest Debian 9 image:
         * projects/debian-cloud/global/images/family/debian-9   Alternatively, use
         * a specific version of a public operating system image:
         * projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD   To
         * create a disk with a custom image that you created, specify the image
         * name in the following format: global/images/my-custom-image   You can
         * also specify a custom image by its image family, which returns the latest
         * version of the image in that family. Replace the image name with
         * family/family-name: global/images/family/my-image-family
         */
        sourceImage?: string;
        /**
         * The customer-supplied encryption key of the source image. Required if the
         * source image is protected by a customer-supplied encryption key.
         */
        sourceImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the image used to create this disk. This
         * value identifies the exact image that was used to create this persistent
         * disk. For example, if you created the persistent disk from an image that
         * was later deleted and recreated under the same name, the source image ID
         * would identify the exact version of the image that was used.
         */
        sourceImageId?: string;
        /**
         * The source snapshot used to create this disk. You can provide this as a
         * partial or full URL to the resource. For example, the following are valid
         * values:   -
         * https://www.googleapis.com/compute/v1/projects/project/global/snapshots/snapshot
         * - projects/project/global/snapshots/snapshot  - global/snapshots/snapshot
         */
        sourceSnapshot?: string;
        /**
         * The customer-supplied encryption key of the source snapshot. Required if
         * the source snapshot is protected by a customer-supplied encryption key.
         */
        sourceSnapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The unique ID of the snapshot used to create this disk.
         * This value identifies the exact snapshot that was used to create this
         * persistent disk. For example, if you created the persistent disk from a
         * snapshot that was later deleted and recreated under the same name, the
         * source snapshot ID would identify the exact version of the snapshot that
         * was used.
         */
        sourceSnapshotId?: string;
        /**
         * [Output Only] The status of disk creation.
         */
        status?: string;
        /**
         * URL of the disk type resource describing which disk type to use to create
         * the disk. Provide this when creating the disk. For example:
         * project/zones/zone/diskTypes/pd-standard or pd-ssd
         */
        type?: string;
        /**
         * [Output Only] Links to the users of the disk (attached instances) in
         * form: project/zones/zone/instances/instance
         */
        users?: string[];
        /**
         * [Output Only] URL of the zone where the disk resides. You must specify
         * this field as part of the HTTP request URL. It is not settable as a field
         * in the request body.
         */
        zone?: string;
    }
    interface Schema$DiskAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of DisksScopedList resources.
         */
        items?: {
            [key: string]: Schema$DisksScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#diskAggregatedList for
         * aggregated lists of persistent disks.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A specification of the desired way to instantiate a disk in the instance
     * template when its created from a source instance.
     */
    interface Schema$DiskInstantiationConfig {
        /**
         * Specifies whether the disk will be auto-deleted when the instance is
         * deleted (but not when the disk is detached from the instance).
         */
        autoDelete?: boolean;
        /**
         * The custom source image to be used to restore this disk when
         * instantiating this instance template.
         */
        customImage?: string;
        /**
         * Specifies the device name of the disk to which the configurations apply
         * to.
         */
        deviceName?: string;
        /**
         * Specifies whether to include the disk and what image to use. Possible
         * values are:   - source-image: to use the same image that was used to
         * create the source instance&#39;s corresponding disk. Applicable to the
         * boot disk and additional read-write disks.  - source-image-family: to use
         * the same image family that was used to create the source instance&#39;s
         * corresponding disk. Applicable to the boot disk and additional read-write
         * disks.  - custom-image: to use a user-provided image url for disk
         * creation. Applicable to the boot disk and additional read-write disks.  -
         * attach-read-only: to attach a read-only disk. Applicable to read-only
         * disks.  - do-not-include: to exclude a disk from the template. Applicable
         * to additional read-write disks, local SSDs, and read-only disks.
         */
        instantiateFrom?: string;
    }
    /**
     * A list of Disk resources.
     */
    interface Schema$DiskList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Disk resources.
         */
        items?: Schema$Disk[];
        /**
         * [Output Only] Type of resource. Always compute#diskList for lists of
         * disks.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$DiskMoveRequest {
        /**
         * The URL of the destination zone to move the disk. This can be a full or
         * partial URL. For example, the following are all valid URLs to a zone:   -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone  -
         * projects/project/zones/zone  - zones/zone
         */
        destinationZone?: string;
        /**
         * The URL of the target disk to move. This can be a full or partial URL.
         * For example, the following are all valid URLs to a disk:   -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
         * - projects/project/zones/zone/disks/disk  - zones/zone/disks/disk
         */
        targetDisk?: string;
    }
    interface Schema$DisksResizeRequest {
        /**
         * The new size of the persistent disk, which is specified in GB.
         */
        sizeGb?: string;
    }
    interface Schema$DisksScopedList {
        /**
         * [Output Only] A list of disks contained in this scope.
         */
        disks?: Schema$Disk[];
        /**
         * [Output Only] Informational warning which replaces the list of disks when
         * the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A DiskType resource. (== resource_for beta.diskTypes ==) (== resource_for
     * v1.diskTypes ==)
     */
    interface Schema$DiskType {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] Server-defined default disk size in GB.
         */
        defaultDiskSizeGb?: string;
        /**
         * [Output Only] The deprecation status associated with this disk type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional description of this resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#diskType for disk
         * types.
         */
        kind?: string;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] URL of the region where the disk type resides. Only
         * applicable for regional resources. You must specify this field as part of
         * the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] An optional textual description of the valid disk size,
         * such as &quot;10GB-10TB&quot;.
         */
        validDiskSize?: string;
        /**
         * [Output Only] URL of the zone where the disk type resides. You must
         * specify this field as part of the HTTP request URL. It is not settable as
         * a field in the request body.
         */
        zone?: string;
    }
    interface Schema$DiskTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of DiskTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$DiskTypesScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#diskTypeAggregatedList.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of disk types.
     */
    interface Schema$DiskTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of DiskType resources.
         */
        items?: Schema$DiskType[];
        /**
         * [Output Only] Type of resource. Always compute#diskTypeList for disk
         * types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$DiskTypesScopedList {
        /**
         * [Output Only] A list of disk types contained in this scope.
         */
        diskTypes?: Schema$DiskType[];
        /**
         * [Output Only] Informational warning which replaces the list of disk types
         * when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$DistributionPolicy {
        /**
         * Zones where the regional managed instance group will create and manage
         * instances.
         */
        zones?: Schema$DistributionPolicyZoneConfiguration[];
    }
    interface Schema$DistributionPolicyZoneConfiguration {
        /**
         * The URL of the zone. The zone must exist in the region where the managed
         * instance group is located.
         */
        zone?: string;
    }
    /**
     * Represents an expression text. Example:  title: &quot;User account
     * presence&quot; description: &quot;Determines whether the request has a user
     * account&quot; expression: &quot;size(request.user) &gt; 0&quot;
     */
    interface Schema$Expr {
        /**
         * An optional description of the expression. This is a longer text which
         * describes the expression, e.g. when hovered over it in a UI.
         */
        description?: string;
        /**
         * Textual representation of an expression in Common Expression Language
         * syntax.  The application context of the containing message determines
         * which well-known feature set of CEL is supported.
         */
        expression?: string;
        /**
         * An optional string indicating the location of the expression for error
         * reporting, e.g. a file name and a position in the file.
         */
        location?: string;
        /**
         * An optional title for the expression, i.e. a short string describing its
         * purpose. This can be used e.g. in UIs which allow to enter the
         * expression.
         */
        title?: string;
    }
    /**
     * Represents a Firewall resource.
     */
    interface Schema$Firewall {
        /**
         * The list of ALLOW rules specified by this firewall. Each rule specifies a
         * protocol and port-range tuple that describes a permitted connection.
         */
        allowed?: Array<{
            IPProtocol?: string;
            ports?: string[];
        }>;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * The list of DENY rules specified by this firewall. Each rule specifies a
         * protocol and port-range tuple that describes a denied connection.
         */
        denied?: Array<{
            IPProtocol?: string;
            ports?: string[];
        }>;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * If destination ranges are specified, the firewall will apply only to
         * traffic that has destination IP address in these ranges. These ranges
         * must be expressed in CIDR format. Only IPv4 is supported.
         */
        destinationRanges?: string[];
        /**
         * Direction of traffic to which this firewall applies; default is INGRESS.
         * Note: For INGRESS traffic, it is NOT supported to specify
         * destinationRanges; For EGRESS traffic, it is NOT supported to specify
         * sourceRanges OR sourceTags.
         */
        direction?: string;
        /**
         * Denotes whether the firewall rule is disabled, i.e not applied to the
         * network it is associated with. When set to true, the firewall rule is not
         * enforced and the network behaves as if it did not exist. If this is
         * unspecified, the firewall rule will be enabled.
         */
        disabled?: boolean;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#firewall for firewall
         * rules.
         */
        kind?: string;
        /**
         * This field denotes the logging options for a particular firewall rule. If
         * logging is enabled, logs will be exported to Stackdriver.
         */
        logConfig?: Schema$FirewallLogConfig;
        /**
         * Name of the resource; provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * URL of the network resource for this firewall rule. If not specified when
         * creating a firewall rule, the default network is used:
         * global/networks/default If you choose to specify this property, you can
         * specify the network as a full or partial URL. For example, the following
         * are all valid URLs:   -
         * https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my-network
         * - projects/myproject/global/networks/my-network  -
         * global/networks/default
         */
        network?: string;
        /**
         * Priority for this rule. This is an integer between 0 and 65535, both
         * inclusive. When not specified, the value assumed is 1000. Relative
         * priorities determine precedence of conflicting rules. Lower value of
         * priority implies higher precedence (eg, a rule with priority 0 has higher
         * precedence than a rule with priority 1). DENY rules take precedence over
         * ALLOW rules having equal priority.
         */
        priority?: number;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * If source ranges are specified, the firewall will apply only to traffic
         * that has source IP address in these ranges. These ranges must be
         * expressed in CIDR format. One or both of sourceRanges and sourceTags may
         * be set. If both properties are set, the firewall will apply to traffic
         * that has source IP address within sourceRanges OR the source IP that
         * belongs to a tag listed in the sourceTags property. The connection does
         * not need to match both properties for the firewall to apply. Only IPv4 is
         * supported.
         */
        sourceRanges?: string[];
        /**
         * If source service accounts are specified, the firewall will apply only to
         * traffic originating from an instance with a service account in this list.
         * Source service accounts cannot be used to control traffic to an
         * instance&#39;s external IP address because service accounts are
         * associated with an instance, not an IP address. sourceRanges can be set
         * at the same time as sourceServiceAccounts. If both are set, the firewall
         * will apply to traffic that has source IP address within sourceRanges OR
         * the source IP belongs to an instance with service account listed in
         * sourceServiceAccount. The connection does not need to match both
         * properties for the firewall to apply. sourceServiceAccounts cannot be
         * used at the same time as sourceTags or targetTags.
         */
        sourceServiceAccounts?: string[];
        /**
         * If source tags are specified, the firewall rule applies only to traffic
         * with source IPs that match the primary network interfaces of VM instances
         * that have the tag and are in the same VPC network. Source tags cannot be
         * used to control traffic to an instance&#39;s external IP address, it only
         * applies to traffic between instances in the same virtual network. Because
         * tags are associated with instances, not IP addresses. One or both of
         * sourceRanges and sourceTags may be set. If both properties are set, the
         * firewall will apply to traffic that has source IP address within
         * sourceRanges OR the source IP that belongs to a tag listed in the
         * sourceTags property. The connection does not need to match both
         * properties for the firewall to apply.
         */
        sourceTags?: string[];
        /**
         * A list of service accounts indicating sets of instances located in the
         * network that may make network connections as specified in allowed[].
         * targetServiceAccounts cannot be used at the same time as targetTags or
         * sourceTags. If neither targetServiceAccounts nor targetTags are
         * specified, the firewall rule applies to all instances on the specified
         * network.
         */
        targetServiceAccounts?: string[];
        /**
         * A list of tags that controls which instances the firewall rule applies
         * to. If targetTags are specified, then the firewall rule applies only to
         * instances in the VPC network that have one of those tags. If no
         * targetTags are specified, the firewall rule applies to all instances on
         * the specified network.
         */
        targetTags?: string[];
    }
    /**
     * Contains a list of firewalls.
     */
    interface Schema$FirewallList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Firewall resources.
         */
        items?: Schema$Firewall[];
        /**
         * [Output Only] Type of resource. Always compute#firewallList for lists of
         * firewalls.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * The available logging options for a firewall rule.
     */
    interface Schema$FirewallLogConfig {
        /**
         * This field denotes whether to enable logging for a particular firewall
         * rule.
         */
        enable?: boolean;
    }
    /**
     * Encapsulates numeric value that can be either absolute or relative.
     */
    interface Schema$FixedOrPercent {
        /**
         * [Output Only] Absolute value of VM instances calculated based on the
         * specific mode.    - If the value is fixed, then the caculated value is
         * equal to the fixed value.  - If the value is a percent, then the
         * calculated value is percent/100 * targetSize. For example, the calculated
         * value of a 80% of a managed instance group with 150 instances would be
         * (80/100 * 150) = 120 VM instances. If there is a remainder, the number is
         * rounded up.
         */
        calculated?: number;
        /**
         * Specifies a fixed number of VM instances. This must be a positive
         * integer.
         */
        fixed?: number;
        /**
         * Specifies a percentage of instances between 0 to 100%, inclusive. For
         * example, specify 80 for 80%.
         */
        percent?: number;
    }
    /**
     * A ForwardingRule resource. A ForwardingRule resource specifies which pool
     * of target virtual machines to forward a packet to if it matches the given
     * [IPAddress, IPProtocol, ports] tuple. (== resource_for beta.forwardingRules
     * ==) (== resource_for v1.forwardingRules ==) (== resource_for
     * beta.globalForwardingRules ==) (== resource_for v1.globalForwardingRules
     * ==) (== resource_for beta.regionForwardingRules ==) (== resource_for
     * v1.regionForwardingRules ==)
     */
    interface Schema$ForwardingRule {
        /**
         * This field is used along with the backend_service field for internal load
         * balancing or with the target field for internal TargetInstance. This
         * field cannot be used with port or portRange fields.  When the load
         * balancing scheme is INTERNAL and protocol is TCP/UDP, specify this field
         * to allow packets addressed to any ports will be forwarded to the backends
         * configured with this forwarding rule.
         */
        allPorts?: boolean;
        /**
         * This field is only used for INTERNAL load balancing.  For internal load
         * balancing, this field identifies the BackendService resource to receive
         * the matched traffic.
         */
        backendService?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * The IP address that this forwarding rule is serving on behalf of.
         * Addresses are restricted based on the forwarding rule&#39;s load
         * balancing scheme (EXTERNAL or INTERNAL) and scope (global or regional).
         * When the load balancing scheme is EXTERNAL, for global forwarding rules,
         * the address must be a global IP, and for regional forwarding rules, the
         * address must live in the same region as the forwarding rule. If this
         * field is empty, an ephemeral IPv4 address from the same scope (global or
         * regional) will be assigned. A regional forwarding rule supports IPv4
         * only. A global forwarding rule supports either IPv4 or IPv6.  When the
         * load balancing scheme is INTERNAL_SELF_MANAGED, this must be a URL
         * reference to an existing Address resource ( internal regional static IP
         * address), with a purpose of GCE_END_POINT and address_type of INTERNAL.
         * When the load balancing scheme is INTERNAL, this can only be an RFC 1918
         * IP address belonging to the network/subnet configured for the forwarding
         * rule. By default, if this field is empty, an ephemeral internal IP
         * address will be automatically allocated from the IP range of the subnet
         * or network configured for this forwarding rule.  An address can be
         * specified either by a literal IP address or a URL reference to an
         * existing Address resource. The following examples are all valid:   -
         * 100.1.2.3  -
         * https://www.googleapis.com/compute/v1/projects/project/regions/region/addresses/address
         * - projects/project/regions/region/addresses/address  -
         * regions/region/addresses/address  - global/addresses/address  - address
         */
        IPAddress?: string;
        /**
         * The IP protocol to which this rule applies. Valid options are TCP, UDP,
         * ESP, AH, SCTP or ICMP.  When the load balancing scheme is INTERNAL, only
         * TCP and UDP are valid. When the load balancing scheme is
         * INTERNAL_SELF_MANAGED, only TCPis valid.
         */
        IPProtocol?: string;
        /**
         * The IP Version that will be used by this forwarding rule. Valid options
         * are IPV4 or IPV6. This can only be specified for an external global
         * forwarding rule.
         */
        ipVersion?: string;
        /**
         * [Output Only] Type of the resource. Always compute#forwardingRule for
         * Forwarding Rule resources.
         */
        kind?: string;
        /**
         * This signifies what the ForwardingRule will be used for and can only take
         * the following values: INTERNAL, INTERNAL_SELF_MANAGED, EXTERNAL. The
         * value of INTERNAL means that this will be used for Internal Network Load
         * Balancing (TCP, UDP). The value of INTERNAL_SELF_MANAGED means that this
         * will be used for Internal Global HTTP(S) LB. The value of EXTERNAL means
         * that this will be used for External Load Balancing (HTTP(S) LB, External
         * TCP/UDP LB, SSL Proxy)
         */
        loadBalancingScheme?: string;
        /**
         * Name of the resource; provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * This field is not used for external load balancing.  For INTERNAL and
         * INTERNAL_SELF_MANAGED load balancing, this field identifies the network
         * that the load balanced IP should belong to for this Forwarding Rule. If
         * this field is not specified, the default network will be used.
         */
        network?: string;
        /**
         * This signifies the networking tier used for configuring this load
         * balancer and can only take the following values: PREMIUM , STANDARD.  For
         * regional ForwardingRule, the valid values are PREMIUM and STANDARD. For
         * GlobalForwardingRule, the valid value is PREMIUM.  If this field is not
         * specified, it is assumed to be PREMIUM. If IPAddress is specified, this
         * value must be equal to the networkTier of the Address.
         */
        networkTier?: string;
        /**
         * This field is used along with the target field for TargetHttpProxy,
         * TargetHttpsProxy, TargetSslProxy, TargetTcpProxy, TargetVpnGateway,
         * TargetPool, TargetInstance.  Applicable only when IPProtocol is TCP, UDP,
         * or SCTP, only packets addressed to ports in the specified range will be
         * forwarded to target. Forwarding rules with the same [IPAddress,
         * IPProtocol] pair must have disjoint port ranges.  Some types of
         * forwarding target have constraints on the acceptable ports:   -
         * TargetHttpProxy: 80, 8080  - TargetHttpsProxy: 443  - TargetTcpProxy: 25,
         * 43, 110, 143, 195, 443, 465, 587, 700, 993, 995, 1688, 1883, 5222  -
         * TargetSslProxy: 25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995,
         * 1688, 1883, 5222  - TargetVpnGateway: 500, 4500
         */
        portRange?: string;
        /**
         * This field is used along with the backend_service field for internal load
         * balancing.  When the load balancing scheme is INTERNAL, a list of ports
         * can be configured, for example, [&#39;80&#39;],
         * [&#39;8000&#39;,&#39;9000&#39;] etc. Only packets addressed to these
         * ports will be forwarded to the backends configured with this forwarding
         * rule.  You may specify a maximum of up to 5 ports.
         */
        ports?: string[];
        /**
         * [Output Only] URL of the region where the regional forwarding rule
         * resides. This field is not applicable to global forwarding rules. You
         * must specify this field as part of the HTTP request URL. It is not
         * settable as a field in the request body.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * An optional prefix to the service name for this Forwarding Rule. If
         * specified, will be the first label of the fully qualified service name.
         * The label must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the label must be 1-63 characters long and match the
         * regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
         * character must be a lowercase letter, and all following characters must
         * be a dash, lowercase letter, or digit, except the last character, which
         * cannot be a dash.  This field is only used for internal load balancing.
         */
        serviceLabel?: string;
        /**
         * [Output Only] The internal fully qualified service name for this
         * Forwarding Rule.  This field is only used for internal load balancing.
         */
        serviceName?: string;
        /**
         * This field is only used for INTERNAL load balancing.  For internal load
         * balancing, this field identifies the subnetwork that the load balanced IP
         * should belong to for this Forwarding Rule.  If the network specified is
         * in auto subnet mode, this field is optional. However, if the network is
         * in custom subnet mode, a subnetwork must be specified.
         */
        subnetwork?: string;
        /**
         * The URL of the target resource to receive the matched traffic. For
         * regional forwarding rules, this target must live in the same region as
         * the forwarding rule. For global forwarding rules, this target must be a
         * global load balancing resource. The forwarded traffic must be of a type
         * appropriate to the target object. For INTERNAL_SELF_MANAGED load
         * balancing, only HTTP and HTTPS targets are valid.
         */
        target?: string;
    }
    interface Schema$ForwardingRuleAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of ForwardingRulesScopedList resources.
         */
        items?: {
            [key: string]: Schema$ForwardingRulesScopedList;
        };
        /**
         * [Output Only] Type of resource. Always
         * compute#forwardingRuleAggregatedList for lists of forwarding rules.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of ForwardingRule resources.
     */
    interface Schema$ForwardingRuleList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of ForwardingRule resources.
         */
        items?: Schema$ForwardingRule[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$ForwardingRuleReference {
        forwardingRule?: string;
    }
    interface Schema$ForwardingRulesScopedList {
        /**
         * A list of forwarding rules contained in this scope.
         */
        forwardingRules?: Schema$ForwardingRule[];
        /**
         * Informational warning which replaces the list of forwarding rules when
         * the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$GlobalSetLabelsRequest {
        /**
         * The fingerprint of the previous set of labels for this resource, used to
         * detect conflicts. The fingerprint is initially generated by Compute
         * Engine and changes after every request to modify or update labels. You
         * must always provide an up-to-date fingerprint hash when updating or
         * changing labels, otherwise the request will fail with error 412
         * conditionNotMet. Make a get() request to the resource to get the latest
         * fingerprint.
         */
        labelFingerprint?: string;
        /**
         * A list of labels to apply for this resource. Each label key &amp; value
         * must comply with RFC1035. Specifically, the name must be 1-63 characters
         * long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
         * means the first character must be a lowercase letter, and all following
         * characters must be a dash, lowercase letter, or digit, except the last
         * character, which cannot be a dash. For example,
         * &quot;webserver-frontend&quot;: &quot;images&quot;. A label value can
         * also be empty (e.g. &quot;my-label&quot;: &quot;&quot;).
         */
        labels?: {
            [key: string]: string;
        };
    }
    interface Schema$GlobalSetPolicyRequest {
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated.
         * Use &#39;policy&#39; to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated.
         * Use &#39;policy&#39; to specify the etag.
         */
        etag?: string;
        /**
         * REQUIRED: The complete policy to be applied to the &#39;resource&#39;.
         * The size of the policy is limited to a few 10s of KB. An empty policy is
         * in general a valid policy but certain services (like Projects) might
         * reject them.
         */
        policy?: Schema$Policy;
    }
    /**
     * Guest OS features.
     */
    interface Schema$GuestOsFeature {
        /**
         * The ID of a supported feature. Read  Enabling guest operating system
         * features to see a list of available options.
         */
        type?: string;
    }
    /**
     * An HealthCheck resource. This resource defines a template for how
     * individual virtual machines should be checked for health, via one of the
     * supported protocols.
     */
    interface Schema$HealthCheck {
        /**
         * How often (in seconds) to send a health check. The default value is 5
         * seconds.
         */
        checkIntervalSec?: number;
        /**
         * [Output Only] Creation timestamp in 3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * A so-far unhealthy instance will be marked healthy after this many
         * consecutive successes. The default value is 2.
         */
        healthyThreshold?: number;
        http2HealthCheck?: Schema$HTTP2HealthCheck;
        httpHealthCheck?: Schema$HTTPHealthCheck;
        httpsHealthCheck?: Schema$HTTPSHealthCheck;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * Type of the resource.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        sslHealthCheck?: Schema$SSLHealthCheck;
        tcpHealthCheck?: Schema$TCPHealthCheck;
        /**
         * How long (in seconds) to wait before claiming failure. The default value
         * is 5 seconds. It is invalid for timeoutSec to have greater value than
         * checkIntervalSec.
         */
        timeoutSec?: number;
        /**
         * Specifies the type of the healthCheck, either TCP, SSL, HTTP or HTTPS. If
         * not specified, the default is TCP. Exactly one of the protocol-specific
         * health check field must be specified, which must match type field.
         */
        type?: string;
        /**
         * A so-far healthy instance will be marked unhealthy after this many
         * consecutive failures. The default value is 2.
         */
        unhealthyThreshold?: number;
    }
    /**
     * Contains a list of HealthCheck resources.
     */
    interface Schema$HealthCheckList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of HealthCheck resources.
         */
        items?: Schema$HealthCheck[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A full or valid partial URL to a health check. For example, the following
     * are valid URLs:   -
     * https://www.googleapis.com/compute/beta/projects/project-id/global/httpHealthChecks/health-check
     * - projects/project-id/global/httpHealthChecks/health-check  -
     * global/httpHealthChecks/health-check
     */
    interface Schema$HealthCheckReference {
        healthCheck?: string;
    }
    interface Schema$HealthStatus {
        /**
         * Health state of the instance.
         */
        healthState?: string;
        /**
         * URL of the instance resource.
         */
        instance?: string;
        /**
         * The IP address represented by this resource.
         */
        ipAddress?: string;
        /**
         * The port on the instance.
         */
        port?: number;
    }
    interface Schema$HealthStatusForNetworkEndpoint {
        /**
         * URL of the backend service associated with the health state of the
         * network endpoint.
         */
        backendService?: Schema$BackendServiceReference;
        /**
         * URL of the forwarding rule associated with the health state of the
         * network endpoint.
         */
        forwardingRule?: Schema$ForwardingRuleReference;
        /**
         * URL of the health check associated with the health state of the network
         * endpoint.
         */
        healthCheck?: Schema$HealthCheckReference;
        /**
         * Health state of the network endpoint determined based on the health
         * checks configured.
         */
        healthState?: string;
    }
    /**
     * UrlMaps A host-matching rule for a URL. If matched, will use the named
     * PathMatcher to select the BackendService.
     */
    interface Schema$HostRule {
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * The list of host patterns to match. They must be valid hostnames, except
         * * will match any string of ([a-z0-9-.]*). In that case, * must be the
         * first character and must be followed in the pattern by either - or ..
         */
        hosts?: string[];
        /**
         * The name of the PathMatcher to use to match the path portion of the URL
         * if the hostRule matches the URL&#39;s host portion.
         */
        pathMatcher?: string;
    }
    interface Schema$HTTP2HealthCheck {
        /**
         * The value of the host header in the HTTP/2 health check request. If left
         * empty (default value), the IP on behalf of which this health check is
         * performed will be used.
         */
        host?: string;
        /**
         * The TCP port number for the health check request. The default value is
         * 443. Valid values are 1 through 65535.
         */
        port?: number;
        /**
         * Port name as defined in InstanceGroup#NamedPort#name. If both port and
         * port_name are defined, port takes precedence.
         */
        portName?: string;
        /**
         * Specifies how port is selected for health checking, can be one of
         * following values: USE_FIXED_PORT: The port number in port is used for
         * health checking. USE_NAMED_PORT: The portName is used for health
         * checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified
         * for each network endpoint is used for health checking. For other
         * backends, the port or named port specified in the Backend Service is used
         * for health checking.   If not specified, HTTP2 health check follows
         * behavior specified in port and portName fields.
         */
        portSpecification?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * The request path of the HTTP/2 health check request. The default value is
         * /.
         */
        requestPath?: string;
        /**
         * The string to match anywhere in the first 1024 bytes of the response
         * body. If left empty (the default value), the status code determines
         * health. The response data can only be ASCII.
         */
        response?: string;
    }
    interface Schema$HTTPHealthCheck {
        /**
         * The value of the host header in the HTTP health check request. If left
         * empty (default value), the IP on behalf of which this health check is
         * performed will be used.
         */
        host?: string;
        /**
         * The TCP port number for the health check request. The default value
         * is 80. Valid values are 1 through 65535.
         */
        port?: number;
        /**
         * Port name as defined in InstanceGroup#NamedPort#name. If both port and
         * port_name are defined, port takes precedence.
         */
        portName?: string;
        /**
         * Specifies how port is selected for health checking, can be one of
         * following values: USE_FIXED_PORT: The port number in port is used for
         * health checking. USE_NAMED_PORT: The portName is used for health
         * checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified
         * for each network endpoint is used for health checking. For other
         * backends, the port or named port specified in the Backend Service is used
         * for health checking.   If not specified, HTTP health check follows
         * behavior specified in port and portName fields.
         */
        portSpecification?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * The request path of the HTTP health check request. The default value is
         * /.
         */
        requestPath?: string;
        /**
         * The string to match anywhere in the first 1024 bytes of the response
         * body. If left empty (the default value), the status code determines
         * health. The response data can only be ASCII.
         */
        response?: string;
    }
    /**
     * An HttpHealthCheck resource. This resource defines a template for how
     * individual instances should be checked for health, via HTTP.
     */
    interface Schema$HttpHealthCheck {
        /**
         * How often (in seconds) to send a health check. The default value is 5
         * seconds.
         */
        checkIntervalSec?: number;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * A so-far unhealthy instance will be marked healthy after this many
         * consecutive successes. The default value is 2.
         */
        healthyThreshold?: number;
        /**
         * The value of the host header in the HTTP health check request. If left
         * empty (default value), the public IP on behalf of which this health check
         * is performed will be used.
         */
        host?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#httpHealthCheck for
         * HTTP health checks.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The TCP port number for the HTTP health check request. The default value
         * is 80.
         */
        port?: number;
        /**
         * The request path of the HTTP health check request. The default value is
         * /.
         */
        requestPath?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * How long (in seconds) to wait before claiming failure. The default value
         * is 5 seconds. It is invalid for timeoutSec to have greater value than
         * checkIntervalSec.
         */
        timeoutSec?: number;
        /**
         * A so-far healthy instance will be marked unhealthy after this many
         * consecutive failures. The default value is 2.
         */
        unhealthyThreshold?: number;
    }
    /**
     * Contains a list of HttpHealthCheck resources.
     */
    interface Schema$HttpHealthCheckList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of HttpHealthCheck resources.
         */
        items?: Schema$HttpHealthCheck[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$HTTPSHealthCheck {
        /**
         * The value of the host header in the HTTPS health check request. If left
         * empty (default value), the IP on behalf of which this health check is
         * performed will be used.
         */
        host?: string;
        /**
         * The TCP port number for the health check request. The default value is
         * 443. Valid values are 1 through 65535.
         */
        port?: number;
        /**
         * Port name as defined in InstanceGroup#NamedPort#name. If both port and
         * port_name are defined, port takes precedence.
         */
        portName?: string;
        /**
         * Specifies how port is selected for health checking, can be one of
         * following values: USE_FIXED_PORT: The port number in port is used for
         * health checking. USE_NAMED_PORT: The portName is used for health
         * checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified
         * for each network endpoint is used for health checking. For other
         * backends, the port or named port specified in the Backend Service is used
         * for health checking.   If not specified, HTTPS health check follows
         * behavior specified in port and portName fields.
         */
        portSpecification?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * The request path of the HTTPS health check request. The default value is
         * /.
         */
        requestPath?: string;
        /**
         * The string to match anywhere in the first 1024 bytes of the response
         * body. If left empty (the default value), the status code determines
         * health. The response data can only be ASCII.
         */
        response?: string;
    }
    /**
     * An HttpsHealthCheck resource. This resource defines a template for how
     * individual instances should be checked for health, via HTTPS.
     */
    interface Schema$HttpsHealthCheck {
        /**
         * How often (in seconds) to send a health check. The default value is 5
         * seconds.
         */
        checkIntervalSec?: number;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * A so-far unhealthy instance will be marked healthy after this many
         * consecutive successes. The default value is 2.
         */
        healthyThreshold?: number;
        /**
         * The value of the host header in the HTTPS health check request. If left
         * empty (default value), the public IP on behalf of which this health check
         * is performed will be used.
         */
        host?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * Type of the resource.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The TCP port number for the HTTPS health check request. The default value
         * is 443.
         */
        port?: number;
        /**
         * The request path of the HTTPS health check request. The default value is
         * &quot;/&quot;.
         */
        requestPath?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * How long (in seconds) to wait before claiming failure. The default value
         * is 5 seconds. It is invalid for timeoutSec to have a greater value than
         * checkIntervalSec.
         */
        timeoutSec?: number;
        /**
         * A so-far healthy instance will be marked unhealthy after this many
         * consecutive failures. The default value is 2.
         */
        unhealthyThreshold?: number;
    }
    /**
     * Contains a list of HttpsHealthCheck resources.
     */
    interface Schema$HttpsHealthCheckList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of HttpsHealthCheck resources.
         */
        items?: Schema$HttpsHealthCheck[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * An Image resource. (== resource_for beta.images ==) (== resource_for
     * v1.images ==)
     */
    interface Schema$Image {
        /**
         * Size of the image tar.gz archive stored in Google Cloud Storage (in
         * bytes).
         */
        archiveSizeBytes?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * The deprecation status associated with this image.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * Size of the image when restored onto a persistent disk (in GB).
         */
        diskSizeGb?: string;
        /**
         * The name of the image family to which this image belongs. You can create
         * disks by specifying an image family instead of a specific image name. The
         * image family always returns its latest image that is not deprecated. The
         * name of the image family must comply with RFC1035.
         */
        family?: string;
        /**
         * A list of features to enable on the guest operating system. Applicable
         * only for bootable images. Read  Enabling guest operating system features
         * to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * Encrypts the image using a customer-supplied encryption key.  After you
         * encrypt an image with a customer-supplied key, you must provide the same
         * key if you use the image later (e.g. to create a disk from the image).
         * Customer-supplied encryption keys do not protect access to metadata of
         * the disk.  If you do not provide an encryption key when creating the
         * image, then the disk will be encrypted using an automatically generated
         * key and you do not need to provide a key to use the image later.
         */
        imageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] Type of the resource. Always compute#image for images.
         */
        kind?: string;
        /**
         * A fingerprint for the labels being applied to this image, which is
         * essentially a hash of the labels used for optimistic locking. The
         * fingerprint is initially generated by Compute Engine and changes after
         * every request to modify or update labels. You must always provide an
         * up-to-date fingerprint hash in order to update or change labels,
         * otherwise the request will fail with error 412 conditionNotMet.  To see
         * the latest fingerprint, make a get() request to retrieve an image.
         */
        labelFingerprint?: string;
        /**
         * Labels to apply to this image. These can be later modified by the
         * setLabels method.
         */
        labels?: {
            [key: string]: string;
        };
        /**
         * Integer license codes indicating which licenses are attached to this
         * image.
         */
        licenseCodes?: string[];
        /**
         * Any applicable license URI.
         */
        licenses?: string[];
        /**
         * Name of the resource; provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The parameters of the raw disk image.
         */
        rawDisk?: {
            containerType?: string;
            sha1Checksum?: string;
            source?: string;
        };
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * URL of the source disk used to create this image. This can be a full or
         * valid partial URL. You must provide either this property or the
         * rawDisk.source property but not both to create an image. For example, the
         * following are valid values:   -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
         * - projects/project/zones/zone/disks/disk  - zones/zone/disks/disk
         */
        sourceDisk?: string;
        /**
         * The customer-supplied encryption key of the source disk. Required if the
         * source disk is protected by a customer-supplied encryption key.
         */
        sourceDiskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the disk used to create this image. This
         * value may be used to determine whether the image was taken from the
         * current or a previous instance of a given disk name.
         */
        sourceDiskId?: string;
        /**
         * URL of the source image used to create this image. This can be a full or
         * valid partial URL. You must provide exactly one of:   - this property, or
         * - the rawDisk.source property, or   - the sourceDisk property   in order
         * to create an image.
         */
        sourceImage?: string;
        /**
         * The customer-supplied encryption key of the source image. Required if the
         * source image is protected by a customer-supplied encryption key.
         */
        sourceImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the image used to create this image. This
         * value may be used to determine whether the image was taken from the
         * current or a previous instance of a given image name.
         */
        sourceImageId?: string;
        /**
         * URL of the source snapshot used to create this image. This can be a full
         * or valid partial URL. You must provide exactly one of:   - this property,
         * or   - the sourceImage property, or   - the rawDisk.source property, or
         * - the sourceDisk property   in order to create an image.
         */
        sourceSnapshot?: string;
        /**
         * The customer-supplied encryption key of the source snapshot. Required if
         * the source snapshot is protected by a customer-supplied encryption key.
         */
        sourceSnapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the snapshot used to create this image.
         * This value may be used to determine whether the snapshot was taken from
         * the current or a previous instance of a given snapshot name.
         */
        sourceSnapshotId?: string;
        /**
         * The type of the image used to create this disk. The default and only
         * value is RAW
         */
        sourceType?: string;
        /**
         * [Output Only] The status of the image. An image can be used to create
         * other resources, such as instances, only after the image has been
         * successfully created and the status is set to READY. Possible values are
         * FAILED, PENDING, or READY.
         */
        status?: string;
    }
    /**
     * Contains a list of images.
     */
    interface Schema$ImageList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Image resources.
         */
        items?: Schema$Image[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * An Instance resource. (== resource_for beta.instances ==) (== resource_for
     * v1.instances ==)
     */
    interface Schema$Instance {
        /**
         * Allows this instance to send and receive packets with non-matching
         * destination or source IPs. This is required if you plan to use this
         * instance to forward routes. For more information, see Enabling IP
         * Forwarding.
         */
        canIpForward?: boolean;
        /**
         * [Output Only] The CPU platform used by this instance.
         */
        cpuPlatform?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * Whether the resource should be protected against deletion.
         */
        deletionProtection?: boolean;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * Array of disks associated with this instance. Persistent disks must be
         * created before you can assign them.
         */
        disks?: Schema$AttachedDisk[];
        /**
         * A list of the type and count of accelerator cards attached to the
         * instance.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
        hostname?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#instance for
         * instances.
         */
        kind?: string;
        /**
         * A fingerprint for this request, which is essentially a hash of the
         * label&#39;s contents and used for optimistic locking. The fingerprint is
         * initially generated by Compute Engine and changes after every request to
         * modify or update labels. You must always provide an up-to-date
         * fingerprint hash in order to update or change labels.  To see the latest
         * fingerprint, make get() request to the instance.
         */
        labelFingerprint?: string;
        /**
         * Labels to apply to this instance. These can be later modified by the
         * setLabels method.
         */
        labels?: {
            [key: string]: string;
        };
        /**
         * Full or partial URL of the machine type resource to use for this
         * instance, in the format: zones/zone/machineTypes/machine-type. This is
         * provided by the client when the instance is created. For example, the
         * following is a valid partial url to a predefined machine type:
         * zones/us-central1-f/machineTypes/n1-standard-1   To create a custom
         * machine type, provide a URL to a machine type in the following format,
         * where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and
         * MEMORY is the total memory for this instance. Memory must be a multiple
         * of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB):
         * zones/zone/machineTypes/custom-CPUS-MEMORY   For example:
         * zones/us-central1-f/machineTypes/custom-4-5120   For a full list of
         * restrictions, read the Specifications for custom machine types.
         */
        machineType?: string;
        /**
         * The metadata key/value pairs assigned to this instance. This includes
         * custom metadata and predefined keys.
         */
        metadata?: Schema$Metadata;
        /**
         * Specifies a minimum CPU platform for the VM instance. Applicable values
         * are the friendly names of CPU platforms, such as minCpuPlatform:
         * &quot;Intel Haswell&quot; or minCpuPlatform: &quot;Intel Sandy
         * Bridge&quot;.
         */
        minCpuPlatform?: string;
        /**
         * The name of the resource, provided by the client when initially creating
         * the resource. The resource name must be 1-63 characters long, and comply
         * with RFC1035. Specifically, the name must be 1-63 characters long and
         * match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
         * first character must be a lowercase letter, and all following characters
         * must be a dash, lowercase letter, or digit, except the last character,
         * which cannot be a dash.
         */
        name?: string;
        /**
         * An array of network configurations for this instance. These specify how
         * interfaces are configured to interact with other network services, such
         * as connecting to the internet. Multiple interfaces are supported per
         * instance.
         */
        networkInterfaces?: Schema$NetworkInterface[];
        /**
         * Sets the scheduling options for this instance.
         */
        scheduling?: Schema$Scheduling;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * A list of service accounts, with their specified scopes, authorized for
         * this instance. Only one service account per VM instance is supported.
         * Service accounts generate access tokens that can be accessed through the
         * metadata server and used to authenticate applications on the instance.
         * See Service Accounts for more information.
         */
        serviceAccounts?: Schema$ServiceAccount[];
        shieldedInstanceConfig?: Schema$ShieldedInstanceConfig;
        shieldedInstanceIntegrityPolicy?: Schema$ShieldedInstanceIntegrityPolicy;
        /**
         * [Output Only] Whether a VM has been restricted for start because Compute
         * Engine has detected suspicious activity.
         */
        startRestricted?: boolean;
        /**
         * [Output Only] The status of the instance. One of the following values:
         * PROVISIONING, STAGING, RUNNING, STOPPING, STOPPED, SUSPENDING, SUSPENDED,
         * and TERMINATED.
         */
        status?: string;
        /**
         * [Output Only] An optional, human-readable explanation of the status.
         */
        statusMessage?: string;
        /**
         * Tags to apply to this instance. Tags are used to identify valid sources
         * or targets for network firewalls and are specified by the client during
         * instance creation. The tags can be later modified by the setTags method.
         * Each tag within the list must comply with RFC1035. Multiple tags can be
         * specified via the &#39;tags.items&#39; field.
         */
        tags?: Schema$Tags;
        /**
         * [Output Only] URL of the zone where the instance resides. You must
         * specify this field as part of the HTTP request URL. It is not settable as
         * a field in the request body.
         */
        zone?: string;
    }
    interface Schema$InstanceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstancesScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstancesScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#instanceAggregatedList for
         * aggregated lists of Instance resources.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * InstanceGroups (== resource_for beta.instanceGroups ==) (== resource_for
     * v1.instanceGroups ==) (== resource_for beta.regionInstanceGroups ==) (==
     * resource_for v1.regionInstanceGroups ==)
     */
    interface Schema$InstanceGroup {
        /**
         * [Output Only] The creation timestamp for this instance group in RFC3339
         * text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The fingerprint of the named ports. The system uses this
         * fingerprint to detect conflicts when multiple users change the named
         * ports concurrently.
         */
        fingerprint?: string;
        /**
         * [Output Only] A unique identifier for this instance group, generated by
         * the server.
         */
        id?: string;
        /**
         * [Output Only] The resource type, which is always compute#instanceGroup
         * for instance groups.
         */
        kind?: string;
        /**
         * The name of the instance group. The name must be 1-63 characters long,
         * and comply with RFC1035.
         */
        name?: string;
        /**
         * Assigns a name to a port number. For example: {name: &quot;http&quot;,
         * port: 80}  This allows the system to reference ports by the assigned name
         * instead of a port number. Named ports can also contain multiple ports.
         * For example: [{name: &quot;http&quot;, port: 80},{name: &quot;http&quot;,
         * port: 8080}]   Named ports apply to all instances in this instance group.
         */
        namedPorts?: Schema$NamedPort[];
        /**
         * The URL of the network to which all instances in the instance group
         * belong.
         */
        network?: string;
        /**
         * [Output Only] The URL of the region where the instance group is located
         * (for regional resources).
         */
        region?: string;
        /**
         * [Output Only] The URL for this instance group. The server generates this
         * URL.
         */
        selfLink?: string;
        /**
         * [Output Only] The total number of instances in the instance group.
         */
        size?: number;
        /**
         * [Output Only] The URL of the subnetwork to which all instances in the
         * instance group belong.
         */
        subnetwork?: string;
        /**
         * [Output Only] The URL of the zone where the instance group is located
         * (for zonal resources).
         */
        zone?: string;
    }
    interface Schema$InstanceGroupAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceGroupsScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstanceGroupsScopedList;
        };
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupAggregatedList for aggregated lists of instance
         * groups.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A list of InstanceGroup resources.
     */
    interface Schema$InstanceGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceGroup resources.
         */
        items?: Schema$InstanceGroup[];
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupList for instance group lists.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * An Instance Group Manager resource. (== resource_for
     * beta.instanceGroupManagers ==) (== resource_for v1.instanceGroupManagers
     * ==) (== resource_for beta.regionInstanceGroupManagers ==) (== resource_for
     * v1.regionInstanceGroupManagers ==)
     */
    interface Schema$InstanceGroupManager {
        /**
         * The autohealing policy for this managed instance group. You can specify
         * only one value.
         */
        autoHealingPolicies?: Schema$InstanceGroupManagerAutoHealingPolicy[];
        /**
         * The base instance name to use for instances in this group. The value must
         * be 1-58 characters long. Instances are named by appending a hyphen and a
         * random four-character string to the base instance name. The base instance
         * name must comply with RFC1035.
         */
        baseInstanceName?: string;
        /**
         * [Output Only] The creation timestamp for this managed instance group in
         * RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] The list of instance actions and the number of instances in
         * this managed instance group that are scheduled for each of those actions.
         */
        currentActions?: Schema$InstanceGroupManagerActionsSummary;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * Policy specifying intended distribution of instances in regional managed
         * instance group.
         */
        distributionPolicy?: Schema$DistributionPolicy;
        /**
         * Fingerprint of this resource. This field may be used in optimistic
         * locking. It will be ignored when inserting an InstanceGroupManager. An
         * up-to-date fingerprint must be provided in order to update the
         * InstanceGroupManager, otherwise the request will fail with error 412
         * conditionNotMet.  To see the latest fingerprint, make a get() request to
         * retrieve an InstanceGroupManager.
         */
        fingerprint?: string;
        /**
         * [Output Only] A unique identifier for this resource type. The server
         * generates this identifier.
         */
        id?: string;
        /**
         * [Output Only] The URL of the Instance Group resource.
         */
        instanceGroup?: string;
        /**
         * The URL of the instance template that is specified for this managed
         * instance group. The group uses this template to create all new instances
         * in the managed instance group.
         */
        instanceTemplate?: string;
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupManager for managed instance groups.
         */
        kind?: string;
        /**
         * The name of the managed instance group. The name must be 1-63 characters
         * long, and comply with RFC1035.
         */
        name?: string;
        /**
         * Named ports configured for the Instance Groups complementary to this
         * Instance Group Manager.
         */
        namedPorts?: Schema$NamedPort[];
        /**
         * [Output Only] The URL of the region where the managed instance group
         * resides (for regional resources).
         */
        region?: string;
        /**
         * [Output Only] The URL for this managed instance group. The server defines
         * this URL.
         */
        selfLink?: string;
        /**
         * [Output Only] The status of this managed instance group.
         */
        status?: Schema$InstanceGroupManagerStatus;
        /**
         * The URLs for all TargetPool resources to which instances in the
         * instanceGroup field are added. The target pools automatically apply to
         * all of the instances in the managed instance group.
         */
        targetPools?: string[];
        /**
         * The target number of running instances for this managed instance group.
         * Deleting or abandoning instances reduces this number. Resizing the group
         * changes this number.
         */
        targetSize?: number;
        /**
         * The update policy for this managed instance group.
         */
        updatePolicy?: Schema$InstanceGroupManagerUpdatePolicy;
        /**
         * Specifies the instance templates used by this managed instance group to
         * create instances.  Each version is defined by an instanceTemplate. Every
         * template can appear at most once per instance group. This field overrides
         * the top-level instanceTemplate field. Read more about the relationships
         * between these fields. Exactly one version must leave the targetSize field
         * unset. That version will be applied to all remaining instances. For more
         * information, read about canary updates.
         */
        versions?: Schema$InstanceGroupManagerVersion[];
        /**
         * [Output Only] The URL of the zone where the managed instance group is
         * located (for zonal resources).
         */
        zone?: string;
    }
    interface Schema$InstanceGroupManagerActionsSummary {
        /**
         * [Output Only] The total number of instances in the managed instance group
         * that are scheduled to be abandoned. Abandoning an instance removes it
         * from the managed instance group without deleting it.
         */
        abandoning?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are scheduled to be created or are currently being created. If the group
         * fails to create any of these instances, it tries again until it creates
         * the instance successfully.  If you have disabled creation retries, this
         * field will not be populated; instead, the creatingWithoutRetries field
         * will be populated.
         */
        creating?: number;
        /**
         * [Output Only] The number of instances that the managed instance group
         * will attempt to create. The group attempts to create each instance only
         * once. If the group fails to create any of these instances, it decreases
         * the group&#39;s targetSize value accordingly.
         */
        creatingWithoutRetries?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are scheduled to be deleted or are currently being deleted.
         */
        deleting?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are running and have no scheduled actions.
         */
        none?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are scheduled to be recreated or are currently being being recreated.
         * Recreating an instance deletes the existing root persistent disk and
         * creates a new disk from the image that is defined in the instance
         * template.
         */
        recreating?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are being reconfigured with properties that do not require a restart or a
         * recreate action. For example, setting or removing target pools for the
         * instance.
         */
        refreshing?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are scheduled to be restarted or are currently being restarted.
         */
        restarting?: number;
        /**
         * [Output Only] The number of instances in the managed instance group that
         * are being verified. See the managedInstances[].currentAction property in
         * the listManagedInstances method documentation.
         */
        verifying?: number;
    }
    interface Schema$InstanceGroupManagerAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceGroupManagersScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstanceGroupManagersScopedList;
        };
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupManagerAggregatedList for an aggregated list of
         * managed instance groups.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceGroupManagerAutoHealingPolicy {
        /**
         * The URL for the health check that signals autohealing.
         */
        healthCheck?: string;
        /**
         * The number of seconds that the managed instance group waits before it
         * applies autohealing policies to new instances or recently recreated
         * instances. This initial delay allows instances to initialize and run
         * their startup scripts before the instance group determines that they are
         * UNHEALTHY. This prevents the managed instance group from recreating its
         * instances prematurely. This value must be from range [0, 3600].
         */
        initialDelaySec?: number;
    }
    /**
     * [Output Only] A list of managed instance groups.
     */
    interface Schema$InstanceGroupManagerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceGroupManager resources.
         */
        items?: Schema$InstanceGroupManager[];
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupManagerList for a list of managed instance groups.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceGroupManagersAbandonInstancesRequest {
        /**
         * The URLs of one or more instances to abandon. This can be a full URL or a
         * partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[];
    }
    interface Schema$InstanceGroupManagersDeleteInstancesRequest {
        /**
         * The URLs of one or more instances to delete. This can be a full URL or a
         * partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[];
    }
    interface Schema$InstanceGroupManagersListManagedInstancesResponse {
        /**
         * [Output Only] The list of instances in the managed instance group.
         */
        managedInstances?: Schema$ManagedInstance[];
    }
    interface Schema$InstanceGroupManagersRecreateInstancesRequest {
        /**
         * The URLs of one or more instances to recreate. This can be a full URL or
         * a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[];
    }
    interface Schema$InstanceGroupManagersScopedList {
        /**
         * [Output Only] The list of managed instance groups that are contained in
         * the specified project and zone.
         */
        instanceGroupManagers?: Schema$InstanceGroupManager[];
        /**
         * [Output Only] The warning that replaces the list of managed instance
         * groups when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceGroupManagersSetInstanceTemplateRequest {
        /**
         * The URL of the instance template that is specified for this managed
         * instance group. The group uses this template to create all new instances
         * in the managed instance group.
         */
        instanceTemplate?: string;
    }
    interface Schema$InstanceGroupManagersSetTargetPoolsRequest {
        /**
         * The fingerprint of the target pools information. Use this optional
         * property to prevent conflicts when multiple users change the target pools
         * settings concurrently. Obtain the fingerprint with the
         * instanceGroupManagers.get method. Then, include the fingerprint in your
         * request to ensure that you do not overwrite changes that were applied
         * from another concurrent request.
         */
        fingerprint?: string;
        /**
         * The list of target pool URLs that instances in this managed instance
         * group belong to. The managed instance group applies these target pools to
         * all of the instances in the group. Existing instances and new instances
         * in the group all receive these target pool settings.
         */
        targetPools?: string[];
    }
    interface Schema$InstanceGroupManagerStatus {
        /**
         * [Output Only] A bit indicating whether the managed instance group is in a
         * stable state. A stable state means that: none of the instances in the
         * managed instance group is currently undergoing any type of change (for
         * example, creation, restart, or deletion); no future changes are scheduled
         * for instances in the managed instance group; and the managed instance
         * group itself is not being modified.
         */
        isStable?: boolean;
    }
    interface Schema$InstanceGroupManagerUpdatePolicy {
        /**
         * The maximum number of instances that can be created above the specified
         * targetSize during the update process. By default, a fixed value of 1 is
         * used. This value can be either a fixed number or a percentage if the
         * instance group has 10 or more instances. If you set a percentage, the
         * number of instances will be rounded up if necessary.  At least one of
         * either maxSurge or maxUnavailable must be greater than 0. Learn more
         * about maxSurge.
         */
        maxSurge?: Schema$FixedOrPercent;
        /**
         * The maximum number of instances that can be unavailable during the update
         * process. An instance is considered available if all of the following
         * conditions are satisfied:    - The instance&#39;s status is RUNNING.  -
         * If there is a health check on the instance group, the instance&#39;s
         * liveness health check result must be HEALTHY at least once. If there is
         * no health check on the group, then the instance only needs to have a
         * status of RUNNING to be considered available.  By default, a fixed value
         * of 1 is used. This value can be either a fixed number or a percentage if
         * the instance group has 10 or more instances. If you set a percentage, the
         * number of instances will be rounded up if necessary.  At least one of
         * either maxSurge or maxUnavailable must be greater than 0. Learn more
         * about maxUnavailable.
         */
        maxUnavailable?: Schema$FixedOrPercent;
        /**
         * Minimal action to be taken on an instance. You can specify either RESTART
         * to restart existing instances or REPLACE to delete and create new
         * instances from the target template. If you specify a RESTART, the Updater
         * will attempt to perform that action only. However, if the Updater
         * determines that the minimal action you specify is not enough to perform
         * the update, it might perform a more disruptive action.
         */
        minimalAction?: string;
        type?: string;
    }
    interface Schema$InstanceGroupManagerVersion {
        instanceTemplate?: string;
        /**
         * Name of the version. Unique among all versions in the scope of this
         * managed instance group.
         */
        name?: string;
        /**
         * Specifies the intended number of instances to be created from the
         * instanceTemplate. The final number of instances created from the template
         * will be equal to:   - If expressed as a fixed number, the minimum of
         * either targetSize.fixed or instanceGroupManager.targetSize is used.  - if
         * expressed as a percent, the targetSize would be (targetSize.percent/100 *
         * InstanceGroupManager.targetSize) If there is a remainder, the number is
         * rounded up.  If unset, this version will update any remaining instances
         * not updated by another version. Read Starting a canary update for more
         * information.
         */
        targetSize?: Schema$FixedOrPercent;
    }
    interface Schema$InstanceGroupsAddInstancesRequest {
        /**
         * The list of instances to add to the instance group.
         */
        instances?: Schema$InstanceReference[];
    }
    interface Schema$InstanceGroupsListInstances {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceWithNamedPorts resources.
         */
        items?: Schema$InstanceWithNamedPorts[];
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupsListInstances for the list of instances in the
         * specified instance group.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceGroupsListInstancesRequest {
        /**
         * A filter for the state of the instances in the instance group. Valid
         * options are ALL or RUNNING. If you do not specify this parameter the list
         * includes all instances regardless of their state.
         */
        instanceState?: string;
    }
    interface Schema$InstanceGroupsRemoveInstancesRequest {
        /**
         * The list of instances to remove from the instance group.
         */
        instances?: Schema$InstanceReference[];
    }
    interface Schema$InstanceGroupsScopedList {
        /**
         * [Output Only] The list of instance groups that are contained in this
         * scope.
         */
        instanceGroups?: Schema$InstanceGroup[];
        /**
         * [Output Only] An informational warning that replaces the list of instance
         * groups when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceGroupsSetNamedPortsRequest {
        /**
         * The fingerprint of the named ports information for this instance group.
         * Use this optional property to prevent conflicts when multiple users
         * change the named ports settings concurrently. Obtain the fingerprint with
         * the instanceGroups.get method. Then, include the fingerprint in your
         * request to ensure that you do not overwrite changes that were applied
         * from another concurrent request. A request with an incorrect fingerprint
         * will fail with error 412 conditionNotMet.
         */
        fingerprint?: string;
        /**
         * The list of named ports to set for this instance group.
         */
        namedPorts?: Schema$NamedPort[];
    }
    /**
     * Contains a list of instances.
     */
    interface Schema$InstanceList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Instance resources.
         */
        items?: Schema$Instance[];
        /**
         * [Output Only] Type of resource. Always compute#instanceList for lists of
         * Instance resources.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of instance referrers.
     */
    interface Schema$InstanceListReferrers {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Reference resources.
         */
        items?: Schema$Reference[];
        /**
         * [Output Only] Type of resource. Always compute#instanceListReferrers for
         * lists of Instance referrers.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceMoveRequest {
        /**
         * The URL of the destination zone to move the instance. This can be a full
         * or partial URL. For example, the following are all valid URLs to a zone:
         * - https://www.googleapis.com/compute/v1/projects/project/zones/zone  -
         * projects/project/zones/zone  - zones/zone
         */
        destinationZone?: string;
        /**
         * The URL of the target instance to move. This can be a full or partial
         * URL. For example, the following are all valid URLs to an instance:   -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
         * - projects/project/zones/zone/instances/instance  -
         * zones/zone/instances/instance
         */
        targetInstance?: string;
    }
    interface Schema$InstanceProperties {
        /**
         * Enables instances created based on this template to send packets with
         * source IP addresses other than their own and receive packets with
         * destination IP addresses other than their own. If these instances will be
         * used as an IP gateway or it will be set as the next-hop in a Route
         * resource, specify true. If unsure, leave this set to false. See the
         * Enable IP forwarding documentation for more information.
         */
        canIpForward?: boolean;
        /**
         * An optional text description for the instances that are created from this
         * instance template.
         */
        description?: string;
        /**
         * An array of disks that are associated with the instances that are created
         * from this template.
         */
        disks?: Schema$AttachedDisk[];
        /**
         * A list of guest accelerator cards&#39; type and count to use for
         * instances created from the instance template.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
        /**
         * Labels to apply to instances that are created from this template.
         */
        labels?: {
            [key: string]: string;
        };
        /**
         * The machine type to use for instances that are created from this
         * template.
         */
        machineType?: string;
        /**
         * The metadata key/value pairs to assign to instances that are created from
         * this template. These pairs can consist of custom metadata or predefined
         * keys. See Project and instance metadata for more information.
         */
        metadata?: Schema$Metadata;
        /**
         * Minimum cpu/platform to be used by this instance. The instance may be
         * scheduled on the specified or newer cpu/platform. Applicable values are
         * the friendly names of CPU platforms, such as minCpuPlatform: &quot;Intel
         * Haswell&quot; or minCpuPlatform: &quot;Intel Sandy Bridge&quot;. For more
         * information, read Specifying a Minimum CPU Platform.
         */
        minCpuPlatform?: string;
        /**
         * An array of network access configurations for this interface.
         */
        networkInterfaces?: Schema$NetworkInterface[];
        /**
         * Specifies the scheduling options for the instances that are created from
         * this template.
         */
        scheduling?: Schema$Scheduling;
        /**
         * A list of service accounts with specified scopes. Access tokens for these
         * service accounts are available to the instances that are created from
         * this template. Use metadata queries to obtain the access tokens for these
         * instances.
         */
        serviceAccounts?: Schema$ServiceAccount[];
        shieldedInstanceConfig?: Schema$ShieldedInstanceConfig;
        /**
         * A list of tags to apply to the instances that are created from this
         * template. The tags identify valid sources or targets for network
         * firewalls. The setTags method can modify this list of tags. Each tag
         * within the list must comply with RFC1035.
         */
        tags?: Schema$Tags;
    }
    interface Schema$InstanceReference {
        /**
         * The URL for a specific instance.
         */
        instance?: string;
    }
    interface Schema$InstancesScopedList {
        /**
         * [Output Only] A list of instances contained in this scope.
         */
        instances?: Schema$Instance[];
        /**
         * [Output Only] Informational warning which replaces the list of instances
         * when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstancesSetLabelsRequest {
        /**
         * Fingerprint of the previous set of labels for this resource, used to
         * prevent conflicts. Provide the latest fingerprint value when making a
         * request to add or change labels.
         */
        labelFingerprint?: string;
        labels?: {
            [key: string]: string;
        };
    }
    interface Schema$InstancesSetMachineResourcesRequest {
        /**
         * A list of the type and count of accelerator cards attached to the
         * instance.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
    }
    interface Schema$InstancesSetMachineTypeRequest {
        /**
         * Full or partial URL of the machine type resource. See Machine Types for a
         * full list of machine types. For example:
         * zones/us-central1-f/machineTypes/n1-standard-1
         */
        machineType?: string;
    }
    interface Schema$InstancesSetMinCpuPlatformRequest {
        /**
         * Minimum cpu/platform this instance should be started at.
         */
        minCpuPlatform?: string;
    }
    interface Schema$InstancesSetServiceAccountRequest {
        /**
         * Email address of the service account.
         */
        email?: string;
        /**
         * The list of scopes to be made available for this service account.
         */
        scopes?: string[];
    }
    interface Schema$InstancesStartWithEncryptionKeyRequest {
        /**
         * Array of disks associated with this instance that are protected with a
         * customer-supplied encryption key.  In order to start the instance, the
         * disk url and its corresponding key must be provided.  If the disk is not
         * protected with a customer-supplied encryption key it should not be
         * specified.
         */
        disks?: Schema$CustomerEncryptionKeyProtectedDisk[];
    }
    /**
     * An Instance Template resource. (== resource_for beta.instanceTemplates ==)
     * (== resource_for v1.instanceTemplates ==)
     */
    interface Schema$InstanceTemplate {
        /**
         * [Output Only] The creation timestamp for this instance template in
         * RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] A unique identifier for this instance template. The server
         * defines this identifier.
         */
        id?: string;
        /**
         * [Output Only] The resource type, which is always compute#instanceTemplate
         * for instance templates.
         */
        kind?: string;
        /**
         * Name of the resource; provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The instance properties for this instance template.
         */
        properties?: Schema$InstanceProperties;
        /**
         * [Output Only] The URL for this instance template. The server defines this
         * URL.
         */
        selfLink?: string;
        /**
         * The source instance used to create the template. You can provide this as
         * a partial or full URL to the resource. For example, the following are
         * valid values:   -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
         * - projects/project/zones/zone/instances/instance
         */
        sourceInstance?: string;
        /**
         * The source instance params to use to create this instance template.
         */
        sourceInstanceParams?: Schema$SourceInstanceParams;
    }
    /**
     * A list of instance templates.
     */
    interface Schema$InstanceTemplateList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceTemplate resources.
         */
        items?: Schema$InstanceTemplate[];
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceTemplatesListResponse for instance template lists.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$InstanceWithNamedPorts {
        /**
         * [Output Only] The URL of the instance.
         */
        instance?: string;
        /**
         * [Output Only] The named ports that belong to this instance group.
         */
        namedPorts?: Schema$NamedPort[];
        /**
         * [Output Only] The status of the instance.
         */
        status?: string;
    }
    /**
     * Represents an Interconnects resource. The Interconnects resource is a
     * dedicated connection between Google&#39;s network and your on-premises
     * network. For more information, see the  Dedicated overview page. (==
     * resource_for v1.interconnects ==) (== resource_for beta.interconnects ==)
     */
    interface Schema$Interconnect {
        /**
         * Administrative status of the interconnect. When this is set to true, the
         * Interconnect is functional and can carry traffic. When set to false, no
         * packets can be carried over the interconnect and no BGP routes are
         * exchanged over it. By default, the status is set to true.
         */
        adminEnabled?: boolean;
        /**
         * [Output Only] A list of CircuitInfo objects, that describe the individual
         * circuits in this LAG.
         */
        circuitInfos?: Schema$InterconnectCircuitInfo[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * Customer name, to put in the Letter of Authorization as the party
         * authorized to request a crossconnect.
         */
        customerName?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] A list of outages expected for this Interconnect.
         */
        expectedOutages?: Schema$InterconnectOutageNotification[];
        /**
         * [Output Only] IP address configured on the Google side of the
         * Interconnect link. This can be used only for ping tests.
         */
        googleIpAddress?: string;
        /**
         * [Output Only] Google reference ID to be used when raising support tickets
         * with Google or otherwise to debug backend connectivity issues.
         */
        googleReferenceId?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] A list of the URLs of all InterconnectAttachments
         * configured to use this Interconnect.
         */
        interconnectAttachments?: string[];
        /**
         * Type of interconnect. Note that &quot;IT_PRIVATE&quot; has been
         * deprecated in favor of &quot;DEDICATED&quot;
         */
        interconnectType?: string;
        /**
         * [Output Only] Type of the resource. Always compute#interconnect for
         * interconnects.
         */
        kind?: string;
        /**
         * Type of link requested. This field indicates speed of each of the links
         * in the bundle, not the entire bundle.
         */
        linkType?: string;
        /**
         * URL of the InterconnectLocation object that represents where this
         * connection is to be provisioned.
         */
        location?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Email address to contact the customer NOC for operations and maintenance
         * notifications regarding this Interconnect. If specified, this will be
         * used for notifications in addition to all other forms described, such as
         * Stackdriver logs alerting and Cloud Notifications.
         */
        nocContactEmail?: string;
        /**
         * [Output Only] The current status of whether or not this Interconnect is
         * functional.
         */
        operationalStatus?: string;
        /**
         * [Output Only] IP address configured on the customer side of the
         * Interconnect link. The customer should configure this IP address during
         * turnup when prompted by Google NOC. This can be used only for ping tests.
         */
        peerIpAddress?: string;
        /**
         * [Output Only] Number of links actually provisioned in this interconnect.
         */
        provisionedLinkCount?: number;
        /**
         * Target number of physical links in the link bundle, as requested by the
         * customer.
         */
        requestedLinkCount?: number;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The current state of whether or not this Interconnect is
         * functional.
         */
        state?: string;
    }
    /**
     * Represents an InterconnectAttachment (VLAN attachment) resource. For more
     * information, see  Creating VLAN Attachments. (== resource_for
     * beta.interconnectAttachments ==) (== resource_for
     * v1.interconnectAttachments ==)
     */
    interface Schema$InterconnectAttachment {
        /**
         * Determines whether this Attachment will carry packets. Not present for
         * PARTNER_PROVIDER.
         */
        adminEnabled?: boolean;
        /**
         * Provisioned bandwidth capacity for the interconnectAttachment. Can be set
         * by the partner to update the customer&#39;s provisioned bandwidth. Output
         * only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED.
         */
        bandwidth?: string;
        /**
         * Up to 16 candidate prefixes that can be used to restrict the allocation
         * of cloudRouterIpAddress and customerRouterIpAddress for this attachment.
         * All prefixes must be within link-local address space (169.254.0.0/16) and
         * must be /29 or shorter (/28, /27, etc). Google will attempt to select an
         * unused /29 from the supplied candidate prefix(es). The request will fail
         * if all possible /29s are in use on Google?s edge. If not supplied, Google
         * will randomly select an unused /29 from all of link-local space.
         */
        candidateSubnets?: string[];
        /**
         * [Output Only] IPv4 address + prefix length to be configured on Cloud
         * Router Interface for this interconnect attachment.
         */
        cloudRouterIpAddress?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] IPv4 address + prefix length to be configured on the
         * customer router subinterface for this interconnect attachment.
         */
        customerRouterIpAddress?: string;
        /**
         * An optional description of this resource.
         */
        description?: string;
        /**
         * Desired availability domain for the attachment. Only available for type
         * PARTNER, at creation time. For improved reliability, customers should
         * configure a pair of attachments with one per availability domain. The
         * selected availability domain will be provided to the Partner via the
         * pairing key so that the provisioned circuit will lie in the specified
         * domain. If not specified, the value will default to
         * AVAILABILITY_DOMAIN_ANY.
         */
        edgeAvailabilityDomain?: string;
        /**
         * [Output Only] Google reference ID, to be used when raising support
         * tickets with Google or otherwise to debug backend connectivity issues.
         */
        googleReferenceId?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * URL of the underlying Interconnect object that this attachment&#39;s
         * traffic will traverse through.
         */
        interconnect?: string;
        /**
         * [Output Only] Type of the resource. Always compute#interconnectAttachment
         * for interconnect attachments.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] The current status of whether or not this interconnect
         * attachment is functional.
         */
        operationalStatus?: string;
        /**
         * [Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not
         * present for DEDICATED]. The opaque identifier of an PARTNER attachment
         * used to initiate provisioning with a selected partner. Of the form
         * &quot;XXXXX/region/domain&quot;
         */
        pairingKey?: string;
        /**
         * Optional BGP ASN for the router that should be supplied by a layer 3
         * Partner if they configured BGP on behalf of the customer. Output only for
         * PARTNER type, input only for PARTNER_PROVIDER, not available for
         * DEDICATED.
         */
        partnerAsn?: string;
        /**
         * Informational metadata about Partner attachments from Partners to display
         * to customers. Output only for for PARTNER type, mutable for
         * PARTNER_PROVIDER, not available for DEDICATED.
         */
        partnerMetadata?: Schema$InterconnectAttachmentPartnerMetadata;
        /**
         * [Output Only] Information specific to an InterconnectAttachment. This
         * property is populated if the interconnect that this is attached to is of
         * type DEDICATED.
         */
        privateInterconnectInfo?: Schema$InterconnectAttachmentPrivateInfo;
        /**
         * [Output Only] URL of the region where the regional interconnect
         * attachment resides. You must specify this field as part of the HTTP
         * request URL. It is not settable as a field in the request body.
         */
        region?: string;
        /**
         * URL of the Cloud Router to be used for dynamic routing. This router must
         * be in the same region as this InterconnectAttachment. The
         * InterconnectAttachment will automatically connect the Interconnect to the
         * network &amp; region within which the Cloud Router is configured.
         */
        router?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The current state of this attachment&#39;s functionality.
         */
        state?: string;
        type?: string;
        /**
         * The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4094. Only
         * specified at creation time.
         */
        vlanTag8021q?: number;
    }
    interface Schema$InterconnectAttachmentAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InterconnectAttachmentsScopedList resources.
         */
        items?: {
            [key: string]: Schema$InterconnectAttachmentsScopedList;
        };
        /**
         * [Output Only] Type of resource. Always
         * compute#interconnectAttachmentAggregatedList for aggregated lists of
         * interconnect attachments.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Response to the list request, and contains a list of interconnect
     * attachments.
     */
    interface Schema$InterconnectAttachmentList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InterconnectAttachment resources.
         */
        items?: Schema$InterconnectAttachment[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectAttachmentList
         * for lists of interconnect attachments.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Informational metadata about Partner attachments from Partners to display
     * to customers. These fields are propagated from PARTNER_PROVIDER attachments
     * to their corresponding PARTNER attachments.
     */
    interface Schema$InterconnectAttachmentPartnerMetadata {
        /**
         * Plain text name of the Interconnect this attachment is connected to, as
         * displayed in the Partner?s portal. For instance &quot;Chicago 1&quot;.
         * This value may be validated to match approved Partner values.
         */
        interconnectName?: string;
        /**
         * Plain text name of the Partner providing this attachment. This value may
         * be validated to match approved Partner values.
         */
        partnerName?: string;
        /**
         * URL of the Partner?s portal for this Attachment. Partners may customise
         * this to be a deep-link to the specific resource on the Partner portal.
         * This value may be validated to match approved Partner values.
         */
        portalUrl?: string;
    }
    /**
     * Information for an interconnect attachment when this belongs to an
     * interconnect of type DEDICATED.
     */
    interface Schema$InterconnectAttachmentPrivateInfo {
        /**
         * [Output Only] 802.1q encapsulation tag to be used for traffic between
         * Google and the customer, going to and from this network and region.
         */
        tag8021q?: number;
    }
    interface Schema$InterconnectAttachmentsScopedList {
        /**
         * A list of interconnect attachments contained in this scope.
         */
        interconnectAttachments?: Schema$InterconnectAttachment[];
        /**
         * Informational warning which replaces the list of addresses when the list
         * is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Describes a single physical circuit between the Customer and Google.
     * CircuitInfo objects are created by Google, so all fields are output only.
     * Next id: 4
     */
    interface Schema$InterconnectCircuitInfo {
        /**
         * Customer-side demarc ID for this circuit.
         */
        customerDemarcId?: string;
        /**
         * Google-assigned unique ID for this circuit. Assigned at circuit turn-up.
         */
        googleCircuitId?: string;
        /**
         * Google-side demarc ID for this circuit. Assigned at circuit turn-up and
         * provided by Google to the customer in the LOA.
         */
        googleDemarcId?: string;
    }
    /**
     * Diagnostics information about interconnect, contains detailed and current
     * technical information about Google?s side of the connection.
     */
    interface Schema$InterconnectDiagnostics {
        /**
         * A list of InterconnectDiagnostics.ARPEntry objects, describing individual
         * neighbors currently seen by the Google router in the ARP cache for the
         * Interconnect. This will be empty when the Interconnect is not bundled.
         */
        arpCaches?: Schema$InterconnectDiagnosticsARPEntry[];
        /**
         * A list of InterconnectDiagnostics.LinkStatus objects, describing the
         * status for each link on the Interconnect.
         */
        links?: Schema$InterconnectDiagnosticsLinkStatus[];
        /**
         * The MAC address of the Interconnect&#39;s bundle interface.
         */
        macAddress?: string;
    }
    /**
     * Describing the ARP neighbor entries seen on this link
     */
    interface Schema$InterconnectDiagnosticsARPEntry {
        /**
         * The IP address of this ARP neighbor.
         */
        ipAddress?: string;
        /**
         * The MAC address of this ARP neighbor.
         */
        macAddress?: string;
    }
    interface Schema$InterconnectDiagnosticsLinkLACPStatus {
        /**
         * System ID of the port on Google?s side of the LACP exchange.
         */
        googleSystemId?: string;
        /**
         * System ID of the port on the neighbor?s side of the LACP exchange.
         */
        neighborSystemId?: string;
        state?: string;
    }
    interface Schema$InterconnectDiagnosticsLinkOpticalPower {
        /**
         * The status of the current value when compared to the warning and alarm
         * levels for the receiving or transmitting transceiver. Possible states
         * include:   - OK: The value has not crossed a warning threshold.  -
         * LOW_WARNING: The value has crossed below the low warning threshold.  -
         * HIGH_WARNING: The value has crossed above the high warning threshold.  -
         * LOW_ALARM: The value has crossed below the low alarm threshold.  -
         * HIGH_ALARM: The value has crossed above the high alarm threshold.
         */
        state?: string;
        /**
         * Value of the current receiving or transmitting optical power, read in
         * dBm. Take a known good optical value, give it a 10% margin and trigger
         * warnings relative to that value. In general, a -7dBm warning and a -11dBm
         * alarm are good optical value estimates for most links.
         */
        value?: number;
    }
    interface Schema$InterconnectDiagnosticsLinkStatus {
        /**
         * A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP
         * neighbor entries seen on this link. This will be empty if the link is
         * bundled
         */
        arpCaches?: Schema$InterconnectDiagnosticsARPEntry[];
        /**
         * The unique ID for this link assigned during turn up by Google.
         */
        circuitId?: string;
        /**
         * The Demarc address assigned by Google and provided in the LoA.
         */
        googleDemarc?: string;
        lacpStatus?: Schema$InterconnectDiagnosticsLinkLACPStatus;
        /**
         * An InterconnectDiagnostics.LinkOpticalPower object, describing the
         * current value and status of the received light level.
         */
        receivingOpticalPower?: Schema$InterconnectDiagnosticsLinkOpticalPower;
        /**
         * An InterconnectDiagnostics.LinkOpticalPower object, describing the
         * current value and status of the transmitted light level.
         */
        transmittingOpticalPower?: Schema$InterconnectDiagnosticsLinkOpticalPower;
    }
    /**
     * Response to the list request, and contains a list of interconnects.
     */
    interface Schema$InterconnectList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Interconnect resources.
         */
        items?: Schema$Interconnect[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectList for lists
         * of interconnects.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Represents an InterconnectLocations resource. The InterconnectLocations
     * resource describes the locations where you can connect to Google&#39;s
     * networks. For more information, see  Colocation Facilities.
     */
    interface Schema$InterconnectLocation {
        /**
         * [Output Only] The postal address of the Point of Presence, each line in
         * the address is separated by a newline character.
         */
        address?: string;
        /**
         * [Output Only] Availability zone for this InterconnectLocation. Within a
         * metropolitan area (metro), maintenance will not be simultaneously
         * scheduled in more than one availability zone. Example: &quot;zone1&quot;
         * or &quot;zone2&quot;.
         */
        availabilityZone?: string;
        /**
         * [Output Only] Metropolitan area designator that indicates which city an
         * interconnect is located. For example: &quot;Chicago, IL&quot;,
         * &quot;Amsterdam, Netherlands&quot;.
         */
        city?: string;
        /**
         * [Output Only] Continent for this location.
         */
        continent?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] An optional description of the resource.
         */
        description?: string;
        /**
         * [Output Only] The name of the provider for this facility (e.g., EQUINIX).
         */
        facilityProvider?: string;
        /**
         * [Output Only] A provider-assigned Identifier for this facility (e.g.,
         * Ashburn-DC1).
         */
        facilityProviderFacilityId?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#interconnectLocation
         * for interconnect locations.
         */
        kind?: string;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] The peeringdb identifier for this facility (corresponding
         * with a netfac type in peeringdb).
         */
        peeringdbFacilityId?: string;
        /**
         * [Output Only] A list of InterconnectLocation.RegionInfo objects, that
         * describe parameters pertaining to the relation between this
         * InterconnectLocation and various Google Cloud regions.
         */
        regionInfos?: Schema$InterconnectLocationRegionInfo[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The status of this InterconnectLocation. If the status is
         * AVAILABLE, new Interconnects may be provisioned in this
         * InterconnectLocation. Otherwise, no new Interconnects may be provisioned.
         */
        status?: string;
    }
    /**
     * Response to the list request, and contains a list of interconnect
     * locations.
     */
    interface Schema$InterconnectLocationList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InterconnectLocation resources.
         */
        items?: Schema$InterconnectLocation[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectLocationList
         * for lists of interconnect locations.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Information about any potential InterconnectAttachments between an
     * Interconnect at a specific InterconnectLocation, and a specific Cloud
     * Region.
     */
    interface Schema$InterconnectLocationRegionInfo {
        /**
         * Expected round-trip time in milliseconds, from this InterconnectLocation
         * to a VM in this region.
         */
        expectedRttMs?: string;
        /**
         * Identifies the network presence of this location.
         */
        locationPresence?: string;
        /**
         * URL for the region of this location.
         */
        region?: string;
    }
    /**
     * Description of a planned outage on this Interconnect. Next id: 9
     */
    interface Schema$InterconnectOutageNotification {
        /**
         * If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs
         * that will be affected.
         */
        affectedCircuits?: string[];
        /**
         * A description about the purpose of the outage.
         */
        description?: string;
        /**
         * Scheduled end time for the outage (milliseconds since Unix epoch).
         */
        endTime?: string;
        /**
         * Form this outage is expected to take. Note that the &quot;IT_&quot;
         * versions of this enum have been deprecated in favor of the unprefixed
         * values.
         */
        issueType?: string;
        /**
         * Unique identifier for this outage notification.
         */
        name?: string;
        /**
         * The party that generated this notification. Note that
         * &quot;NSRC_GOOGLE&quot; has been deprecated in favor of
         * &quot;GOOGLE&quot;
         */
        source?: string;
        /**
         * Scheduled start time for the outage (milliseconds since Unix epoch).
         */
        startTime?: string;
        /**
         * State of this notification. Note that the &quot;NS_&quot; versions of
         * this enum have been deprecated in favor of the unprefixed values.
         */
        state?: string;
    }
    /**
     * Response for the InterconnectsGetDiagnosticsRequest.
     */
    interface Schema$InterconnectsGetDiagnosticsResponse {
        result?: Schema$InterconnectDiagnostics;
    }
    /**
     * A license resource.
     */
    interface Schema$License {
        /**
         * [Output Only] Deprecated. This field no longer reflects whether a license
         * charges a usage fee.
         */
        chargesUseFee?: boolean;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional textual description of the resource; provided by the client
         * when the resource is created.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#license for licenses.
         */
        kind?: string;
        /**
         * [Output Only] The unique code used to attach this license to images,
         * snapshots, and disks.
         */
        licenseCode?: string;
        /**
         * Name of the resource. The name must be 1-63 characters long and comply
         * with RFC1035.
         */
        name?: string;
        resourceRequirements?: Schema$LicenseResourceRequirements;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * If false, licenses will not be copied from the source resource when
         * creating an image from a disk, disk from snapshot, or snapshot from disk.
         */
        transferable?: boolean;
    }
    interface Schema$LicenseCode {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] Description of this License Code.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#licenseCode for licenses.
         */
        kind?: string;
        /**
         * [Output Only] URL and description aliases of Licenses with the same
         * License Code.
         */
        licenseAlias?: Schema$LicenseCodeLicenseAlias[];
        /**
         * [Output Only] Name of the resource. The name is 1-20 characters long and
         * must be a valid 64 bit integer.
         */
        name?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Current state of this License Code.
         */
        state?: string;
        /**
         * [Output Only] If true, the license will remain attached when creating
         * images or snapshots from disks. Otherwise, the license is not
         * transferred.
         */
        transferable?: boolean;
    }
    interface Schema$LicenseCodeLicenseAlias {
        /**
         * [Output Only] Description of this License Code.
         */
        description?: string;
        /**
         * [Output Only] URL of license corresponding to this License Code.
         */
        selfLink?: string;
    }
    interface Schema$LicenseResourceRequirements {
        /**
         * Minimum number of guest cpus required to use the Instance. Enforced at
         * Instance creation and Instance start.
         */
        minGuestCpuCount?: number;
        /**
         * Minimum memory required to use the Instance. Enforced at Instance
         * creation and Instance start.
         */
        minMemoryMb?: number;
    }
    interface Schema$LicensesListResponse {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of License resources.
         */
        items?: Schema$License[];
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Specifies what kind of log the caller must write
     */
    interface Schema$LogConfig {
        /**
         * Cloud audit options.
         */
        cloudAudit?: Schema$LogConfigCloudAuditOptions;
        /**
         * Counter options.
         */
        counter?: Schema$LogConfigCounterOptions;
        /**
         * Data access options.
         */
        dataAccess?: Schema$LogConfigDataAccessOptions;
    }
    /**
     * Write a Cloud Audit log
     */
    interface Schema$LogConfigCloudAuditOptions {
        /**
         * Information used by the Cloud Audit Logging pipeline.
         */
        authorizationLoggingOptions?: Schema$AuthorizationLoggingOptions;
        /**
         * The log_name to populate in the Cloud Audit Record.
         */
        logName?: string;
    }
    /**
     * Increment a streamz counter with the specified metric and field names.
     * Metric names should start with a &#39;/&#39;, generally be lowercase-only,
     * and end in &quot;_count&quot;. Field names should not contain an initial
     * slash. The actual exported metric names will have &quot;/iam/policy&quot;
     * prepended.  Field names correspond to IAM request parameters and field
     * values are their respective values.  Supported field names: -
     * &quot;authority&quot;, which is &quot;[token]&quot; if IAMContext.token is
     * present, otherwise the value of IAMContext.authority_selector if present,
     * and otherwise a representation of IAMContext.principal; or -
     * &quot;iam_principal&quot;, a representation of IAMContext.principal even if
     * a token or authority selector is present; or - &quot;&quot; (empty string),
     * resulting in a counter with no fields.  Examples: counter { metric:
     * &quot;/debug_access_count&quot; field: &quot;iam_principal&quot; } ==&gt;
     * increment counter /iam/policy/backend_debug_access_count
     * {iam_principal=[value of IAMContext.principal]}  At this time we do not
     * support multiple field names (though this may be supported in the future).
     */
    interface Schema$LogConfigCounterOptions {
        /**
         * The field value to attribute.
         */
        field?: string;
        /**
         * The metric to update.
         */
        metric?: string;
    }
    /**
     * Write a Data Access (Gin) log
     */
    interface Schema$LogConfigDataAccessOptions {
        /**
         * Whether Gin logging should happen in a fail-closed manner at the caller.
         * This is relevant only in the LocalIAM implementation, for now.  NOTE:
         * Logging to Gin in a fail-closed manner is currently unsupported while
         * work is being done to satisfy the requirements of go/345. Currently,
         * setting LOG_FAIL_CLOSED mode will have no effect, but still exists
         * because there is active work being done to support it (b/115874152).
         */
        logMode?: string;
    }
    /**
     * A Machine Type resource. (== resource_for v1.machineTypes ==) (==
     * resource_for beta.machineTypes ==)
     */
    interface Schema$MachineType {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] The deprecation status associated with this machine type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional textual description of the resource.
         */
        description?: string;
        /**
         * [Output Only] The number of virtual CPUs that are available to the
         * instance.
         */
        guestCpus?: number;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Deprecated] This property is deprecated and will never be populated with
         * any relevant values.
         */
        imageSpaceGb?: number;
        /**
         * [Output Only] Whether this machine type has a shared CPU. See Shared-core
         * machine types for more information.
         */
        isSharedCpu?: boolean;
        /**
         * [Output Only] The type of the resource. Always compute#machineType for
         * machine types.
         */
        kind?: string;
        /**
         * [Output Only] Maximum persistent disks allowed.
         */
        maximumPersistentDisks?: number;
        /**
         * [Output Only] Maximum total persistent disks size (GB) allowed.
         */
        maximumPersistentDisksSizeGb?: string;
        /**
         * [Output Only] The amount of physical memory available to the instance,
         * defined in MB.
         */
        memoryMb?: number;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] A list of extended scratch disks assigned to the instance.
         */
        scratchDisks?: Array<{
            diskGb?: number;
        }>;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The name of the zone where the machine type resides, such
         * as us-central1-a.
         */
        zone?: string;
    }
    interface Schema$MachineTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of MachineTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$MachineTypesScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#machineTypeAggregatedList
         * for aggregated lists of machine types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of machine types.
     */
    interface Schema$MachineTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of MachineType resources.
         */
        items?: Schema$MachineType[];
        /**
         * [Output Only] Type of resource. Always compute#machineTypeList for lists
         * of machine types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$MachineTypesScopedList {
        /**
         * [Output Only] A list of machine types contained in this scope.
         */
        machineTypes?: Schema$MachineType[];
        /**
         * [Output Only] An informational warning that appears when the machine
         * types list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A Managed Instance resource.
     */
    interface Schema$ManagedInstance {
        /**
         * [Output Only] The current action that the managed instance group has
         * scheduled for the instance. Possible values:  - NONE The instance is
         * running, and the managed instance group does not have any scheduled
         * actions for this instance.  - CREATING The managed instance group is
         * creating this instance. If the group fails to create this instance, it
         * will try again until it is successful.  - CREATING_WITHOUT_RETRIES The
         * managed instance group is attempting to create this instance only once.
         * If the group fails to create this instance, it does not try again and the
         * group&#39;s targetSize value is decreased instead.  - RECREATING The
         * managed instance group is recreating this instance.  - DELETING The
         * managed instance group is permanently deleting this instance.  -
         * ABANDONING The managed instance group is abandoning this instance. The
         * instance will be removed from the instance group and from any target
         * pools that are associated with this group.  - RESTARTING The managed
         * instance group is restarting the instance.  - REFRESHING The managed
         * instance group is applying configuration changes to the instance without
         * stopping it. For example, the group can update the target pool list for
         * an instance without stopping that instance.  - VERIFYING The managed
         * instance group has created the instance and it is in the process of being
         * verified.
         */
        currentAction?: string;
        /**
         * [Output only] The unique identifier for this resource. This field is
         * empty when instance does not exist.
         */
        id?: string;
        /**
         * [Output Only] The URL of the instance. The URL can exist even if the
         * instance has not yet been created.
         */
        instance?: string;
        /**
         * [Output Only] The status of the instance. This field is empty when the
         * instance does not exist.
         */
        instanceStatus?: string;
        /**
         * [Output Only] Information about the last attempt to create or delete the
         * instance.
         */
        lastAttempt?: Schema$ManagedInstanceLastAttempt;
        /**
         * [Output Only] Intended version of this instance.
         */
        version?: Schema$ManagedInstanceVersion;
    }
    interface Schema$ManagedInstanceLastAttempt {
        /**
         * [Output Only] Encountered errors during the last attempt to create or
         * delete the instance.
         */
        errors?: {
            errors?: Array<{
                code?: string;
                location?: string;
                message?: string;
            }>;
        };
    }
    interface Schema$ManagedInstanceVersion {
        /**
         * [Output Only] The intended template of the instance. This field is empty
         * when current_action is one of { DELETING, ABANDONING }.
         */
        instanceTemplate?: string;
        /**
         * [Output Only] Name of the version.
         */
        name?: string;
    }
    /**
     * A metadata key/value entry.
     */
    interface Schema$Metadata {
        /**
         * Specifies a fingerprint for this request, which is essentially a hash of
         * the metadata&#39;s contents and used for optimistic locking. The
         * fingerprint is initially generated by Compute Engine and changes after
         * every request to modify or update metadata. You must always provide an
         * up-to-date fingerprint hash in order to update or change metadata,
         * otherwise the request will fail with error 412 conditionNotMet.  To see
         * the latest fingerprint, make a get() request to retrieve the resource.
         */
        fingerprint?: string;
        /**
         * Array of key/value pairs. The total size of all keys and values must be
         * less than 512 KB.
         */
        items?: Array<{
            key?: string;
            value?: string;
        }>;
        /**
         * [Output Only] Type of the resource. Always compute#metadata for metadata.
         */
        kind?: string;
    }
    /**
     * The named port. For example: .
     */
    interface Schema$NamedPort {
        /**
         * The name for this named port. The name must be 1-63 characters long, and
         * comply with RFC1035.
         */
        name?: string;
        /**
         * The port number, which can be a value between 1 and 65535.
         */
        port?: number;
    }
    /**
     * Represents a Network resource. Read Virtual Private Cloud (VPC) Network
     * Overview for more information. (== resource_for v1.networks ==) (==
     * resource_for beta.networks ==)
     */
    interface Schema$Network {
        /**
         * When set to true, the VPC network is created in &quot;auto&quot; mode.
         * When set to false, the VPC network is created in &quot;custom&quot; mode.
         * An auto mode VPC network starts with one subnet per region. Each subnet
         * has a predetermined range as described in Auto mode VPC network IP
         * ranges.
         */
        autoCreateSubnetworks?: boolean;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The gateway address for default routing out of the network.
         * This value is read only and is selected by GCP.
         */
        gatewayIPv4?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * Deprecated in favor of subnet mode networks. The range of internal
         * addresses that are legal on this network. This range is a CIDR
         * specification, for example: 192.168.0.0/16. Provided by the client when
         * the network is created.
         */
        IPv4Range?: string;
        /**
         * [Output Only] Type of the resource. Always compute#network for networks.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] A list of network peerings for the resource.
         */
        peerings?: Schema$NetworkPeering[];
        /**
         * The network-level routing configuration for this network. Used by Cloud
         * Router to determine what type of network-wide routing behavior to
         * enforce.
         */
        routingConfig?: Schema$NetworkRoutingConfig;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Server-defined fully-qualified URLs for all subnetworks in
         * this VPC network.
         */
        subnetworks?: string[];
    }
    /**
     * The network endpoint.
     */
    interface Schema$NetworkEndpoint {
        /**
         * The name for a specific VM instance that the IP address belongs to. This
         * is required for network endpoints of type GCE_VM_IP_PORT. The instance
         * must be in the same zone of network endpoint group.  The name must be
         * 1-63 characters long, and comply with RFC1035.
         */
        instance?: string;
        /**
         * Optional IPv4 address of network endpoint. The IP address must belong to
         * a VM in GCE (either the primary IP or as part of an aliased IP range). If
         * the IP address is not specified, then the primary IP address for the VM
         * instance in the network that the network endpoint group belongs to will
         * be used.
         */
        ipAddress?: string;
        /**
         * Optional port number of network endpoint. If not specified and the
         * NetworkEndpointGroup.network_endpoint_type is GCE_IP_PORT, the
         * defaultPort for the network endpoint group will be used.
         */
        port?: number;
    }
    /**
     * Represents a collection of network endpoints.
     */
    interface Schema$NetworkEndpointGroup {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * The default port used if the port number is not specified in the network
         * endpoint.
         */
        defaultPort?: number;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#networkEndpointGroup
         * for network endpoint group.
         */
        kind?: string;
        /**
         * Name of the resource; provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The URL of the network to which all network endpoints in the NEG belong.
         * Uses &quot;default&quot; project network if unspecified.
         */
        network?: string;
        /**
         * Type of network endpoints in this network endpoint group. Currently the
         * only supported value is GCE_VM_IP_PORT.
         */
        networkEndpointType?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output only] Number of network endpoints in the network endpoint group.
         */
        size?: number;
        /**
         * Optional URL of the subnetwork to which all network endpoints in the NEG
         * belong.
         */
        subnetwork?: string;
        /**
         * [Output Only] The URL of the zone where the network endpoint group is
         * located.
         */
        zone?: string;
    }
    interface Schema$NetworkEndpointGroupAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NetworkEndpointGroupsScopedList resources.
         */
        items?: {
            [key: string]: Schema$NetworkEndpointGroupsScopedList;
        };
        /**
         * [Output Only] The resource type, which is always
         * compute#networkEndpointGroupAggregatedList for aggregated lists of
         * network endpoint groups.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NetworkEndpointGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NetworkEndpointGroup resources.
         */
        items?: Schema$NetworkEndpointGroup[];
        /**
         * [Output Only] The resource type, which is always
         * compute#networkEndpointGroupList for network endpoint group lists.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NetworkEndpointGroupsAttachEndpointsRequest {
        /**
         * The list of network endpoints to be attached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    interface Schema$NetworkEndpointGroupsDetachEndpointsRequest {
        /**
         * The list of network endpoints to be detached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    interface Schema$NetworkEndpointGroupsListEndpointsRequest {
        /**
         * Optional query parameter for showing the health status of each network
         * endpoint. Valid options are SKIP or SHOW. If you don&#39;t specifiy this
         * parameter, the health status of network endpoints will not be provided.
         */
        healthStatus?: string;
    }
    interface Schema$NetworkEndpointGroupsListNetworkEndpoints {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NetworkEndpointWithHealthStatus resources.
         */
        items?: Schema$NetworkEndpointWithHealthStatus[];
        /**
         * [Output Only] The resource type, which is always
         * compute#networkEndpointGroupsListNetworkEndpoints for the list of network
         * endpoints in the specified network endpoint group.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NetworkEndpointGroupsScopedList {
        /**
         * [Output Only] The list of network endpoint groups that are contained in
         * this scope.
         */
        networkEndpointGroups?: Schema$NetworkEndpointGroup[];
        /**
         * [Output Only] An informational warning that replaces the list of network
         * endpoint groups when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NetworkEndpointWithHealthStatus {
        /**
         * [Output only] The health status of network endpoint;
         */
        healths?: Schema$HealthStatusForNetworkEndpoint[];
        /**
         * [Output only] The network endpoint;
         */
        networkEndpoint?: Schema$NetworkEndpoint;
    }
    /**
     * A network interface resource attached to an instance.
     */
    interface Schema$NetworkInterface {
        /**
         * An array of configurations for this interface. Currently, only one access
         * config, ONE_TO_ONE_NAT, is supported. If there are no accessConfigs
         * specified, then this instance will have no external internet access.
         */
        accessConfigs?: Schema$AccessConfig[];
        /**
         * An array of alias IP ranges for this network interface. Can only be
         * specified for network interfaces on subnet-mode networks.
         */
        aliasIpRanges?: Schema$AliasIpRange[];
        /**
         * Fingerprint hash of contents stored in this network interface. This field
         * will be ignored when inserting an Instance or adding a NetworkInterface.
         * An up-to-date fingerprint must be provided in order to update the
         * NetworkInterface, otherwise the request will fail with error 412
         * conditionNotMet.
         */
        fingerprint?: string;
        /**
         * [Output Only] Type of the resource. Always compute#networkInterface for
         * network interfaces.
         */
        kind?: string;
        /**
         * [Output Only] The name of the network interface, generated by the server.
         * For network devices, these are eth0, eth1, etc.
         */
        name?: string;
        /**
         * URL of the network resource for this instance. When creating an instance,
         * if neither the network nor the subnetwork is specified, the default
         * network global/networks/default is used; if the network is not specified
         * but the subnetwork is specified, the network is inferred.  This field is
         * optional when creating a firewall rule. If not specified when creating a
         * firewall rule, the default network global/networks/default is used.  If
         * you specify this property, you can specify the network as a full or
         * partial URL. For example, the following are all valid URLs:   -
         * https://www.googleapis.com/compute/v1/projects/project/global/networks/network
         * - projects/project/global/networks/network  - global/networks/default
         */
        network?: string;
        /**
         * An IPv4 internal network address to assign to the instance for this
         * network interface. If not specified by the user, an unused internal IP is
         * assigned by the system.
         */
        networkIP?: string;
        /**
         * The URL of the Subnetwork resource for this instance. If the network
         * resource is in legacy mode, do not provide this property. If the network
         * is in auto subnet mode, providing the subnetwork is optional. If the
         * network is in custom subnet mode, then this field should be specified. If
         * you specify this property, you can specify the subnetwork as a full or
         * partial URL. For example, the following are all valid URLs:   -
         * https://www.googleapis.com/compute/v1/projects/project/regions/region/subnetworks/subnetwork
         * - regions/region/subnetworks/subnetwork
         */
        subnetwork?: string;
    }
    /**
     * Contains a list of networks.
     */
    interface Schema$NetworkList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Network resources.
         */
        items?: Schema$Network[];
        /**
         * [Output Only] Type of resource. Always compute#networkList for lists of
         * networks.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A network peering attached to a network resource. The message includes the
     * peering name, peer network, peering state, and a flag indicating whether
     * Google Compute Engine should automatically create routes for the peering.
     */
    interface Schema$NetworkPeering {
        /**
         * This field will be deprecated soon. Prefer using exchange_subnet_routes
         * instead. Indicates whether full mesh connectivity is created and managed
         * automatically. When it is set to true, Google Compute Engine will
         * automatically create and manage the routes between two networks when the
         * state is ACTIVE. Otherwise, user needs to create routes manually to route
         * packets to peer network.
         */
        autoCreateRoutes?: boolean;
        /**
         * Whether full mesh connectivity is created and managed automatically. When
         * it is set to true, Google Compute Engine will automatically create and
         * manage the routes between two networks when the peering state is ACTIVE.
         * Otherwise, user needs to create routes manually to route packets to peer
         * network.
         */
        exchangeSubnetRoutes?: boolean;
        /**
         * Name of this peering. Provided by the client when the peering is created.
         * The name must comply with RFC1035. Specifically, the name must be 1-63
         * characters long and match regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`
         * which means the first character must be a lowercase letter, and all the
         * following characters must be a dash, lowercase letter, or digit, except
         * the last character, which cannot be a dash.
         */
        name?: string;
        /**
         * The URL of the peer network. It can be either full URL or partial URL.
         * The peer network may belong to a different project. If the partial URL
         * does not contain project, it is assumed that the peer network is in the
         * same project as the current network.
         */
        network?: string;
        /**
         * [Output Only] State for the peering.
         */
        state?: string;
        /**
         * [Output Only] Details about the current state of the peering.
         */
        stateDetails?: string;
    }
    /**
     * A routing configuration attached to a network resource. The message
     * includes the list of routers associated with the network, and a flag
     * indicating the type of routing behavior to enforce network-wide.
     */
    interface Schema$NetworkRoutingConfig {
        /**
         * The network-wide routing mode to use. If set to REGIONAL, this
         * network&#39;s cloud routers will only advertise routes with subnets of
         * this network in the same region as the router. If set to GLOBAL, this
         * network&#39;s cloud routers will advertise routes with all subnets of
         * this network, across regions.
         */
        routingMode?: string;
    }
    interface Schema$NetworksAddPeeringRequest {
        /**
         * This field will be deprecated soon. Prefer using exchange_subnet_routes
         * in network_peering instead. Whether Google Compute Engine manages the
         * routes automatically.
         */
        autoCreateRoutes?: boolean;
        /**
         * Name of the peering, which should conform to RFC1035.
         */
        name?: string;
        /**
         * Network peering parameters. In order to specify route policies for
         * peering using import/export custom routes, you will have to fill all
         * peering related parameters (name, peer network, exchange_subnet_routes)
         * in network_peeringfield. Corresponding fields in
         * NetworksAddPeeringRequest will be deprecated soon.
         */
        networkPeering?: Schema$NetworkPeering;
        /**
         * URL of the peer network. It can be either full URL or partial URL. The
         * peer network may belong to a different project. If the partial URL does
         * not contain project, it is assumed that the peer network is in the same
         * project as the current network.
         */
        peerNetwork?: string;
    }
    interface Schema$NetworksRemovePeeringRequest {
        /**
         * Name of the peering, which should conform to RFC1035.
         */
        name?: string;
    }
    /**
     * A NodeGroup resource. (== resource_for beta.nodeGroups ==) (== resource_for
     * v1.nodeGroups ==)
     */
    interface Schema$NodeGroup {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] The type of the resource. Always compute#nodeGroup for node
         * group.
         */
        kind?: string;
        /**
         * The name of the resource, provided by the client when initially creating
         * the resource. The resource name must be 1-63 characters long, and comply
         * with RFC1035. Specifically, the name must be 1-63 characters long and
         * match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
         * first character must be a lowercase letter, and all following characters
         * must be a dash, lowercase letter, or digit, except the last character,
         * which cannot be a dash.
         */
        name?: string;
        /**
         * The URL of the node template to which this node group belongs.
         */
        nodeTemplate?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The total number of nodes in the node group.
         */
        size?: number;
        status?: string;
        /**
         * [Output Only] The name of the zone where the node group resides, such as
         * us-central1-a.
         */
        zone?: string;
    }
    interface Schema$NodeGroupAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NodeGroupsScopedList resources.
         */
        items?: {
            [key: string]: Schema$NodeGroupsScopedList;
        };
        /**
         * [Output Only] Type of resource.Always compute#nodeGroupAggregatedList for
         * aggregated lists of node groups.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of nodeGroups.
     */
    interface Schema$NodeGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NodeGroup resources.
         */
        items?: Schema$NodeGroup[];
        /**
         * [Output Only] Type of resource.Always compute#nodeGroupList for lists of
         * node groups.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NodeGroupNode {
        /**
         * Instances scheduled on this node.
         */
        instances?: string[];
        /**
         * The name of the node.
         */
        name?: string;
        /**
         * The type of this node.
         */
        nodeType?: string;
        status?: string;
    }
    interface Schema$NodeGroupsAddNodesRequest {
        /**
         * Count of additional nodes to be added to the node group.
         */
        additionalNodeCount?: number;
    }
    interface Schema$NodeGroupsDeleteNodesRequest {
        nodes?: string[];
    }
    interface Schema$NodeGroupsListNodes {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Node resources.
         */
        items?: Schema$NodeGroupNode[];
        /**
         * [Output Only] The resource type, which is always
         * compute.nodeGroupsListNodes for the list of nodes in the specified node
         * group.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NodeGroupsScopedList {
        /**
         * [Output Only] A list of node groups contained in this scope.
         */
        nodeGroups?: Schema$NodeGroup[];
        /**
         * [Output Only] An informational warning that appears when the nodeGroup
         * list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NodeGroupsSetNodeTemplateRequest {
        /**
         * Full or partial URL of the node template resource to be updated for this
         * node group.
         */
        nodeTemplate?: string;
    }
    /**
     * A Node Template resource.
     */
    interface Schema$NodeTemplate {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] The type of the resource. Always compute#nodeTemplate for
         * node templates.
         */
        kind?: string;
        /**
         * The name of the resource, provided by the client when initially creating
         * the resource. The resource name must be 1-63 characters long, and comply
         * with RFC1035. Specifically, the name must be 1-63 characters long and
         * match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
         * first character must be a lowercase letter, and all following characters
         * must be a dash, lowercase letter, or digit, except the last character,
         * which cannot be a dash.
         */
        name?: string;
        /**
         * Labels to use for node affinity, which will be used in instance
         * scheduling.
         */
        nodeAffinityLabels?: {
            [key: string]: string;
        };
        /**
         * The node type to use for nodes group that are created from this template.
         */
        nodeType?: string;
        /**
         * The flexible properties of the desired node type. Node groups that use
         * this node template will create nodes of a type that matches these
         * properties.  This field is mutually exclusive with the node_type
         * property; you can only define one or the other, but not both.
         */
        nodeTypeFlexibility?: Schema$NodeTemplateNodeTypeFlexibility;
        /**
         * [Output Only] The name of the region where the node template resides,
         * such as us-central1.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The status of the node template. One of the following
         * values: CREATING, READY, and DELETING.
         */
        status?: string;
        /**
         * [Output Only] An optional, human-readable explanation of the status.
         */
        statusMessage?: string;
    }
    interface Schema$NodeTemplateAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NodeTemplatesScopedList resources.
         */
        items?: {
            [key: string]: Schema$NodeTemplatesScopedList;
        };
        /**
         * [Output Only] Type of resource.Always compute#nodeTemplateAggregatedList
         * for aggregated lists of node templates.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of node templates.
     */
    interface Schema$NodeTemplateList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NodeTemplate resources.
         */
        items?: Schema$NodeTemplate[];
        /**
         * [Output Only] Type of resource.Always compute#nodeTemplateList for lists
         * of node templates.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NodeTemplateNodeTypeFlexibility {
        cpus?: string;
        localSsd?: string;
        memory?: string;
    }
    interface Schema$NodeTemplatesScopedList {
        /**
         * [Output Only] A list of node templates contained in this scope.
         */
        nodeTemplates?: Schema$NodeTemplate[];
        /**
         * [Output Only] An informational warning that appears when the node
         * templates list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A Node Type resource.
     */
    interface Schema$NodeType {
        /**
         * [Output Only] The CPU platform used by this node type.
         */
        cpuPlatform?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] The deprecation status associated with this node type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional textual description of the resource.
         */
        description?: string;
        /**
         * [Output Only] The number of virtual CPUs that are available to the node
         * type.
         */
        guestCpus?: number;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] The type of the resource. Always compute#nodeType for node
         * types.
         */
        kind?: string;
        /**
         * [Output Only] Local SSD available to the node type, defined in GB.
         */
        localSsdGb?: number;
        /**
         * [Output Only] The amount of physical memory available to the node type,
         * defined in MB.
         */
        memoryMb?: number;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The name of the zone where the node type resides, such as
         * us-central1-a.
         */
        zone?: string;
    }
    interface Schema$NodeTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NodeTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$NodeTypesScopedList;
        };
        /**
         * [Output Only] Type of resource.Always compute#nodeTypeAggregatedList for
         * aggregated lists of node types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of node types.
     */
    interface Schema$NodeTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of NodeType resources.
         */
        items?: Schema$NodeType[];
        /**
         * [Output Only] Type of resource.Always compute#nodeTypeList for lists of
         * node types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$NodeTypesScopedList {
        /**
         * [Output Only] A list of node types contained in this scope.
         */
        nodeTypes?: Schema$NodeType[];
        /**
         * [Output Only] An informational warning that appears when the node types
         * list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * An Operation resource, used to manage asynchronous API requests. (==
     * resource_for v1.globalOperations ==) (== resource_for beta.globalOperations
     * ==) (== resource_for v1.regionOperations ==) (== resource_for
     * beta.regionOperations ==) (== resource_for v1.zoneOperations ==) (==
     * resource_for beta.zoneOperations ==)
     */
    interface Schema$Operation {
        /**
         * [Output Only] The value of `requestId` if you provided it in the request.
         * Not present otherwise.
         */
        clientOperationId?: string;
        /**
         * [Deprecated] This field is deprecated.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] A textual description of the operation, which is set when
         * the operation is created.
         */
        description?: string;
        /**
         * [Output Only] The time that this operation was completed. This value is
         * in RFC3339 text format.
         */
        endTime?: string;
        /**
         * [Output Only] If errors are generated during processing of the operation,
         * this field will be populated.
         */
        error?: {
            errors?: Array<{
                code?: string;
                location?: string;
                message?: string;
            }>;
        };
        /**
         * [Output Only] If the operation fails, this field contains the HTTP error
         * message that was returned, such as NOT FOUND.
         */
        httpErrorMessage?: string;
        /**
         * [Output Only] If the operation fails, this field contains the HTTP error
         * status code that was returned. For example, a 404 means the resource was
         * not found.
         */
        httpErrorStatusCode?: number;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] The time that this operation was requested. This value is
         * in RFC3339 text format.
         */
        insertTime?: string;
        /**
         * [Output Only] Type of the resource. Always compute#operation for
         * Operation resources.
         */
        kind?: string;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] The type of operation, such as insert, update, or delete,
         * and so on.
         */
        operationType?: string;
        /**
         * [Output Only] An optional progress indicator that ranges from 0 to 100.
         * There is no requirement that this be linear or support any granularity of
         * operations. This should not be used to guess when the operation will be
         * complete. This number should monotonically increase as the operation
         * progresses.
         */
        progress?: number;
        /**
         * [Output Only] The URL of the region where the operation resides. Only
         * available when performing regional operations. You must specify this
         * field as part of the HTTP request URL. It is not settable as a field in
         * the request body.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The time that this operation was started by the server.
         * This value is in RFC3339 text format.
         */
        startTime?: string;
        /**
         * [Output Only] The status of the operation, which can be one of the
         * following: PENDING, RUNNING, or DONE.
         */
        status?: string;
        /**
         * [Output Only] An optional textual description of the current status of
         * the operation.
         */
        statusMessage?: string;
        /**
         * [Output Only] The unique target ID, which identifies a specific
         * incarnation of the target resource.
         */
        targetId?: string;
        /**
         * [Output Only] The URL of the resource that the operation modifies. For
         * operations related to creating a snapshot, this points to the persistent
         * disk that the snapshot was created from.
         */
        targetLink?: string;
        /**
         * [Output Only] User who requested the operation, for example:
         * user@example.com.
         */
        user?: string;
        /**
         * [Output Only] If warning messages are generated during processing of the
         * operation, this field will be populated.
         */
        warnings?: Array<{
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        }>;
        /**
         * [Output Only] The URL of the zone where the operation resides. Only
         * available when performing per-zone operations. You must specify this
         * field as part of the HTTP request URL. It is not settable as a field in
         * the request body.
         */
        zone?: string;
    }
    interface Schema$OperationAggregatedList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] A map of scoped operation lists.
         */
        items?: {
            [key: string]: Schema$OperationsScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#operationAggregatedList
         * for aggregated lists of operations.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of Operation resources.
     */
    interface Schema$OperationList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] A list of Operation resources.
         */
        items?: Schema$Operation[];
        /**
         * [Output Only] Type of resource. Always compute#operations for Operations
         * resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$OperationsScopedList {
        /**
         * [Output Only] A list of operations contained in this scope.
         */
        operations?: Schema$Operation[];
        /**
         * [Output Only] Informational warning which replaces the list of operations
         * when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A matcher for the path portion of the URL. The BackendService from the
     * longest-matched rule will serve the URL. If no rule was matched, the
     * default service will be used.
     */
    interface Schema$PathMatcher {
        /**
         * The full or partial URL to the BackendService resource. This will be used
         * if none of the pathRules or routeRules defined by this PathMatcher are
         * matched. For example, the following are all valid URLs to a
         * BackendService resource:   -
         * https://www.googleapis.com/compute/v1/projects/project/global/backendServices/backendService
         * - compute/v1/projects/project/global/backendServices/backendService  -
         * global/backendServices/backendService  If defaultRouteAction is
         * additionally specified, advanced routing actions like URL Rewrites, etc.
         * take effect prior to sending the request to the backend. However, if
         * defaultService is specified, defaultRouteAction cannot contain any
         * weightedBackendServices. Conversely, if defaultRouteAction specifies any
         * weightedBackendServices, defaultService must not be specified. Only one
         * of defaultService, defaultUrlRedirect  or
         * defaultRouteAction.weightedBackendService must be set. Authorization
         * requires one or more of the following Google IAM permissions on the
         * specified resource default_service:   - compute.backendBuckets.use  -
         * compute.backendServices.use
         */
        defaultService?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * The name to which this PathMatcher is referred by the HostRule.
         */
        name?: string;
        /**
         * The list of path rules. Use this list instead of routeRules when routing
         * based on simple path matching is all that&#39;s required. The order by
         * which path rules are specified does not matter. Matches are always done
         * on the longest-path-first basis. For example: a pathRule with a path
         * /a/b/c/* will match before /a/b/* irrespective of the order in which
         * those paths appear in this list. Only one of pathRules or routeRules must
         * be set.
         */
        pathRules?: Schema$PathRule[];
    }
    /**
     * A path-matching rule for a URL. If matched, will use the specified
     * BackendService to handle the traffic arriving at this URL.
     */
    interface Schema$PathRule {
        /**
         * The list of path patterns to match. Each must start with / and the only
         * place a * is allowed is at the end following a /. The string fed to the
         * path matcher does not include any text after the first ? or #, and those
         * chars are not allowed here.
         */
        paths?: string[];
        /**
         * The full or partial URL of the backend service resource to which traffic
         * is directed if this rule is matched. If routeAction is additionally
         * specified, advanced routing actions like URL Rewrites, etc. take effect
         * prior to sending the request to the backend. However, if service is
         * specified, routeAction cannot contain any weightedBackendService s.
         * Conversely, if routeAction specifies any  weightedBackendServices,
         * service must not be specified. Only one of urlRedirect, service or
         * routeAction.weightedBackendService must be set.
         */
        service?: string;
    }
    /**
     * Defines an Identity and Access Management (IAM) policy. It is used to
     * specify access control policies for Cloud Platform resources.    A `Policy`
     * consists of a list of `bindings`. A `binding` binds a list of `members` to
     * a `role`, where the members can be user accounts, Google groups, Google
     * domains, and service accounts. A `role` is a named list of permissions
     * defined by IAM.  **JSON Example**  { &quot;bindings&quot;: [ {
     * &quot;role&quot;: &quot;roles/owner&quot;, &quot;members&quot;: [
     * &quot;user:mike@example.com&quot;, &quot;group:admins@example.com&quot;,
     * &quot;domain:google.com&quot;,
     * &quot;serviceAccount:my-other-app@appspot.gserviceaccount.com&quot; ] }, {
     * &quot;role&quot;: &quot;roles/viewer&quot;, &quot;members&quot;:
     * [&quot;user:sean@example.com&quot;] } ] }  **YAML Example**  bindings: -
     * members: - user:mike@example.com - group:admins@example.com -
     * domain:google.com - serviceAccount:my-other-app@appspot.gserviceaccount.com
     * role: roles/owner - members: - user:sean@example.com role: roles/viewer For
     * a description of IAM and its features, see the [IAM developer&#39;s
     * guide](https://cloud.google.com/iam/docs).
     */
    interface Schema$Policy {
        /**
         * Specifies cloud audit logging configuration for this policy.
         */
        auditConfigs?: Schema$AuditConfig[];
        /**
         * Associates a list of `members` to a `role`. `bindings` with no members
         * will result in an error.
         */
        bindings?: Schema$Binding[];
        /**
         * `etag` is used for optimistic concurrency control as a way to help
         * prevent simultaneous updates of a policy from overwriting each other. It
         * is strongly suggested that systems make use of the `etag` in the
         * read-modify-write cycle to perform policy updates in order to avoid race
         * conditions: An `etag` is returned in the response to `getIamPolicy`, and
         * systems are expected to put that etag in the request to `setIamPolicy` to
         * ensure that their change will be applied to the same version of the
         * policy.  If no `etag` is provided in the call to `setIamPolicy`, then the
         * existing policy is overwritten blindly.
         */
        etag?: string;
        iamOwned?: boolean;
        /**
         * If more than one rule is specified, the rules are applied in the
         * following manner: - All matching LOG rules are always applied. - If any
         * DENY/DENY_WITH_LOG rule matches, permission is denied. Logging will be
         * applied if one or more matching rule requires logging. - Otherwise, if
         * any ALLOW/ALLOW_WITH_LOG rule matches, permission is granted. Logging
         * will be applied if one or more matching rule requires logging. -
         * Otherwise, if no rule applies, permission is denied.
         */
        rules?: Schema$Rule[];
        /**
         * Deprecated.
         */
        version?: number;
    }
    /**
     * A Project resource. For an overview of projects, see  Cloud Platform
     * Resource Hierarchy. (== resource_for v1.projects ==) (== resource_for
     * beta.projects ==)
     */
    interface Schema$Project {
        /**
         * Metadata key/value pairs available to all instances contained in this
         * project. See Custom metadata for more information.
         */
        commonInstanceMetadata?: Schema$Metadata;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * This signifies the default network tier used for configuring resources of
         * the project and can only take the following values: PREMIUM, STANDARD.
         * Initially the default network tier is PREMIUM.
         */
        defaultNetworkTier?: string;
        /**
         * [Output Only] Default service account used by VMs running in this
         * project.
         */
        defaultServiceAccount?: string;
        /**
         * An optional textual description of the resource.
         */
        description?: string;
        /**
         * Restricted features enabled for use on this project.
         */
        enabledFeatures?: string[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server. This is not the project ID, and is just a unique
         * ID used by Compute Engine to identify resources.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#project for projects.
         */
        kind?: string;
        /**
         * The project ID. For example: my-example-project. Use the project ID to
         * make requests to Compute Engine.
         */
        name?: string;
        /**
         * [Output Only] Quotas assigned to this project.
         */
        quotas?: Schema$Quota[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * The naming prefix for daily usage reports and the Google Cloud Storage
         * bucket where they are stored.
         */
        usageExportLocation?: Schema$UsageExportLocation;
        /**
         * [Output Only] The role this project has in a shared VPC configuration.
         * Currently only HOST projects are differentiated.
         */
        xpnProjectStatus?: string;
    }
    interface Schema$ProjectsDisableXpnResourceRequest {
        /**
         * Service resource (a.k.a service project) ID.
         */
        xpnResource?: Schema$XpnResourceId;
    }
    interface Schema$ProjectsEnableXpnResourceRequest {
        /**
         * Service resource (a.k.a service project) ID.
         */
        xpnResource?: Schema$XpnResourceId;
    }
    interface Schema$ProjectsGetXpnResources {
        /**
         * [Output Only] Type of resource. Always compute#projectsGetXpnResources
         * for lists of service resources (a.k.a service projects)
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * Service resources (a.k.a service projects) attached to this project as
         * their shared VPC host.
         */
        resources?: Schema$XpnResourceId[];
    }
    interface Schema$ProjectsListXpnHostsRequest {
        /**
         * Optional organization ID managed by Cloud Resource Manager, for which to
         * list shared VPC host projects. If not specified, the organization will be
         * inferred from the project.
         */
        organization?: string;
    }
    interface Schema$ProjectsSetDefaultNetworkTierRequest {
        /**
         * Default network tier to be set.
         */
        networkTier?: string;
    }
    /**
     * A quotas entry.
     */
    interface Schema$Quota {
        /**
         * [Output Only] Quota limit for this metric.
         */
        limit?: number;
        /**
         * [Output Only] Name of the quota metric.
         */
        metric?: string;
        /**
         * [Output Only] Owning resource. This is the resource on which this quota
         * is applied.
         */
        owner?: string;
        /**
         * [Output Only] Current usage of this metric.
         */
        usage?: number;
    }
    /**
     * Represents a reference to a resource.
     */
    interface Schema$Reference {
        /**
         * [Output Only] Type of the resource. Always compute#reference for
         * references.
         */
        kind?: string;
        /**
         * A description of the reference type with no implied semantics. Possible
         * values include:   - MEMBER_OF
         */
        referenceType?: string;
        /**
         * URL of the resource which refers to the target.
         */
        referrer?: string;
        /**
         * URL of the resource to which this reference points.
         */
        target?: string;
    }
    /**
     * Region resource. (== resource_for beta.regions ==) (== resource_for
     * v1.regions ==)
     */
    interface Schema$Region {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] The deprecation status associated with this region.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] Textual description of the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#region for regions.
         */
        kind?: string;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] Quotas assigned to this region.
         */
        quotas?: Schema$Quota[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Status of the region, either UP or DOWN.
         */
        status?: string;
        /**
         * [Output Only] A list of zones available in this region, in the form of
         * resource URLs.
         */
        zones?: string[];
    }
    /**
     * Contains a list of autoscalers.
     */
    interface Schema$RegionAutoscalerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Autoscaler resources.
         */
        items?: Schema$Autoscaler[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$RegionDisksResizeRequest {
        /**
         * The new size of the regional persistent disk, which is specified in GB.
         */
        sizeGb?: string;
    }
    interface Schema$RegionDiskTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of DiskType resources.
         */
        items?: Schema$DiskType[];
        /**
         * [Output Only] Type of resource. Always compute#regionDiskTypeList for
         * region disk types.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of InstanceGroup resources.
     */
    interface Schema$RegionInstanceGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceGroup resources.
         */
        items?: Schema$InstanceGroup[];
        /**
         * The resource type.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of managed instance groups.
     */
    interface Schema$RegionInstanceGroupManagerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceGroupManager resources.
         */
        items?: Schema$InstanceGroupManager[];
        /**
         * [Output Only] The resource type, which is always
         * compute#instanceGroupManagerList for a list of managed instance groups
         * that exist in th regional scope.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$RegionInstanceGroupManagersAbandonInstancesRequest {
        /**
         * The URLs of one or more instances to abandon. This can be a full URL or a
         * partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[];
    }
    interface Schema$RegionInstanceGroupManagersDeleteInstancesRequest {
        /**
         * The URLs of one or more instances to delete. This can be a full URL or a
         * partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[];
    }
    interface Schema$RegionInstanceGroupManagersListInstancesResponse {
        /**
         * A list of managed instances.
         */
        managedInstances?: Schema$ManagedInstance[];
    }
    interface Schema$RegionInstanceGroupManagersRecreateRequest {
        /**
         * The URLs of one or more instances to recreate. This can be a full URL or
         * a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[];
    }
    interface Schema$RegionInstanceGroupManagersSetTargetPoolsRequest {
        /**
         * Fingerprint of the target pools information, which is a hash of the
         * contents. This field is used for optimistic locking when you update the
         * target pool entries. This field is optional.
         */
        fingerprint?: string;
        /**
         * The URL of all TargetPool resources to which instances in the
         * instanceGroup field are added. The target pools automatically apply to
         * all of the instances in the managed instance group.
         */
        targetPools?: string[];
    }
    interface Schema$RegionInstanceGroupManagersSetTemplateRequest {
        /**
         * URL of the InstanceTemplate resource from which all new instances will be
         * created.
         */
        instanceTemplate?: string;
    }
    interface Schema$RegionInstanceGroupsListInstances {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of InstanceWithNamedPorts resources.
         */
        items?: Schema$InstanceWithNamedPorts[];
        /**
         * The resource type.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$RegionInstanceGroupsListInstancesRequest {
        /**
         * Instances in which state should be returned. Valid options are:
         * &#39;ALL&#39;, &#39;RUNNING&#39;. By default, it lists all instances.
         */
        instanceState?: string;
        /**
         * Name of port user is interested in. It is optional. If it is set, only
         * information about this ports will be returned. If it is not set, all the
         * named ports will be returned. Always lists all instances.
         */
        portName?: string;
    }
    interface Schema$RegionInstanceGroupsSetNamedPortsRequest {
        /**
         * The fingerprint of the named ports information for this instance group.
         * Use this optional property to prevent conflicts when multiple users
         * change the named ports settings concurrently. Obtain the fingerprint with
         * the instanceGroups.get method. Then, include the fingerprint in your
         * request to ensure that you do not overwrite changes that were applied
         * from another concurrent request.
         */
        fingerprint?: string;
        /**
         * The list of named ports to set for this instance group.
         */
        namedPorts?: Schema$NamedPort[];
    }
    /**
     * Contains a list of region resources.
     */
    interface Schema$RegionList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Region resources.
         */
        items?: Schema$Region[];
        /**
         * [Output Only] Type of resource. Always compute#regionList for lists of
         * regions.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$RegionSetLabelsRequest {
        /**
         * The fingerprint of the previous set of labels for this resource, used to
         * detect conflicts. The fingerprint is initially generated by Compute
         * Engine and changes after every request to modify or update labels. You
         * must always provide an up-to-date fingerprint hash in order to update or
         * change labels. Make a get() request to the resource to get the latest
         * fingerprint.
         */
        labelFingerprint?: string;
        /**
         * The labels to set for this resource.
         */
        labels?: {
            [key: string]: string;
        };
    }
    interface Schema$RegionSetPolicyRequest {
        /**
         * Flatten Policy to create a backwacd compatible wire-format. Deprecated.
         * Use &#39;policy&#39; to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated.
         * Use &#39;policy&#39; to specify the etag.
         */
        etag?: string;
        /**
         * REQUIRED: The complete policy to be applied to the &#39;resource&#39;.
         * The size of the policy is limited to a few 10s of KB. An empty policy is
         * in general a valid policy but certain services (like Projects) might
         * reject them.
         */
        policy?: Schema$Policy;
    }
    /**
     * Commitment for a particular resource (a Commitment is composed of one or
     * more of these).
     */
    interface Schema$ResourceCommitment {
        /**
         * The amount of the resource purchased (in a type-dependent unit, such as
         * bytes). For vCPUs, this can just be an integer. For memory, this must be
         * provided in MB. Memory must be a multiple of 256 MB, with up to 6.5GB of
         * memory per every vCPU.
         */
        amount?: string;
        /**
         * Type of resource for which this commitment applies. Possible values are
         * VCPU and MEMORY
         */
        type?: string;
    }
    interface Schema$ResourceGroupReference {
        /**
         * A URI referencing one of the instance groups or network endpoint groups
         * listed in the backend service.
         */
        group?: string;
    }
    /**
     * Represents a Route resource. A route specifies how certain packets should
     * be handled by the network. Routes are associated with instances by tags and
     * the set of routes for a particular instance is called its routing table.
     * For each packet leaving an instance, the system searches that
     * instance&#39;s routing table for a single best matching route. Routes match
     * packets by destination IP address, preferring smaller or more specific
     * ranges over larger ones. If there is a tie, the system selects the route
     * with the smallest priority value. If there is still a tie, it uses the
     * layer three and four packet headers to select just one of the remaining
     * matching routes. The packet is then forwarded as specified by the nextHop
     * field of the winning route - either to another instance destination, an
     * instance gateway, or a Google Compute Engine-operated gateway.  Packets
     * that do not match any route in the sending instance&#39;s routing table are
     * dropped. (== resource_for beta.routes ==) (== resource_for v1.routes ==)
     */
    interface Schema$Route {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * The destination range of outgoing packets that this route applies to.
         * Only IPv4 is supported.
         */
        destRange?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of this resource. Always compute#routes for Route
         * resources.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Fully-qualified URL of the network that this route applies to.
         */
        network?: string;
        /**
         * The URL to a gateway that should handle matching packets. You can only
         * specify the internet gateway using a full or partial valid URL:
         * projects/&lt;project-id&gt;/global/gateways/default-internet-gateway
         */
        nextHopGateway?: string;
        /**
         * The URL to an instance that should handle matching packets. You can
         * specify this as a full or partial URL. For example:
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/
         */
        nextHopInstance?: string;
        /**
         * The network IP address of an instance that should handle matching
         * packets. Only IPv4 is supported.
         */
        nextHopIp?: string;
        /**
         * The URL of the local network if it should handle matching packets.
         */
        nextHopNetwork?: string;
        /**
         * [Output Only] The network peering name that should handle matching
         * packets, which should conform to RFC1035.
         */
        nextHopPeering?: string;
        /**
         * The URL to a VpnTunnel that should handle matching packets.
         */
        nextHopVpnTunnel?: string;
        /**
         * The priority of this route. Priority is used to break ties in cases where
         * there is more than one matching route of equal prefix length. In the case
         * of two routes with equal prefix length, the one with the lowest-numbered
         * priority value wins. Default value is 1000. Valid range is 0 through
         * 65535.
         */
        priority?: number;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string;
        /**
         * A list of instance tags to which this route applies.
         */
        tags?: string[];
        /**
         * [Output Only] If potential misconfigurations are detected for this route,
         * this field will be populated with warning messages.
         */
        warnings?: Array<{
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        }>;
    }
    /**
     * Contains a list of Route resources.
     */
    interface Schema$RouteList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Route resources.
         */
        items?: Schema$Route[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Router resource.
     */
    interface Schema$Router {
        /**
         * BGP information specific to this router.
         */
        bgp?: Schema$RouterBgp;
        /**
         * BGP information that needs to be configured into the routing stack to
         * establish the BGP peering. It must specify peer ASN and either interface
         * name, IP, or peer IP. Please refer to RFC4273.
         */
        bgpPeers?: Schema$RouterBgpPeer[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * Router interfaces. Each interface requires either one linked resource
         * (e.g. linkedVpnTunnel), or IP address and IP address range (e.g.
         * ipRange), or both.
         */
        interfaces?: Schema$RouterInterface[];
        /**
         * [Output Only] Type of resource. Always compute#router for routers.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * A list of Nat services created in this router.
         */
        nats?: Schema$RouterNat[];
        /**
         * URI of the network to which this router belongs.
         */
        network?: string;
        /**
         * [Output Only] URI of the region where the router resides. You must
         * specify this field as part of the HTTP request URL. It is not settable as
         * a field in the request body.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
    }
    /**
     * Description-tagged IP ranges for the router to advertise.
     */
    interface Schema$RouterAdvertisedIpRange {
        /**
         * User-specified description for the IP range.
         */
        description?: string;
        /**
         * The IP range to advertise. The value must be a CIDR-formatted string.
         */
        range?: string;
    }
    /**
     * Contains a list of routers.
     */
    interface Schema$RouterAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Router resources.
         */
        items?: {
            [key: string]: Schema$RoutersScopedList;
        };
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$RouterBgp {
        /**
         * User-specified list of prefix groups to advertise in custom mode. This
         * field can only be populated if advertise_mode is CUSTOM and is advertised
         * to all peers of the router. These groups will be advertised in addition
         * to any specified prefixes. Leave this field blank to advertise no custom
         * groups.
         */
        advertisedGroups?: string[];
        /**
         * User-specified list of individual IP ranges to advertise in custom mode.
         * This field can only be populated if advertise_mode is CUSTOM and is
         * advertised to all peers of the router. These IP ranges will be advertised
         * in addition to any specified groups. Leave this field blank to advertise
         * no custom IP ranges.
         */
        advertisedIpRanges?: Schema$RouterAdvertisedIpRange[];
        /**
         * User-specified flag to indicate which mode to use for advertisement.
         */
        advertiseMode?: string;
        /**
         * Local BGP Autonomous System Number (ASN). Must be an RFC6996 private ASN,
         * either 16-bit or 32-bit. The value will be fixed for this router
         * resource. All VPN tunnels that link to this router will have the same
         * local ASN.
         */
        asn?: number;
    }
    interface Schema$RouterBgpPeer {
        /**
         * User-specified list of prefix groups to advertise in custom mode. This
         * field can only be populated if advertise_mode is CUSTOM and overrides the
         * list defined for the router (in Bgp message). These groups will be
         * advertised in addition to any specified prefixes. Leave this field blank
         * to advertise no custom groups.
         */
        advertisedGroups?: string[];
        /**
         * User-specified list of individual IP ranges to advertise in custom mode.
         * This field can only be populated if advertise_mode is CUSTOM and
         * overrides the list defined for the router (in Bgp message). These IP
         * ranges will be advertised in addition to any specified groups. Leave this
         * field blank to advertise no custom IP ranges.
         */
        advertisedIpRanges?: Schema$RouterAdvertisedIpRange[];
        /**
         * The priority of routes advertised to this BGP peer. In the case where
         * there is more than one matching route of maximum length, the routes with
         * lowest priority value win.
         */
        advertisedRoutePriority?: number;
        /**
         * User-specified flag to indicate which mode to use for advertisement.
         */
        advertiseMode?: string;
        /**
         * Name of the interface the BGP peer is associated with.
         */
        interfaceName?: string;
        /**
         * IP address of the interface inside Google Cloud Platform. Only IPv4 is
         * supported.
         */
        ipAddress?: string;
        /**
         * [Output Only] The resource that configures and manages this BGP peer.
         * MANAGED_BY_USER is the default value and can be managed by you or other
         * users; MANAGED_BY_ATTACHMENT is a BGP peer that is configured and managed
         * by Cloud Interconnect, specifically by an InterconnectAttachment of type
         * PARTNER. Google will automatically create, update, and delete this type
         * of BGP peer when the PARTNER InterconnectAttachment is created, updated,
         * or deleted.
         */
        managementType?: string;
        /**
         * Name of this BGP peer. The name must be 1-63 characters long and comply
         * with RFC1035.
         */
        name?: string;
        /**
         * Peer BGP Autonomous System Number (ASN). For VPN use case, this value can
         * be different for every tunnel.
         */
        peerAsn?: number;
        /**
         * IP address of the BGP interface outside Google cloud. Only IPv4 is
         * supported.
         */
        peerIpAddress?: string;
    }
    interface Schema$RouterInterface {
        /**
         * IP address and range of the interface. The IP range must be in the
         * RFC3927 link-local IP space. The value must be a CIDR-formatted string,
         * for example: 169.254.0.1/30. NOTE: Do not truncate the address as it
         * represents the IP address of the interface.
         */
        ipRange?: string;
        /**
         * URI of the linked interconnect attachment. It must be in the same region
         * as the router. Each interface can have at most one linked resource and it
         * could either be a VPN Tunnel or an interconnect attachment.
         */
        linkedInterconnectAttachment?: string;
        /**
         * URI of the linked VPN tunnel. It must be in the same region as the
         * router. Each interface can have at most one linked resource and it could
         * either be a VPN Tunnel or an interconnect attachment.
         */
        linkedVpnTunnel?: string;
        /**
         * [Output Only] The resource that configures and manages this interface.
         * MANAGED_BY_USER is the default value and can be managed by you or other
         * users; MANAGED_BY_ATTACHMENT is an interface that is configured and
         * managed by Cloud Interconnect, specifically by an InterconnectAttachment
         * of type PARTNER. Google will automatically create, update, and delete
         * this type of interface when the PARTNER InterconnectAttachment is
         * created, updated, or deleted.
         */
        managementType?: string;
        /**
         * Name of this interface entry. The name must be 1-63 characters long and
         * comply with RFC1035.
         */
        name?: string;
    }
    /**
     * Contains a list of Router resources.
     */
    interface Schema$RouterList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Router resources.
         */
        items?: Schema$Router[];
        /**
         * [Output Only] Type of resource. Always compute#router for routers.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Represents a Nat resource. It enables the VMs within the specified
     * subnetworks to access Internet without external IP addresses. It specifies
     * a list of subnetworks (and the ranges within) that want to use NAT.
     * Customers can also provide the external IPs that would be used for NAT. GCP
     * would auto-allocate ephemeral IPs if no external IPs are provided.
     */
    interface Schema$RouterNat {
        /**
         * Timeout (in seconds) for ICMP connections. Defaults to 30s if not set.
         */
        icmpIdleTimeoutSec?: number;
        /**
         * Minimum number of ports allocated to a VM from this NAT config. If not
         * set, a default number of ports is allocated to a VM. This gets rounded up
         * to the nearest power of 2. Eg. if the value of this field is 50, at least
         * 64 ports will be allocated to a VM.
         */
        minPortsPerVm?: number;
        /**
         * Unique name of this Nat service. The name must be 1-63 characters long
         * and comply with RFC1035.
         */
        name?: string;
        /**
         * Specify the NatIpAllocateOption. If it is AUTO_ONLY, then nat_ip should
         * be empty.
         */
        natIpAllocateOption?: string;
        /**
         * A list of URLs of the IP resources used for this Nat service. These IPs
         * must be valid static external IP addresses assigned to the project.
         * max_length is subject to change post alpha.
         */
        natIps?: string[];
        /**
         * Specify the Nat option. If this field contains
         * ALL_SUBNETWORKS_ALL_IP_RANGES or ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES,
         * then there should not be any other Router.Nat section in any Router for
         * this network in this region.
         */
        sourceSubnetworkIpRangesToNat?: string;
        /**
         * A list of Subnetwork resources whose traffic should be translated by NAT
         * Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the
         * SubnetworkIpRangeToNatOption above.
         */
        subnetworks?: Schema$RouterNatSubnetworkToNat[];
        /**
         * Timeout (in seconds) for TCP established connections. Defaults to 1200s
         * if not set.
         */
        tcpEstablishedIdleTimeoutSec?: number;
        /**
         * Timeout (in seconds) for TCP transitory connections. Defaults to 30s if
         * not set.
         */
        tcpTransitoryIdleTimeoutSec?: number;
        /**
         * Timeout (in seconds) for UDP connections. Defaults to 30s if not set.
         */
        udpIdleTimeoutSec?: number;
    }
    /**
     * Defines the IP ranges that want to use NAT for a subnetwork.
     */
    interface Schema$RouterNatSubnetworkToNat {
        /**
         * URL for the subnetwork resource to use NAT.
         */
        name?: string;
        /**
         * A list of the secondary ranges of the Subnetwork that are allowed to use
         * NAT. This can be populated only if
         * &quot;LIST_OF_SECONDARY_IP_RANGES&quot; is one of the values in
         * source_ip_ranges_to_nat.
         */
        secondaryIpRangeNames?: string[];
        /**
         * Specify the options for NAT ranges in the Subnetwork. All usages of
         * single value are valid except NAT_IP_RANGE_OPTION_UNSPECIFIED. The only
         * valid option with multiple values is: [&quot;PRIMARY_IP_RANGE&quot;,
         * &quot;LIST_OF_SECONDARY_IP_RANGES&quot;] Default: [ALL_IP_RANGES]
         */
        sourceIpRangesToNat?: string[];
    }
    interface Schema$RoutersPreviewResponse {
        /**
         * Preview of given router.
         */
        resource?: Schema$Router;
    }
    interface Schema$RoutersScopedList {
        /**
         * A list of routers contained in this scope.
         */
        routers?: Schema$Router[];
        /**
         * Informational warning which replaces the list of routers when the list is
         * empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$RouterStatus {
        /**
         * Best routes for this router&#39;s network.
         */
        bestRoutes?: Schema$Route[];
        /**
         * Best routes learned by this router.
         */
        bestRoutesForRouter?: Schema$Route[];
        bgpPeerStatus?: Schema$RouterStatusBgpPeerStatus[];
        natStatus?: Schema$RouterStatusNatStatus[];
        /**
         * URI of the network to which this router belongs.
         */
        network?: string;
    }
    interface Schema$RouterStatusBgpPeerStatus {
        /**
         * Routes that were advertised to the remote BGP peer
         */
        advertisedRoutes?: Schema$Route[];
        /**
         * IP address of the local BGP interface.
         */
        ipAddress?: string;
        /**
         * URL of the VPN tunnel that this BGP peer controls.
         */
        linkedVpnTunnel?: string;
        /**
         * Name of this BGP peer. Unique within the Routers resource.
         */
        name?: string;
        /**
         * Number of routes learned from the remote BGP Peer.
         */
        numLearnedRoutes?: number;
        /**
         * IP address of the remote BGP interface.
         */
        peerIpAddress?: string;
        /**
         * BGP state as specified in RFC1771.
         */
        state?: string;
        /**
         * Status of the BGP peer: {UP, DOWN}
         */
        status?: string;
        /**
         * Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23
         * hours, 59 minutes, 59 seconds
         */
        uptime?: string;
        /**
         * Time this session has been up, in seconds. Format: 145
         */
        uptimeSeconds?: string;
    }
    /**
     * Status of a NAT contained in this router. Next tag: 9
     */
    interface Schema$RouterStatusNatStatus {
        /**
         * A list of IPs auto-allocated for NAT. Example: [&quot;1.1.1.1&quot;,
         * &quot;129.2.16.89&quot;]
         */
        autoAllocatedNatIps?: string[];
        /**
         * The number of extra IPs to allocate. This will be greater than 0 only if
         * user-specified IPs are NOT enough to allow all configured VMs to use NAT.
         * This value is meaningful only when auto-allocation of NAT IPs is *not*
         * used.
         */
        minExtraNatIpsNeeded?: number;
        /**
         * Unique name of this NAT.
         */
        name?: string;
        /**
         * Number of VM endpoints (i.e., Nics) that can use NAT.
         */
        numVmEndpointsWithNatMappings?: number;
        /**
         * A list of fully qualified URLs of reserved IP address resources.
         */
        userAllocatedNatIpResources?: string[];
        /**
         * A list of IPs user-allocated for NAT. They will be raw IP strings like
         * &quot;179.12.26.133&quot;.
         */
        userAllocatedNatIps?: string[];
    }
    interface Schema$RouterStatusResponse {
        /**
         * Type of resource.
         */
        kind?: string;
        result?: Schema$RouterStatus;
    }
    /**
     * A rule to be applied in a Policy.
     */
    interface Schema$Rule {
        /**
         * Required
         */
        action?: string;
        /**
         * Additional restrictions that must be met. All conditions must pass for
         * the rule to match.
         */
        conditions?: Schema$Condition[];
        /**
         * Human-readable description of the rule.
         */
        description?: string;
        /**
         * If one or more &#39;in&#39; clauses are specified, the rule matches if
         * the PRINCIPAL/AUTHORITY_SELECTOR is in at least one of these entries.
         */
        ins?: string[];
        /**
         * The config returned to callers of tech.iam.IAM.CheckPolicy for any
         * entries that match the LOG action.
         */
        logConfigs?: Schema$LogConfig[];
        /**
         * If one or more &#39;not_in&#39; clauses are specified, the rule matches
         * if the PRINCIPAL/AUTHORITY_SELECTOR is in none of the entries.
         */
        notIns?: string[];
        /**
         * A permission is a string of form &#39;..&#39; (e.g.,
         * &#39;storage.buckets.list&#39;). A value of &#39;*&#39; matches all
         * permissions, and a verb part of &#39;*&#39; (e.g.,
         * &#39;storage.buckets.*&#39;) matches all verbs.
         */
        permissions?: string[];
    }
    /**
     * Sets the scheduling options for an Instance.
     */
    interface Schema$Scheduling {
        /**
         * Specifies whether the instance should be automatically restarted if it is
         * terminated by Compute Engine (not terminated by a user). You can only set
         * the automatic restart option for standard instances. Preemptible
         * instances cannot be automatically restarted.  By default, this is set to
         * true so an instance is automatically restarted if it is terminated by
         * Compute Engine.
         */
        automaticRestart?: boolean;
        /**
         * A set of node affinity and anti-affinity.
         */
        nodeAffinities?: Schema$SchedulingNodeAffinity[];
        /**
         * Defines the maintenance behavior for this instance. For standard
         * instances, the default behavior is MIGRATE. For preemptible instances,
         * the default and only possible behavior is TERMINATE. For more
         * information, see Setting Instance Scheduling Options.
         */
        onHostMaintenance?: string;
        /**
         * Defines whether the instance is preemptible. This can only be set during
         * instance creation, it cannot be set or changed after the instance has
         * been created.
         */
        preemptible?: boolean;
    }
    /**
     * Node Affinity: the configuration of desired nodes onto which this Instance
     * could be scheduled.
     */
    interface Schema$SchedulingNodeAffinity {
        /**
         * Corresponds to the label key of Node resource.
         */
        key?: string;
        /**
         * Defines the operation of node selection.
         */
        operator?: string;
        /**
         * Corresponds to the label values of Node resource.
         */
        values?: string[];
    }
    /**
     * A security policy is comprised of one or more rules. It can also be
     * associated with one or more &#39;targets&#39;. (== resource_for
     * v1.securityPolicies ==) (== resource_for beta.securityPolicies ==)
     */
    interface Schema$SecurityPolicy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * Specifies a fingerprint for this resource, which is essentially a hash of
         * the metadata&#39;s contents and used for optimistic locking. The
         * fingerprint is initially generated by Compute Engine and changes after
         * every request to modify or update metadata. You must always provide an
         * up-to-date fingerprint hash in order to update or change metadata,
         * otherwise the request will fail with error 412 conditionNotMet.  To see
         * the latest fingerprint, make get() request to the security policy.
         */
        fingerprint?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output only] Type of the resource. Always compute#securityPolicyfor
         * security policies
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * A list of rules that belong to this policy. There must always be a
         * default rule (rule with priority 2147483647 and match &quot;*&quot;). If
         * no rules are provided when creating a security policy, a default rule
         * with action &quot;allow&quot; will be added.
         */
        rules?: Schema$SecurityPolicyRule[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
    }
    interface Schema$SecurityPolicyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of SecurityPolicy resources.
         */
        items?: Schema$SecurityPolicy[];
        /**
         * [Output Only] Type of resource. Always compute#securityPolicyList for
         * listsof securityPolicies
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$SecurityPolicyReference {
        securityPolicy?: string;
    }
    /**
     * Represents a rule that describes one or more match conditions along with
     * the action to be taken when traffic matches this condition (allow or deny).
     */
    interface Schema$SecurityPolicyRule {
        /**
         * The Action to preform when the client connection triggers the rule. Can
         * currently be either &quot;allow&quot; or &quot;deny()&quot; where valid
         * values for status are 403, 404, and 502.
         */
        action?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output only] Type of the resource. Always compute#securityPolicyRule for
         * security policy rules
         */
        kind?: string;
        /**
         * A match condition that incoming traffic is evaluated against. If it
         * evaluates to true, the corresponding ?action? is enforced.
         */
        match?: Schema$SecurityPolicyRuleMatcher;
        /**
         * If set to true, the specified action is not enforced.
         */
        preview?: boolean;
        /**
         * An integer indicating the priority of a rule in the list. The priority
         * must be a positive value between 0 and 2147483647. Rules are evaluated
         * from highest to lowest priority where 0 is the highest priority and
         * 2147483647 is the lowest prority.
         */
        priority?: number;
    }
    /**
     * Represents a match condition that incoming traffic is evaluated against.
     * Exactly one field must be specified.
     */
    interface Schema$SecurityPolicyRuleMatcher {
        /**
         * The configuration options available when specifying versioned_expr. This
         * field must be specified if versioned_expr is specified and cannot be
         * specified if versioned_expr is not specified.
         */
        config?: Schema$SecurityPolicyRuleMatcherConfig;
        /**
         * Preconfigured versioned expression. If this field is specified, config
         * must also be specified. Available preconfigured expressions along with
         * their requirements are: SRC_IPS_V1 - must specify the corresponding
         * src_ip_range field in config.
         */
        versionedExpr?: string;
    }
    interface Schema$SecurityPolicyRuleMatcherConfig {
        /**
         * CIDR IP address range.
         */
        srcIpRanges?: string[];
    }
    /**
     * An instance&#39;s serial console output.
     */
    interface Schema$SerialPortOutput {
        /**
         * [Output Only] The contents of the console output.
         */
        contents?: string;
        /**
         * [Output Only] Type of the resource. Always compute#serialPortOutput for
         * serial port output.
         */
        kind?: string;
        /**
         * [Output Only] The position of the next byte of content from the serial
         * console output. Use this value in the next request as the start
         * parameter.
         */
        next?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * The starting byte position of the output that was returned. This should
         * match the start parameter sent with the request. If the serial console
         * output exceeds the size of the buffer, older output will be overwritten
         * by newer content and the start values will be mismatched.
         */
        start?: string;
    }
    /**
     * A service account.
     */
    interface Schema$ServiceAccount {
        /**
         * Email address of the service account.
         */
        email?: string;
        /**
         * The list of scopes to be made available for this service account.
         */
        scopes?: string[];
    }
    /**
     * A set of Shielded Instance options.
     */
    interface Schema$ShieldedInstanceConfig {
        /**
         * Defines whether the instance has integrity monitoring enabled.
         */
        enableIntegrityMonitoring?: boolean;
        /**
         * Defines whether the instance has Secure Boot enabled.
         */
        enableSecureBoot?: boolean;
        /**
         * Defines whether the instance has the vTPM enabled.
         */
        enableVtpm?: boolean;
    }
    /**
     * A shielded Instance identity entry.
     */
    interface Schema$ShieldedInstanceIdentity {
        /**
         * An Endorsement Key (EK) issued to the Shielded Instance&#39;s vTPM.
         */
        encryptionKey?: Schema$ShieldedInstanceIdentityEntry;
        /**
         * [Output Only] Type of the resource. Always
         * compute#shieldedInstanceIdentity for shielded Instance identity entry.
         */
        kind?: string;
        /**
         * An Attestation Key (AK) issued to the Shielded Instance&#39;s vTPM.
         */
        signingKey?: Schema$ShieldedInstanceIdentityEntry;
    }
    /**
     * A Shielded Instance Identity Entry.
     */
    interface Schema$ShieldedInstanceIdentityEntry {
        /**
         * A PEM-encoded X.509 certificate. This field can be empty.
         */
        ekCert?: string;
        /**
         * A PEM-encoded public key.
         */
        ekPub?: string;
    }
    /**
     * The policy describes the baseline against which Instance boot integrity is
     * measured.
     */
    interface Schema$ShieldedInstanceIntegrityPolicy {
        /**
         * Updates the integrity policy baseline using the measurements from the VM
         * instance&#39;s most recent boot.
         */
        updateAutoLearnPolicy?: boolean;
    }
    /**
     * Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs
     */
    interface Schema$SignedUrlKey {
        /**
         * Name of the key. The name must be 1-63 characters long, and comply with
         * RFC1035. Specifically, the name must be 1-63 characters long and match
         * the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
         * character must be a lowercase letter, and all following characters must
         * be a dash, lowercase letter, or digit, except the last character, which
         * cannot be a dash.
         */
        keyName?: string;
        /**
         * 128-bit key value used for signing the URL. The key value must be a valid
         * RFC 4648 Section 5 base64url encoded string.
         */
        keyValue?: string;
    }
    /**
     * A persistent disk snapshot resource. (== resource_for beta.snapshots ==)
     * (== resource_for v1.snapshots ==)
     */
    interface Schema$Snapshot {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] Size of the snapshot, specified in GB.
         */
        diskSizeGb?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#snapshot for Snapshot
         * resources.
         */
        kind?: string;
        /**
         * A fingerprint for the labels being applied to this snapshot, which is
         * essentially a hash of the labels set used for optimistic locking. The
         * fingerprint is initially generated by Compute Engine and changes after
         * every request to modify or update labels. You must always provide an
         * up-to-date fingerprint hash in order to update or change labels,
         * otherwise the request will fail with error 412 conditionNotMet.  To see
         * the latest fingerprint, make a get() request to retrieve a snapshot.
         */
        labelFingerprint?: string;
        /**
         * Labels to apply to this snapshot. These can be later modified by the
         * setLabels method. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        };
        /**
         * [Output Only] Integer license codes indicating which licenses are
         * attached to this snapshot.
         */
        licenseCodes?: string[];
        /**
         * [Output Only] A list of public visible licenses that apply to this
         * snapshot. This can be because the original image had licenses attached
         * (such as a Windows image).
         */
        licenses?: string[];
        /**
         * Name of the resource; provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * Encrypts the snapshot using a customer-supplied encryption key.  After
         * you encrypt a snapshot using a customer-supplied key, you must provide
         * the same key if you use the image later For example, you must provide the
         * encryption key when you create a disk from the encrypted snapshot in a
         * future request.  Customer-supplied encryption keys do not protect access
         * to metadata of the disk.  If you do not provide an encryption key when
         * creating the snapshot, then the snapshot will be encrypted using an
         * automatically generated key and you do not need to provide a key to use
         * the snapshot later.
         */
        snapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The source disk used to create this snapshot.
         */
        sourceDisk?: string;
        /**
         * The customer-supplied encryption key of the source disk. Required if the
         * source disk is protected by a customer-supplied encryption key.
         */
        sourceDiskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the disk used to create this snapshot. This
         * value may be used to determine whether the snapshot was taken from the
         * current or a previous instance of a given disk name.
         */
        sourceDiskId?: string;
        /**
         * [Output Only] The status of the snapshot. This can be CREATING, DELETING,
         * FAILED, READY, or UPLOADING.
         */
        status?: string;
        /**
         * [Output Only] A size of the storage used by the snapshot. As snapshots
         * share storage, this number is expected to change with snapshot
         * creation/deletion.
         */
        storageBytes?: string;
        /**
         * [Output Only] An indicator whether storageBytes is in a stable state or
         * it is being adjusted as a result of shared storage reallocation. This
         * status can either be UPDATING, meaning the size of the snapshot is being
         * updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
         */
        storageBytesStatus?: string;
        /**
         * GCS bucket storage location of the snapshot (regional or multi-regional).
         */
        storageLocations?: string[];
    }
    /**
     * Contains a list of Snapshot resources.
     */
    interface Schema$SnapshotList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Snapshot resources.
         */
        items?: Schema$Snapshot[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A specification of the parameters to use when creating the instance
     * template from a source instance.
     */
    interface Schema$SourceInstanceParams {
        /**
         * Attached disks configuration. If not provided, defaults are applied: For
         * boot disk and any other R/W disks, new custom images will be created from
         * each disk. For read-only disks, they will be attached in read-only mode.
         * Local SSD disks will be created as blank volumes.
         */
        diskConfigs?: Schema$DiskInstantiationConfig[];
    }
    /**
     * An SslCertificate resource. This resource provides a mechanism to upload an
     * SSL key and certificate to the load balancer to serve secure connections
     * from the user. (== resource_for beta.sslCertificates ==) (== resource_for
     * v1.sslCertificates ==)
     */
    interface Schema$SslCertificate {
        /**
         * A local certificate file. The certificate must be in PEM format. The
         * certificate chain must be no greater than 5 certs long. The chain must
         * include at least one intermediate cert.
         */
        certificate?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#sslCertificate for SSL
         * certificates.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * A write-only private key in PEM format. Only insert requests will include
         * this field.
         */
        privateKey?: string;
        /**
         * [Output only] Server-defined URL for the resource.
         */
        selfLink?: string;
    }
    /**
     * Contains a list of SslCertificate resources.
     */
    interface Schema$SslCertificateList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of SslCertificate resources.
         */
        items?: Schema$SslCertificate[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$SSLHealthCheck {
        /**
         * The TCP port number for the health check request. The default value is
         * 443. Valid values are 1 through 65535.
         */
        port?: number;
        /**
         * Port name as defined in InstanceGroup#NamedPort#name. If both port and
         * port_name are defined, port takes precedence.
         */
        portName?: string;
        /**
         * Specifies how port is selected for health checking, can be one of
         * following values: USE_FIXED_PORT: The port number in port is used for
         * health checking. USE_NAMED_PORT: The portName is used for health
         * checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified
         * for each network endpoint is used for health checking. For other
         * backends, the port or named port specified in the Backend Service is used
         * for health checking.   If not specified, SSL health check follows
         * behavior specified in port and portName fields.
         */
        portSpecification?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * The application data to send once the SSL connection has been established
         * (default value is empty). If both request and response are empty, the
         * connection establishment alone will indicate health. The request data can
         * only be ASCII.
         */
        request?: string;
        /**
         * The bytes to match against the beginning of the response data. If left
         * empty (the default value), any response will indicate health. The
         * response data can only be ASCII.
         */
        response?: string;
    }
    interface Schema$SslPoliciesList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of SslPolicy resources.
         */
        items?: Schema$SslPolicy[];
        /**
         * [Output Only] Type of the resource. Always compute#sslPoliciesList for
         * lists of sslPolicies.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$SslPoliciesListAvailableFeaturesResponse {
        features?: string[];
    }
    /**
     * A SSL policy specifies the server-side support for SSL features. This can
     * be attached to a TargetHttpsProxy or a TargetSslProxy. This affects
     * connections between clients and the HTTPS or SSL proxy load balancer. They
     * do not affect the connection between the load balancers and the backends.
     */
    interface Schema$SslPolicy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * A list of features enabled when the selected profile is CUSTOM. The -
         * method returns the set of features that can be specified in this list.
         * This field must be empty if the profile is not CUSTOM.
         */
        customFeatures?: string[];
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The list of features enabled in the SSL policy.
         */
        enabledFeatures?: string[];
        /**
         * Fingerprint of this resource. A hash of the contents stored in this
         * object. This field is used in optimistic locking. This field will be
         * ignored when inserting a SslPolicy. An up-to-date fingerprint must be
         * provided in order to update the SslPolicy, otherwise the request will
         * fail with error 412 conditionNotMet.  To see the latest fingerprint, make
         * a get() request to retrieve an SslPolicy.
         */
        fingerprint?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output only] Type of the resource. Always compute#sslPolicyfor SSL
         * policies.
         */
        kind?: string;
        /**
         * The minimum version of SSL protocol that can be used by the clients to
         * establish a connection with the load balancer. This can be one of
         * TLS_1_0, TLS_1_1, TLS_1_2.
         */
        minTlsVersion?: string;
        /**
         * Name of the resource. The name must be 1-63 characters long, and comply
         * with RFC1035. Specifically, the name must be 1-63 characters long and
         * match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
         * first character must be a lowercase letter, and all following characters
         * must be a dash, lowercase letter, or digit, except the last character,
         * which cannot be a dash.
         */
        name?: string;
        /**
         * Profile specifies the set of SSL features that can be used by the load
         * balancer when negotiating SSL with clients. This can be one of
         * COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of
         * SSL features to enable must be specified in the customFeatures field.
         */
        profile?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] If potential misconfigurations are detected for this SSL
         * policy, this field will be populated with warning messages.
         */
        warnings?: Array<{
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        }>;
    }
    interface Schema$SslPolicyReference {
        /**
         * URL of the SSL policy resource. Set this to empty string to clear any
         * existing SSL policy associated with the target proxy resource.
         */
        sslPolicy?: string;
    }
    /**
     * A Subnetwork resource. (== resource_for beta.subnetworks ==) (==
     * resource_for v1.subnetworks ==)
     */
    interface Schema$Subnetwork {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource. This field can be set only at resource creation
         * time.
         */
        description?: string;
        /**
         * Whether to enable flow logging for this subnetwork. If this field is not
         * explicitly set, it will not appear in get listings. If not set the
         * default behavior is to disable flow logging.
         */
        enableFlowLogs?: boolean;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this
         * object. This field is used in optimistic locking. This field will be
         * ignored when inserting a Subnetwork. An up-to-date fingerprint must be
         * provided in order to update the Subnetwork, otherwise the request will
         * fail with error 412 conditionNotMet.  To see the latest fingerprint, make
         * a get() request to retrieve a Subnetwork.
         */
        fingerprint?: string;
        /**
         * [Output Only] The gateway address for default routes to reach destination
         * addresses outside this subnetwork.
         */
        gatewayAddress?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * The range of internal addresses that are owned by this subnetwork.
         * Provide this property when you create the subnetwork. For
         * example, 10.0.0.0/8 or 192.168.0.0/16. Ranges must be unique and
         * non-overlapping within a network. Only IPv4 is supported. This field can
         * be set only at resource creation time.
         */
        ipCidrRange?: string;
        /**
         * [Output Only] Type of the resource. Always compute#subnetwork for
         * Subnetwork resources.
         */
        kind?: string;
        /**
         * The name of the resource, provided by the client when initially creating
         * the resource. The name must be 1-63 characters long, and comply with
         * RFC1035. Specifically, the name must be 1-63 characters long and match
         * the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
         * character must be a lowercase letter, and all following characters must
         * be a dash, lowercase letter, or digit, except the last character, which
         * cannot be a dash.
         */
        name?: string;
        /**
         * The URL of the network to which this subnetwork belongs, provided by the
         * client when initially creating the subnetwork. Only networks that are in
         * the distributed mode can have subnetworks. This field can be set only at
         * resource creation time.
         */
        network?: string;
        /**
         * Whether the VMs in this subnet can access Google services without
         * assigned external IP addresses. This field can be both set at resource
         * creation time and updated using setPrivateIpGoogleAccess.
         */
        privateIpGoogleAccess?: boolean;
        /**
         * URL of the region where the Subnetwork resides. This field can be set
         * only at resource creation time.
         */
        region?: string;
        /**
         * An array of configurations for secondary IP ranges for VM instances
         * contained in this subnetwork. The primary IP of such VM must belong to
         * the primary ipCidrRange of the subnetwork. The alias IPs may belong to
         * either primary or secondary ranges. This field can be updated with a
         * patch request.
         */
        secondaryIpRanges?: Schema$SubnetworkSecondaryRange[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
    }
    interface Schema$SubnetworkAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of SubnetworksScopedList resources.
         */
        items?: {
            [key: string]: Schema$SubnetworksScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#subnetworkAggregatedList
         * for aggregated lists of subnetworks.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of Subnetwork resources.
     */
    interface Schema$SubnetworkList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Subnetwork resources.
         */
        items?: Schema$Subnetwork[];
        /**
         * [Output Only] Type of resource. Always compute#subnetworkList for lists
         * of subnetworks.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Represents a secondary IP range of a subnetwork.
     */
    interface Schema$SubnetworkSecondaryRange {
        /**
         * The range of IP addresses belonging to this subnetwork secondary range.
         * Provide this property when you create the subnetwork. Ranges must be
         * unique and non-overlapping with all primary and secondary IP ranges
         * within a network. Only IPv4 is supported.
         */
        ipCidrRange?: string;
        /**
         * The name associated with this subnetwork secondary range, used when
         * adding an alias IP range to a VM instance. The name must be 1-63
         * characters long, and comply with RFC1035. The name must be unique within
         * the subnetwork.
         */
        rangeName?: string;
    }
    interface Schema$SubnetworksExpandIpCidrRangeRequest {
        /**
         * The IP (in CIDR format or netmask) of internal addresses that are legal
         * on this Subnetwork. This range should be disjoint from other subnetworks
         * within this network. This range can only be larger than (i.e. a superset
         * of) the range previously defined before the update.
         */
        ipCidrRange?: string;
    }
    interface Schema$SubnetworksScopedList {
        /**
         * A list of subnetworks contained in this scope.
         */
        subnetworks?: Schema$Subnetwork[];
        /**
         * An informational warning that appears when the list of addresses is
         * empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$SubnetworksSetPrivateIpGoogleAccessRequest {
        privateIpGoogleAccess?: boolean;
    }
    /**
     * A set of instance tags.
     */
    interface Schema$Tags {
        /**
         * Specifies a fingerprint for this request, which is essentially a hash of
         * the tags&#39; contents and used for optimistic locking. The fingerprint
         * is initially generated by Compute Engine and changes after every request
         * to modify or update tags. You must always provide an up-to-date
         * fingerprint hash in order to update or change tags.  To see the latest
         * fingerprint, make get() request to the instance.
         */
        fingerprint?: string;
        /**
         * An array of tags. Each tag must be 1-63 characters long, and comply with
         * RFC1035.
         */
        items?: string[];
    }
    /**
     * A TargetHttpProxy resource. This resource defines an HTTP proxy. (==
     * resource_for beta.targetHttpProxies ==) (== resource_for
     * v1.targetHttpProxies ==)
     */
    interface Schema$TargetHttpProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#targetHttpProxy for target
         * HTTP proxies.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * URL to the UrlMap resource that defines the mapping from URL to the
         * BackendService.
         */
        urlMap?: string;
    }
    /**
     * A list of TargetHttpProxy resources.
     */
    interface Schema$TargetHttpProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetHttpProxy resources.
         */
        items?: Schema$TargetHttpProxy[];
        /**
         * Type of resource. Always compute#targetHttpProxyList for lists of target
         * HTTP proxies.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetHttpsProxiesSetQuicOverrideRequest {
        /**
         * QUIC policy for the TargetHttpsProxy resource.
         */
        quicOverride?: string;
    }
    interface Schema$TargetHttpsProxiesSetSslCertificatesRequest {
        /**
         * New set of SslCertificate resources to associate with this
         * TargetHttpsProxy resource. Currently exactly one SslCertificate resource
         * must be specified.
         */
        sslCertificates?: string[];
    }
    /**
     * A TargetHttpsProxy resource. This resource defines an HTTPS proxy. (==
     * resource_for beta.targetHttpsProxies ==) (== resource_for
     * v1.targetHttpsProxies ==)
     */
    interface Schema$TargetHttpsProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#targetHttpsProxy for
         * target HTTPS proxies.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Specifies the QUIC override policy for this TargetHttpsProxy resource.
         * This determines whether the load balancer will attempt to negotiate QUIC
         * with clients or not. Can specify one of NONE, ENABLE, or DISABLE. Specify
         * ENABLE to always enable QUIC, Enables QUIC when set to ENABLE, and
         * disables QUIC when set to DISABLE. If NONE is specified, uses the QUIC
         * policy with no user overrides, which is equivalent to DISABLE. Not
         * specifying this field is equivalent to specifying NONE.
         */
        quicOverride?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * URLs to SslCertificate resources that are used to authenticate
         * connections between users and the load balancer. At least one SSL
         * certificate must be specified. Currently, you may specify up to 15 SSL
         * certificates.
         */
        sslCertificates?: string[];
        /**
         * URL of SslPolicy resource that will be associated with the
         * TargetHttpsProxy resource. If not set, the TargetHttpsProxy resource will
         * not have any SSL policy configured.
         */
        sslPolicy?: string;
        /**
         * A fully-qualified or valid partial URL to the UrlMap resource that
         * defines the mapping from URL to the BackendService. For example, the
         * following are all valid URLs for specifying a URL map:   -
         * https://www.googleapis.compute/v1/projects/project/global/urlMaps/url-map
         * - projects/project/global/urlMaps/url-map  - global/urlMaps/url-map
         */
        urlMap?: string;
    }
    /**
     * Contains a list of TargetHttpsProxy resources.
     */
    interface Schema$TargetHttpsProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetHttpsProxy resources.
         */
        items?: Schema$TargetHttpsProxy[];
        /**
         * Type of resource. Always compute#targetHttpsProxyList for lists of target
         * HTTPS proxies.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A TargetInstance resource. This resource defines an endpoint instance that
     * terminates traffic of certain protocols. (== resource_for
     * beta.targetInstances ==) (== resource_for v1.targetInstances ==)
     */
    interface Schema$TargetInstance {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * A URL to the virtual machine instance that handles traffic for this
         * target instance. When creating a target instance, you can provide the
         * fully-qualified URL or a valid partial URL to the desired virtual
         * machine. For example, the following are all valid URLs:  -
         * https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
         * - projects/project/zones/zone/instances/instance  -
         * zones/zone/instances/instance
         */
        instance?: string;
        /**
         * [Output Only] The type of the resource. Always compute#targetInstance for
         * target instances.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * NAT option controlling how IPs are NAT&#39;ed to the instance. Currently
         * only NO_NAT (default value) is supported.
         */
        natPolicy?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] URL of the zone where the target instance resides. You must
         * specify this field as part of the HTTP request URL. It is not settable as
         * a field in the request body.
         */
        zone?: string;
    }
    interface Schema$TargetInstanceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetInstance resources.
         */
        items?: {
            [key: string]: Schema$TargetInstancesScopedList;
        };
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of TargetInstance resources.
     */
    interface Schema$TargetInstanceList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetInstance resources.
         */
        items?: Schema$TargetInstance[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetInstancesScopedList {
        /**
         * A list of target instances contained in this scope.
         */
        targetInstances?: Schema$TargetInstance[];
        /**
         * Informational warning which replaces the list of addresses when the list
         * is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * A TargetPool resource. This resource defines a pool of instances, an
     * associated HttpHealthCheck resource, and the fallback target pool. (==
     * resource_for beta.targetPools ==) (== resource_for v1.targetPools ==)
     */
    interface Schema$TargetPool {
        /**
         * This field is applicable only when the containing target pool is serving
         * a forwarding rule as the primary pool, and its failoverRatio field is
         * properly set to a value between [0, 1].  backupPool and failoverRatio
         * together define the fallback behavior of the primary target pool: if the
         * ratio of the healthy instances in the primary pool is at or below
         * failoverRatio, traffic arriving at the load-balanced IP will be directed
         * to the backup pool.  In case where failoverRatio and backupPool are not
         * set, or all the instances in the backup pool are unhealthy, the traffic
         * will be directed back to the primary pool in the &quot;force&quot; mode,
         * where traffic will be spread to the healthy instances with the best
         * effort, or to all instances when no instance is healthy.
         */
        backupPool?: string;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * This field is applicable only when the containing target pool is serving
         * a forwarding rule as the primary pool (i.e., not as a backup pool to some
         * other target pool). The value of the field must be in [0, 1].  If set,
         * backupPool must also be set. They together define the fallback behavior
         * of the primary target pool: if the ratio of the healthy instances in the
         * primary pool is at or below this number, traffic arriving at the
         * load-balanced IP will be directed to the backup pool.  In case where
         * failoverRatio is not set or all the instances in the backup pool are
         * unhealthy, the traffic will be directed back to the primary pool in the
         * &quot;force&quot; mode, where traffic will be spread to the healthy
         * instances with the best effort, or to all instances when no instance is
         * healthy.
         */
        failoverRatio?: number;
        /**
         * The URL of the HttpHealthCheck resource. A member instance in this pool
         * is considered healthy if and only if the health checks pass. An empty
         * list means all member instances will be considered healthy at all times.
         * Only HttpHealthChecks are supported. Only one health check may be
         * specified.
         */
        healthChecks?: string[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * A list of resource URLs to the virtual machine instances serving this
         * pool. They must live in zones contained in the same region as this pool.
         */
        instances?: string[];
        /**
         * [Output Only] Type of the resource. Always compute#targetPool for target
         * pools.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * [Output Only] URL of the region where the target pool resides.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * Session affinity option, must be one of the following values: NONE:
         * Connections from the same client IP may go to any instance in the pool.
         * CLIENT_IP: Connections from the same client IP will go to the same
         * instance in the pool while that instance remains healthy.
         * CLIENT_IP_PROTO: Connections from the same client IP with the same IP
         * protocol will go to the same instance in the pool while that instance
         * remains healthy.
         */
        sessionAffinity?: string;
    }
    interface Schema$TargetPoolAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetPool resources.
         */
        items?: {
            [key: string]: Schema$TargetPoolsScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#targetPoolAggregatedList
         * for aggregated lists of target pools.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetPoolInstanceHealth {
        healthStatus?: Schema$HealthStatus[];
        /**
         * [Output Only] Type of resource. Always compute#targetPoolInstanceHealth
         * when checking the health of an instance.
         */
        kind?: string;
    }
    /**
     * Contains a list of TargetPool resources.
     */
    interface Schema$TargetPoolList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetPool resources.
         */
        items?: Schema$TargetPool[];
        /**
         * [Output Only] Type of resource. Always compute#targetPoolList for lists
         * of target pools.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetPoolsAddHealthCheckRequest {
        /**
         * The HttpHealthCheck to add to the target pool.
         */
        healthChecks?: Schema$HealthCheckReference[];
    }
    interface Schema$TargetPoolsAddInstanceRequest {
        /**
         * A full or partial URL to an instance to add to this target pool. This can
         * be a full or partial URL. For example, the following are valid URLs:   -
         * https://www.googleapis.com/compute/v1/projects/project-id/zones/zone/instances/instance-name
         * - projects/project-id/zones/zone/instances/instance-name  -
         * zones/zone/instances/instance-name
         */
        instances?: Schema$InstanceReference[];
    }
    interface Schema$TargetPoolsRemoveHealthCheckRequest {
        /**
         * Health check URL to be removed. This can be a full or valid partial URL.
         * For example, the following are valid URLs:   -
         * https://www.googleapis.com/compute/beta/projects/project/global/httpHealthChecks/health-check
         * - projects/project/global/httpHealthChecks/health-check  -
         * global/httpHealthChecks/health-check
         */
        healthChecks?: Schema$HealthCheckReference[];
    }
    interface Schema$TargetPoolsRemoveInstanceRequest {
        /**
         * URLs of the instances to be removed from target pool.
         */
        instances?: Schema$InstanceReference[];
    }
    interface Schema$TargetPoolsScopedList {
        /**
         * A list of target pools contained in this scope.
         */
        targetPools?: Schema$TargetPool[];
        /**
         * Informational warning which replaces the list of addresses when the list
         * is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetReference {
        target?: string;
    }
    interface Schema$TargetSslProxiesSetBackendServiceRequest {
        /**
         * The URL of the new BackendService resource for the targetSslProxy.
         */
        service?: string;
    }
    interface Schema$TargetSslProxiesSetProxyHeaderRequest {
        /**
         * The new type of proxy header to append before sending data to the
         * backend. NONE or PROXY_V1 are allowed.
         */
        proxyHeader?: string;
    }
    interface Schema$TargetSslProxiesSetSslCertificatesRequest {
        /**
         * New set of URLs to SslCertificate resources to associate with this
         * TargetSslProxy. Currently exactly one ssl certificate must be specified.
         */
        sslCertificates?: string[];
    }
    /**
     * A TargetSslProxy resource. This resource defines an SSL proxy. (==
     * resource_for beta.targetSslProxies ==) (== resource_for v1.targetSslProxies
     * ==)
     */
    interface Schema$TargetSslProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#targetSslProxy for
         * target SSL proxies.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * URL to the BackendService resource.
         */
        service?: string;
        /**
         * URLs to SslCertificate resources that are used to authenticate
         * connections to Backends. At least one SSL certificate must be specified.
         * Currently, you may specify up to 15 SSL certificates.
         */
        sslCertificates?: string[];
        /**
         * URL of SslPolicy resource that will be associated with the TargetSslProxy
         * resource. If not set, the TargetSslProxy resource will not have any SSL
         * policy configured.
         */
        sslPolicy?: string;
    }
    /**
     * Contains a list of TargetSslProxy resources.
     */
    interface Schema$TargetSslProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetSslProxy resources.
         */
        items?: Schema$TargetSslProxy[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetTcpProxiesSetBackendServiceRequest {
        /**
         * The URL of the new BackendService resource for the targetTcpProxy.
         */
        service?: string;
    }
    interface Schema$TargetTcpProxiesSetProxyHeaderRequest {
        /**
         * The new type of proxy header to append before sending data to the
         * backend. NONE or PROXY_V1 are allowed.
         */
        proxyHeader?: string;
    }
    /**
     * A TargetTcpProxy resource. This resource defines a TCP proxy. (==
     * resource_for beta.targetTcpProxies ==) (== resource_for v1.targetTcpProxies
     * ==)
     */
    interface Schema$TargetTcpProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#targetTcpProxy for
         * target TCP proxies.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * URL to the BackendService resource.
         */
        service?: string;
    }
    /**
     * Contains a list of TargetTcpProxy resources.
     */
    interface Schema$TargetTcpProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetTcpProxy resources.
         */
        items?: Schema$TargetTcpProxy[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Represents a Target VPN gateway resource. (== resource_for
     * beta.targetVpnGateways ==) (== resource_for v1.targetVpnGateways ==)
     */
    interface Schema$TargetVpnGateway {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] A list of URLs to the ForwardingRule resources.
         * ForwardingRules are created using compute.forwardingRules.insert and
         * associated with a VPN gateway.
         */
        forwardingRules?: string[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#targetVpnGateway for
         * target VPN gateways.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * URL of the network to which this VPN gateway is attached. Provided by the
         * client when the VPN gateway is created.
         */
        network?: string;
        /**
         * [Output Only] URL of the region where the target VPN gateway resides. You
         * must specify this field as part of the HTTP request URL. It is not
         * settable as a field in the request body.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] The status of the VPN gateway, which can be one of the
         * following: CREATING, READY, FAILED, or DELETING.
         */
        status?: string;
        /**
         * [Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are
         * created using the compute.vpntunnels.insert method and associated with a
         * VPN gateway.
         */
        tunnels?: string[];
    }
    interface Schema$TargetVpnGatewayAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetVpnGateway resources.
         */
        items?: {
            [key: string]: Schema$TargetVpnGatewaysScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#targetVpnGateway for
         * target VPN gateways.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of TargetVpnGateway resources.
     */
    interface Schema$TargetVpnGatewayList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of TargetVpnGateway resources.
         */
        items?: Schema$TargetVpnGateway[];
        /**
         * [Output Only] Type of resource. Always compute#targetVpnGateway for
         * target VPN gateways.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TargetVpnGatewaysScopedList {
        /**
         * [Output Only] A list of target VPN gateways contained in this scope.
         */
        targetVpnGateways?: Schema$TargetVpnGateway[];
        /**
         * [Output Only] Informational warning which replaces the list of addresses
         * when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$TCPHealthCheck {
        /**
         * The TCP port number for the health check request. The default value
         * is 80. Valid values are 1 through 65535.
         */
        port?: number;
        /**
         * Port name as defined in InstanceGroup#NamedPort#name. If both port and
         * port_name are defined, port takes precedence.
         */
        portName?: string;
        /**
         * Specifies how port is selected for health checking, can be one of
         * following values: USE_FIXED_PORT: The port number in port is used for
         * health checking. USE_NAMED_PORT: The portName is used for health
         * checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified
         * for each network endpoint is used for health checking. For other
         * backends, the port or named port specified in the Backend Service is used
         * for health checking.   If not specified, TCP health check follows
         * behavior specified in port and portName fields.
         */
        portSpecification?: string;
        /**
         * Specifies the type of proxy header to append before sending data to the
         * backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string;
        /**
         * The application data to send once the TCP connection has been established
         * (default value is empty). If both request and response are empty, the
         * connection establishment alone will indicate health. The request data can
         * only be ASCII.
         */
        request?: string;
        /**
         * The bytes to match against the beginning of the response data. If left
         * empty (the default value), any response will indicate health. The
         * response data can only be ASCII.
         */
        response?: string;
    }
    interface Schema$TestFailure {
        actualService?: string;
        expectedService?: string;
        host?: string;
        path?: string;
    }
    interface Schema$TestPermissionsRequest {
        /**
         * The set of permissions to check for the &#39;resource&#39;. Permissions
         * with wildcards (such as &#39;*&#39; or &#39;storage.*&#39;) are not
         * allowed.
         */
        permissions?: string[];
    }
    interface Schema$TestPermissionsResponse {
        /**
         * A subset of `TestPermissionsRequest.permissions` that the caller is
         * allowed.
         */
        permissions?: string[];
    }
    /**
     * A UrlMap resource. This resource defines the mapping from URL to the
     * BackendService resource, based on the &quot;longest-match&quot; of the
     * URL&#39;s host and path.
     */
    interface Schema$UrlMap {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * The full or partial URL of the defaultService resource to which traffic
         * is directed if none of the hostRules match. If defaultRouteAction is
         * additionally specified, advanced routing actions like URL Rewrites, etc.
         * take effect prior to sending the request to the backend. However, if
         * defaultService is specified, defaultRouteAction cannot contain any
         * weightedBackendServices. Conversely, if routeAction specifies any
         * weightedBackendServices, service must not be specified. Only one of
         * defaultService, defaultUrlRedirect  or
         * defaultRouteAction.weightedBackendService must be set.
         */
        defaultService?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this
         * object. This field is used in optimistic locking. This field will be
         * ignored when inserting a UrlMap. An up-to-date fingerprint must be
         * provided in order to update the UrlMap, otherwise the request will fail
         * with error 412 conditionNotMet.  To see the latest fingerprint, make a
         * get() request to retrieve a UrlMap.
         */
        fingerprint?: string;
        /**
         * The list of HostRules to use against the URL.
         */
        hostRules?: Schema$HostRule[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#urlMaps for url maps.
         */
        kind?: string;
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * The list of named PathMatchers to use against the URL.
         */
        pathMatchers?: Schema$PathMatcher[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * The list of expected URL mapping tests. Request to update this UrlMap
         * will succeed only if all of the test cases pass. You can specify a
         * maximum of 100 tests per UrlMap.
         */
        tests?: Schema$UrlMapTest[];
    }
    /**
     * Contains a list of UrlMap resources.
     */
    interface Schema$UrlMapList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of UrlMap resources.
         */
        items?: Schema$UrlMap[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$UrlMapReference {
        urlMap?: string;
    }
    interface Schema$UrlMapsValidateRequest {
        /**
         * Content of the UrlMap to be validated.
         */
        resource?: Schema$UrlMap;
    }
    interface Schema$UrlMapsValidateResponse {
        result?: Schema$UrlMapValidationResult;
    }
    /**
     * Message for the expected URL mappings.
     */
    interface Schema$UrlMapTest {
        /**
         * Description of this test case.
         */
        description?: string;
        /**
         * Host portion of the URL.
         */
        host?: string;
        /**
         * Path portion of the URL.
         */
        path?: string;
        /**
         * Expected BackendService resource the given URL should be mapped to.
         */
        service?: string;
    }
    /**
     * Message representing the validation result for a UrlMap.
     */
    interface Schema$UrlMapValidationResult {
        loadErrors?: string[];
        /**
         * Whether the given UrlMap can be successfully loaded. If false,
         * &#39;loadErrors&#39; indicates the reasons.
         */
        loadSucceeded?: boolean;
        testFailures?: Schema$TestFailure[];
        /**
         * If successfully loaded, this field indicates whether the test passed. If
         * false, &#39;testFailures&#39;s indicate the reason of failure.
         */
        testPassed?: boolean;
    }
    /**
     * Subnetwork which the current user has compute.subnetworks.use permission
     * on.
     */
    interface Schema$UsableSubnetwork {
        /**
         * The range of internal addresses that are owned by this subnetwork.
         */
        ipCidrRange?: string;
        /**
         * Network URL.
         */
        network?: string;
        /**
         * Secondary IP ranges.
         */
        secondaryIpRanges?: Schema$UsableSubnetworkSecondaryRange[];
        /**
         * Subnetwork URL.
         */
        subnetwork?: string;
    }
    interface Schema$UsableSubnetworksAggregatedList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output] A list of usable subnetwork URLs.
         */
        items?: Schema$UsableSubnetwork[];
        /**
         * [Output Only] Type of resource. Always
         * compute#usableSubnetworksAggregatedList for aggregated lists of usable
         * subnetworks.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Secondary IP range of a usable subnetwork.
     */
    interface Schema$UsableSubnetworkSecondaryRange {
        /**
         * The range of IP addresses belonging to this subnetwork secondary range.
         */
        ipCidrRange?: string;
        /**
         * The name associated with this subnetwork secondary range, used when
         * adding an alias IP range to a VM instance. The name must be 1-63
         * characters long, and comply with RFC1035. The name must be unique within
         * the subnetwork.
         */
        rangeName?: string;
    }
    /**
     * The location in Cloud Storage and naming method of the daily usage report.
     * Contains bucket_name and report_name prefix.
     */
    interface Schema$UsageExportLocation {
        /**
         * The name of an existing bucket in Cloud Storage where the usage report
         * object is stored. The Google Service Account is granted write access to
         * this bucket. This can either be the bucket name by itself, such as
         * example-bucket, or the bucket name with gs:// or
         * https://storage.googleapis.com/ in front of it, such as
         * gs://example-bucket.
         */
        bucketName?: string;
        /**
         * An optional prefix for the name of the usage report object stored in
         * bucketName. If not supplied, defaults to usage. The report is stored as a
         * CSV file named report_name_prefix_gce_YYYYMMDD.csv where YYYYMMDD is the
         * day of the usage according to Pacific Time. If you supply a prefix, it
         * should conform to Cloud Storage object naming conventions.
         */
        reportNamePrefix?: string;
    }
    /**
     * Contain information of Nat mapping for a VM endpoint (i.e., NIC).
     */
    interface Schema$VmEndpointNatMappings {
        /**
         * Name of the VM instance which the endpoint belongs to
         */
        instanceName?: string;
        interfaceNatMappings?: Schema$VmEndpointNatMappingsInterfaceNatMappings[];
    }
    /**
     * Contain information of Nat mapping for an interface of this endpoint.
     */
    interface Schema$VmEndpointNatMappingsInterfaceNatMappings {
        /**
         * A list of all IP:port-range mappings assigned to this interface. These
         * ranges are inclusive, that is, both the first and the last ports can be
         * used for NAT. Example: [&quot;2.2.2.2:12345-12355&quot;,
         * &quot;1.1.1.1:2234-2234&quot;].
         */
        natIpPortRanges?: string[];
        /**
         * Total number of ports across all NAT IPs allocated to this interface. It
         * equals to the aggregated port number in the field nat_ip_port_ranges.
         */
        numTotalNatPorts?: number;
        /**
         * Alias IP range for this interface endpoint. It will be a private (RFC
         * 1918) IP range. Examples: &quot;10.33.4.55/32&quot;, or
         * &quot;192.168.5.0/24&quot;.
         */
        sourceAliasIpRange?: string;
        /**
         * Primary IP of the VM for this NIC.
         */
        sourceVirtualIp?: string;
    }
    /**
     * Contains a list of VmEndpointNatMappings.
     */
    interface Schema$VmEndpointNatMappingsList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of resource. Always compute#vmEndpointNatMappingsList
         * for lists of Nat mappings of VM endpoints.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] A list of Nat mapping information of VM endpoints.
         */
        result?: Schema$VmEndpointNatMappings[];
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * VPN tunnel resource. (== resource_for beta.vpnTunnels ==) (== resource_for
     * v1.vpnTunnels ==)
     */
    interface Schema$VpnTunnel {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * An optional description of this resource. Provide this property when you
         * create the resource.
         */
        description?: string;
        /**
         * [Output Only] Detailed status message for the VPN tunnel.
         */
        detailedStatus?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * IKE protocol version to use when establishing the VPN tunnel with the
         * peer VPN gateway. Acceptable IKE versions are 1 or 2. The default version
         * is 2.
         */
        ikeVersion?: number;
        /**
         * [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
         */
        kind?: string;
        /**
         * Local traffic selector to use when establishing the VPN tunnel with the
         * peer VPN gateway. The value should be a CIDR formatted string, for
         * example: 192.168.0.0/16. The ranges must be disjoint. Only IPv4 is
         * supported.
         */
        localTrafficSelector?: string[];
        /**
         * Name of the resource. Provided by the client when the resource is
         * created. The name must be 1-63 characters long, and comply with RFC1035.
         * Specifically, the name must be 1-63 characters long and match the regular
         * expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character
         * must be a lowercase letter, and all following characters must be a dash,
         * lowercase letter, or digit, except the last character, which cannot be a
         * dash.
         */
        name?: string;
        /**
         * IP address of the peer VPN gateway. Only IPv4 is supported.
         */
        peerIp?: string;
        /**
         * [Output Only] URL of the region where the VPN tunnel resides. You must
         * specify this field as part of the HTTP request URL. It is not settable as
         * a field in the request body.
         */
        region?: string;
        /**
         * Remote traffic selectors to use when establishing the VPN tunnel with the
         * peer VPN gateway. The value should be a CIDR formatted string, for
         * example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is
         * supported.
         */
        remoteTrafficSelector?: string[];
        /**
         * URL of the router resource to be used for dynamic routing.
         */
        router?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * Shared secret used to set the secure session between the Cloud VPN
         * gateway and the peer VPN gateway.
         */
        sharedSecret?: string;
        /**
         * Hash of the shared secret.
         */
        sharedSecretHash?: string;
        /**
         * [Output Only] The status of the VPN tunnel, which can be one of the
         * following:  - PROVISIONING: Resource is being allocated for the VPN
         * tunnel.  - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related
         * configs from the user. Network, TargetVpnGateway, VpnTunnel,
         * ForwardingRule, and Route resources are needed to setup the VPN tunnel.
         * - FIRST_HANDSHAKE: Successful first handshake with the peer VPN.  -
         * ESTABLISHED: Secure session is successfully established with the peer
         * VPN.  - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS  -
         * AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).  -
         * NEGOTIATION_FAILURE: Handshake failed.  - DEPROVISIONING: Resources are
         * being deallocated for the VPN tunnel.  - FAILED: Tunnel creation has
         * failed and the tunnel is not ready to be used.
         */
        status?: string;
        /**
         * URL of the Target VPN gateway with which this VPN tunnel is associated.
         * Provided by the client when the VPN tunnel is created.
         */
        targetVpnGateway?: string;
    }
    interface Schema$VpnTunnelAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of VpnTunnelsScopedList resources.
         */
        items?: {
            [key: string]: Schema$VpnTunnelsScopedList;
        };
        /**
         * [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Contains a list of VpnTunnel resources.
     */
    interface Schema$VpnTunnelList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of VpnTunnel resources.
         */
        items?: Schema$VpnTunnel[];
        /**
         * [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$VpnTunnelsScopedList {
        /**
         * A list of VPN tunnels contained in this scope.
         */
        vpnTunnels?: Schema$VpnTunnel[];
        /**
         * Informational warning which replaces the list of addresses when the list
         * is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$XpnHostList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * [Output Only] A list of shared VPC host project URLs.
         */
        items?: Schema$Project[];
        /**
         * [Output Only] Type of resource. Always compute#xpnHostList for lists of
         * shared VPC hosts.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    /**
     * Service resource (a.k.a service project) ID.
     */
    interface Schema$XpnResourceId {
        /**
         * The ID of the service resource. In the case of projects, this field
         * supports project id (e.g., my-project-123) and project number (e.g.
         * 12345678).
         */
        id?: string;
        /**
         * The type of the service resource.
         */
        type?: string;
    }
    /**
     * A Zone resource. (== resource_for beta.zones ==) (== resource_for v1.zones
     * ==)
     */
    interface Schema$Zone {
        /**
         * [Output Only] Available cpu/platform selections for the zone.
         */
        availableCpuPlatforms?: string[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string;
        /**
         * [Output Only] The deprecation status associated with this zone.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] Textual description of the resource.
         */
        description?: string;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is
         * defined by the server.
         */
        id?: string;
        /**
         * [Output Only] Type of the resource. Always compute#zone for zones.
         */
        kind?: string;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string;
        /**
         * [Output Only] Full URL reference to the region which hosts the zone.
         */
        region?: string;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Status of the zone, either UP or DOWN.
         */
        status?: string;
    }
    /**
     * Contains a list of zone resources.
     */
    interface Schema$ZoneList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string;
        /**
         * A list of Zone resources.
         */
        items?: Schema$Zone[];
        /**
         * Type of resource.
         */
        kind?: string;
        /**
         * [Output Only] This token allows you to get the next page of results for
         * list requests. If the number of results is larger than maxResults, use
         * the nextPageToken as a value for the query parameter pageToken in the
         * next list request. Subsequent list requests will have their own
         * nextPageToken to continue paging through the results.
         */
        nextPageToken?: string;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        };
    }
    interface Schema$ZoneSetLabelsRequest {
        /**
         * The fingerprint of the previous set of labels for this resource, used to
         * detect conflicts. The fingerprint is initially generated by Compute
         * Engine and changes after every request to modify or update labels. You
         * must always provide an up-to-date fingerprint hash in order to update or
         * change labels. Make a get() request to the resource to get the latest
         * fingerprint.
         */
        labelFingerprint?: string;
        /**
         * The labels to set for this resource.
         */
        labels?: {
            [key: string]: string;
        };
    }
    interface Schema$ZoneSetPolicyRequest {
        /**
         * Flatten Policy to create a backwacd compatible wire-format. Deprecated.
         * Use &#39;policy&#39; to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated.
         * Use &#39;policy&#39; to specify the etag.
         */
        etag?: string;
        /**
         * REQUIRED: The complete policy to be applied to the &#39;resource&#39;.
         * The size of the policy is limited to a few 10s of KB. An empty policy is
         * in general a valid policy but certain services (like Projects) might
         * reject them.
         */
        policy?: Schema$Policy;
    }
    class Resource$Acceleratortypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.acceleratorTypes.aggregatedList
         * @desc Retrieves an aggregated list of accelerator types.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.acceleratorTypes.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.acceleratorTypes.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.acceleratorTypes.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Acceleratortypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$AcceleratorTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Acceleratortypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>, callback: BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Acceleratortypes$Aggregatedlist, callback: BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>): void;
        /**
         * compute.acceleratorTypes.get
         * @desc Returns the specified accelerator type.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the accelerator type to return.
         *     acceleratorType: 'my-accelerator-type',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.acceleratorTypes.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.acceleratorTypes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.acceleratorType Name of the accelerator type to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Acceleratortypes$Get, options?: MethodOptions): GaxiosPromise<Schema$AcceleratorType>;
        get(params: Params$Resource$Acceleratortypes$Get, options: MethodOptions | BodyResponseCallback<Schema$AcceleratorType>, callback: BodyResponseCallback<Schema$AcceleratorType>): void;
        get(params: Params$Resource$Acceleratortypes$Get, callback: BodyResponseCallback<Schema$AcceleratorType>): void;
        get(callback: BodyResponseCallback<Schema$AcceleratorType>): void;
        /**
         * compute.acceleratorTypes.list
         * @desc Retrieves a list of accelerator types available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.acceleratorTypes.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.acceleratorTypes.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.acceleratorTypes.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Acceleratortypes$List, options?: MethodOptions): GaxiosPromise<Schema$AcceleratorTypeList>;
        list(params: Params$Resource$Acceleratortypes$List, options: MethodOptions | BodyResponseCallback<Schema$AcceleratorTypeList>, callback: BodyResponseCallback<Schema$AcceleratorTypeList>): void;
        list(params: Params$Resource$Acceleratortypes$List, callback: BodyResponseCallback<Schema$AcceleratorTypeList>): void;
        list(callback: BodyResponseCallback<Schema$AcceleratorTypeList>): void;
    }
    interface Params$Resource$Acceleratortypes$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Acceleratortypes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the accelerator type to return.
         */
        acceleratorType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Acceleratortypes$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    class Resource$Addresses {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.addresses.aggregatedList
         * @desc Retrieves an aggregated list of addresses.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.addresses.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.addresses.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.addresses.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Addresses$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$AddressAggregatedList>;
        aggregatedList(params: Params$Resource$Addresses$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$AddressAggregatedList>, callback: BodyResponseCallback<Schema$AddressAggregatedList>): void;
        aggregatedList(params: Params$Resource$Addresses$Aggregatedlist, callback: BodyResponseCallback<Schema$AddressAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$AddressAggregatedList>): void;
        /**
         * compute.addresses.delete
         * @desc Deletes the specified address resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the address resource to delete.
         *     address: 'my-address',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.addresses.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.addresses.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.address Name of the address resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Addresses$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Addresses$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Addresses$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.addresses.get
         * @desc Returns the specified address resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the address resource to return.
         *     address: 'my-address',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.addresses.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.addresses.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.address Name of the address resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Addresses$Get, options?: MethodOptions): GaxiosPromise<Schema$Address>;
        get(params: Params$Resource$Addresses$Get, options: MethodOptions | BodyResponseCallback<Schema$Address>, callback: BodyResponseCallback<Schema$Address>): void;
        get(params: Params$Resource$Addresses$Get, callback: BodyResponseCallback<Schema$Address>): void;
        get(callback: BodyResponseCallback<Schema$Address>): void;
        /**
         * compute.addresses.insert
         * @desc Creates an address resource in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.addresses.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.addresses.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Address} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Addresses$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Addresses$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Addresses$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.addresses.list
         * @desc Retrieves a list of addresses contained within the specified
         * region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.addresses.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.addresses.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.addresses.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Addresses$List, options?: MethodOptions): GaxiosPromise<Schema$AddressList>;
        list(params: Params$Resource$Addresses$List, options: MethodOptions | BodyResponseCallback<Schema$AddressList>, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(params: Params$Resource$Addresses$List, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(callback: BodyResponseCallback<Schema$AddressList>): void;
    }
    interface Params$Resource$Addresses$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Addresses$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the address resource to delete.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Addresses$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the address resource to return.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Addresses$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Address;
    }
    interface Params$Resource$Addresses$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    class Resource$Autoscalers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.autoscalers.aggregatedList
         * @desc Retrieves an aggregated list of autoscalers.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.autoscalers.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.autoscalers.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Autoscalers$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$AutoscalerAggregatedList>;
        aggregatedList(params: Params$Resource$Autoscalers$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$AutoscalerAggregatedList>, callback: BodyResponseCallback<Schema$AutoscalerAggregatedList>): void;
        aggregatedList(params: Params$Resource$Autoscalers$Aggregatedlist, callback: BodyResponseCallback<Schema$AutoscalerAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$AutoscalerAggregatedList>): void;
        /**
         * compute.autoscalers.delete
         * @desc Deletes the specified autoscaler.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the autoscaler to delete.
         *     autoscaler: 'my-autoscaler',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.autoscalers.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.autoscaler Name of the autoscaler to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone Name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Autoscalers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Autoscalers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Autoscalers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.autoscalers.get
         * @desc Returns the specified autoscaler resource. Gets a list of available
         * autoscalers by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the autoscaler to return.
         *     autoscaler: 'my-autoscaler',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.autoscalers.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.autoscaler Name of the autoscaler to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Autoscalers$Get, options?: MethodOptions): GaxiosPromise<Schema$Autoscaler>;
        get(params: Params$Resource$Autoscalers$Get, options: MethodOptions | BodyResponseCallback<Schema$Autoscaler>, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(params: Params$Resource$Autoscalers$Get, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(callback: BodyResponseCallback<Schema$Autoscaler>): void;
        /**
         * compute.autoscalers.insert
         * @desc Creates an autoscaler in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.autoscalers.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone Name of the zone for this request.
         * @param {().Autoscaler} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Autoscalers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Autoscalers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Autoscalers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.autoscalers.list
         * @desc Retrieves a list of autoscalers contained within the specified
         * zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.autoscalers.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.autoscalers.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Autoscalers$List, options?: MethodOptions): GaxiosPromise<Schema$AutoscalerList>;
        list(params: Params$Resource$Autoscalers$List, options: MethodOptions | BodyResponseCallback<Schema$AutoscalerList>, callback: BodyResponseCallback<Schema$AutoscalerList>): void;
        list(params: Params$Resource$Autoscalers$List, callback: BodyResponseCallback<Schema$AutoscalerList>): void;
        list(callback: BodyResponseCallback<Schema$AutoscalerList>): void;
        /**
         * compute.autoscalers.patch
         * @desc Updates an autoscaler in the specified project using the data
         * included in the request. This method supports PATCH semantics and uses
         * the JSON merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.autoscalers.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.autoscaler Name of the autoscaler to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone Name of the zone for this request.
         * @param {().Autoscaler} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Autoscalers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Autoscalers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Autoscalers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.autoscalers.update
         * @desc Updates an autoscaler in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.autoscalers.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.autoscalers.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.autoscaler Name of the autoscaler to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone Name of the zone for this request.
         * @param {().Autoscaler} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Autoscalers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Autoscalers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Autoscalers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Autoscalers$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Autoscalers$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to delete.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Autoscalers$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to return.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Autoscalers$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    interface Params$Resource$Autoscalers$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Autoscalers$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to patch.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    interface Params$Resource$Autoscalers$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to update.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    class Resource$Backendbuckets {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.backendBuckets.addSignedUrlKey
         * @desc Adds a key for validating requests with signed URLs for this
         * backend bucket.
         * @alias compute.backendBuckets.addSignedUrlKey
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendBucket Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().SignedUrlKey} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addSignedUrlKey(params?: Params$Resource$Backendbuckets$Addsignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addSignedUrlKey(params: Params$Resource$Backendbuckets$Addsignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(params: Params$Resource$Backendbuckets$Addsignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendBuckets.delete
         * @desc Deletes the specified BackendBucket resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendBucket resource to delete.
         *     backendBucket: 'my-backend-bucket',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendBuckets.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendBuckets.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendBucket Name of the BackendBucket resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Backendbuckets$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Backendbuckets$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Backendbuckets$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendBuckets.deleteSignedUrlKey
         * @desc Deletes a key for validating requests with signed URLs for this
         * backend bucket.
         * @alias compute.backendBuckets.deleteSignedUrlKey
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendBucket Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         * @param {string} params.keyName The name of the Signed URL Key to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deleteSignedUrlKey(params?: Params$Resource$Backendbuckets$Deletesignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteSignedUrlKey(params: Params$Resource$Backendbuckets$Deletesignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(params: Params$Resource$Backendbuckets$Deletesignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendBuckets.get
         * @desc Returns the specified BackendBucket resource. Gets a list of
         * available backend buckets by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendBucket resource to return.
         *     backendBucket: 'my-backend-bucket',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendBuckets.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendBuckets.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendBucket Name of the BackendBucket resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Backendbuckets$Get, options?: MethodOptions): GaxiosPromise<Schema$BackendBucket>;
        get(params: Params$Resource$Backendbuckets$Get, options: MethodOptions | BodyResponseCallback<Schema$BackendBucket>, callback: BodyResponseCallback<Schema$BackendBucket>): void;
        get(params: Params$Resource$Backendbuckets$Get, callback: BodyResponseCallback<Schema$BackendBucket>): void;
        get(callback: BodyResponseCallback<Schema$BackendBucket>): void;
        /**
         * compute.backendBuckets.insert
         * @desc Creates a BackendBucket resource in the specified project using the
         * data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendBuckets.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendBuckets.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendBucket} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Backendbuckets$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Backendbuckets$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Backendbuckets$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendBuckets.list
         * @desc Retrieves the list of BackendBucket resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.backendBuckets.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.backendBuckets.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendBuckets.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Backendbuckets$List, options?: MethodOptions): GaxiosPromise<Schema$BackendBucketList>;
        list(params: Params$Resource$Backendbuckets$List, options: MethodOptions | BodyResponseCallback<Schema$BackendBucketList>, callback: BodyResponseCallback<Schema$BackendBucketList>): void;
        list(params: Params$Resource$Backendbuckets$List, callback: BodyResponseCallback<Schema$BackendBucketList>): void;
        list(callback: BodyResponseCallback<Schema$BackendBucketList>): void;
        /**
         * compute.backendBuckets.patch
         * @desc Updates the specified BackendBucket resource with the data included
         * in the request. This method supports PATCH semantics and uses the JSON
         * merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendBucket resource to patch.
         *     backendBucket: 'my-backend-bucket',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendBuckets.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendBuckets.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendBucket Name of the BackendBucket resource to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendBucket} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Backendbuckets$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Backendbuckets$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Backendbuckets$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendBuckets.update
         * @desc Updates the specified BackendBucket resource with the data included
         * in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendBucket resource to update.
         *     backendBucket: 'my-backend-bucket',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendBuckets.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendBuckets.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendBucket Name of the BackendBucket resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendBucket} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Backendbuckets$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Backendbuckets$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Backendbuckets$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Backendbuckets$Addsignedurlkey extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendBucket resource to which the Signed URL Key should be
         * added. The name should conform to RFC1035.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SignedUrlKey;
    }
    interface Params$Resource$Backendbuckets$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendBucket resource to delete.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Backendbuckets$Deletesignedurlkey extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendBucket resource to which the Signed URL Key should be
         * added. The name should conform to RFC1035.
         */
        backendBucket?: string;
        /**
         * The name of the Signed URL Key to delete.
         */
        keyName?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Backendbuckets$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendBucket resource to return.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Backendbuckets$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendBucket;
    }
    interface Params$Resource$Backendbuckets$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Backendbuckets$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendBucket resource to patch.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendBucket;
    }
    interface Params$Resource$Backendbuckets$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendBucket resource to update.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendBucket;
    }
    class Resource$Backendservices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.backendServices.addSignedUrlKey
         * @desc Adds a key for validating requests with signed URLs for this
         * backend service.
         * @alias compute.backendServices.addSignedUrlKey
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().SignedUrlKey} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addSignedUrlKey(params?: Params$Resource$Backendservices$Addsignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addSignedUrlKey(params: Params$Resource$Backendservices$Addsignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(params: Params$Resource$Backendservices$Addsignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendServices.aggregatedList
         * @desc Retrieves the list of all BackendService resources, regional and
         * global, available to the specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Name of the project scoping this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.backendServices.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.backendServices.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Name of the project scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Backendservices$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceAggregatedList>;
        aggregatedList(params: Params$Resource$Backendservices$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceAggregatedList>, callback: BodyResponseCallback<Schema$BackendServiceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Backendservices$Aggregatedlist, callback: BodyResponseCallback<Schema$BackendServiceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$BackendServiceAggregatedList>): void;
        /**
         * compute.backendServices.delete
         * @desc Deletes the specified BackendService resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to delete.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendServices.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Backendservices$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Backendservices$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Backendservices$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendServices.deleteSignedUrlKey
         * @desc Deletes a key for validating requests with signed URLs for this
         * backend service.
         * @alias compute.backendServices.deleteSignedUrlKey
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         * @param {string} params.keyName The name of the Signed URL Key to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deleteSignedUrlKey(params?: Params$Resource$Backendservices$Deletesignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteSignedUrlKey(params: Params$Resource$Backendservices$Deletesignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(params: Params$Resource$Backendservices$Deletesignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendServices.get
         * @desc Returns the specified BackendService resource. Gets a list of
         * available backend services.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to return.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendServices.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Backendservices$Get, options?: MethodOptions): GaxiosPromise<Schema$BackendService>;
        get(params: Params$Resource$Backendservices$Get, options: MethodOptions | BodyResponseCallback<Schema$BackendService>, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(params: Params$Resource$Backendservices$Get, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(callback: BodyResponseCallback<Schema$BackendService>): void;
        /**
         * compute.backendServices.getHealth
         * @desc Gets the most recent health check results for this BackendService.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to which the queried instance
         * belongs. backendService: 'my-backend-service',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendServices.getHealth(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.getHealth
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to which the queried instance belongs.
         * @param {string} params.project
         * @param {().ResourceGroupReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getHealth(params?: Params$Resource$Backendservices$Gethealth, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceGroupHealth>;
        getHealth(params: Params$Resource$Backendservices$Gethealth, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceGroupHealth>, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(params: Params$Resource$Backendservices$Gethealth, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        /**
         * compute.backendServices.insert
         * @desc Creates a BackendService resource in the specified project using
         * the data included in the request. There are several restrictions and
         * guidelines to keep in mind when creating a backend service. Read
         * Restrictions and Guidelines for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendServices.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendService} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Backendservices$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Backendservices$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Backendservices$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendServices.list
         * @desc Retrieves the list of BackendService resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.backendServices.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.backendServices.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Backendservices$List, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceList>;
        list(params: Params$Resource$Backendservices$List, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceList>, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(params: Params$Resource$Backendservices$List, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        /**
         * compute.backendServices.patch
         * @desc Patches the specified BackendService resource with the data
         * included in the request. There are several restrictions and guidelines to
         * keep in mind when updating a backend service. Read  Restrictions and
         * Guidelines for more information. This method supports PATCH semantics and
         * uses the JSON merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to patch.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendServices.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendService} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Backendservices$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Backendservices$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Backendservices$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendServices.setSecurityPolicy
         * @desc Sets the security policy for the specified backend service.
         * @alias compute.backendServices.setSecurityPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to which the security policy should be set. The name should conform to RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().SecurityPolicyReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setSecurityPolicy(params?: Params$Resource$Backendservices$Setsecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSecurityPolicy(params: Params$Resource$Backendservices$Setsecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(params: Params$Resource$Backendservices$Setsecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.backendServices.update
         * @desc Updates the specified BackendService resource with the data
         * included in the request. There are several restrictions and guidelines to
         * keep in mind when updating a backend service. Read  Restrictions and
         * Guidelines for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to update.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.backendServices.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.backendServices.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendService} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Backendservices$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Backendservices$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Backendservices$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Backendservices$Addsignedurlkey extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to which the Signed URL Key should be
         * added. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SignedUrlKey;
    }
    interface Params$Resource$Backendservices$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
    }
    interface Params$Resource$Backendservices$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to delete.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Backendservices$Deletesignedurlkey extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to which the Signed URL Key should be
         * added. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * The name of the Signed URL Key to delete.
         */
        keyName?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Backendservices$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to return.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Backendservices$Gethealth extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to which the queried instance
         * belongs.
         */
        backendService?: string;
        /**
         *
         */
        project?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ResourceGroupReference;
    }
    interface Params$Resource$Backendservices$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    interface Params$Resource$Backendservices$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Backendservices$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to patch.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    interface Params$Resource$Backendservices$Setsecuritypolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to which the security policy should
         * be set. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    interface Params$Resource$Backendservices$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to update.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    class Resource$Disks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.disks.aggregatedList
         * @desc Retrieves an aggregated list of persistent disks.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.disks.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.disks.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Disks$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$DiskAggregatedList>;
        aggregatedList(params: Params$Resource$Disks$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$DiskAggregatedList>, callback: BodyResponseCallback<Schema$DiskAggregatedList>): void;
        aggregatedList(params: Params$Resource$Disks$Aggregatedlist, callback: BodyResponseCallback<Schema$DiskAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$DiskAggregatedList>): void;
        /**
         * compute.disks.createSnapshot
         * @desc Creates a snapshot of a specified persistent disk.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the persistent disk to snapshot.
         *     disk: 'my-disk',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.disks.createSnapshot(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.createSnapshot
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the persistent disk to snapshot.
         * @param {boolean=} params.guestFlush
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().Snapshot} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        createSnapshot(params?: Params$Resource$Disks$Createsnapshot, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        createSnapshot(params: Params$Resource$Disks$Createsnapshot, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(params: Params$Resource$Disks$Createsnapshot, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.disks.delete
         * @desc Deletes the specified persistent disk. Deleting a disk removes its
         * data permanently and is irreversible. However, deleting a disk does not
         * delete any snapshots previously made from the disk. You must separately
         * delete snapshots.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the persistent disk to delete.
         *     disk: 'my-disk',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.disks.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the persistent disk to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Disks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Disks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Disks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.disks.get
         * @desc Returns a specified persistent disk. Gets a list of available
         * persistent disks by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the persistent disk to return.
         *     disk: 'my-disk',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.disks.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the persistent disk to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Disks$Get, options?: MethodOptions): GaxiosPromise<Schema$Disk>;
        get(params: Params$Resource$Disks$Get, options: MethodOptions | BodyResponseCallback<Schema$Disk>, callback: BodyResponseCallback<Schema$Disk>): void;
        get(params: Params$Resource$Disks$Get, callback: BodyResponseCallback<Schema$Disk>): void;
        get(callback: BodyResponseCallback<Schema$Disk>): void;
        /**
         * compute.disks.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.disks.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Disks$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Disks$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Disks$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.disks.insert
         * @desc Creates a persistent disk in the specified project using the data
         * in the request. You can create a disk with a sourceImage, a
         * sourceSnapshot, or create an empty 500 GB data disk by omitting all
         * properties. You can also create a disk that is larger than the default
         * size by specifying the sizeGb property.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.disks.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string=} params.sourceImage Optional. Source image to restore onto a disk.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().Disk} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Disks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Disks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Disks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.disks.list
         * @desc Retrieves a list of persistent disks contained within the specified
         * zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.disks.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.disks.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Disks$List, options?: MethodOptions): GaxiosPromise<Schema$DiskList>;
        list(params: Params$Resource$Disks$List, options: MethodOptions | BodyResponseCallback<Schema$DiskList>, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(params: Params$Resource$Disks$List, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(callback: BodyResponseCallback<Schema$DiskList>): void;
        /**
         * compute.disks.resize
         * @desc Resizes the specified persistent disk. You can only increase the
         * size of the disk.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the persistent disk.
         *     disk: 'my-disk',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.disks.resize(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.resize
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk The name of the persistent disk.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().DisksResizeRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        resize(params?: Params$Resource$Disks$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Disks$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Disks$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.disks.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.disks.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().ZoneSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Disks$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Disks$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Disks$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.disks.setLabels
         * @desc Sets the labels on a disk. To learn more about labels, read the
         * Labeling Resources documentation.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the resource for this request.
         *     resource_: 'my-resource',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.disks.setLabels(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.disks.setLabels
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().ZoneSetLabelsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setLabels(params?: Params$Resource$Disks$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Disks$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Disks$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.disks.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.disks.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Disks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Disks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Disks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Disks$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Disks$Createsnapshot extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the persistent disk to snapshot.
         */
        disk?: string;
        /**
         *
         */
        guestFlush?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Snapshot;
    }
    interface Params$Resource$Disks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the persistent disk to delete.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Disks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the persistent disk to return.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Disks$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Disks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Optional. Source image to restore onto a disk.
         */
        sourceImage?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Disk;
    }
    interface Params$Resource$Disks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Disks$Resize extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the persistent disk.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksResizeRequest;
    }
    interface Params$Resource$Disks$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    interface Params$Resource$Disks$Setlabels extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetLabelsRequest;
    }
    interface Params$Resource$Disks$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Disktypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.diskTypes.aggregatedList
         * @desc Retrieves an aggregated list of disk types.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.diskTypes.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.diskTypes.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.diskTypes.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Disktypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$DiskTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Disktypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$DiskTypeAggregatedList>, callback: BodyResponseCallback<Schema$DiskTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Disktypes$Aggregatedlist, callback: BodyResponseCallback<Schema$DiskTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$DiskTypeAggregatedList>): void;
        /**
         * compute.diskTypes.get
         * @desc Returns the specified disk type. Gets a list of available disk
         * types by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the disk type to return.
         *     diskType: 'my-disk-type',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.diskTypes.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.diskTypes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.diskType Name of the disk type to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Disktypes$Get, options?: MethodOptions): GaxiosPromise<Schema$DiskType>;
        get(params: Params$Resource$Disktypes$Get, options: MethodOptions | BodyResponseCallback<Schema$DiskType>, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(params: Params$Resource$Disktypes$Get, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(callback: BodyResponseCallback<Schema$DiskType>): void;
        /**
         * compute.diskTypes.list
         * @desc Retrieves a list of disk types available to the specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.diskTypes.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.diskTypes.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.diskTypes.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Disktypes$List, options?: MethodOptions): GaxiosPromise<Schema$DiskTypeList>;
        list(params: Params$Resource$Disktypes$List, options: MethodOptions | BodyResponseCallback<Schema$DiskTypeList>, callback: BodyResponseCallback<Schema$DiskTypeList>): void;
        list(params: Params$Resource$Disktypes$List, callback: BodyResponseCallback<Schema$DiskTypeList>): void;
        list(callback: BodyResponseCallback<Schema$DiskTypeList>): void;
    }
    interface Params$Resource$Disktypes$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Disktypes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the disk type to return.
         */
        diskType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Disktypes$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    class Resource$Firewalls {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.firewalls.delete
         * @desc Deletes the specified firewall.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the firewall rule to delete.
         *     firewall: 'my-firewall',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.firewalls.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.firewalls.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.firewall Name of the firewall rule to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Firewalls$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Firewalls$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Firewalls$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.firewalls.get
         * @desc Returns the specified firewall.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the firewall rule to return.
         *     firewall: 'my-firewall',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.firewalls.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.firewalls.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.firewall Name of the firewall rule to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Firewalls$Get, options?: MethodOptions): GaxiosPromise<Schema$Firewall>;
        get(params: Params$Resource$Firewalls$Get, options: MethodOptions | BodyResponseCallback<Schema$Firewall>, callback: BodyResponseCallback<Schema$Firewall>): void;
        get(params: Params$Resource$Firewalls$Get, callback: BodyResponseCallback<Schema$Firewall>): void;
        get(callback: BodyResponseCallback<Schema$Firewall>): void;
        /**
         * compute.firewalls.insert
         * @desc Creates a firewall rule in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.firewalls.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.firewalls.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Firewall} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Firewalls$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Firewalls$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Firewalls$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.firewalls.list
         * @desc Retrieves the list of firewall rules available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.firewalls.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.firewalls.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.firewalls.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Firewalls$List, options?: MethodOptions): GaxiosPromise<Schema$FirewallList>;
        list(params: Params$Resource$Firewalls$List, options: MethodOptions | BodyResponseCallback<Schema$FirewallList>, callback: BodyResponseCallback<Schema$FirewallList>): void;
        list(params: Params$Resource$Firewalls$List, callback: BodyResponseCallback<Schema$FirewallList>): void;
        list(callback: BodyResponseCallback<Schema$FirewallList>): void;
        /**
         * compute.firewalls.patch
         * @desc Updates the specified firewall rule with the data included in the
         * request. This method supports PATCH semantics and uses the JSON merge
         * patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the firewall rule to patch.
         *     firewall: 'my-firewall',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.firewalls.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.firewalls.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.firewall Name of the firewall rule to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Firewall} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Firewalls$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Firewalls$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Firewalls$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.firewalls.update
         * @desc Updates the specified firewall rule with the data included in the
         * request. The PUT method can only update the following fields of firewall
         * rule: allowed, description, sourceRanges, sourceTags, targetTags.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the firewall rule to update.
         *     firewall: 'my-firewall',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.firewalls.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.firewalls.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.firewall Name of the firewall rule to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Firewall} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Firewalls$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Firewalls$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Firewalls$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Firewalls$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the firewall rule to delete.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Firewalls$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the firewall rule to return.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Firewalls$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Firewall;
    }
    interface Params$Resource$Firewalls$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Firewalls$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the firewall rule to patch.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Firewall;
    }
    interface Params$Resource$Firewalls$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the firewall rule to update.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Firewall;
    }
    class Resource$Forwardingrules {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.forwardingRules.aggregatedList
         * @desc Retrieves an aggregated list of forwarding rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.forwardingRules.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.forwardingRules.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.forwardingRules.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Forwardingrules$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRuleAggregatedList>;
        aggregatedList(params: Params$Resource$Forwardingrules$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRuleAggregatedList>, callback: BodyResponseCallback<Schema$ForwardingRuleAggregatedList>): void;
        aggregatedList(params: Params$Resource$Forwardingrules$Aggregatedlist, callback: BodyResponseCallback<Schema$ForwardingRuleAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$ForwardingRuleAggregatedList>): void;
        /**
         * compute.forwardingRules.delete
         * @desc Deletes the specified ForwardingRule resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the ForwardingRule resource to delete.
         *     forwardingRule: 'my-forwarding-rule',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.forwardingRules.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.forwardingRules.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.forwardingRule Name of the ForwardingRule resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Forwardingrules$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Forwardingrules$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Forwardingrules$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.forwardingRules.get
         * @desc Returns the specified ForwardingRule resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the ForwardingRule resource to return.
         *     forwardingRule: 'my-forwarding-rule',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.forwardingRules.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.forwardingRules.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.forwardingRule Name of the ForwardingRule resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Forwardingrules$Get, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRule>;
        get(params: Params$Resource$Forwardingrules$Get, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRule>, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(params: Params$Resource$Forwardingrules$Get, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        /**
         * compute.forwardingRules.insert
         * @desc Creates a ForwardingRule resource in the specified project and
         * region using the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.forwardingRules.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.forwardingRules.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().ForwardingRule} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Forwardingrules$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Forwardingrules$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Forwardingrules$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.forwardingRules.list
         * @desc Retrieves a list of ForwardingRule resources available to the
         * specified project and region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.forwardingRules.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.forwardingRules.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.forwardingRules.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Forwardingrules$List, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRuleList>;
        list(params: Params$Resource$Forwardingrules$List, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRuleList>, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(params: Params$Resource$Forwardingrules$List, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        /**
         * compute.forwardingRules.setTarget
         * @desc Changes target URL for forwarding rule. The new target should be of
         * the same type as the old target.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the ForwardingRule resource in which target is to be set.
         *     forwardingRule: 'my-forwarding-rule',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.forwardingRules.setTarget(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.forwardingRules.setTarget
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.forwardingRule Name of the ForwardingRule resource in which target is to be set.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setTarget(params?: Params$Resource$Forwardingrules$Settarget, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTarget(params: Params$Resource$Forwardingrules$Settarget, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(params: Params$Resource$Forwardingrules$Settarget, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Forwardingrules$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Forwardingrules$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the ForwardingRule resource to delete.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Forwardingrules$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the ForwardingRule resource to return.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Forwardingrules$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ForwardingRule;
    }
    interface Params$Resource$Forwardingrules$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Forwardingrules$Settarget extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the ForwardingRule resource in which target is to be set.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetReference;
    }
    class Resource$Globaladdresses {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.globalAddresses.delete
         * @desc Deletes the specified address resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the address resource to delete.
         *     address: 'my-address',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalAddresses.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalAddresses.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.address Name of the address resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Globaladdresses$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Globaladdresses$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Globaladdresses$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.globalAddresses.get
         * @desc Returns the specified address resource. Gets a list of available
         * addresses by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the address resource to return.
         *     address: 'my-address',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalAddresses.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalAddresses.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.address Name of the address resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Globaladdresses$Get, options?: MethodOptions): GaxiosPromise<Schema$Address>;
        get(params: Params$Resource$Globaladdresses$Get, options: MethodOptions | BodyResponseCallback<Schema$Address>, callback: BodyResponseCallback<Schema$Address>): void;
        get(params: Params$Resource$Globaladdresses$Get, callback: BodyResponseCallback<Schema$Address>): void;
        get(callback: BodyResponseCallback<Schema$Address>): void;
        /**
         * compute.globalAddresses.insert
         * @desc Creates an address resource in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalAddresses.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalAddresses.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Address} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Globaladdresses$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Globaladdresses$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Globaladdresses$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.globalAddresses.list
         * @desc Retrieves a list of global addresses.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.globalAddresses.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.globalAddresses.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalAddresses.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Globaladdresses$List, options?: MethodOptions): GaxiosPromise<Schema$AddressList>;
        list(params: Params$Resource$Globaladdresses$List, options: MethodOptions | BodyResponseCallback<Schema$AddressList>, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(params: Params$Resource$Globaladdresses$List, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(callback: BodyResponseCallback<Schema$AddressList>): void;
    }
    interface Params$Resource$Globaladdresses$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the address resource to delete.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Globaladdresses$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the address resource to return.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Globaladdresses$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Address;
    }
    interface Params$Resource$Globaladdresses$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    class Resource$Globalforwardingrules {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.globalForwardingRules.delete
         * @desc Deletes the specified GlobalForwardingRule resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the ForwardingRule resource to delete.
         *     forwardingRule: 'my-forwarding-rule',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalForwardingRules.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalForwardingRules.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.forwardingRule Name of the ForwardingRule resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Globalforwardingrules$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Globalforwardingrules$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Globalforwardingrules$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.globalForwardingRules.get
         * @desc Returns the specified GlobalForwardingRule resource. Gets a list of
         * available forwarding rules by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the ForwardingRule resource to return.
         *     forwardingRule: 'my-forwarding-rule',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalForwardingRules.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalForwardingRules.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.forwardingRule Name of the ForwardingRule resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Globalforwardingrules$Get, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRule>;
        get(params: Params$Resource$Globalforwardingrules$Get, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRule>, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(params: Params$Resource$Globalforwardingrules$Get, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        /**
         * compute.globalForwardingRules.insert
         * @desc Creates a GlobalForwardingRule resource in the specified project
         * using the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalForwardingRules.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalForwardingRules.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().ForwardingRule} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Globalforwardingrules$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Globalforwardingrules$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Globalforwardingrules$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.globalForwardingRules.list
         * @desc Retrieves a list of GlobalForwardingRule resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.globalForwardingRules.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.globalForwardingRules.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalForwardingRules.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Globalforwardingrules$List, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRuleList>;
        list(params: Params$Resource$Globalforwardingrules$List, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRuleList>, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(params: Params$Resource$Globalforwardingrules$List, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        /**
         * compute.globalForwardingRules.setTarget
         * @desc Changes target URL for the GlobalForwardingRule resource. The new
         * target should be of the same type as the old target.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the ForwardingRule resource in which target is to be set.
         *     forwardingRule: 'my-forwarding-rule',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalForwardingRules.setTarget(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalForwardingRules.setTarget
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.forwardingRule Name of the ForwardingRule resource in which target is to be set.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setTarget(params?: Params$Resource$Globalforwardingrules$Settarget, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTarget(params: Params$Resource$Globalforwardingrules$Settarget, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(params: Params$Resource$Globalforwardingrules$Settarget, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Globalforwardingrules$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the ForwardingRule resource to delete.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Globalforwardingrules$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the ForwardingRule resource to return.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Globalforwardingrules$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ForwardingRule;
    }
    interface Params$Resource$Globalforwardingrules$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Globalforwardingrules$Settarget extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the ForwardingRule resource in which target is to be set.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetReference;
    }
    class Resource$Globaloperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.globalOperations.aggregatedList
         * @desc Retrieves an aggregated list of all operations.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.globalOperations.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.globalOperations.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalOperations.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Globaloperations$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$OperationAggregatedList>;
        aggregatedList(params: Params$Resource$Globaloperations$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$OperationAggregatedList>, callback: BodyResponseCallback<Schema$OperationAggregatedList>): void;
        aggregatedList(params: Params$Resource$Globaloperations$Aggregatedlist, callback: BodyResponseCallback<Schema$OperationAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$OperationAggregatedList>): void;
        /**
         * compute.globalOperations.delete
         * @desc Deletes the specified Operations resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the Operations resource to delete.
         *     operation: 'my-operation',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalOperations.delete(request, function(err) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalOperations.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.operation Name of the Operations resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Globaloperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Globaloperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Globaloperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * compute.globalOperations.get
         * @desc Retrieves the specified Operations resource. Gets a list of
         * operations by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the Operations resource to return.
         *     operation: 'my-operation',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.globalOperations.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalOperations.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.operation Name of the Operations resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Globaloperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Globaloperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Globaloperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.globalOperations.list
         * @desc Retrieves a list of Operation resources contained within the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.globalOperations.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.globalOperations.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.globalOperations.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Globaloperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Globaloperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Globaloperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
    }
    interface Params$Resource$Globaloperations$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Globaloperations$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Globaloperations$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Globaloperations$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    class Resource$Healthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.healthChecks.delete
         * @desc Deletes the specified HealthCheck resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HealthCheck resource to delete.
         *     healthCheck: 'my-health-check',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.healthChecks.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.healthChecks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.healthCheck Name of the HealthCheck resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Healthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Healthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Healthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.healthChecks.get
         * @desc Returns the specified HealthCheck resource. Gets a list of
         * available health checks by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HealthCheck resource to return.
         *     healthCheck: 'my-health-check',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.healthChecks.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.healthChecks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.healthCheck Name of the HealthCheck resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Healthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HealthCheck>;
        get(params: Params$Resource$Healthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HealthCheck>, callback: BodyResponseCallback<Schema$HealthCheck>): void;
        get(params: Params$Resource$Healthchecks$Get, callback: BodyResponseCallback<Schema$HealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HealthCheck>): void;
        /**
         * compute.healthChecks.insert
         * @desc Creates a HealthCheck resource in the specified project using the
         * data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.healthChecks.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.healthChecks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Healthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Healthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Healthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.healthChecks.list
         * @desc Retrieves the list of HealthCheck resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.healthChecks.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.healthChecks.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.healthChecks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Healthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HealthCheckList>;
        list(params: Params$Resource$Healthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HealthCheckList>, callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        list(params: Params$Resource$Healthchecks$List, callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        /**
         * compute.healthChecks.patch
         * @desc Updates a HealthCheck resource in the specified project using the
         * data included in the request. This method supports PATCH semantics and
         * uses the JSON merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HealthCheck resource to patch.
         *     healthCheck: 'my-health-check',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.healthChecks.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.healthChecks.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.healthCheck Name of the HealthCheck resource to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Healthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Healthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Healthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.healthChecks.update
         * @desc Updates a HealthCheck resource in the specified project using the
         * data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HealthCheck resource to update.
         *     healthCheck: 'my-health-check',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.healthChecks.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.healthChecks.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.healthCheck Name of the HealthCheck resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Healthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Healthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Healthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Healthchecks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HealthCheck resource to delete.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Healthchecks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HealthCheck resource to return.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Healthchecks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    interface Params$Resource$Healthchecks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Healthchecks$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HealthCheck resource to patch.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    interface Params$Resource$Healthchecks$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HealthCheck resource to update.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    class Resource$Httphealthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.httpHealthChecks.delete
         * @desc Deletes the specified HttpHealthCheck resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpHealthCheck resource to delete.
         *     httpHealthCheck: 'my-http-health-check',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpHealthChecks.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpHealthChecks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpHealthCheck Name of the HttpHealthCheck resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Httphealthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Httphealthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Httphealthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.httpHealthChecks.get
         * @desc Returns the specified HttpHealthCheck resource. Gets a list of
         * available HTTP health checks by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpHealthCheck resource to return.
         *     httpHealthCheck: 'my-http-health-check',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpHealthChecks.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpHealthChecks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpHealthCheck Name of the HttpHealthCheck resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Httphealthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HttpHealthCheck>;
        get(params: Params$Resource$Httphealthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HttpHealthCheck>, callback: BodyResponseCallback<Schema$HttpHealthCheck>): void;
        get(params: Params$Resource$Httphealthchecks$Get, callback: BodyResponseCallback<Schema$HttpHealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HttpHealthCheck>): void;
        /**
         * compute.httpHealthChecks.insert
         * @desc Creates a HttpHealthCheck resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpHealthChecks.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpHealthChecks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HttpHealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Httphealthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Httphealthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Httphealthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.httpHealthChecks.list
         * @desc Retrieves the list of HttpHealthCheck resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.httpHealthChecks.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.httpHealthChecks.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpHealthChecks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Httphealthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HttpHealthCheckList>;
        list(params: Params$Resource$Httphealthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HttpHealthCheckList>, callback: BodyResponseCallback<Schema$HttpHealthCheckList>): void;
        list(params: Params$Resource$Httphealthchecks$List, callback: BodyResponseCallback<Schema$HttpHealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HttpHealthCheckList>): void;
        /**
         * compute.httpHealthChecks.patch
         * @desc Updates a HttpHealthCheck resource in the specified project using
         * the data included in the request. This method supports PATCH semantics
         * and uses the JSON merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpHealthCheck resource to patch.
         *     httpHealthCheck: 'my-http-health-check',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpHealthChecks.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpHealthChecks.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpHealthCheck Name of the HttpHealthCheck resource to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HttpHealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Httphealthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Httphealthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Httphealthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.httpHealthChecks.update
         * @desc Updates a HttpHealthCheck resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpHealthCheck resource to update.
         *     httpHealthCheck: 'my-http-health-check',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpHealthChecks.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpHealthChecks.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpHealthCheck Name of the HttpHealthCheck resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HttpHealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Httphealthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Httphealthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Httphealthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Httphealthchecks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpHealthCheck resource to delete.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Httphealthchecks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpHealthCheck resource to return.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Httphealthchecks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpHealthCheck;
    }
    interface Params$Resource$Httphealthchecks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Httphealthchecks$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpHealthCheck resource to patch.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpHealthCheck;
    }
    interface Params$Resource$Httphealthchecks$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpHealthCheck resource to update.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpHealthCheck;
    }
    class Resource$Httpshealthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.httpsHealthChecks.delete
         * @desc Deletes the specified HttpsHealthCheck resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpsHealthCheck resource to delete.
         *     httpsHealthCheck: 'my-https-health-check',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpsHealthChecks.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpsHealthChecks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpsHealthCheck Name of the HttpsHealthCheck resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Httpshealthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Httpshealthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Httpshealthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.httpsHealthChecks.get
         * @desc Returns the specified HttpsHealthCheck resource. Gets a list of
         * available HTTPS health checks by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpsHealthCheck resource to return.
         *     httpsHealthCheck: 'my-https-health-check',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpsHealthChecks.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpsHealthChecks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpsHealthCheck Name of the HttpsHealthCheck resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Httpshealthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HttpsHealthCheck>;
        get(params: Params$Resource$Httpshealthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HttpsHealthCheck>, callback: BodyResponseCallback<Schema$HttpsHealthCheck>): void;
        get(params: Params$Resource$Httpshealthchecks$Get, callback: BodyResponseCallback<Schema$HttpsHealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HttpsHealthCheck>): void;
        /**
         * compute.httpsHealthChecks.insert
         * @desc Creates a HttpsHealthCheck resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpsHealthChecks.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpsHealthChecks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HttpsHealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Httpshealthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Httpshealthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Httpshealthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.httpsHealthChecks.list
         * @desc Retrieves the list of HttpsHealthCheck resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.httpsHealthChecks.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.httpsHealthChecks.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpsHealthChecks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Httpshealthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HttpsHealthCheckList>;
        list(params: Params$Resource$Httpshealthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HttpsHealthCheckList>, callback: BodyResponseCallback<Schema$HttpsHealthCheckList>): void;
        list(params: Params$Resource$Httpshealthchecks$List, callback: BodyResponseCallback<Schema$HttpsHealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HttpsHealthCheckList>): void;
        /**
         * compute.httpsHealthChecks.patch
         * @desc Updates a HttpsHealthCheck resource in the specified project using
         * the data included in the request. This method supports PATCH semantics
         * and uses the JSON merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpsHealthCheck resource to patch.
         *     httpsHealthCheck: 'my-https-health-check',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpsHealthChecks.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpsHealthChecks.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpsHealthCheck Name of the HttpsHealthCheck resource to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HttpsHealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Httpshealthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Httpshealthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Httpshealthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.httpsHealthChecks.update
         * @desc Updates a HttpsHealthCheck resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the HttpsHealthCheck resource to update.
         *     httpsHealthCheck: 'my-https-health-check',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.httpsHealthChecks.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.httpsHealthChecks.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.httpsHealthCheck Name of the HttpsHealthCheck resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().HttpsHealthCheck} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Httpshealthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Httpshealthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Httpshealthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Httpshealthchecks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpsHealthCheck resource to delete.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Httpshealthchecks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpsHealthCheck resource to return.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Httpshealthchecks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpsHealthCheck;
    }
    interface Params$Resource$Httpshealthchecks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Httpshealthchecks$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpsHealthCheck resource to patch.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpsHealthCheck;
    }
    interface Params$Resource$Httpshealthchecks$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the HttpsHealthCheck resource to update.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpsHealthCheck;
    }
    class Resource$Images {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.images.delete
         * @desc Deletes the specified image.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the image resource to delete.
         *     image: 'my-image',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.images.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.image Name of the image resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Images$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Images$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Images$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.images.deprecate
         * @desc Sets the deprecation status of an image.  If an empty request body
         * is given, clears the deprecation status instead.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Image name.
         *     image: 'my-image',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.images.deprecate(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.deprecate
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.image Image name.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().DeprecationStatus} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deprecate(params?: Params$Resource$Images$Deprecate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deprecate(params: Params$Resource$Images$Deprecate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deprecate(params: Params$Resource$Images$Deprecate, callback: BodyResponseCallback<Schema$Operation>): void;
        deprecate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.images.get
         * @desc Returns the specified image. Gets a list of available images by
         * making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the image resource to return.
         *     image: 'my-image',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.images.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.image Name of the image resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Images$Get, options?: MethodOptions): GaxiosPromise<Schema$Image>;
        get(params: Params$Resource$Images$Get, options: MethodOptions | BodyResponseCallback<Schema$Image>, callback: BodyResponseCallback<Schema$Image>): void;
        get(params: Params$Resource$Images$Get, callback: BodyResponseCallback<Schema$Image>): void;
        get(callback: BodyResponseCallback<Schema$Image>): void;
        /**
         * compute.images.getFromFamily
         * @desc Returns the latest image that is part of an image family and is not
         * deprecated.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the image family to search for.
         *     family: 'my-family',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.images.getFromFamily(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.getFromFamily
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.family Name of the image family to search for.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getFromFamily(params?: Params$Resource$Images$Getfromfamily, options?: MethodOptions): GaxiosPromise<Schema$Image>;
        getFromFamily(params: Params$Resource$Images$Getfromfamily, options: MethodOptions | BodyResponseCallback<Schema$Image>, callback: BodyResponseCallback<Schema$Image>): void;
        getFromFamily(params: Params$Resource$Images$Getfromfamily, callback: BodyResponseCallback<Schema$Image>): void;
        getFromFamily(callback: BodyResponseCallback<Schema$Image>): void;
        /**
         * compute.images.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.images.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Images$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Images$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Images$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.images.insert
         * @desc Creates an image in the specified project using the data included
         * in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.images.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {boolean=} params.forceCreate Force image creation if true.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Image} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Images$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Images$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Images$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.images.list
         * @desc Retrieves the list of custom images available to the specified
         * project. Custom images are images you create that belong to your project.
         * This method does not get any images that belong to other projects,
         * including publicly-available images, like Debian 8. If you want to get a
         * list of publicly-available images, use this method to make a request to
         * the respective image project, such as debian-cloud or windows-cloud.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.images.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.images.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Images$List, options?: MethodOptions): GaxiosPromise<Schema$ImageList>;
        list(params: Params$Resource$Images$List, options: MethodOptions | BodyResponseCallback<Schema$ImageList>, callback: BodyResponseCallback<Schema$ImageList>): void;
        list(params: Params$Resource$Images$List, callback: BodyResponseCallback<Schema$ImageList>): void;
        list(callback: BodyResponseCallback<Schema$ImageList>): void;
        /**
         * compute.images.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.images.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().GlobalSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Images$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Images$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Images$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.images.setLabels
         * @desc Sets the labels on an image. To learn more about labels, read the
         * Labeling Resources documentation.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the resource for this request.
         *     resource_: 'my-resource',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.images.setLabels(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.images.setLabels
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().GlobalSetLabelsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setLabels(params?: Params$Resource$Images$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Images$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Images$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.images.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.images.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Images$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Images$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Images$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Images$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the image resource to delete.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Images$Deprecate extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Image name.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DeprecationStatus;
    }
    interface Params$Resource$Images$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the image resource to return.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Images$Getfromfamily extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the image family to search for.
         */
        family?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Images$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    interface Params$Resource$Images$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Force image creation if true.
         */
        forceCreate?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Image;
    }
    interface Params$Resource$Images$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Images$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    interface Params$Resource$Images$Setlabels extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    interface Params$Resource$Images$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Instancegroupmanagers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.instanceGroupManagers.abandonInstances
         * @desc Flags the specified instances to be removed from the managed
         * instance group. Abandoning an instance does not delete the instance, but
         * it does remove the instance from any target pools that are applied by the
         * managed instance group. This method reduces the targetSize of the managed
         * instance group by the number of instances that you abandon. This
         * operation is marked as DONE when the action is scheduled even if the
         * instances have not yet been removed from the group. You must separately
         * verify the status of the abandoning action with the listmanagedinstances
         * method.  If the group is part of a backend service that has enabled
         * connection draining, it can take up to 60 seconds after the connection
         * draining duration has elapsed before the VM instance is removed or
         * deleted.  You can specify a maximum of 1000 instances with this method
         * per request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.abandonInstances(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.abandonInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {().InstanceGroupManagersAbandonInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        abandonInstances(params?: Params$Resource$Instancegroupmanagers$Abandoninstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        abandonInstances(params: Params$Resource$Instancegroupmanagers$Abandoninstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(params: Params$Resource$Instancegroupmanagers$Abandoninstances, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.aggregatedList
         * @desc Retrieves the list of managed instance groups and groups them by
         * zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instanceGroupManagers.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.instanceGroupManagers.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Instancegroupmanagers$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagerAggregatedList>;
        aggregatedList(params: Params$Resource$Instancegroupmanagers$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>, callback: BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instancegroupmanagers$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>): void;
        /**
         * compute.instanceGroupManagers.delete
         * @desc Deletes the specified managed instance group and all of the
         * instances in that group. Note that the instance group must not belong to
         * a backend service. Read  Deleting an instance group for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group to delete.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Instancegroupmanagers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancegroupmanagers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancegroupmanagers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.deleteInstances
         * @desc Flags the specified instances in the managed instance group for
         * immediate deletion. The instances are also removed from any target pools
         * of which they were a member. This method reduces the targetSize of the
         * managed instance group by the number of instances that you delete. This
         * operation is marked as DONE when the action is scheduled even if the
         * instances are still being deleted. You must separately verify the status
         * of the deleting action with the listmanagedinstances method.  If the
         * group is part of a backend service that has enabled connection draining,
         * it can take up to 60 seconds after the connection draining duration has
         * elapsed before the VM instance is removed or deleted.  You can specify a
         * maximum of 1000 instances with this method per request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.deleteInstances(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.deleteInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {().InstanceGroupManagersDeleteInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deleteInstances(params?: Params$Resource$Instancegroupmanagers$Deleteinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteInstances(params: Params$Resource$Instancegroupmanagers$Deleteinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(params: Params$Resource$Instancegroupmanagers$Deleteinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.get
         * @desc Returns all of the details about the specified managed instance
         * group. Gets a list of available managed instance groups by making a
         * list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Instancegroupmanagers$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManager>;
        get(params: Params$Resource$Instancegroupmanagers$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManager>, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(params: Params$Resource$Instancegroupmanagers$Get, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        /**
         * compute.instanceGroupManagers.insert
         * @desc Creates a managed instance group using the information that you
         * specify in the request. After the group is created, instances in the
         * group are created using the specified instance template. This operation
         * is marked as DONE when the group is created even if the instances in the
         * group have not yet been created. You must separately verify the status of
         * the individual instances with the listmanagedinstances method.  A managed
         * instance group can have up to 1000 VM instances per group. Please contact
         * Cloud Support if you need an increase in this limit.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where you want to create the managed instance
         * group. zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where you want to create the managed instance group.
         * @param {().InstanceGroupManager} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Instancegroupmanagers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancegroupmanagers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancegroupmanagers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.list
         * @desc Retrieves a list of managed instance groups that are contained
         * within the specified project and zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instanceGroupManagers.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.instanceGroupManagers.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Instancegroupmanagers$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagerList>;
        list(params: Params$Resource$Instancegroupmanagers$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagerList>, callback: BodyResponseCallback<Schema$InstanceGroupManagerList>): void;
        list(params: Params$Resource$Instancegroupmanagers$List, callback: BodyResponseCallback<Schema$InstanceGroupManagerList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceGroupManagerList>): void;
        /**
         * compute.instanceGroupManagers.listManagedInstances
         * @desc Lists all of the instances in the managed instance group. Each
         * instance in the list has a currentAction, which indicates the action that
         * the managed instance group is performing on the instance. For example, if
         * the group is still creating an instance, the currentAction is CREATING.
         * If a previous action failed, the list displays the errors for that failed
         * action.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.listManagedInstances(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.listManagedInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.order_by Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listManagedInstances(params?: Params$Resource$Instancegroupmanagers$Listmanagedinstances, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagersListManagedInstancesResponse>;
        listManagedInstances(params: Params$Resource$Instancegroupmanagers$Listmanagedinstances, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>, callback: BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>): void;
        listManagedInstances(params: Params$Resource$Instancegroupmanagers$Listmanagedinstances, callback: BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>): void;
        listManagedInstances(callback: BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>): void;
        /**
         * compute.instanceGroupManagers.patch
         * @desc Updates a managed instance group using the information that you
         * specify in the request. This operation is marked as DONE when the group
         * is patched even if the instances in the group are still in the process of
         * being patched. You must separately verify the status of the individual
         * instances with the listManagedInstances method. This method supports
         * PATCH semantics and uses the JSON merge patch format and processing
         * rules.
         * @alias compute.instanceGroupManagers.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the instance group manager.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where you want to create the managed instance group.
         * @param {().InstanceGroupManager} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Instancegroupmanagers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Instancegroupmanagers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Instancegroupmanagers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.recreateInstances
         * @desc Flags the specified instances in the managed instance group to be
         * immediately recreated. The instances are deleted and recreated using the
         * current instance template for the managed instance group. This operation
         * is marked as DONE when the flag is set even if the instances have not yet
         * been recreated. You must separately verify the status of the recreating
         * action with the listmanagedinstances method.  If the group is part of a
         * backend service that has enabled connection draining, it can take up to
         * 60 seconds after the connection draining duration has elapsed before the
         * VM instance is removed or deleted.  You can specify a maximum of 1000
         * instances with this method per request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.recreateInstances(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.recreateInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {().InstanceGroupManagersRecreateInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        recreateInstances(params?: Params$Resource$Instancegroupmanagers$Recreateinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        recreateInstances(params: Params$Resource$Instancegroupmanagers$Recreateinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(params: Params$Resource$Instancegroupmanagers$Recreateinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.resize
         * @desc Resizes the managed instance group. If you increase the size, the
         * group creates new instances using the current instance template. If you
         * decrease the size, the group deletes instances. The resize operation is
         * marked DONE when the resize actions are scheduled even if the group has
         * not yet added or deleted any instances. You must separately verify the
         * status of the creating or deleting actions with the listmanagedinstances
         * method.  When resizing down, the instance group arbitrarily chooses the
         * order in which VMs are deleted. The group takes into account some VM
         * attributes when making the selection including:  + The status of the VM
         * instance. + The health of the VM instance. + The instance template
         * version the VM is based on. + For regional managed instance groups, the
         * location of the VM instance.  This list is subject to change.  If the
         * group is part of a backend service that has enabled connection draining,
         * it can take up to 60 seconds after the connection draining duration has
         * elapsed before the VM instance is removed or deleted.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     // The number of running instances that the managed instance group
         * should maintain at any given time.
         *     // The group automatically adds or removes instances to maintain the
         * number of instances specified by
         *     // this parameter.
         *     size: 0,  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.resize(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.resize
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {integer} params.size The number of running instances that the managed instance group should maintain at any given time. The group automatically adds or removes instances to maintain the number of instances specified by this parameter.
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        resize(params?: Params$Resource$Instancegroupmanagers$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Instancegroupmanagers$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Instancegroupmanagers$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.setInstanceTemplate
         * @desc Specifies the instance template to use when creating new instances
         * in this group. The templates for existing instances in the group do not
         * change unless you recreate them.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.setInstanceTemplate(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.setInstanceTemplate
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {().InstanceGroupManagersSetInstanceTemplateRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setInstanceTemplate(params?: Params$Resource$Instancegroupmanagers$Setinstancetemplate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setInstanceTemplate(params: Params$Resource$Instancegroupmanagers$Setinstancetemplate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(params: Params$Resource$Instancegroupmanagers$Setinstancetemplate, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroupManagers.setTargetPools
         * @desc Modifies the target pools to which all instances in this managed
         * instance group are assigned. The target pools automatically apply to all
         * of the instances in the managed instance group. This operation is marked
         * DONE when you make the request even if the instances have not yet been
         * added to their target pools. The change might take some time to apply to
         * all of the instances in the group depending on the size of the group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the managed instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroupManagers.setTargetPools(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroupManagers.setTargetPools
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the managed instance group is located.
         * @param {().InstanceGroupManagersSetTargetPoolsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setTargetPools(params?: Params$Resource$Instancegroupmanagers$Settargetpools, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTargetPools(params: Params$Resource$Instancegroupmanagers$Settargetpools, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(params: Params$Resource$Instancegroupmanagers$Settargetpools, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Instancegroupmanagers$Abandoninstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersAbandonInstancesRequest;
    }
    interface Params$Resource$Instancegroupmanagers$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Instancegroupmanagers$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group to delete.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroupmanagers$Deleteinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersDeleteInstancesRequest;
    }
    interface Params$Resource$Instancegroupmanagers$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroupmanagers$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the managed instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    interface Params$Resource$Instancegroupmanagers$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroupmanagers$Listmanagedinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        order_by?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroupmanagers$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the managed instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    interface Params$Resource$Instancegroupmanagers$Recreateinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersRecreateInstancesRequest;
    }
    interface Params$Resource$Instancegroupmanagers$Resize extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The number of running instances that the managed instance group should
         * maintain at any given time. The group automatically adds or removes
         * instances to maintain the number of instances specified by this
         * parameter.
         */
        size?: number;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroupmanagers$Setinstancetemplate extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersSetInstanceTemplateRequest;
    }
    interface Params$Resource$Instancegroupmanagers$Settargetpools extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersSetTargetPoolsRequest;
    }
    class Resource$Instancegroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.instanceGroups.addInstances
         * @desc Adds a list of instances to the specified instance group. All of
         * the instances in the instance group must be in the same
         * network/subnetwork. Read  Adding instances for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the instance group where you are adding instances.
         *     instanceGroup: 'my-instance-group',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroups.addInstances(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.addInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup The name of the instance group where you are adding instances.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {().InstanceGroupsAddInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addInstances(params?: Params$Resource$Instancegroups$Addinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addInstances(params: Params$Resource$Instancegroups$Addinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstances(params: Params$Resource$Instancegroups$Addinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroups.aggregatedList
         * @desc Retrieves the list of instance groups and sorts them by zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instanceGroups.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.instanceGroups.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Instancegroups$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupAggregatedList>;
        aggregatedList(params: Params$Resource$Instancegroups$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupAggregatedList>, callback: BodyResponseCallback<Schema$InstanceGroupAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instancegroups$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceGroupAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceGroupAggregatedList>): void;
        /**
         * compute.instanceGroups.delete
         * @desc Deletes the specified instance group. The instances in the group
         * are not deleted. Note that instance group must not belong to a backend
         * service. Read  Deleting an instance group for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the instance group to delete.
         *     instanceGroup: 'my-instance-group',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroups.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup The name of the instance group to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Instancegroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancegroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancegroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroups.get
         * @desc Returns the specified instance group. Gets a list of available
         * instance groups by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the instance group.
         *     instanceGroup: 'my-instance-group',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroups.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup The name of the instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Instancegroups$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroup>;
        get(params: Params$Resource$Instancegroups$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroup>, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(params: Params$Resource$Instancegroups$Get, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        /**
         * compute.instanceGroups.insert
         * @desc Creates an instance group in the specified project using the
         * parameters that are included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where you want to create the instance group.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroups.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where you want to create the instance group.
         * @param {().InstanceGroup} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Instancegroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancegroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancegroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroups.list
         * @desc Retrieves the list of instance groups that are located in the
         * specified project and zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instanceGroups.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.instanceGroups.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Instancegroups$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupList>;
        list(params: Params$Resource$Instancegroups$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupList>, callback: BodyResponseCallback<Schema$InstanceGroupList>): void;
        list(params: Params$Resource$Instancegroups$List, callback: BodyResponseCallback<Schema$InstanceGroupList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceGroupList>): void;
        /**
         * compute.instanceGroups.listInstances
         * @desc Lists the instances in the specified instance group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the instance group from which you want to generate a
         * list of included instances. instanceGroup: 'my-instance-group',  // TODO:
         * Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instanceGroups.listInstances(request, handlePage);
         *     }
         *   };
         *
         *   compute.instanceGroups.listInstances(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.listInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {string} params.instanceGroup The name of the instance group from which you want to generate a list of included instances.
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {().InstanceGroupsListInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listInstances(params?: Params$Resource$Instancegroups$Listinstances, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupsListInstances>;
        listInstances(params: Params$Resource$Instancegroups$Listinstances, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupsListInstances>, callback: BodyResponseCallback<Schema$InstanceGroupsListInstances>): void;
        listInstances(params: Params$Resource$Instancegroups$Listinstances, callback: BodyResponseCallback<Schema$InstanceGroupsListInstances>): void;
        listInstances(callback: BodyResponseCallback<Schema$InstanceGroupsListInstances>): void;
        /**
         * compute.instanceGroups.removeInstances
         * @desc Removes one or more instances from the specified instance group,
         * but does not delete those instances.  If the group is part of a backend
         * service that has enabled connection draining, it can take up to 60
         * seconds after the connection draining duration before the VM instance is
         * removed or deleted.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the instance group where the specified instances will
         * be removed. instanceGroup: 'my-instance-group',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroups.removeInstances(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.removeInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup The name of the instance group where the specified instances will be removed.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {().InstanceGroupsRemoveInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        removeInstances(params?: Params$Resource$Instancegroups$Removeinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeInstances(params: Params$Resource$Instancegroups$Removeinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstances(params: Params$Resource$Instancegroups$Removeinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceGroups.setNamedPorts
         * @desc Sets the named ports for the specified instance group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone where the instance group is located.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The name of the instance group where the named ports are updated.
         *     instanceGroup: 'my-instance-group',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceGroups.setNamedPorts(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceGroups.setNamedPorts
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup The name of the instance group where the named ports are updated.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the instance group is located.
         * @param {().InstanceGroupsSetNamedPortsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setNamedPorts(params?: Params$Resource$Instancegroups$Setnamedports, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setNamedPorts(params: Params$Resource$Instancegroups$Setnamedports, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(params: Params$Resource$Instancegroups$Setnamedports, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Instancegroups$Addinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group where you are adding instances.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsAddInstancesRequest;
    }
    interface Params$Resource$Instancegroups$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Instancegroups$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group to delete.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroups$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroups$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroup;
    }
    interface Params$Resource$Instancegroups$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
    }
    interface Params$Resource$Instancegroups$Listinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The name of the instance group from which you want to generate a list of
         * included instances.
         */
        instanceGroup?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsListInstancesRequest;
    }
    interface Params$Resource$Instancegroups$Removeinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group where the specified instances will be
         * removed.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsRemoveInstancesRequest;
    }
    interface Params$Resource$Instancegroups$Setnamedports extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group where the named ports are updated.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsSetNamedPortsRequest;
    }
    class Resource$Instances {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.instances.addAccessConfig
         * @desc Adds an access config to an instance's network interface.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The instance name for this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     // The name of the network interface to add to this instance.
         *     networkInterface: '',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.addAccessConfig(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.addAccessConfig
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance The instance name for this request.
         * @param {string} params.networkInterface The name of the network interface to add to this instance.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().AccessConfig} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addAccessConfig(params?: Params$Resource$Instances$Addaccessconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addAccessConfig(params: Params$Resource$Instances$Addaccessconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addAccessConfig(params: Params$Resource$Instances$Addaccessconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        addAccessConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.aggregatedList
         * @desc Retrieves aggregated list of all of the instances in your project
         * across all regions and zones.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instances.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.instances.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Instances$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceAggregatedList>;
        aggregatedList(params: Params$Resource$Instances$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceAggregatedList>, callback: BodyResponseCallback<Schema$InstanceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instances$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceAggregatedList>): void;
        /**
         * compute.instances.attachDisk
         * @desc Attaches an existing Disk resource to an instance. You must first
         * create the disk before you can attach it. It is not possible to create
         * and attach a disk at the same time. For more information, read Adding a
         * persistent disk to your instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The instance name for this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.attachDisk(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.attachDisk
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {boolean=} params.forceAttach Whether to force attach the disk even if it's currently attached to another instance.
         * @param {string} params.instance The instance name for this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().AttachedDisk} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        attachDisk(params?: Params$Resource$Instances$Attachdisk, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        attachDisk(params: Params$Resource$Instances$Attachdisk, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        attachDisk(params: Params$Resource$Instances$Attachdisk, callback: BodyResponseCallback<Schema$Operation>): void;
        attachDisk(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.delete
         * @desc Deletes the specified Instance resource. For more information, see
         * Stopping or Deleting an Instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance resource to delete.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Instances$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instances$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instances$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.deleteAccessConfig
         * @desc Deletes an access config from an instance's network interface.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The instance name for this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     // The name of the access config to delete.
         *     accessConfig: '',  // TODO: Update placeholder value.
         *
         *     // The name of the network interface.
         *     networkInterface: '',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.deleteAccessConfig(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.deleteAccessConfig
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.accessConfig The name of the access config to delete.
         * @param {string} params.instance The instance name for this request.
         * @param {string} params.networkInterface The name of the network interface.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deleteAccessConfig(params?: Params$Resource$Instances$Deleteaccessconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteAccessConfig(params: Params$Resource$Instances$Deleteaccessconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteAccessConfig(params: Params$Resource$Instances$Deleteaccessconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteAccessConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.detachDisk
         * @desc Detaches a disk from an instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Instance name.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     // Disk device name to detach.
         *     deviceName: '',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.detachDisk(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.detachDisk
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.deviceName The device name of the disk to detach. Make a get() request on the instance to view currently attached disks and device names.
         * @param {string} params.instance Instance name for this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        detachDisk(params?: Params$Resource$Instances$Detachdisk, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        detachDisk(params: Params$Resource$Instances$Detachdisk, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        detachDisk(params: Params$Resource$Instances$Detachdisk, callback: BodyResponseCallback<Schema$Operation>): void;
        detachDisk(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.get
         * @desc Returns the specified Instance resource. Gets a list of available
         * instances by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance resource to return.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Instances$Get, options?: MethodOptions): GaxiosPromise<Schema$Instance>;
        get(params: Params$Resource$Instances$Get, options: MethodOptions | BodyResponseCallback<Schema$Instance>, callback: BodyResponseCallback<Schema$Instance>): void;
        get(params: Params$Resource$Instances$Get, callback: BodyResponseCallback<Schema$Instance>): void;
        get(callback: BodyResponseCallback<Schema$Instance>): void;
        /**
         * compute.instances.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.instances.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Instances$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Instances$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Instances$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.instances.getSerialPortOutput
         * @desc Returns the last 1 MB of serial port output from the specified
         * instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.getSerialPortOutput(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.getSerialPortOutput
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {integer=} params.port Specifies which COM or serial port to retrieve data from.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.start Returns output starting from a specific byte position. Use this to page through output when the output is too large to return in a single request. For the initial request, leave this field unspecified. For subsequent calls, this field should be set to the next value returned in the previous call.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getSerialPortOutput(params?: Params$Resource$Instances$Getserialportoutput, options?: MethodOptions): GaxiosPromise<Schema$SerialPortOutput>;
        getSerialPortOutput(params: Params$Resource$Instances$Getserialportoutput, options: MethodOptions | BodyResponseCallback<Schema$SerialPortOutput>, callback: BodyResponseCallback<Schema$SerialPortOutput>): void;
        getSerialPortOutput(params: Params$Resource$Instances$Getserialportoutput, callback: BodyResponseCallback<Schema$SerialPortOutput>): void;
        getSerialPortOutput(callback: BodyResponseCallback<Schema$SerialPortOutput>): void;
        /**
         * compute.instances.getShieldedInstanceIdentity
         * @desc Returns the Shielded Instance Identity of an instance
         * @alias compute.instances.getShieldedInstanceIdentity
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name or id of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getShieldedInstanceIdentity(params?: Params$Resource$Instances$Getshieldedinstanceidentity, options?: MethodOptions): GaxiosPromise<Schema$ShieldedInstanceIdentity>;
        getShieldedInstanceIdentity(params: Params$Resource$Instances$Getshieldedinstanceidentity, options: MethodOptions | BodyResponseCallback<Schema$ShieldedInstanceIdentity>, callback: BodyResponseCallback<Schema$ShieldedInstanceIdentity>): void;
        getShieldedInstanceIdentity(params: Params$Resource$Instances$Getshieldedinstanceidentity, callback: BodyResponseCallback<Schema$ShieldedInstanceIdentity>): void;
        getShieldedInstanceIdentity(callback: BodyResponseCallback<Schema$ShieldedInstanceIdentity>): void;
        /**
         * compute.instances.insert
         * @desc Creates an instance resource in the specified project using the
         * data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string=} params.sourceInstanceTemplate Specifies instance template to create the instance.  This field is optional. It can be a full or partial URL. For example, the following are all valid URLs to an instance template:   - https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate  - projects/project/global/instanceTemplates/instanceTemplate  - global/instanceTemplates/instanceTemplate
         * @param {string} params.zone The name of the zone for this request.
         * @param {().Instance} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Instances$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instances$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instances$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.list
         * @desc Retrieves the list of instances contained within the specified
         * zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instances.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.instances.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Instances$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceList>;
        list(params: Params$Resource$Instances$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceList>, callback: BodyResponseCallback<Schema$InstanceList>): void;
        list(params: Params$Resource$Instances$List, callback: BodyResponseCallback<Schema$InstanceList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceList>): void;
        /**
         * compute.instances.listReferrers
         * @desc Retrieves the list of referrers to instances contained within the
         * specified zone. For more information, read Viewing Referrers to VM
         * Instances.
         * @alias compute.instances.listReferrers
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {string} params.instance Name of the target instance scoping this request, or '-' if the request should span over all instances in the container.
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listReferrers(params?: Params$Resource$Instances$Listreferrers, options?: MethodOptions): GaxiosPromise<Schema$InstanceListReferrers>;
        listReferrers(params: Params$Resource$Instances$Listreferrers, options: MethodOptions | BodyResponseCallback<Schema$InstanceListReferrers>, callback: BodyResponseCallback<Schema$InstanceListReferrers>): void;
        listReferrers(params: Params$Resource$Instances$Listreferrers, callback: BodyResponseCallback<Schema$InstanceListReferrers>): void;
        listReferrers(callback: BodyResponseCallback<Schema$InstanceListReferrers>): void;
        /**
         * compute.instances.reset
         * @desc Performs a reset on the instance. This is a hard reset the VM does
         * not do a graceful shutdown. For more information, see Resetting an
         * instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.reset(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.reset
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        reset(params?: Params$Resource$Instances$Reset, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        reset(params: Params$Resource$Instances$Reset, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        reset(params: Params$Resource$Instances$Reset, callback: BodyResponseCallback<Schema$Operation>): void;
        reset(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setDeletionProtection
         * @desc Sets deletion protection on the instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the resource for this request.
         *     resource_: 'my-resource',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setDeletionProtection(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setDeletionProtection
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {boolean=} params.deletionProtection Whether the resource should be protected against deletion.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setDeletionProtection(params?: Params$Resource$Instances$Setdeletionprotection, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDeletionProtection(params: Params$Resource$Instances$Setdeletionprotection, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDeletionProtection(params: Params$Resource$Instances$Setdeletionprotection, callback: BodyResponseCallback<Schema$Operation>): void;
        setDeletionProtection(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setDiskAutoDelete
         * @desc Sets the auto-delete flag for a disk attached to an instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // The instance name.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     // Whether to auto-delete the disk when the instance is deleted.
         *     autoDelete: false,  // TODO: Update placeholder value.
         *
         *     // The device name of the disk to modify.
         *     deviceName: '',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setDiskAutoDelete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setDiskAutoDelete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {boolean} params.autoDelete Whether to auto-delete the disk when the instance is deleted.
         * @param {string} params.deviceName The device name of the disk to modify. Make a get() request on the instance to view currently attached disks and device names.
         * @param {string} params.instance The instance name for this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setDiskAutoDelete(params?: Params$Resource$Instances$Setdiskautodelete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDiskAutoDelete(params: Params$Resource$Instances$Setdiskautodelete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDiskAutoDelete(params: Params$Resource$Instances$Setdiskautodelete, callback: BodyResponseCallback<Schema$Operation>): void;
        setDiskAutoDelete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.instances.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().ZoneSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Instances$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Instances$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Instances$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.instances.setLabels
         * @desc Sets labels on an instance. To learn more about labels, read the
         * Labeling Resources documentation.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setLabels(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setLabels
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().InstancesSetLabelsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setLabels(params?: Params$Resource$Instances$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Instances$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Instances$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setMachineResources
         * @desc Changes the number and/or type of accelerator for a stopped
         * instance to the values specified in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setMachineResources(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setMachineResources
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().InstancesSetMachineResourcesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setMachineResources(params?: Params$Resource$Instances$Setmachineresources, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMachineResources(params: Params$Resource$Instances$Setmachineresources, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineResources(params: Params$Resource$Instances$Setmachineresources, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineResources(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setMachineType
         * @desc Changes the machine type for a stopped instance to the machine type
         * specified in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setMachineType(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setMachineType
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().InstancesSetMachineTypeRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setMachineType(params?: Params$Resource$Instances$Setmachinetype, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMachineType(params: Params$Resource$Instances$Setmachinetype, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineType(params: Params$Resource$Instances$Setmachinetype, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineType(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setMetadata
         * @desc Sets metadata for the specified instance to the data included in
         * the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setMetadata(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setMetadata
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().Metadata} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setMetadata(params?: Params$Resource$Instances$Setmetadata, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMetadata(params: Params$Resource$Instances$Setmetadata, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMetadata(params: Params$Resource$Instances$Setmetadata, callback: BodyResponseCallback<Schema$Operation>): void;
        setMetadata(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setMinCpuPlatform
         * @desc Changes the minimum CPU platform that this instance should use.
         * This method can only be called on a stopped instance. For more
         * information, read Specifying a Minimum CPU Platform.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setMinCpuPlatform(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setMinCpuPlatform
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().InstancesSetMinCpuPlatformRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setMinCpuPlatform(params?: Params$Resource$Instances$Setmincpuplatform, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMinCpuPlatform(params: Params$Resource$Instances$Setmincpuplatform, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMinCpuPlatform(params: Params$Resource$Instances$Setmincpuplatform, callback: BodyResponseCallback<Schema$Operation>): void;
        setMinCpuPlatform(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setScheduling
         * @desc Sets an instance's scheduling options.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Instance name.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setScheduling(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setScheduling
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Instance name for this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().Scheduling} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setScheduling(params?: Params$Resource$Instances$Setscheduling, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setScheduling(params: Params$Resource$Instances$Setscheduling, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setScheduling(params: Params$Resource$Instances$Setscheduling, callback: BodyResponseCallback<Schema$Operation>): void;
        setScheduling(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setServiceAccount
         * @desc Sets the service account on the instance. For more information,
         * read Changing the service account and access scopes for an instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance resource to start.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setServiceAccount(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setServiceAccount
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance resource to start.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().InstancesSetServiceAccountRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setServiceAccount(params?: Params$Resource$Instances$Setserviceaccount, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setServiceAccount(params: Params$Resource$Instances$Setserviceaccount, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setServiceAccount(params: Params$Resource$Instances$Setserviceaccount, callback: BodyResponseCallback<Schema$Operation>): void;
        setServiceAccount(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setShieldedInstanceIntegrityPolicy
         * @desc Sets the Shielded Instance integrity policy for an instance. You
         * can only use this method on a running instance. This method supports
         * PATCH semantics and uses the JSON merge patch format and processing
         * rules.
         * @alias compute.instances.setShieldedInstanceIntegrityPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name or id of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().ShieldedInstanceIntegrityPolicy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setShieldedInstanceIntegrityPolicy(params?: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setShieldedInstanceIntegrityPolicy(params: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setShieldedInstanceIntegrityPolicy(params: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setShieldedInstanceIntegrityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.setTags
         * @desc Sets network tags for the specified instance to the data included
         * in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance scoping this request.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.setTags(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.setTags
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().Tags} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setTags(params?: Params$Resource$Instances$Settags, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTags(params: Params$Resource$Instances$Settags, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTags(params: Params$Resource$Instances$Settags, callback: BodyResponseCallback<Schema$Operation>): void;
        setTags(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.simulateMaintenanceEvent
         * @desc Simulates a maintenance event on the instance.
         * @alias compute.instances.simulateMaintenanceEvent
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        simulateMaintenanceEvent(params?: Params$Resource$Instances$Simulatemaintenanceevent, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        simulateMaintenanceEvent(params: Params$Resource$Instances$Simulatemaintenanceevent, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        simulateMaintenanceEvent(params: Params$Resource$Instances$Simulatemaintenanceevent, callback: BodyResponseCallback<Schema$Operation>): void;
        simulateMaintenanceEvent(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.start
         * @desc Starts an instance that was stopped using the instances().stop
         * method. For more information, see Restart an instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance resource to start.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.start(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.start
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance resource to start.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        start(params?: Params$Resource$Instances$Start, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        start(params: Params$Resource$Instances$Start, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        start(params: Params$Resource$Instances$Start, callback: BodyResponseCallback<Schema$Operation>): void;
        start(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.startWithEncryptionKey
         * @desc Starts an instance that was stopped using the instances().stop
         * method. For more information, see Restart an instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance resource to start.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.startWithEncryptionKey(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.startWithEncryptionKey
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance resource to start.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().InstancesStartWithEncryptionKeyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        startWithEncryptionKey(params?: Params$Resource$Instances$Startwithencryptionkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        startWithEncryptionKey(params: Params$Resource$Instances$Startwithencryptionkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        startWithEncryptionKey(params: Params$Resource$Instances$Startwithencryptionkey, callback: BodyResponseCallback<Schema$Operation>): void;
        startWithEncryptionKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.stop
         * @desc Stops a running instance, shutting it down cleanly, and allows you
         * to restart the instance at a later time. Stopped instances do not incur
         * VM usage charges while they are stopped. However, resources that the VM
         * is using, such as persistent disks and static IP addresses, will continue
         * to be charged until they are deleted. For more information, see Stopping
         * an instance.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the instance resource to stop.
         *     instance: 'my-instance',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instances.stop(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instances.stop
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name of the instance resource to stop.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        stop(params?: Params$Resource$Instances$Stop, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stop(params: Params$Resource$Instances$Stop, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stop(params: Params$Resource$Instances$Stop, callback: BodyResponseCallback<Schema$Operation>): void;
        stop(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.instances.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Instances$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instances$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instances$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * compute.instances.updateAccessConfig
         * @desc Updates the specified access config from an instance's network
         * interface with the data included in the request. This method supports
         * PATCH semantics and uses the JSON merge patch format and processing
         * rules.
         * @alias compute.instances.updateAccessConfig
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance The instance name for this request.
         * @param {string} params.networkInterface The name of the network interface where the access config is attached.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().AccessConfig} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        updateAccessConfig(params?: Params$Resource$Instances$Updateaccessconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateAccessConfig(params: Params$Resource$Instances$Updateaccessconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateAccessConfig(params: Params$Resource$Instances$Updateaccessconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        updateAccessConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.updateNetworkInterface
         * @desc Updates an instance's network interface. This method follows PATCH
         * semantics.
         * @alias compute.instances.updateNetworkInterface
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance The instance name for this request.
         * @param {string} params.networkInterface The name of the network interface to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().NetworkInterface} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        updateNetworkInterface(params?: Params$Resource$Instances$Updatenetworkinterface, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateNetworkInterface(params: Params$Resource$Instances$Updatenetworkinterface, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateNetworkInterface(params: Params$Resource$Instances$Updatenetworkinterface, callback: BodyResponseCallback<Schema$Operation>): void;
        updateNetworkInterface(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instances.updateShieldedInstanceConfig
         * @desc Updates the Shielded Instance config for an instance. You can only
         * use this method on a stopped instance. This method supports PATCH
         * semantics and uses the JSON merge patch format and processing rules.
         * @alias compute.instances.updateShieldedInstanceConfig
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instance Name or id of the instance scoping this request.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().ShieldedInstanceConfig} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        updateShieldedInstanceConfig(params?: Params$Resource$Instances$Updateshieldedinstanceconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateShieldedInstanceConfig(params: Params$Resource$Instances$Updateshieldedinstanceconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateShieldedInstanceConfig(params: Params$Resource$Instances$Updateshieldedinstanceconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        updateShieldedInstanceConfig(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Instances$Addaccessconfig extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface to add to this instance.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$AccessConfig;
    }
    interface Params$Resource$Instances$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Instances$Attachdisk extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Whether to force attach the disk even if it's currently attached to
         * another instance.
         */
        forceAttach?: boolean;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$AttachedDisk;
    }
    interface Params$Resource$Instances$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance resource to delete.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Deleteaccessconfig extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the access config to delete.
         */
        accessConfig?: string;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Detachdisk extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The device name of the disk to detach. Make a get() request on the
         * instance to view currently attached disks and device names.
         */
        deviceName?: string;
        /**
         * Instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance resource to return.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Getserialportoutput extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Specifies which COM or serial port to retrieve data from.
         */
        port?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Returns output starting from a specific byte position. Use this to page
         * through output when the output is too large to return in a single
         * request. For the initial request, leave this field unspecified. For
         * subsequent calls, this field should be set to the next value returned in
         * the previous call.
         */
        start?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Getshieldedinstanceidentity extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name or id of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Specifies instance template to create the instance.  This field is
         * optional. It can be a full or partial URL. For example, the following are
         * all valid URLs to an instance template:   -
         * https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate
         * - projects/project/global/instanceTemplates/instanceTemplate  -
         * global/instanceTemplates/instanceTemplate
         */
        sourceInstanceTemplate?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Instance;
    }
    interface Params$Resource$Instances$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Listreferrers extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * Name of the target instance scoping this request, or '-' if the request
         * should span over all instances in the container.
         */
        instance?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Reset extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Setdeletionprotection extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Whether the resource should be protected against deletion.
         */
        deletionProtection?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Setdiskautodelete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Whether to auto-delete the disk when the instance is deleted.
         */
        autoDelete?: boolean;
        /**
         * The device name of the disk to modify. Make a get() request on the
         * instance to view currently attached disks and device names.
         */
        deviceName?: string;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    interface Params$Resource$Instances$Setlabels extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetLabelsRequest;
    }
    interface Params$Resource$Instances$Setmachineresources extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetMachineResourcesRequest;
    }
    interface Params$Resource$Instances$Setmachinetype extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetMachineTypeRequest;
    }
    interface Params$Resource$Instances$Setmetadata extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Metadata;
    }
    interface Params$Resource$Instances$Setmincpuplatform extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetMinCpuPlatformRequest;
    }
    interface Params$Resource$Instances$Setscheduling extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Scheduling;
    }
    interface Params$Resource$Instances$Setserviceaccount extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance resource to start.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetServiceAccountRequest;
    }
    interface Params$Resource$Instances$Setshieldedinstanceintegritypolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name or id of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ShieldedInstanceIntegrityPolicy;
    }
    interface Params$Resource$Instances$Settags extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Tags;
    }
    interface Params$Resource$Instances$Simulatemaintenanceevent extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Start extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance resource to start.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Startwithencryptionkey extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance resource to start.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesStartWithEncryptionKeyRequest;
    }
    interface Params$Resource$Instances$Stop extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance resource to stop.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Instances$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    interface Params$Resource$Instances$Updateaccessconfig extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface where the access config is attached.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$AccessConfig;
    }
    interface Params$Resource$Instances$Updatenetworkinterface extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface to update.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkInterface;
    }
    interface Params$Resource$Instances$Updateshieldedinstanceconfig extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name or id of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ShieldedInstanceConfig;
    }
    class Resource$Instancetemplates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.instanceTemplates.delete
         * @desc Deletes the specified instance template. Deleting an instance
         * template is permanent and cannot be undone. It is not possible to delete
         * templates that are already in use by a managed instance group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the instance template to delete.
         *     instanceTemplate: 'my-instance-template',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceTemplates.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceTemplates.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceTemplate The name of the instance template to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Instancetemplates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancetemplates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancetemplates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceTemplates.get
         * @desc Returns the specified instance template. Gets a list of available
         * instance templates by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the instance template.
         *     instanceTemplate: 'my-instance-template',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceTemplates.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceTemplates.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceTemplate The name of the instance template.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Instancetemplates$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplate>;
        get(params: Params$Resource$Instancetemplates$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplate>, callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        get(params: Params$Resource$Instancetemplates$Get, callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        get(callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        /**
         * compute.instanceTemplates.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.instanceTemplates.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Instancetemplates$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Instancetemplates$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Instancetemplates$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.instanceTemplates.insert
         * @desc Creates an instance template in the specified project using the
         * data that is included in the request. If you are creating a new template
         * to update an existing instance group, your new instance template must use
         * the same network or, if applicable, the same subnetwork as the original
         * template.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.instanceTemplates.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceTemplates.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().InstanceTemplate} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Instancetemplates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancetemplates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancetemplates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.instanceTemplates.list
         * @desc Retrieves a list of instance templates that are contained within
         * the specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.instanceTemplates.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.instanceTemplates.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.instanceTemplates.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Instancetemplates$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplateList>;
        list(params: Params$Resource$Instancetemplates$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplateList>, callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        list(params: Params$Resource$Instancetemplates$List, callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        /**
         * compute.instanceTemplates.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.instanceTemplates.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().GlobalSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Instancetemplates$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Instancetemplates$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Instancetemplates$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.instanceTemplates.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.instanceTemplates.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Instancetemplates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instancetemplates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instancetemplates$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Instancetemplates$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance template to delete.
         */
        instanceTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Instancetemplates$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance template.
         */
        instanceTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Instancetemplates$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    interface Params$Resource$Instancetemplates$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceTemplate;
    }
    interface Params$Resource$Instancetemplates$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Instancetemplates$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    interface Params$Resource$Instancetemplates$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Interconnectattachments {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.interconnectAttachments.aggregatedList
         * @desc Retrieves an aggregated list of interconnect attachments.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.interconnectAttachments.aggregatedList(request,
         * handlePage);
         *     }
         *   };
         *
         *   compute.interconnectAttachments.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectAttachments.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Interconnectattachments$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InterconnectAttachmentAggregatedList>;
        aggregatedList(params: Params$Resource$Interconnectattachments$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>, callback: BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>): void;
        aggregatedList(params: Params$Resource$Interconnectattachments$Aggregatedlist, callback: BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>): void;
        /**
         * compute.interconnectAttachments.delete
         * @desc Deletes the specified interconnect attachment.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the interconnect attachment to delete.
         *     interconnectAttachment: 'my-interconnect-attachment',  // TODO:
         * Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnectAttachments.delete(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectAttachments.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnectAttachment Name of the interconnect attachment to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Interconnectattachments$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Interconnectattachments$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Interconnectattachments$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.interconnectAttachments.get
         * @desc Returns the specified interconnect attachment.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the interconnect attachment to return.
         *     interconnectAttachment: 'my-interconnect-attachment',  // TODO:
         * Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnectAttachments.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectAttachments.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnectAttachment Name of the interconnect attachment to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Interconnectattachments$Get, options?: MethodOptions): GaxiosPromise<Schema$InterconnectAttachment>;
        get(params: Params$Resource$Interconnectattachments$Get, options: MethodOptions | BodyResponseCallback<Schema$InterconnectAttachment>, callback: BodyResponseCallback<Schema$InterconnectAttachment>): void;
        get(params: Params$Resource$Interconnectattachments$Get, callback: BodyResponseCallback<Schema$InterconnectAttachment>): void;
        get(callback: BodyResponseCallback<Schema$InterconnectAttachment>): void;
        /**
         * compute.interconnectAttachments.insert
         * @desc Creates an InterconnectAttachment in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnectAttachments.insert(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectAttachments.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().InterconnectAttachment} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Interconnectattachments$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Interconnectattachments$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Interconnectattachments$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.interconnectAttachments.list
         * @desc Retrieves the list of interconnect attachments contained within the
         * specified region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.interconnectAttachments.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.interconnectAttachments.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectAttachments.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Interconnectattachments$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectAttachmentList>;
        list(params: Params$Resource$Interconnectattachments$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectAttachmentList>, callback: BodyResponseCallback<Schema$InterconnectAttachmentList>): void;
        list(params: Params$Resource$Interconnectattachments$List, callback: BodyResponseCallback<Schema$InterconnectAttachmentList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectAttachmentList>): void;
        /**
         * compute.interconnectAttachments.patch
         * @desc Updates the specified interconnect attachment with the data
         * included in the request. This method supports PATCH semantics and uses
         * the JSON merge patch format and processing rules.
         * @alias compute.interconnectAttachments.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnectAttachment Name of the interconnect attachment to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().InterconnectAttachment} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Interconnectattachments$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Interconnectattachments$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Interconnectattachments$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Interconnectattachments$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Interconnectattachments$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect attachment to delete.
         */
        interconnectAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Interconnectattachments$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect attachment to return.
         */
        interconnectAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Interconnectattachments$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InterconnectAttachment;
    }
    interface Params$Resource$Interconnectattachments$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Interconnectattachments$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect attachment to patch.
         */
        interconnectAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InterconnectAttachment;
    }
    class Resource$Interconnectlocations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.interconnectLocations.get
         * @desc Returns the details for the specified interconnect location. Gets a
         * list of available interconnect locations by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the interconnect location to return.
         *     interconnectLocation: 'my-interconnect-location',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnectLocations.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectLocations.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnectLocation Name of the interconnect location to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Interconnectlocations$Get, options?: MethodOptions): GaxiosPromise<Schema$InterconnectLocation>;
        get(params: Params$Resource$Interconnectlocations$Get, options: MethodOptions | BodyResponseCallback<Schema$InterconnectLocation>, callback: BodyResponseCallback<Schema$InterconnectLocation>): void;
        get(params: Params$Resource$Interconnectlocations$Get, callback: BodyResponseCallback<Schema$InterconnectLocation>): void;
        get(callback: BodyResponseCallback<Schema$InterconnectLocation>): void;
        /**
         * compute.interconnectLocations.list
         * @desc Retrieves the list of interconnect locations available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.interconnectLocations.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.interconnectLocations.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnectLocations.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Interconnectlocations$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectLocationList>;
        list(params: Params$Resource$Interconnectlocations$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectLocationList>, callback: BodyResponseCallback<Schema$InterconnectLocationList>): void;
        list(params: Params$Resource$Interconnectlocations$List, callback: BodyResponseCallback<Schema$InterconnectLocationList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectLocationList>): void;
    }
    interface Params$Resource$Interconnectlocations$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect location to return.
         */
        interconnectLocation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Interconnectlocations$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    class Resource$Interconnects {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.interconnects.delete
         * @desc Deletes the specified interconnect.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the interconnect to delete.
         *     interconnect: 'my-interconnect',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnects.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnects.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnect Name of the interconnect to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Interconnects$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Interconnects$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Interconnects$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.interconnects.get
         * @desc Returns the specified interconnect. Get a list of available
         * interconnects by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the interconnect to return.
         *     interconnect: 'my-interconnect',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnects.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnects.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnect Name of the interconnect to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Interconnects$Get, options?: MethodOptions): GaxiosPromise<Schema$Interconnect>;
        get(params: Params$Resource$Interconnects$Get, options: MethodOptions | BodyResponseCallback<Schema$Interconnect>, callback: BodyResponseCallback<Schema$Interconnect>): void;
        get(params: Params$Resource$Interconnects$Get, callback: BodyResponseCallback<Schema$Interconnect>): void;
        get(callback: BodyResponseCallback<Schema$Interconnect>): void;
        /**
         * compute.interconnects.getDiagnostics
         * @desc Returns the interconnectDiagnostics for the specified interconnect.
         * @alias compute.interconnects.getDiagnostics
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnect Name of the interconnect resource to query.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getDiagnostics(params?: Params$Resource$Interconnects$Getdiagnostics, options?: MethodOptions): GaxiosPromise<Schema$InterconnectsGetDiagnosticsResponse>;
        getDiagnostics(params: Params$Resource$Interconnects$Getdiagnostics, options: MethodOptions | BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>, callback: BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>): void;
        getDiagnostics(params: Params$Resource$Interconnects$Getdiagnostics, callback: BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>): void;
        getDiagnostics(callback: BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>): void;
        /**
         * compute.interconnects.insert
         * @desc Creates a Interconnect in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnects.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnects.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Interconnect} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Interconnects$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Interconnects$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Interconnects$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.interconnects.list
         * @desc Retrieves the list of interconnect available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.interconnects.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.interconnects.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnects.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Interconnects$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectList>;
        list(params: Params$Resource$Interconnects$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectList>, callback: BodyResponseCallback<Schema$InterconnectList>): void;
        list(params: Params$Resource$Interconnects$List, callback: BodyResponseCallback<Schema$InterconnectList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectList>): void;
        /**
         * compute.interconnects.patch
         * @desc Updates the specified interconnect with the data included in the
         * request. This method supports PATCH semantics and uses the JSON merge
         * patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the interconnect to update.
         *     interconnect: 'my-interconnect',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.interconnects.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.interconnects.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.interconnect Name of the interconnect to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Interconnect} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Interconnects$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Interconnects$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Interconnects$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Interconnects$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect to delete.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Interconnects$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect to return.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Interconnects$Getdiagnostics extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect resource to query.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Interconnects$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Interconnect;
    }
    interface Params$Resource$Interconnects$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Interconnects$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the interconnect to update.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Interconnect;
    }
    class Resource$Licensecodes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.licenseCodes.get
         * @desc Return a specified license code. License codes are mirrored across
         * all projects that have permissions to read the License Code.
         * @alias compute.licenseCodes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.licenseCode Number corresponding to the License code resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Licensecodes$Get, options?: MethodOptions): GaxiosPromise<Schema$LicenseCode>;
        get(params: Params$Resource$Licensecodes$Get, options: MethodOptions | BodyResponseCallback<Schema$LicenseCode>, callback: BodyResponseCallback<Schema$LicenseCode>): void;
        get(params: Params$Resource$Licensecodes$Get, callback: BodyResponseCallback<Schema$LicenseCode>): void;
        get(callback: BodyResponseCallback<Schema$LicenseCode>): void;
        /**
         * compute.licenseCodes.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.licenseCodes.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Licensecodes$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Licensecodes$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Licensecodes$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Licensecodes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Number corresponding to the License code resource to return.
         */
        licenseCode?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Licensecodes$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Licenses {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.licenses.delete
         * @desc Deletes the specified license.
         * @alias compute.licenses.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.license Name of the license resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Licenses$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Licenses$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Licenses$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.licenses.get
         * @desc Returns the specified License resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the License resource to return.
         *     license: 'my-license',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.licenses.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.licenses.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.license Name of the License resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Licenses$Get, options?: MethodOptions): GaxiosPromise<Schema$License>;
        get(params: Params$Resource$Licenses$Get, options: MethodOptions | BodyResponseCallback<Schema$License>, callback: BodyResponseCallback<Schema$License>): void;
        get(params: Params$Resource$Licenses$Get, callback: BodyResponseCallback<Schema$License>): void;
        get(callback: BodyResponseCallback<Schema$License>): void;
        /**
         * compute.licenses.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.licenses.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Licenses$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Licenses$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Licenses$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.licenses.insert
         * @desc Create a License resource in the specified project.
         * @alias compute.licenses.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().License} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Licenses$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Licenses$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Licenses$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.licenses.list
         * @desc Retrieves the list of licenses available in the specified project.
         * This method does not get any licenses that belong to other projects,
         * including licenses attached to publicly-available images, like Debian 9.
         * If you want to get a list of publicly-available licenses, use this method
         * to make a request to the respective image project, such as debian-cloud
         * or windows-cloud.
         * @alias compute.licenses.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Licenses$List, options?: MethodOptions): GaxiosPromise<Schema$LicensesListResponse>;
        list(params: Params$Resource$Licenses$List, options: MethodOptions | BodyResponseCallback<Schema$LicensesListResponse>, callback: BodyResponseCallback<Schema$LicensesListResponse>): void;
        list(params: Params$Resource$Licenses$List, callback: BodyResponseCallback<Schema$LicensesListResponse>): void;
        list(callback: BodyResponseCallback<Schema$LicensesListResponse>): void;
        /**
         * compute.licenses.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.licenses.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().GlobalSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Licenses$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Licenses$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Licenses$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.licenses.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.licenses.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Licenses$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Licenses$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Licenses$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Licenses$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the license resource to delete.
         */
        license?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Licenses$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the License resource to return.
         */
        license?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Licenses$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    interface Params$Resource$Licenses$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$License;
    }
    interface Params$Resource$Licenses$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Licenses$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    interface Params$Resource$Licenses$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Machinetypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.machineTypes.aggregatedList
         * @desc Retrieves an aggregated list of machine types.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.machineTypes.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.machineTypes.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.machineTypes.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Machinetypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$MachineTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Machinetypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$MachineTypeAggregatedList>, callback: BodyResponseCallback<Schema$MachineTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Machinetypes$Aggregatedlist, callback: BodyResponseCallback<Schema$MachineTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$MachineTypeAggregatedList>): void;
        /**
         * compute.machineTypes.get
         * @desc Returns the specified machine type. Gets a list of available
         * machine types by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the machine type to return.
         *     machineType: 'my-machine-type',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.machineTypes.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.machineTypes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.machineType Name of the machine type to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Machinetypes$Get, options?: MethodOptions): GaxiosPromise<Schema$MachineType>;
        get(params: Params$Resource$Machinetypes$Get, options: MethodOptions | BodyResponseCallback<Schema$MachineType>, callback: BodyResponseCallback<Schema$MachineType>): void;
        get(params: Params$Resource$Machinetypes$Get, callback: BodyResponseCallback<Schema$MachineType>): void;
        get(callback: BodyResponseCallback<Schema$MachineType>): void;
        /**
         * compute.machineTypes.list
         * @desc Retrieves a list of machine types available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // The name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.machineTypes.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.machineTypes.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.machineTypes.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Machinetypes$List, options?: MethodOptions): GaxiosPromise<Schema$MachineTypeList>;
        list(params: Params$Resource$Machinetypes$List, options: MethodOptions | BodyResponseCallback<Schema$MachineTypeList>, callback: BodyResponseCallback<Schema$MachineTypeList>): void;
        list(params: Params$Resource$Machinetypes$List, callback: BodyResponseCallback<Schema$MachineTypeList>): void;
        list(callback: BodyResponseCallback<Schema$MachineTypeList>): void;
    }
    interface Params$Resource$Machinetypes$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Machinetypes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the machine type to return.
         */
        machineType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Machinetypes$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    class Resource$Networkendpointgroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.networkEndpointGroups.aggregatedList
         * @desc Retrieves the list of network endpoint groups and sorts them by
         * zone.
         * @alias compute.networkEndpointGroups.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Networkendpointgroups$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupAggregatedList>;
        aggregatedList(params: Params$Resource$Networkendpointgroups$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>): void;
        aggregatedList(params: Params$Resource$Networkendpointgroups$Aggregatedlist, callback: BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>): void;
        /**
         * compute.networkEndpointGroups.attachNetworkEndpoints
         * @desc Attach a list of network endpoints to the specified network
         * endpoint group.
         * @alias compute.networkEndpointGroups.attachNetworkEndpoints
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.networkEndpointGroup The name of the network endpoint group where you are attaching network endpoints to. It should comply with RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         * @param {().NetworkEndpointGroupsAttachEndpointsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        attachNetworkEndpoints(params?: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        attachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networkEndpointGroups.delete
         * @desc Deletes the specified network endpoint group. The network endpoints
         * in the NEG and the VM instances they belong to are not terminated when
         * the NEG is deleted. Note that the NEG cannot be deleted if there are
         * backend services referencing it.
         * @alias compute.networkEndpointGroups.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.networkEndpointGroup The name of the network endpoint group to delete. It should comply with RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Networkendpointgroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networkendpointgroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networkendpointgroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networkEndpointGroups.detachNetworkEndpoints
         * @desc Detach a list of network endpoints from the specified network
         * endpoint group.
         * @alias compute.networkEndpointGroups.detachNetworkEndpoints
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.networkEndpointGroup The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         * @param {().NetworkEndpointGroupsDetachEndpointsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        detachNetworkEndpoints(params?: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        detachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networkEndpointGroups.get
         * @desc Returns the specified network endpoint group. Gets a list of
         * available network endpoint groups by making a list() request.
         * @alias compute.networkEndpointGroups.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.networkEndpointGroup The name of the network endpoint group. It should comply with RFC1035.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Networkendpointgroups$Get, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroup>;
        get(params: Params$Resource$Networkendpointgroups$Get, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroup>, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(params: Params$Resource$Networkendpointgroups$Get, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        /**
         * compute.networkEndpointGroups.insert
         * @desc Creates a network endpoint group in the specified project using the
         * parameters that are included in the request.
         * @alias compute.networkEndpointGroups.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone where you want to create the network endpoint group. It should comply with RFC1035.
         * @param {().NetworkEndpointGroup} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Networkendpointgroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networkendpointgroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networkendpointgroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networkEndpointGroups.list
         * @desc Retrieves the list of network endpoint groups that are located in
         * the specified project and zone.
         * @alias compute.networkEndpointGroups.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Networkendpointgroups$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupList>;
        list(params: Params$Resource$Networkendpointgroups$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupList>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(params: Params$Resource$Networkendpointgroups$List, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        /**
         * compute.networkEndpointGroups.listNetworkEndpoints
         * @desc Lists the network endpoints in the specified network endpoint
         * group.
         * @alias compute.networkEndpointGroups.listNetworkEndpoints
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string} params.networkEndpointGroup The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         * @param {().NetworkEndpointGroupsListEndpointsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listNetworkEndpoints(params?: Params$Resource$Networkendpointgroups$Listnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupsListNetworkEndpoints>;
        listNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Listnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Listnetworkendpoints, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        /**
         * compute.networkEndpointGroups.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.networkEndpointGroups.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Networkendpointgroups$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Networkendpointgroups$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Networkendpointgroups$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Networkendpointgroups$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Networkendpointgroups$Attachnetworkendpoints extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the network endpoint group where you are attaching network
         * endpoints to. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the network endpoint group is located. It
         * should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroupsAttachEndpointsRequest;
    }
    interface Params$Resource$Networkendpointgroups$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the network endpoint group to delete. It should comply with
         * RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the network endpoint group is located. It
         * should comply with RFC1035.
         */
        zone?: string;
    }
    interface Params$Resource$Networkendpointgroups$Detachnetworkendpoints extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the network endpoint group where you are removing network
         * endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the network endpoint group is located. It
         * should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroupsDetachEndpointsRequest;
    }
    interface Params$Resource$Networkendpointgroups$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the network endpoint group. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the network endpoint group is located. It
         * should comply with RFC1035.
         */
        zone?: string;
    }
    interface Params$Resource$Networkendpointgroups$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the network endpoint group.
         * It should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroup;
    }
    interface Params$Resource$Networkendpointgroups$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the network endpoint group is located. It
         * should comply with RFC1035.
         */
        zone?: string;
    }
    interface Params$Resource$Networkendpointgroups$Listnetworkendpoints extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * The name of the network endpoint group from which you want to generate a
         * list of included network endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the network endpoint group is located. It
         * should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroupsListEndpointsRequest;
    }
    interface Params$Resource$Networkendpointgroups$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Networks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.networks.addPeering
         * @desc Adds a peering to the specified network.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the network resource to add peering to.
         *     network: 'my-network',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.addPeering(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.addPeering
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.network Name of the network resource to add peering to.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().NetworksAddPeeringRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addPeering(params?: Params$Resource$Networks$Addpeering, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addPeering(params: Params$Resource$Networks$Addpeering, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addPeering(params: Params$Resource$Networks$Addpeering, callback: BodyResponseCallback<Schema$Operation>): void;
        addPeering(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networks.delete
         * @desc Deletes the specified network.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the network to delete.
         *     network: 'my-network',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.network Name of the network to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Networks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networks.get
         * @desc Returns the specified network. Gets a list of available networks by
         * making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the network to return.
         *     network: 'my-network',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.network Name of the network to return.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Networks$Get, options?: MethodOptions): GaxiosPromise<Schema$Network>;
        get(params: Params$Resource$Networks$Get, options: MethodOptions | BodyResponseCallback<Schema$Network>, callback: BodyResponseCallback<Schema$Network>): void;
        get(params: Params$Resource$Networks$Get, callback: BodyResponseCallback<Schema$Network>): void;
        get(callback: BodyResponseCallback<Schema$Network>): void;
        /**
         * compute.networks.insert
         * @desc Creates a network in the specified project using the data included
         * in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Network} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Networks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networks.list
         * @desc Retrieves the list of networks available to the specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.networks.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.networks.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Networks$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkList>;
        list(params: Params$Resource$Networks$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkList>, callback: BodyResponseCallback<Schema$NetworkList>): void;
        list(params: Params$Resource$Networks$List, callback: BodyResponseCallback<Schema$NetworkList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkList>): void;
        /**
         * compute.networks.patch
         * @desc Patches the specified network with the data included in the
         * request. Only the following fields can be modified:
         * routingConfig.routingMode.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the network to update.
         *     network: 'my-network',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.network Name of the network to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Network} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Networks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Networks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Networks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networks.removePeering
         * @desc Removes a peering from the specified network.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the network resource to remove peering from.
         *     network: 'my-network',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.removePeering(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.removePeering
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.network Name of the network resource to remove peering from.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().NetworksRemovePeeringRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        removePeering(params?: Params$Resource$Networks$Removepeering, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removePeering(params: Params$Resource$Networks$Removepeering, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removePeering(params: Params$Resource$Networks$Removepeering, callback: BodyResponseCallback<Schema$Operation>): void;
        removePeering(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.networks.switchToCustomMode
         * @desc Switches the network mode from auto subnet mode to custom subnet
         * mode.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the network to be updated.
         *     network: 'my-network',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.networks.switchToCustomMode(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.networks.switchToCustomMode
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.network Name of the network to be updated.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        switchToCustomMode(params?: Params$Resource$Networks$Switchtocustommode, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        switchToCustomMode(params: Params$Resource$Networks$Switchtocustommode, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        switchToCustomMode(params: Params$Resource$Networks$Switchtocustommode, callback: BodyResponseCallback<Schema$Operation>): void;
        switchToCustomMode(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Networks$Addpeering extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the network resource to add peering to.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworksAddPeeringRequest;
    }
    interface Params$Resource$Networks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the network to delete.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Networks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the network to return.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Networks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Network;
    }
    interface Params$Resource$Networks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Networks$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the network to update.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Network;
    }
    interface Params$Resource$Networks$Removepeering extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the network resource to remove peering from.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworksRemovePeeringRequest;
    }
    interface Params$Resource$Networks$Switchtocustommode extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the network to be updated.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    class Resource$Nodegroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.nodeGroups.addNodes
         * @desc Adds specified number of nodes to the node group.
         * @alias compute.nodeGroups.addNodes
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeGroup Name of the NodeGroup resource.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().NodeGroupsAddNodesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addNodes(params?: Params$Resource$Nodegroups$Addnodes, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addNodes(params: Params$Resource$Nodegroups$Addnodes, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addNodes(params: Params$Resource$Nodegroups$Addnodes, callback: BodyResponseCallback<Schema$Operation>): void;
        addNodes(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeGroups.aggregatedList
         * @desc Retrieves an aggregated list of node groups. Note: use
         * nodeGroups.listNodes for more details about each group.
         * @alias compute.nodeGroups.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Nodegroups$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NodeGroupAggregatedList>;
        aggregatedList(params: Params$Resource$Nodegroups$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NodeGroupAggregatedList>, callback: BodyResponseCallback<Schema$NodeGroupAggregatedList>): void;
        aggregatedList(params: Params$Resource$Nodegroups$Aggregatedlist, callback: BodyResponseCallback<Schema$NodeGroupAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NodeGroupAggregatedList>): void;
        /**
         * compute.nodeGroups.delete
         * @desc Deletes the specified NodeGroup resource.
         * @alias compute.nodeGroups.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeGroup Name of the NodeGroup resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Nodegroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Nodegroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Nodegroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeGroups.deleteNodes
         * @desc Deletes specified nodes from the node group.
         * @alias compute.nodeGroups.deleteNodes
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeGroup Name of the NodeGroup resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().NodeGroupsDeleteNodesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deleteNodes(params?: Params$Resource$Nodegroups$Deletenodes, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteNodes(params: Params$Resource$Nodegroups$Deletenodes, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteNodes(params: Params$Resource$Nodegroups$Deletenodes, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteNodes(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeGroups.get
         * @desc Returns the specified NodeGroup. Get a list of available NodeGroups
         * by making a list() request. Note: the "nodes" field should not be used.
         * Use nodeGroups.listNodes instead.
         * @alias compute.nodeGroups.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeGroup Name of the node group to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Nodegroups$Get, options?: MethodOptions): GaxiosPromise<Schema$NodeGroup>;
        get(params: Params$Resource$Nodegroups$Get, options: MethodOptions | BodyResponseCallback<Schema$NodeGroup>, callback: BodyResponseCallback<Schema$NodeGroup>): void;
        get(params: Params$Resource$Nodegroups$Get, callback: BodyResponseCallback<Schema$NodeGroup>): void;
        get(callback: BodyResponseCallback<Schema$NodeGroup>): void;
        /**
         * compute.nodeGroups.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.nodeGroups.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Nodegroups$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Nodegroups$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Nodegroups$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.nodeGroups.insert
         * @desc Creates a NodeGroup resource in the specified project using the
         * data included in the request.
         * @alias compute.nodeGroups.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {integer} params.initialNodeCount Initial count of nodes in the node group.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().NodeGroup} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Nodegroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Nodegroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Nodegroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeGroups.list
         * @desc Retrieves a list of node groups available to the specified project.
         * Note: use nodeGroups.listNodes for more details about each group.
         * @alias compute.nodeGroups.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Nodegroups$List, options?: MethodOptions): GaxiosPromise<Schema$NodeGroupList>;
        list(params: Params$Resource$Nodegroups$List, options: MethodOptions | BodyResponseCallback<Schema$NodeGroupList>, callback: BodyResponseCallback<Schema$NodeGroupList>): void;
        list(params: Params$Resource$Nodegroups$List, callback: BodyResponseCallback<Schema$NodeGroupList>): void;
        list(callback: BodyResponseCallback<Schema$NodeGroupList>): void;
        /**
         * compute.nodeGroups.listNodes
         * @desc Lists nodes in the node group.
         * @alias compute.nodeGroups.listNodes
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string} params.nodeGroup Name of the NodeGroup resource whose nodes you want to list.
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listNodes(params?: Params$Resource$Nodegroups$Listnodes, options?: MethodOptions): GaxiosPromise<Schema$NodeGroupsListNodes>;
        listNodes(params: Params$Resource$Nodegroups$Listnodes, options: MethodOptions | BodyResponseCallback<Schema$NodeGroupsListNodes>, callback: BodyResponseCallback<Schema$NodeGroupsListNodes>): void;
        listNodes(params: Params$Resource$Nodegroups$Listnodes, callback: BodyResponseCallback<Schema$NodeGroupsListNodes>): void;
        listNodes(callback: BodyResponseCallback<Schema$NodeGroupsListNodes>): void;
        /**
         * compute.nodeGroups.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.nodeGroups.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().ZoneSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Nodegroups$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Nodegroups$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Nodegroups$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.nodeGroups.setNodeTemplate
         * @desc Updates the node template of the node group.
         * @alias compute.nodeGroups.setNodeTemplate
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeGroup Name of the NodeGroup resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone The name of the zone for this request.
         * @param {().NodeGroupsSetNodeTemplateRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setNodeTemplate(params?: Params$Resource$Nodegroups$Setnodetemplate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setNodeTemplate(params: Params$Resource$Nodegroups$Setnodetemplate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setNodeTemplate(params: Params$Resource$Nodegroups$Setnodetemplate, callback: BodyResponseCallback<Schema$Operation>): void;
        setNodeTemplate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeGroups.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.nodeGroups.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Nodegroups$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Nodegroups$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Nodegroups$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Nodegroups$Addnodes extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the NodeGroup resource.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsAddNodesRequest;
    }
    interface Params$Resource$Nodegroups$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Nodegroups$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the NodeGroup resource to delete.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Nodegroups$Deletenodes extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the NodeGroup resource to delete.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsDeleteNodesRequest;
    }
    interface Params$Resource$Nodegroups$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the node group to return.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Nodegroups$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Nodegroups$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Initial count of nodes in the node group.
         */
        initialNodeCount?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroup;
    }
    interface Params$Resource$Nodegroups$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Nodegroups$Listnodes extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Name of the NodeGroup resource whose nodes you want to list.
         */
        nodeGroup?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Nodegroups$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    interface Params$Resource$Nodegroups$Setnodetemplate extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the NodeGroup resource to update.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsSetNodeTemplateRequest;
    }
    interface Params$Resource$Nodegroups$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Nodetemplates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.nodeTemplates.aggregatedList
         * @desc Retrieves an aggregated list of node templates.
         * @alias compute.nodeTemplates.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Nodetemplates$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NodeTemplateAggregatedList>;
        aggregatedList(params: Params$Resource$Nodetemplates$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NodeTemplateAggregatedList>, callback: BodyResponseCallback<Schema$NodeTemplateAggregatedList>): void;
        aggregatedList(params: Params$Resource$Nodetemplates$Aggregatedlist, callback: BodyResponseCallback<Schema$NodeTemplateAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NodeTemplateAggregatedList>): void;
        /**
         * compute.nodeTemplates.delete
         * @desc Deletes the specified NodeTemplate resource.
         * @alias compute.nodeTemplates.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeTemplate Name of the NodeTemplate resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Nodetemplates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Nodetemplates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Nodetemplates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeTemplates.get
         * @desc Returns the specified node template. Gets a list of available node
         * templates by making a list() request.
         * @alias compute.nodeTemplates.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeTemplate Name of the node template to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Nodetemplates$Get, options?: MethodOptions): GaxiosPromise<Schema$NodeTemplate>;
        get(params: Params$Resource$Nodetemplates$Get, options: MethodOptions | BodyResponseCallback<Schema$NodeTemplate>, callback: BodyResponseCallback<Schema$NodeTemplate>): void;
        get(params: Params$Resource$Nodetemplates$Get, callback: BodyResponseCallback<Schema$NodeTemplate>): void;
        get(callback: BodyResponseCallback<Schema$NodeTemplate>): void;
        /**
         * compute.nodeTemplates.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.nodeTemplates.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Nodetemplates$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Nodetemplates$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Nodetemplates$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.nodeTemplates.insert
         * @desc Creates a NodeTemplate resource in the specified project using the
         * data included in the request.
         * @alias compute.nodeTemplates.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().NodeTemplate} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Nodetemplates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Nodetemplates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Nodetemplates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.nodeTemplates.list
         * @desc Retrieves a list of node templates available to the specified
         * project.
         * @alias compute.nodeTemplates.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Nodetemplates$List, options?: MethodOptions): GaxiosPromise<Schema$NodeTemplateList>;
        list(params: Params$Resource$Nodetemplates$List, options: MethodOptions | BodyResponseCallback<Schema$NodeTemplateList>, callback: BodyResponseCallback<Schema$NodeTemplateList>): void;
        list(params: Params$Resource$Nodetemplates$List, callback: BodyResponseCallback<Schema$NodeTemplateList>): void;
        list(callback: BodyResponseCallback<Schema$NodeTemplateList>): void;
        /**
         * compute.nodeTemplates.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.nodeTemplates.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().RegionSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Nodetemplates$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Nodetemplates$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Nodetemplates$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.nodeTemplates.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.nodeTemplates.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Nodetemplates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Nodetemplates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Nodetemplates$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Nodetemplates$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Nodetemplates$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the NodeTemplate resource to delete.
         */
        nodeTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Nodetemplates$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the node template to return.
         */
        nodeTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Nodetemplates$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    interface Params$Resource$Nodetemplates$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeTemplate;
    }
    interface Params$Resource$Nodetemplates$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Nodetemplates$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    interface Params$Resource$Nodetemplates$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Nodetypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.nodeTypes.aggregatedList
         * @desc Retrieves an aggregated list of node types.
         * @alias compute.nodeTypes.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Nodetypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NodeTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Nodetypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NodeTypeAggregatedList>, callback: BodyResponseCallback<Schema$NodeTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Nodetypes$Aggregatedlist, callback: BodyResponseCallback<Schema$NodeTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NodeTypeAggregatedList>): void;
        /**
         * compute.nodeTypes.get
         * @desc Returns the specified node type. Gets a list of available node
         * types by making a list() request.
         * @alias compute.nodeTypes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.nodeType Name of the node type to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Nodetypes$Get, options?: MethodOptions): GaxiosPromise<Schema$NodeType>;
        get(params: Params$Resource$Nodetypes$Get, options: MethodOptions | BodyResponseCallback<Schema$NodeType>, callback: BodyResponseCallback<Schema$NodeType>): void;
        get(params: Params$Resource$Nodetypes$Get, callback: BodyResponseCallback<Schema$NodeType>): void;
        get(callback: BodyResponseCallback<Schema$NodeType>): void;
        /**
         * compute.nodeTypes.list
         * @desc Retrieves a list of node types available to the specified project.
         * @alias compute.nodeTypes.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone The name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Nodetypes$List, options?: MethodOptions): GaxiosPromise<Schema$NodeTypeList>;
        list(params: Params$Resource$Nodetypes$List, options: MethodOptions | BodyResponseCallback<Schema$NodeTypeList>, callback: BodyResponseCallback<Schema$NodeTypeList>): void;
        list(params: Params$Resource$Nodetypes$List, callback: BodyResponseCallback<Schema$NodeTypeList>): void;
        list(callback: BodyResponseCallback<Schema$NodeTypeList>): void;
    }
    interface Params$Resource$Nodetypes$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Nodetypes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the node type to return.
         */
        nodeType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Nodetypes$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    class Resource$Projects {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.projects.disableXpnHost
         * @desc Disable this project as a shared VPC host project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.disableXpnHost(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.disableXpnHost
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        disableXpnHost(params?: Params$Resource$Projects$Disablexpnhost, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        disableXpnHost(params: Params$Resource$Projects$Disablexpnhost, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnHost(params: Params$Resource$Projects$Disablexpnhost, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnHost(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.disableXpnResource
         * @desc Disable a serivce resource (a.k.a service project) associated with
         * this host project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.disableXpnResource(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.disableXpnResource
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().ProjectsDisableXpnResourceRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        disableXpnResource(params?: Params$Resource$Projects$Disablexpnresource, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        disableXpnResource(params: Params$Resource$Projects$Disablexpnresource, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnResource(params: Params$Resource$Projects$Disablexpnresource, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnResource(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.enableXpnHost
         * @desc Enable this project as a shared VPC host project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.enableXpnHost(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.enableXpnHost
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        enableXpnHost(params?: Params$Resource$Projects$Enablexpnhost, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        enableXpnHost(params: Params$Resource$Projects$Enablexpnhost, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnHost(params: Params$Resource$Projects$Enablexpnhost, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnHost(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.enableXpnResource
         * @desc Enable service resource (a.k.a service project) for a host project,
         * so that subnets in the host project can be used by instances in the
         * service project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.enableXpnResource(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.enableXpnResource
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().ProjectsEnableXpnResourceRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        enableXpnResource(params?: Params$Resource$Projects$Enablexpnresource, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        enableXpnResource(params: Params$Resource$Projects$Enablexpnresource, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnResource(params: Params$Resource$Projects$Enablexpnresource, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnResource(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.get
         * @desc Returns the specified Project resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Projects$Get, options?: MethodOptions): GaxiosPromise<Schema$Project>;
        get(params: Params$Resource$Projects$Get, options: MethodOptions | BodyResponseCallback<Schema$Project>, callback: BodyResponseCallback<Schema$Project>): void;
        get(params: Params$Resource$Projects$Get, callback: BodyResponseCallback<Schema$Project>): void;
        get(callback: BodyResponseCallback<Schema$Project>): void;
        /**
         * compute.projects.getXpnHost
         * @desc Gets the shared VPC host project that this project links to. May be
         * empty if no link exists.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.getXpnHost(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.getXpnHost
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getXpnHost(params?: Params$Resource$Projects$Getxpnhost, options?: MethodOptions): GaxiosPromise<Schema$Project>;
        getXpnHost(params: Params$Resource$Projects$Getxpnhost, options: MethodOptions | BodyResponseCallback<Schema$Project>, callback: BodyResponseCallback<Schema$Project>): void;
        getXpnHost(params: Params$Resource$Projects$Getxpnhost, callback: BodyResponseCallback<Schema$Project>): void;
        getXpnHost(callback: BodyResponseCallback<Schema$Project>): void;
        /**
         * compute.projects.getXpnResources
         * @desc Gets service resources (a.k.a service project) associated with this
         * host project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var resourcesPage = response['resources'];
         *     if (!resourcesPage) {
         *       return;
         *     }
         *     for (var i = 0; i < resourcesPage.length; i++) {
         *       // TODO: Change code below to process each resource in
         * `resourcesPage`: console.log(JSON.stringify(resourcesPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.projects.getXpnResources(request, handlePage);
         *     }
         *   };
         *
         *   compute.projects.getXpnResources(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.getXpnResources
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.order_by Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getXpnResources(params?: Params$Resource$Projects$Getxpnresources, options?: MethodOptions): GaxiosPromise<Schema$ProjectsGetXpnResources>;
        getXpnResources(params: Params$Resource$Projects$Getxpnresources, options: MethodOptions | BodyResponseCallback<Schema$ProjectsGetXpnResources>, callback: BodyResponseCallback<Schema$ProjectsGetXpnResources>): void;
        getXpnResources(params: Params$Resource$Projects$Getxpnresources, callback: BodyResponseCallback<Schema$ProjectsGetXpnResources>): void;
        getXpnResources(callback: BodyResponseCallback<Schema$ProjectsGetXpnResources>): void;
        /**
         * compute.projects.listXpnHosts
         * @desc Lists all shared VPC host projects visible to the user in an
         * organization.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.projects.listXpnHosts(request, handlePage);
         *     }
         *   };
         *
         *   compute.projects.listXpnHosts(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.listXpnHosts
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.order_by Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {().ProjectsListXpnHostsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listXpnHosts(params?: Params$Resource$Projects$Listxpnhosts, options?: MethodOptions): GaxiosPromise<Schema$XpnHostList>;
        listXpnHosts(params: Params$Resource$Projects$Listxpnhosts, options: MethodOptions | BodyResponseCallback<Schema$XpnHostList>, callback: BodyResponseCallback<Schema$XpnHostList>): void;
        listXpnHosts(params: Params$Resource$Projects$Listxpnhosts, callback: BodyResponseCallback<Schema$XpnHostList>): void;
        listXpnHosts(callback: BodyResponseCallback<Schema$XpnHostList>): void;
        /**
         * compute.projects.moveDisk
         * @desc Moves a persistent disk from one zone to another.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.moveDisk(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.moveDisk
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().DiskMoveRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        moveDisk(params?: Params$Resource$Projects$Movedisk, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        moveDisk(params: Params$Resource$Projects$Movedisk, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        moveDisk(params: Params$Resource$Projects$Movedisk, callback: BodyResponseCallback<Schema$Operation>): void;
        moveDisk(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.moveInstance
         * @desc Moves an instance and its attached persistent disks from one zone
         * to another.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.moveInstance(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.moveInstance
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().InstanceMoveRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        moveInstance(params?: Params$Resource$Projects$Moveinstance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        moveInstance(params: Params$Resource$Projects$Moveinstance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        moveInstance(params: Params$Resource$Projects$Moveinstance, callback: BodyResponseCallback<Schema$Operation>): void;
        moveInstance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.setCommonInstanceMetadata
         * @desc Sets metadata common to all instances within the specified project
         * using the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.setCommonInstanceMetadata(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.setCommonInstanceMetadata
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Metadata} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setCommonInstanceMetadata(params?: Params$Resource$Projects$Setcommoninstancemetadata, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setCommonInstanceMetadata(params: Params$Resource$Projects$Setcommoninstancemetadata, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setCommonInstanceMetadata(params: Params$Resource$Projects$Setcommoninstancemetadata, callback: BodyResponseCallback<Schema$Operation>): void;
        setCommonInstanceMetadata(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.setDefaultNetworkTier
         * @desc Sets the default network tier of the project. The default network
         * tier is used when an address/forwardingRule/instance is created without
         * specifying the network tier field.
         * @alias compute.projects.setDefaultNetworkTier
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().ProjectsSetDefaultNetworkTierRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setDefaultNetworkTier(params?: Params$Resource$Projects$Setdefaultnetworktier, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDefaultNetworkTier(params: Params$Resource$Projects$Setdefaultnetworktier, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDefaultNetworkTier(params: Params$Resource$Projects$Setdefaultnetworktier, callback: BodyResponseCallback<Schema$Operation>): void;
        setDefaultNetworkTier(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.projects.setUsageExportBucket
         * @desc Enables the usage export feature and sets the usage export bucket
         * where reports are stored. If you provide an empty request body using this
         * method, the usage export feature will be disabled.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.projects.setUsageExportBucket(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.projects.setUsageExportBucket
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().UsageExportLocation} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setUsageExportBucket(params?: Params$Resource$Projects$Setusageexportbucket, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUsageExportBucket(params: Params$Resource$Projects$Setusageexportbucket, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUsageExportBucket(params: Params$Resource$Projects$Setusageexportbucket, callback: BodyResponseCallback<Schema$Operation>): void;
        setUsageExportBucket(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Projects$Disablexpnhost extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Projects$Disablexpnresource extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsDisableXpnResourceRequest;
    }
    interface Params$Resource$Projects$Enablexpnhost extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Projects$Enablexpnresource extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsEnableXpnResourceRequest;
    }
    interface Params$Resource$Projects$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Projects$Getxpnhost extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Projects$Getxpnresources extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        order_by?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Projects$Listxpnhosts extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        order_by?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsListXpnHostsRequest;
    }
    interface Params$Resource$Projects$Movedisk extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DiskMoveRequest;
    }
    interface Params$Resource$Projects$Moveinstance extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceMoveRequest;
    }
    interface Params$Resource$Projects$Setcommoninstancemetadata extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Metadata;
    }
    interface Params$Resource$Projects$Setdefaultnetworktier extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsSetDefaultNetworkTierRequest;
    }
    interface Params$Resource$Projects$Setusageexportbucket extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UsageExportLocation;
    }
    class Resource$Regionautoscalers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionAutoscalers.delete
         * @desc Deletes the specified autoscaler.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the autoscaler to delete.
         *     autoscaler: 'my-autoscaler',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionAutoscalers.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionAutoscalers.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.autoscaler Name of the autoscaler to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Regionautoscalers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionautoscalers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionautoscalers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionAutoscalers.get
         * @desc Returns the specified autoscaler.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the autoscaler to return.
         *     autoscaler: 'my-autoscaler',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionAutoscalers.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionAutoscalers.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.autoscaler Name of the autoscaler to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regionautoscalers$Get, options?: MethodOptions): GaxiosPromise<Schema$Autoscaler>;
        get(params: Params$Resource$Regionautoscalers$Get, options: MethodOptions | BodyResponseCallback<Schema$Autoscaler>, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(params: Params$Resource$Regionautoscalers$Get, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(callback: BodyResponseCallback<Schema$Autoscaler>): void;
        /**
         * compute.regionAutoscalers.insert
         * @desc Creates an autoscaler in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionAutoscalers.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionAutoscalers.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Autoscaler} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Regionautoscalers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionautoscalers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionautoscalers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionAutoscalers.list
         * @desc Retrieves a list of autoscalers contained within the specified
         * region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionAutoscalers.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionAutoscalers.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionAutoscalers.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regionautoscalers$List, options?: MethodOptions): GaxiosPromise<Schema$RegionAutoscalerList>;
        list(params: Params$Resource$Regionautoscalers$List, options: MethodOptions | BodyResponseCallback<Schema$RegionAutoscalerList>, callback: BodyResponseCallback<Schema$RegionAutoscalerList>): void;
        list(params: Params$Resource$Regionautoscalers$List, callback: BodyResponseCallback<Schema$RegionAutoscalerList>): void;
        list(callback: BodyResponseCallback<Schema$RegionAutoscalerList>): void;
        /**
         * compute.regionAutoscalers.patch
         * @desc Updates an autoscaler in the specified project using the data
         * included in the request. This method supports PATCH semantics and uses
         * the JSON merge patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionAutoscalers.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionAutoscalers.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.autoscaler Name of the autoscaler to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Autoscaler} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Regionautoscalers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionautoscalers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionautoscalers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionAutoscalers.update
         * @desc Updates an autoscaler in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionAutoscalers.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionAutoscalers.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.autoscaler Name of the autoscaler to update.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Autoscaler} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Regionautoscalers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regionautoscalers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regionautoscalers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Regionautoscalers$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to delete.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Regionautoscalers$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to return.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regionautoscalers$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    interface Params$Resource$Regionautoscalers$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regionautoscalers$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to patch.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    interface Params$Resource$Regionautoscalers$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the autoscaler to update.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    class Resource$Regionbackendservices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionBackendServices.delete
         * @desc Deletes the specified regional BackendService resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to delete.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionBackendServices.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Regionbackendservices$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionbackendservices$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionbackendservices$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionBackendServices.get
         * @desc Returns the specified regional BackendService resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to return.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionBackendServices.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regionbackendservices$Get, options?: MethodOptions): GaxiosPromise<Schema$BackendService>;
        get(params: Params$Resource$Regionbackendservices$Get, options: MethodOptions | BodyResponseCallback<Schema$BackendService>, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(params: Params$Resource$Regionbackendservices$Get, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(callback: BodyResponseCallback<Schema$BackendService>): void;
        /**
         * compute.regionBackendServices.getHealth
         * @desc Gets the most recent health check results for this regional
         * BackendService.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to which the queried instance
         * belongs. backendService: 'my-backend-service',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionBackendServices.getHealth(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.getHealth
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource for which to get health.
         * @param {string} params.project
         * @param {string} params.region Name of the region scoping this request.
         * @param {().ResourceGroupReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getHealth(params?: Params$Resource$Regionbackendservices$Gethealth, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceGroupHealth>;
        getHealth(params: Params$Resource$Regionbackendservices$Gethealth, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceGroupHealth>, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(params: Params$Resource$Regionbackendservices$Gethealth, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        /**
         * compute.regionBackendServices.insert
         * @desc Creates a regional BackendService resource in the specified project
         * using the data included in the request. There are several restrictions
         * and guidelines to keep in mind when creating a regional backend service.
         * Read  Restrictions and Guidelines for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionBackendServices.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendService} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Regionbackendservices$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionbackendservices$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionbackendservices$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionBackendServices.list
         * @desc Retrieves the list of regional BackendService resources available
         * to the specified project in the given region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionBackendServices.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionBackendServices.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regionbackendservices$List, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceList>;
        list(params: Params$Resource$Regionbackendservices$List, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceList>, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(params: Params$Resource$Regionbackendservices$List, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        /**
         * compute.regionBackendServices.patch
         * @desc Updates the specified regional BackendService resource with the
         * data included in the request. There are several restrictions and
         * guidelines to keep in mind when updating a backend service. Read
         * Restrictions and Guidelines for more information. This method supports
         * PATCH semantics and uses the JSON merge patch format and processing
         * rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to patch.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionBackendServices.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendService} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Regionbackendservices$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionbackendservices$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionbackendservices$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionBackendServices.update
         * @desc Updates the specified regional BackendService resource with the
         * data included in the request. There are several restrictions and
         * guidelines to keep in mind when updating a backend service. Read
         * Restrictions and Guidelines for more information.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the BackendService resource to update.
         *     backendService: 'my-backend-service',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionBackendServices.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionBackendServices.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.backendService Name of the BackendService resource to update.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().BackendService} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Regionbackendservices$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regionbackendservices$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regionbackendservices$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Regionbackendservices$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to delete.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Regionbackendservices$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to return.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regionbackendservices$Gethealth extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource for which to get health.
         */
        backendService?: string;
        /**
         *
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ResourceGroupReference;
    }
    interface Params$Resource$Regionbackendservices$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    interface Params$Resource$Regionbackendservices$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regionbackendservices$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to patch.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    interface Params$Resource$Regionbackendservices$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the BackendService resource to update.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    class Resource$Regioncommitments {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionCommitments.aggregatedList
         * @desc Retrieves an aggregated list of commitments.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionCommitments.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionCommitments.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionCommitments.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Regioncommitments$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$CommitmentAggregatedList>;
        aggregatedList(params: Params$Resource$Regioncommitments$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$CommitmentAggregatedList>, callback: BodyResponseCallback<Schema$CommitmentAggregatedList>): void;
        aggregatedList(params: Params$Resource$Regioncommitments$Aggregatedlist, callback: BodyResponseCallback<Schema$CommitmentAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$CommitmentAggregatedList>): void;
        /**
         * compute.regionCommitments.get
         * @desc Returns the specified commitment resource. Gets a list of available
         * commitments by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the commitment to return.
         *     commitment: 'my-commitment',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionCommitments.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionCommitments.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.commitment Name of the commitment to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regioncommitments$Get, options?: MethodOptions): GaxiosPromise<Schema$Commitment>;
        get(params: Params$Resource$Regioncommitments$Get, options: MethodOptions | BodyResponseCallback<Schema$Commitment>, callback: BodyResponseCallback<Schema$Commitment>): void;
        get(params: Params$Resource$Regioncommitments$Get, callback: BodyResponseCallback<Schema$Commitment>): void;
        get(callback: BodyResponseCallback<Schema$Commitment>): void;
        /**
         * compute.regionCommitments.insert
         * @desc Creates a commitment in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionCommitments.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionCommitments.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Commitment} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Regioncommitments$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regioncommitments$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regioncommitments$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionCommitments.list
         * @desc Retrieves a list of commitments contained within the specified
         * region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionCommitments.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionCommitments.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionCommitments.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regioncommitments$List, options?: MethodOptions): GaxiosPromise<Schema$CommitmentList>;
        list(params: Params$Resource$Regioncommitments$List, options: MethodOptions | BodyResponseCallback<Schema$CommitmentList>, callback: BodyResponseCallback<Schema$CommitmentList>): void;
        list(params: Params$Resource$Regioncommitments$List, callback: BodyResponseCallback<Schema$CommitmentList>): void;
        list(callback: BodyResponseCallback<Schema$CommitmentList>): void;
    }
    interface Params$Resource$Regioncommitments$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Regioncommitments$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the commitment to return.
         */
        commitment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Regioncommitments$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Commitment;
    }
    interface Params$Resource$Regioncommitments$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    class Resource$Regiondisks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionDisks.createSnapshot
         * @desc Creates a snapshot of this regional disk.
         * @alias compute.regionDisks.createSnapshot
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the regional persistent disk to snapshot.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Snapshot} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        createSnapshot(params?: Params$Resource$Regiondisks$Createsnapshot, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        createSnapshot(params: Params$Resource$Regiondisks$Createsnapshot, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(params: Params$Resource$Regiondisks$Createsnapshot, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionDisks.delete
         * @desc Deletes the specified regional persistent disk. Deleting a regional
         * disk removes all the replicas of its data permanently and is
         * irreversible. However, deleting a disk does not delete any snapshots
         * previously made from the disk. You must separately delete snapshots.
         * @alias compute.regionDisks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the regional persistent disk to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Regiondisks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regiondisks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regiondisks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionDisks.get
         * @desc Returns a specified regional persistent disk.
         * @alias compute.regionDisks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the regional persistent disk to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regiondisks$Get, options?: MethodOptions): GaxiosPromise<Schema$Disk>;
        get(params: Params$Resource$Regiondisks$Get, options: MethodOptions | BodyResponseCallback<Schema$Disk>, callback: BodyResponseCallback<Schema$Disk>): void;
        get(params: Params$Resource$Regiondisks$Get, callback: BodyResponseCallback<Schema$Disk>): void;
        get(callback: BodyResponseCallback<Schema$Disk>): void;
        /**
         * compute.regionDisks.insert
         * @desc Creates a persistent regional disk in the specified project using
         * the data included in the request.
         * @alias compute.regionDisks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string=} params.sourceImage Optional. Source image to restore onto a disk.
         * @param {().Disk} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Regiondisks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regiondisks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regiondisks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionDisks.list
         * @desc Retrieves the list of persistent disks contained within the
         * specified region.
         * @alias compute.regionDisks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regiondisks$List, options?: MethodOptions): GaxiosPromise<Schema$DiskList>;
        list(params: Params$Resource$Regiondisks$List, options: MethodOptions | BodyResponseCallback<Schema$DiskList>, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(params: Params$Resource$Regiondisks$List, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(callback: BodyResponseCallback<Schema$DiskList>): void;
        /**
         * compute.regionDisks.resize
         * @desc Resizes the specified regional persistent disk.
         * @alias compute.regionDisks.resize
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.disk Name of the regional persistent disk.
         * @param {string} params.project The project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionDisksResizeRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        resize(params?: Params$Resource$Regiondisks$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Regiondisks$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Regiondisks$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionDisks.setLabels
         * @desc Sets the labels on the target regional disk.
         * @alias compute.regionDisks.setLabels
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().RegionSetLabelsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setLabels(params?: Params$Resource$Regiondisks$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Regiondisks$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Regiondisks$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionDisks.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.regionDisks.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Regiondisks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regiondisks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regiondisks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Regiondisks$Createsnapshot extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the regional persistent disk to snapshot.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Snapshot;
    }
    interface Params$Resource$Regiondisks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the regional persistent disk to delete.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Regiondisks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the regional persistent disk to return.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Regiondisks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Optional. Source image to restore onto a disk.
         */
        sourceImage?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Disk;
    }
    interface Params$Resource$Regiondisks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Regiondisks$Resize extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the regional persistent disk.
         */
        disk?: string;
        /**
         * The project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionDisksResizeRequest;
    }
    interface Params$Resource$Regiondisks$Setlabels extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    interface Params$Resource$Regiondisks$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Regiondisktypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionDiskTypes.get
         * @desc Returns the specified regional disk type. Gets a list of available
         * disk types by making a list() request.
         * @alias compute.regionDiskTypes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.diskType Name of the disk type to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regiondisktypes$Get, options?: MethodOptions): GaxiosPromise<Schema$DiskType>;
        get(params: Params$Resource$Regiondisktypes$Get, options: MethodOptions | BodyResponseCallback<Schema$DiskType>, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(params: Params$Resource$Regiondisktypes$Get, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(callback: BodyResponseCallback<Schema$DiskType>): void;
        /**
         * compute.regionDiskTypes.list
         * @desc Retrieves a list of regional disk types available to the specified
         * project.
         * @alias compute.regionDiskTypes.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regiondisktypes$List, options?: MethodOptions): GaxiosPromise<Schema$RegionDiskTypeList>;
        list(params: Params$Resource$Regiondisktypes$List, options: MethodOptions | BodyResponseCallback<Schema$RegionDiskTypeList>, callback: BodyResponseCallback<Schema$RegionDiskTypeList>): void;
        list(params: Params$Resource$Regiondisktypes$List, callback: BodyResponseCallback<Schema$RegionDiskTypeList>): void;
        list(callback: BodyResponseCallback<Schema$RegionDiskTypeList>): void;
    }
    interface Params$Resource$Regiondisktypes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the disk type to return.
         */
        diskType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Regiondisktypes$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    class Resource$Regioninstancegroupmanagers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionInstanceGroupManagers.abandonInstances
         * @desc Flags the specified instances to be immediately removed from the
         * managed instance group. Abandoning an instance does not delete the
         * instance, but it does remove the instance from any target pools that are
         * applied by the managed instance group. This method reduces the targetSize
         * of the managed instance group by the number of instances that you
         * abandon. This operation is marked as DONE when the action is scheduled
         * even if the instances have not yet been removed from the group. You must
         * separately verify the status of the abandoning action with the
         * listmanagedinstances method.  If the group is part of a backend service
         * that has enabled connection draining, it can take up to 60 seconds after
         * the connection draining duration has elapsed before the VM instance is
         * removed or deleted.  You can specify a maximum of 1000 instances with
         * this method per request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.abandonInstances(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.abandonInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionInstanceGroupManagersAbandonInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        abandonInstances(params?: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        abandonInstances(params: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(params: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.delete
         * @desc Deletes the specified managed instance group and all of the
         * instances in that group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group to delete.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.delete(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Regioninstancegroupmanagers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regioninstancegroupmanagers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regioninstancegroupmanagers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.deleteInstances
         * @desc Flags the specified instances in the managed instance group to be
         * immediately deleted. The instances are also removed from any target pools
         * of which they were a member. This method reduces the targetSize of the
         * managed instance group by the number of instances that you delete. The
         * deleteInstances operation is marked DONE if the deleteInstances request
         * is successful. The underlying actions take additional time. You must
         * separately verify the status of the deleting action with the
         * listmanagedinstances method.  If the group is part of a backend service
         * that has enabled connection draining, it can take up to 60 seconds after
         * the connection draining duration has elapsed before the VM instance is
         * removed or deleted.  You can specify a maximum of 1000 instances with
         * this method per request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.deleteInstances(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.deleteInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionInstanceGroupManagersDeleteInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        deleteInstances(params?: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteInstances(params: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(params: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.get
         * @desc Returns all of the details about the specified managed instance
         * group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group to return.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.get(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regioninstancegroupmanagers$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManager>;
        get(params: Params$Resource$Regioninstancegroupmanagers$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManager>, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(params: Params$Resource$Regioninstancegroupmanagers$Get, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        /**
         * compute.regionInstanceGroupManagers.insert
         * @desc Creates a managed instance group using the information that you
         * specify in the request. After the group is created, instances in the
         * group are created using the specified instance template. This operation
         * is marked as DONE when the group is created even if the instances in the
         * group have not yet been created. You must separately verify the status of
         * the individual instances with the listmanagedinstances method.  A
         * regional managed instance group can contain up to 2000 instances.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.insert(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().InstanceGroupManager} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Regioninstancegroupmanagers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regioninstancegroupmanagers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regioninstancegroupmanagers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.list
         * @desc Retrieves the list of managed instance groups that are contained
         * within the specified region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionInstanceGroupManagers.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionInstanceGroupManagers.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regioninstancegroupmanagers$List, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupManagerList>;
        list(params: Params$Resource$Regioninstancegroupmanagers$List, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupManagerList>, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagerList>): void;
        list(params: Params$Resource$Regioninstancegroupmanagers$List, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagerList>): void;
        list(callback: BodyResponseCallback<Schema$RegionInstanceGroupManagerList>): void;
        /**
         * compute.regionInstanceGroupManagers.listManagedInstances
         * @desc Lists the instances in the managed instance group and instances
         * that are scheduled to be created. The list includes any current actions
         * that the group has scheduled for its instances.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.listManagedInstances(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.listManagedInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.order_by Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listManagedInstances(params?: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupManagersListInstancesResponse>;
        listManagedInstances(params: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>): void;
        listManagedInstances(params: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>): void;
        listManagedInstances(callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>): void;
        /**
         * compute.regionInstanceGroupManagers.patch
         * @desc Updates a managed instance group using the information that you
         * specify in the request. This operation is marked as DONE when the group
         * is patched even if the instances in the group are still in the process of
         * being patched. You must separately verify the status of the individual
         * instances with the listmanagedinstances method. This method supports
         * PATCH semantics and uses the JSON merge patch format and processing
         * rules.
         * @alias compute.regionInstanceGroupManagers.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the instance group manager.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().InstanceGroupManager} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Regioninstancegroupmanagers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regioninstancegroupmanagers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regioninstancegroupmanagers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.recreateInstances
         * @desc Flags the specified instances in the managed instance group to be
         * immediately recreated. The instances are deleted and recreated using the
         * current instance template for the managed instance group. This operation
         * is marked as DONE when the flag is set even if the instances have not yet
         * been recreated. You must separately verify the status of the recreating
         * action with the listmanagedinstances method.  If the group is part of a
         * backend service that has enabled connection draining, it can take up to
         * 60 seconds after the connection draining duration has elapsed before the
         * VM instance is removed or deleted.  You can specify a maximum of 1000
         * instances with this method per request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.recreateInstances(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.recreateInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionInstanceGroupManagersRecreateRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        recreateInstances(params?: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        recreateInstances(params: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(params: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.resize
         * @desc Changes the intended size of the managed instance group. If you
         * increase the size, the group creates new instances using the current
         * instance template. If you decrease the size, the group deletes one or
         * more instances.  The resize operation is marked DONE if the resize
         * request is successful. The underlying actions take additional time. You
         * must separately verify the status of the creating or deleting actions
         * with the listmanagedinstances method.  If the group is part of a backend
         * service that has enabled connection draining, it can take up to 60
         * seconds after the connection draining duration has elapsed before the VM
         * instance is removed or deleted.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     // Number of instances that should exist in this instance group
         * manager. size: 0,  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.resize(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.resize
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {integer} params.size Number of instances that should exist in this instance group manager.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        resize(params?: Params$Resource$Regioninstancegroupmanagers$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Regioninstancegroupmanagers$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Regioninstancegroupmanagers$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.setInstanceTemplate
         * @desc Sets the instance template to use when creating new instances or
         * recreating instances in this group. Existing instances are not affected.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // The name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.setInstanceTemplate(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.setInstanceTemplate
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager The name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionInstanceGroupManagersSetTemplateRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setInstanceTemplate(params?: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setInstanceTemplate(params: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(params: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionInstanceGroupManagers.setTargetPools
         * @desc Modifies the target pools to which all new instances in this group
         * are assigned. Existing instances in the group are not affected.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the managed instance group.
         *     instanceGroupManager: 'my-instance-group-manager',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroupManagers.setTargetPools(request,
         * function(err, response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroupManagers.setTargetPools
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroupManager Name of the managed instance group.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionInstanceGroupManagersSetTargetPoolsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setTargetPools(params?: Params$Resource$Regioninstancegroupmanagers$Settargetpools, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTargetPools(params: Params$Resource$Regioninstancegroupmanagers$Settargetpools, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(params: Params$Resource$Regioninstancegroupmanagers$Settargetpools, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Abandoninstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersAbandonInstancesRequest;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group to delete.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Deleteinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersDeleteInstancesRequest;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group to return.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    interface Params$Resource$Regioninstancegroupmanagers$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        order_by?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Recreateinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersRecreateRequest;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Resize extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Number of instances that should exist in this instance group manager.
         */
        size?: number;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersSetTemplateRequest;
    }
    interface Params$Resource$Regioninstancegroupmanagers$Settargetpools extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersSetTargetPoolsRequest;
    }
    class Resource$Regioninstancegroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionInstanceGroups.get
         * @desc Returns the specified instance group resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the instance group resource to return.
         *     instanceGroup: 'my-instance-group',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroups.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroups.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup Name of the instance group resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regioninstancegroups$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroup>;
        get(params: Params$Resource$Regioninstancegroups$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroup>, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(params: Params$Resource$Regioninstancegroups$Get, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        /**
         * compute.regionInstanceGroups.list
         * @desc Retrieves the list of instance group resources contained within the
         * specified region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionInstanceGroups.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionInstanceGroups.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroups.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regioninstancegroups$List, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupList>;
        list(params: Params$Resource$Regioninstancegroups$List, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupList>, callback: BodyResponseCallback<Schema$RegionInstanceGroupList>): void;
        list(params: Params$Resource$Regioninstancegroups$List, callback: BodyResponseCallback<Schema$RegionInstanceGroupList>): void;
        list(callback: BodyResponseCallback<Schema$RegionInstanceGroupList>): void;
        /**
         * compute.regionInstanceGroups.listInstances
         * @desc Lists the instances in the specified instance group and displays
         * information about the named ports. Depending on the specified options,
         * this method can list all instances or only the instances that are
         * running.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the regional instance group for which we want to list the
         * instances. instanceGroup: 'my-instance-group',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionInstanceGroups.listInstances(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionInstanceGroups.listInstances(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroups.listInstances
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {string} params.instanceGroup Name of the regional instance group for which we want to list the instances.
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {().RegionInstanceGroupsListInstancesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listInstances(params?: Params$Resource$Regioninstancegroups$Listinstances, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupsListInstances>;
        listInstances(params: Params$Resource$Regioninstancegroups$Listinstances, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>, callback: BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>): void;
        listInstances(params: Params$Resource$Regioninstancegroups$Listinstances, callback: BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>): void;
        listInstances(callback: BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>): void;
        /**
         * compute.regionInstanceGroups.setNamedPorts
         * @desc Sets the named ports for the specified regional instance group.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // The name of the regional instance group where the named ports are
         * updated. instanceGroup: 'my-instance-group',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionInstanceGroups.setNamedPorts(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionInstanceGroups.setNamedPorts
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.instanceGroup The name of the regional instance group where the named ports are updated.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().RegionInstanceGroupsSetNamedPortsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setNamedPorts(params?: Params$Resource$Regioninstancegroups$Setnamedports, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setNamedPorts(params: Params$Resource$Regioninstancegroups$Setnamedports, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(params: Params$Resource$Regioninstancegroups$Setnamedports, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Regioninstancegroups$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the instance group resource to return.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regioninstancegroups$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Regioninstancegroups$Listinstances extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * Name of the regional instance group for which we want to list the
         * instances.
         */
        instanceGroup?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupsListInstancesRequest;
    }
    interface Params$Resource$Regioninstancegroups$Setnamedports extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The name of the regional instance group where the named ports are
         * updated.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupsSetNamedPortsRequest;
    }
    class Resource$Regionoperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regionOperations.delete
         * @desc Deletes the specified region-specific Operations resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Operations resource to delete.
         *     operation: 'my-operation',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionOperations.delete(request, function(err) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionOperations.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.operation Name of the Operations resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Regionoperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Regionoperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Regionoperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * compute.regionOperations.get
         * @desc Retrieves the specified region-specific Operations resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Operations resource to return.
         *     operation: 'my-operation',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regionOperations.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionOperations.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.operation Name of the Operations resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regionoperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Regionoperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Regionoperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.regionOperations.list
         * @desc Retrieves a list of Operation resources contained within the
         * specified region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regionOperations.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regionOperations.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regionOperations.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regionoperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Regionoperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Regionoperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
    }
    interface Params$Resource$Regionoperations$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Regionoperations$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Regionoperations$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    class Resource$Regions {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.regions.get
         * @desc Returns the specified Region resource. Gets a list of available
         * regions by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region resource to return.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.regions.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regions.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Regions$Get, options?: MethodOptions): GaxiosPromise<Schema$Region>;
        get(params: Params$Resource$Regions$Get, options: MethodOptions | BodyResponseCallback<Schema$Region>, callback: BodyResponseCallback<Schema$Region>): void;
        get(params: Params$Resource$Regions$Get, callback: BodyResponseCallback<Schema$Region>): void;
        get(callback: BodyResponseCallback<Schema$Region>): void;
        /**
         * compute.regions.list
         * @desc Retrieves the list of region resources available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.regions.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.regions.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.regions.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Regions$List, options?: MethodOptions): GaxiosPromise<Schema$RegionList>;
        list(params: Params$Resource$Regions$List, options: MethodOptions | BodyResponseCallback<Schema$RegionList>, callback: BodyResponseCallback<Schema$RegionList>): void;
        list(params: Params$Resource$Regions$List, callback: BodyResponseCallback<Schema$RegionList>): void;
        list(callback: BodyResponseCallback<Schema$RegionList>): void;
    }
    interface Params$Resource$Regions$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region resource to return.
         */
        region?: string;
    }
    interface Params$Resource$Regions$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    class Resource$Routers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.routers.aggregatedList
         * @desc Retrieves an aggregated list of routers.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.routers.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.routers.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Routers$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$RouterAggregatedList>;
        aggregatedList(params: Params$Resource$Routers$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$RouterAggregatedList>, callback: BodyResponseCallback<Schema$RouterAggregatedList>): void;
        aggregatedList(params: Params$Resource$Routers$Aggregatedlist, callback: BodyResponseCallback<Schema$RouterAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$RouterAggregatedList>): void;
        /**
         * compute.routers.delete
         * @desc Deletes the specified Router resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Router resource to delete.
         *     router: 'my-router',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.router Name of the Router resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Routers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Routers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Routers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.routers.get
         * @desc Returns the specified Router resource. Gets a list of available
         * routers by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Router resource to return.
         *     router: 'my-router',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string} params.router Name of the Router resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Routers$Get, options?: MethodOptions): GaxiosPromise<Schema$Router>;
        get(params: Params$Resource$Routers$Get, options: MethodOptions | BodyResponseCallback<Schema$Router>, callback: BodyResponseCallback<Schema$Router>): void;
        get(params: Params$Resource$Routers$Get, callback: BodyResponseCallback<Schema$Router>): void;
        get(callback: BodyResponseCallback<Schema$Router>): void;
        /**
         * compute.routers.getNatMappingInfo
         * @desc Retrieves runtime Nat mapping information of VM endpoints.
         * @alias compute.routers.getNatMappingInfo
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string} params.router Name of the Router resource to query for Nat Mapping information of VM endpoints.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getNatMappingInfo(params?: Params$Resource$Routers$Getnatmappinginfo, options?: MethodOptions): GaxiosPromise<Schema$VmEndpointNatMappingsList>;
        getNatMappingInfo(params: Params$Resource$Routers$Getnatmappinginfo, options: MethodOptions | BodyResponseCallback<Schema$VmEndpointNatMappingsList>, callback: BodyResponseCallback<Schema$VmEndpointNatMappingsList>): void;
        getNatMappingInfo(params: Params$Resource$Routers$Getnatmappinginfo, callback: BodyResponseCallback<Schema$VmEndpointNatMappingsList>): void;
        getNatMappingInfo(callback: BodyResponseCallback<Schema$VmEndpointNatMappingsList>): void;
        /**
         * compute.routers.getRouterStatus
         * @desc Retrieves runtime information of the specified router.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Router resource to query.
         *     router: 'my-router',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.getRouterStatus(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.getRouterStatus
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string} params.router Name of the Router resource to query.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getRouterStatus(params?: Params$Resource$Routers$Getrouterstatus, options?: MethodOptions): GaxiosPromise<Schema$RouterStatusResponse>;
        getRouterStatus(params: Params$Resource$Routers$Getrouterstatus, options: MethodOptions | BodyResponseCallback<Schema$RouterStatusResponse>, callback: BodyResponseCallback<Schema$RouterStatusResponse>): void;
        getRouterStatus(params: Params$Resource$Routers$Getrouterstatus, callback: BodyResponseCallback<Schema$RouterStatusResponse>): void;
        getRouterStatus(callback: BodyResponseCallback<Schema$RouterStatusResponse>): void;
        /**
         * compute.routers.insert
         * @desc Creates a Router resource in the specified project and region using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Router} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Routers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Routers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Routers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.routers.list
         * @desc Retrieves a list of Router resources available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.routers.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.routers.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Routers$List, options?: MethodOptions): GaxiosPromise<Schema$RouterList>;
        list(params: Params$Resource$Routers$List, options: MethodOptions | BodyResponseCallback<Schema$RouterList>, callback: BodyResponseCallback<Schema$RouterList>): void;
        list(params: Params$Resource$Routers$List, callback: BodyResponseCallback<Schema$RouterList>): void;
        list(callback: BodyResponseCallback<Schema$RouterList>): void;
        /**
         * compute.routers.patch
         * @desc Patches the specified Router resource with the data included in the
         * request. This method supports PATCH semantics and uses JSON merge patch
         * format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Router resource to patch.
         *     router: 'my-router',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.router Name of the Router resource to patch.
         * @param {().Router} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Routers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Routers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Routers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.routers.preview
         * @desc Preview fields auto-generated during router create and update
         * operations. Calling this method does NOT create or update the router.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Router resource to query.
         *     router: 'my-router',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.preview(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.preview
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string} params.router Name of the Router resource to query.
         * @param {().Router} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        preview(params?: Params$Resource$Routers$Preview, options?: MethodOptions): GaxiosPromise<Schema$RoutersPreviewResponse>;
        preview(params: Params$Resource$Routers$Preview, options: MethodOptions | BodyResponseCallback<Schema$RoutersPreviewResponse>, callback: BodyResponseCallback<Schema$RoutersPreviewResponse>): void;
        preview(params: Params$Resource$Routers$Preview, callback: BodyResponseCallback<Schema$RoutersPreviewResponse>): void;
        preview(callback: BodyResponseCallback<Schema$RoutersPreviewResponse>): void;
        /**
         * compute.routers.update
         * @desc Updates the specified Router resource with the data included in the
         * request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Router resource to update.
         *     router: 'my-router',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routers.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routers.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.router Name of the Router resource to update.
         * @param {().Router} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Routers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Routers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Routers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Routers$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Routers$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource to delete.
         */
        router?: string;
    }
    interface Params$Resource$Routers$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to return.
         */
        router?: string;
    }
    interface Params$Resource$Routers$Getnatmappinginfo extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query for Nat Mapping information of VM
         * endpoints.
         */
        router?: string;
    }
    interface Params$Resource$Routers$Getrouterstatus extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query.
         */
        router?: string;
    }
    interface Params$Resource$Routers$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    interface Params$Resource$Routers$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    interface Params$Resource$Routers$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource to patch.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    interface Params$Resource$Routers$Preview extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    interface Params$Resource$Routers$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource to update.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    class Resource$Routes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.routes.delete
         * @desc Deletes the specified Route resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the Route resource to delete.
         *     route: 'my-route',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routes.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routes.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.route Name of the Route resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Routes$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Routes$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Routes$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.routes.get
         * @desc Returns the specified Route resource. Gets a list of available
         * routes by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the Route resource to return.
         *     route: 'my-route',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routes.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routes.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.route Name of the Route resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Routes$Get, options?: MethodOptions): GaxiosPromise<Schema$Route>;
        get(params: Params$Resource$Routes$Get, options: MethodOptions | BodyResponseCallback<Schema$Route>, callback: BodyResponseCallback<Schema$Route>): void;
        get(params: Params$Resource$Routes$Get, callback: BodyResponseCallback<Schema$Route>): void;
        get(callback: BodyResponseCallback<Schema$Route>): void;
        /**
         * compute.routes.insert
         * @desc Creates a Route resource in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.routes.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routes.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Route} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Routes$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Routes$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Routes$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.routes.list
         * @desc Retrieves the list of Route resources available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.routes.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.routes.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.routes.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Routes$List, options?: MethodOptions): GaxiosPromise<Schema$RouteList>;
        list(params: Params$Resource$Routes$List, options: MethodOptions | BodyResponseCallback<Schema$RouteList>, callback: BodyResponseCallback<Schema$RouteList>): void;
        list(params: Params$Resource$Routes$List, callback: BodyResponseCallback<Schema$RouteList>): void;
        list(callback: BodyResponseCallback<Schema$RouteList>): void;
    }
    interface Params$Resource$Routes$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Route resource to delete.
         */
        route?: string;
    }
    interface Params$Resource$Routes$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the Route resource to return.
         */
        route?: string;
    }
    interface Params$Resource$Routes$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Route;
    }
    interface Params$Resource$Routes$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    class Resource$Securitypolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.securityPolicies.addRule
         * @desc Inserts a rule into a security policy.
         * @alias compute.securityPolicies.addRule
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.securityPolicy Name of the security policy to update.
         * @param {().SecurityPolicyRule} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addRule(params?: Params$Resource$Securitypolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Securitypolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Securitypolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.securityPolicies.delete
         * @desc Deletes the specified policy.
         * @alias compute.securityPolicies.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.securityPolicy Name of the security policy to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Securitypolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Securitypolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Securitypolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.securityPolicies.get
         * @desc List all of the ordered rules present in a single specified policy.
         * @alias compute.securityPolicies.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.securityPolicy Name of the security policy to get.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Securitypolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicy>;
        get(params: Params$Resource$Securitypolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicy>, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(params: Params$Resource$Securitypolicies$Get, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        /**
         * compute.securityPolicies.getRule
         * @desc Gets a rule at the specified priority.
         * @alias compute.securityPolicies.getRule
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {integer=} params.priority The priority of the rule to get from the security policy.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.securityPolicy Name of the security policy to which the queried rule belongs.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getRule(params?: Params$Resource$Securitypolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyRule>;
        getRule(params: Params$Resource$Securitypolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyRule>, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(params: Params$Resource$Securitypolicies$Getrule, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        /**
         * compute.securityPolicies.insert
         * @desc Creates a new policy in the specified project using the data
         * included in the request.
         * @alias compute.securityPolicies.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().SecurityPolicy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Securitypolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Securitypolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Securitypolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.securityPolicies.list
         * @desc List all the policies that have been configured for the specified
         * project.
         * @alias compute.securityPolicies.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Securitypolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyList>;
        list(params: Params$Resource$Securitypolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyList>, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(params: Params$Resource$Securitypolicies$List, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        /**
         * compute.securityPolicies.patch
         * @desc Patches the specified policy with the data included in the request.
         * @alias compute.securityPolicies.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.securityPolicy Name of the security policy to update.
         * @param {().SecurityPolicy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Securitypolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Securitypolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Securitypolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.securityPolicies.patchRule
         * @desc Patches a rule at the specified priority.
         * @alias compute.securityPolicies.patchRule
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {integer=} params.priority The priority of the rule to patch.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.securityPolicy Name of the security policy to update.
         * @param {().SecurityPolicyRule} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patchRule(params?: Params$Resource$Securitypolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Securitypolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Securitypolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.securityPolicies.removeRule
         * @desc Deletes a rule at the specified priority.
         * @alias compute.securityPolicies.removeRule
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {integer=} params.priority The priority of the rule to remove from the security policy.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.securityPolicy Name of the security policy to update.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        removeRule(params?: Params$Resource$Securitypolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Securitypolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Securitypolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Securitypolicies$Addrule extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    interface Params$Resource$Securitypolicies$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to delete.
         */
        securityPolicy?: string;
    }
    interface Params$Resource$Securitypolicies$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to get.
         */
        securityPolicy?: string;
    }
    interface Params$Resource$Securitypolicies$Getrule extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The priority of the rule to get from the security policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to which the queried rule belongs.
         */
        securityPolicy?: string;
    }
    interface Params$Resource$Securitypolicies$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    interface Params$Resource$Securitypolicies$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Securitypolicies$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    interface Params$Resource$Securitypolicies$Patchrule extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    interface Params$Resource$Securitypolicies$Removerule extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * The priority of the rule to remove from the security policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
    }
    class Resource$Snapshots {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.snapshots.delete
         * @desc Deletes the specified Snapshot resource. Keep in mind that deleting
         * a single snapshot might not necessarily delete all the data on that
         * snapshot. If any data on the snapshot that is marked for deletion is
         * needed for subsequent snapshots, the data will be moved to the next
         * corresponding snapshot.  For more information, see Deleting snapshots.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the Snapshot resource to delete.
         *     snapshot: 'my-snapshot',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.snapshots.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.snapshots.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.snapshot Name of the Snapshot resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Snapshots$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Snapshots$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Snapshots$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.snapshots.get
         * @desc Returns the specified Snapshot resource. Gets a list of available
         * snapshots by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the Snapshot resource to return.
         *     snapshot: 'my-snapshot',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.snapshots.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.snapshots.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.snapshot Name of the Snapshot resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Snapshots$Get, options?: MethodOptions): GaxiosPromise<Schema$Snapshot>;
        get(params: Params$Resource$Snapshots$Get, options: MethodOptions | BodyResponseCallback<Schema$Snapshot>, callback: BodyResponseCallback<Schema$Snapshot>): void;
        get(params: Params$Resource$Snapshots$Get, callback: BodyResponseCallback<Schema$Snapshot>): void;
        get(callback: BodyResponseCallback<Schema$Snapshot>): void;
        /**
         * compute.snapshots.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.snapshots.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Snapshots$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Snapshots$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Snapshots$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.snapshots.list
         * @desc Retrieves the list of Snapshot resources contained within the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.snapshots.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.snapshots.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.snapshots.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Snapshots$List, options?: MethodOptions): GaxiosPromise<Schema$SnapshotList>;
        list(params: Params$Resource$Snapshots$List, options: MethodOptions | BodyResponseCallback<Schema$SnapshotList>, callback: BodyResponseCallback<Schema$SnapshotList>): void;
        list(params: Params$Resource$Snapshots$List, callback: BodyResponseCallback<Schema$SnapshotList>): void;
        list(callback: BodyResponseCallback<Schema$SnapshotList>): void;
        /**
         * compute.snapshots.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.snapshots.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().GlobalSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Snapshots$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Snapshots$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Snapshots$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.snapshots.setLabels
         * @desc Sets the labels on a snapshot. To learn more about labels, read the
         * Labeling Resources documentation.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the resource for this request.
         *     resource_: 'my-resource',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.snapshots.setLabels(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.snapshots.setLabels
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().GlobalSetLabelsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setLabels(params?: Params$Resource$Snapshots$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Snapshots$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Snapshots$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.snapshots.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.snapshots.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Snapshots$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Snapshots$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Snapshots$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Snapshots$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Snapshot resource to delete.
         */
        snapshot?: string;
    }
    interface Params$Resource$Snapshots$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the Snapshot resource to return.
         */
        snapshot?: string;
    }
    interface Params$Resource$Snapshots$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    interface Params$Resource$Snapshots$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Snapshots$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    interface Params$Resource$Snapshots$Setlabels extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    interface Params$Resource$Snapshots$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Sslcertificates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.sslCertificates.delete
         * @desc Deletes the specified SslCertificate resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the SslCertificate resource to delete.
         *     sslCertificate: 'my-ssl-certificate',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.sslCertificates.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.sslCertificates.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.sslCertificate Name of the SslCertificate resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Sslcertificates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Sslcertificates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Sslcertificates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.sslCertificates.get
         * @desc Returns the specified SslCertificate resource. Gets a list of
         * available SSL certificates by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the SslCertificate resource to return.
         *     sslCertificate: 'my-ssl-certificate',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.sslCertificates.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.sslCertificates.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.sslCertificate Name of the SslCertificate resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Sslcertificates$Get, options?: MethodOptions): GaxiosPromise<Schema$SslCertificate>;
        get(params: Params$Resource$Sslcertificates$Get, options: MethodOptions | BodyResponseCallback<Schema$SslCertificate>, callback: BodyResponseCallback<Schema$SslCertificate>): void;
        get(params: Params$Resource$Sslcertificates$Get, callback: BodyResponseCallback<Schema$SslCertificate>): void;
        get(callback: BodyResponseCallback<Schema$SslCertificate>): void;
        /**
         * compute.sslCertificates.insert
         * @desc Creates a SslCertificate resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.sslCertificates.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.sslCertificates.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().SslCertificate} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Sslcertificates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Sslcertificates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Sslcertificates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.sslCertificates.list
         * @desc Retrieves the list of SslCertificate resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.sslCertificates.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.sslCertificates.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.sslCertificates.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Sslcertificates$List, options?: MethodOptions): GaxiosPromise<Schema$SslCertificateList>;
        list(params: Params$Resource$Sslcertificates$List, options: MethodOptions | BodyResponseCallback<Schema$SslCertificateList>, callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        list(params: Params$Resource$Sslcertificates$List, callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        list(callback: BodyResponseCallback<Schema$SslCertificateList>): void;
    }
    interface Params$Resource$Sslcertificates$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SslCertificate resource to delete.
         */
        sslCertificate?: string;
    }
    interface Params$Resource$Sslcertificates$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the SslCertificate resource to return.
         */
        sslCertificate?: string;
    }
    interface Params$Resource$Sslcertificates$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslCertificate;
    }
    interface Params$Resource$Sslcertificates$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    class Resource$Sslpolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.sslPolicies.delete
         * @desc Deletes the specified SSL policy. The SSL policy resource can be
         * deleted only if it is not in use by any TargetHttpsProxy or
         * TargetSslProxy resources.
         * @alias compute.sslPolicies.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.sslPolicy Name of the SSL policy to delete. The name must be 1-63 characters long, and comply with RFC1035.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Sslpolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Sslpolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Sslpolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.sslPolicies.get
         * @desc Lists all of the ordered rules present in a single specified
         * policy.
         * @alias compute.sslPolicies.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.sslPolicy Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Sslpolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SslPolicy>;
        get(params: Params$Resource$Sslpolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SslPolicy>, callback: BodyResponseCallback<Schema$SslPolicy>): void;
        get(params: Params$Resource$Sslpolicies$Get, callback: BodyResponseCallback<Schema$SslPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SslPolicy>): void;
        /**
         * compute.sslPolicies.insert
         * @desc Returns the specified SSL policy resource. Gets a list of available
         * SSL policies by making a list() request.
         * @alias compute.sslPolicies.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().SslPolicy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Sslpolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Sslpolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Sslpolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.sslPolicies.list
         * @desc Lists all the SSL policies that have been configured for the
         * specified project.
         * @alias compute.sslPolicies.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Sslpolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesList>;
        list(params: Params$Resource$Sslpolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesList>, callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        list(params: Params$Resource$Sslpolicies$List, callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        list(callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        /**
         * compute.sslPolicies.listAvailableFeatures
         * @desc Lists all features that can be specified in the SSL policy when
         * using custom profile.
         * @alias compute.sslPolicies.listAvailableFeatures
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listAvailableFeatures(params?: Params$Resource$Sslpolicies$Listavailablefeatures, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesListAvailableFeaturesResponse>;
        listAvailableFeatures(params: Params$Resource$Sslpolicies$Listavailablefeatures, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>, callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        listAvailableFeatures(params: Params$Resource$Sslpolicies$Listavailablefeatures, callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        listAvailableFeatures(callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        /**
         * compute.sslPolicies.patch
         * @desc Patches the specified SSL policy with the data included in the
         * request.
         * @alias compute.sslPolicies.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.sslPolicy Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
         * @param {().SslPolicy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Sslpolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Sslpolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Sslpolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Sslpolicies$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SSL policy to delete. The name must be 1-63 characters long,
         * and comply with RFC1035.
         */
        sslPolicy?: string;
    }
    interface Params$Resource$Sslpolicies$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the SSL policy to update. The name must be 1-63 characters long,
         * and comply with RFC1035.
         */
        sslPolicy?: string;
    }
    interface Params$Resource$Sslpolicies$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicy;
    }
    interface Params$Resource$Sslpolicies$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Sslpolicies$Listavailablefeatures extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Sslpolicies$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SSL policy to update. The name must be 1-63 characters long,
         * and comply with RFC1035.
         */
        sslPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicy;
    }
    class Resource$Subnetworks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.subnetworks.aggregatedList
         * @desc Retrieves an aggregated list of subnetworks.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.subnetworks.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.subnetworks.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Subnetworks$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$SubnetworkAggregatedList>;
        aggregatedList(params: Params$Resource$Subnetworks$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$SubnetworkAggregatedList>, callback: BodyResponseCallback<Schema$SubnetworkAggregatedList>): void;
        aggregatedList(params: Params$Resource$Subnetworks$Aggregatedlist, callback: BodyResponseCallback<Schema$SubnetworkAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$SubnetworkAggregatedList>): void;
        /**
         * compute.subnetworks.delete
         * @desc Deletes the specified subnetwork.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Subnetwork resource to delete.
         *     subnetwork: 'my-subnetwork',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.subnetworks.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.subnetwork Name of the Subnetwork resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Subnetworks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Subnetworks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Subnetworks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.subnetworks.expandIpCidrRange
         * @desc Expands the IP CIDR range of the subnetwork to a specified value.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Subnetwork resource to update.
         *     subnetwork: 'my-subnetwork',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.subnetworks.expandIpCidrRange(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.expandIpCidrRange
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.subnetwork Name of the Subnetwork resource to update.
         * @param {().SubnetworksExpandIpCidrRangeRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        expandIpCidrRange(params?: Params$Resource$Subnetworks$Expandipcidrrange, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        expandIpCidrRange(params: Params$Resource$Subnetworks$Expandipcidrrange, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        expandIpCidrRange(params: Params$Resource$Subnetworks$Expandipcidrrange, callback: BodyResponseCallback<Schema$Operation>): void;
        expandIpCidrRange(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.subnetworks.get
         * @desc Returns the specified subnetwork. Gets a list of available
         * subnetworks list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Subnetwork resource to return.
         *     subnetwork: 'my-subnetwork',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.subnetworks.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string} params.subnetwork Name of the Subnetwork resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Subnetworks$Get, options?: MethodOptions): GaxiosPromise<Schema$Subnetwork>;
        get(params: Params$Resource$Subnetworks$Get, options: MethodOptions | BodyResponseCallback<Schema$Subnetwork>, callback: BodyResponseCallback<Schema$Subnetwork>): void;
        get(params: Params$Resource$Subnetworks$Get, callback: BodyResponseCallback<Schema$Subnetwork>): void;
        get(callback: BodyResponseCallback<Schema$Subnetwork>): void;
        /**
         * compute.subnetworks.getIamPolicy
         * @desc Gets the access control policy for a resource. May be empty if no
         * such policy or resource exists.
         * @alias compute.subnetworks.getIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getIamPolicy(params?: Params$Resource$Subnetworks$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Subnetworks$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Subnetworks$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.subnetworks.insert
         * @desc Creates a subnetwork in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.subnetworks.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().Subnetwork} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Subnetworks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Subnetworks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Subnetworks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.subnetworks.list
         * @desc Retrieves a list of subnetworks available to the specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.subnetworks.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.subnetworks.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Subnetworks$List, options?: MethodOptions): GaxiosPromise<Schema$SubnetworkList>;
        list(params: Params$Resource$Subnetworks$List, options: MethodOptions | BodyResponseCallback<Schema$SubnetworkList>, callback: BodyResponseCallback<Schema$SubnetworkList>): void;
        list(params: Params$Resource$Subnetworks$List, callback: BodyResponseCallback<Schema$SubnetworkList>): void;
        list(callback: BodyResponseCallback<Schema$SubnetworkList>): void;
        /**
         * compute.subnetworks.listUsable
         * @desc Retrieves an aggregated list of usable subnetworks.
         * @alias compute.subnetworks.listUsable
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        listUsable(params?: Params$Resource$Subnetworks$Listusable, options?: MethodOptions): GaxiosPromise<Schema$UsableSubnetworksAggregatedList>;
        listUsable(params: Params$Resource$Subnetworks$Listusable, options: MethodOptions | BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>, callback: BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>): void;
        listUsable(params: Params$Resource$Subnetworks$Listusable, callback: BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>): void;
        listUsable(callback: BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>): void;
        /**
         * compute.subnetworks.patch
         * @desc Patches the specified subnetwork with the data included in the
         * request. Only certain fields can up updated with a patch request as
         * indicated in the field descriptions. You must specify the current
         * fingeprint of the subnetwork resource being patched.
         * @alias compute.subnetworks.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.subnetwork Name of the Subnetwork resource to patch.
         * @param {().Subnetwork} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Subnetworks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Subnetworks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Subnetworks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.subnetworks.setIamPolicy
         * @desc Sets the access control policy on the specified resource. Replaces
         * any existing policy.
         * @alias compute.subnetworks.setIamPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().RegionSetPolicyRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setIamPolicy(params?: Params$Resource$Subnetworks$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Subnetworks$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Subnetworks$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * compute.subnetworks.setPrivateIpGoogleAccess
         * @desc Set whether VMs in this subnet can access Google services without
         * assigning external IP addresses through Private Google Access.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the Subnetwork resource.
         *     subnetwork: 'my-subnetwork',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.subnetworks.setPrivateIpGoogleAccess(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.subnetworks.setPrivateIpGoogleAccess
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.subnetwork Name of the Subnetwork resource.
         * @param {().SubnetworksSetPrivateIpGoogleAccessRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setPrivateIpGoogleAccess(params?: Params$Resource$Subnetworks$Setprivateipgoogleaccess, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setPrivateIpGoogleAccess(params: Params$Resource$Subnetworks$Setprivateipgoogleaccess, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setPrivateIpGoogleAccess(params: Params$Resource$Subnetworks$Setprivateipgoogleaccess, callback: BodyResponseCallback<Schema$Operation>): void;
        setPrivateIpGoogleAccess(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.subnetworks.testIamPermissions
         * @desc Returns permissions that a caller has on the specified resource.
         * @alias compute.subnetworks.testIamPermissions
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region The name of the region for this request.
         * @param {string} params.resource_ Name or id of the resource for this request.
         * @param {().TestPermissionsRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        testIamPermissions(params?: Params$Resource$Subnetworks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Subnetworks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Subnetworks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    interface Params$Resource$Subnetworks$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Subnetworks$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource to delete.
         */
        subnetwork?: string;
    }
    interface Params$Resource$Subnetworks$Expandipcidrrange extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource to update.
         */
        subnetwork?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SubnetworksExpandIpCidrRangeRequest;
    }
    interface Params$Resource$Subnetworks$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the Subnetwork resource to return.
         */
        subnetwork?: string;
    }
    interface Params$Resource$Subnetworks$Getiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    interface Params$Resource$Subnetworks$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Subnetwork;
    }
    interface Params$Resource$Subnetworks$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Subnetworks$Listusable extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Subnetworks$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource to patch.
         */
        subnetwork?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Subnetwork;
    }
    interface Params$Resource$Subnetworks$Setiampolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    interface Params$Resource$Subnetworks$Setprivateipgoogleaccess extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource.
         */
        subnetwork?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SubnetworksSetPrivateIpGoogleAccessRequest;
    }
    interface Params$Resource$Subnetworks$Testiampermissions extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    class Resource$Targethttpproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetHttpProxies.delete
         * @desc Deletes the specified TargetHttpProxy resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpProxy resource to delete.
         *     targetHttpProxy: 'my-target-http-proxy',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpProxies.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpProxies.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpProxy Name of the TargetHttpProxy resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targethttpproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targethttpproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targethttpproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpProxies.get
         * @desc Returns the specified TargetHttpProxy resource. Gets a list of
         * available target HTTP proxies by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpProxy resource to return.
         *     targetHttpProxy: 'my-target-http-proxy',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpProxies.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpProxies.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.targetHttpProxy Name of the TargetHttpProxy resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targethttpproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxy>;
        get(params: Params$Resource$Targethttpproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxy>, callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        get(params: Params$Resource$Targethttpproxies$Get, callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        /**
         * compute.targetHttpProxies.insert
         * @desc Creates a TargetHttpProxy resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpProxies.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpProxies.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetHttpProxy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targethttpproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targethttpproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targethttpproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpProxies.list
         * @desc Retrieves the list of TargetHttpProxy resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetHttpProxies.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetHttpProxies.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpProxies.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targethttpproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxyList>;
        list(params: Params$Resource$Targethttpproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxyList>, callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        list(params: Params$Resource$Targethttpproxies$List, callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        /**
         * compute.targetHttpProxies.setUrlMap
         * @desc Changes the URL map for TargetHttpProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpProxy to set a URL map for.
         *     targetHttpProxy: 'my-target-http-proxy',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpProxies.setUrlMap(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpProxies.setUrlMap
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpProxy Name of the TargetHttpProxy to set a URL map for.
         * @param {().UrlMapReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setUrlMap(params?: Params$Resource$Targethttpproxies$Seturlmap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUrlMap(params: Params$Resource$Targethttpproxies$Seturlmap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(params: Params$Resource$Targethttpproxies$Seturlmap, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Targethttpproxies$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy resource to delete.
         */
        targetHttpProxy?: string;
    }
    interface Params$Resource$Targethttpproxies$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetHttpProxy resource to return.
         */
        targetHttpProxy?: string;
    }
    interface Params$Resource$Targethttpproxies$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpProxy;
    }
    interface Params$Resource$Targethttpproxies$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targethttpproxies$Seturlmap extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy to set a URL map for.
         */
        targetHttpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapReference;
    }
    class Resource$Targethttpsproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetHttpsProxies.delete
         * @desc Deletes the specified TargetHttpsProxy resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpsProxy resource to delete.
         *     targetHttpsProxy: 'my-target-https-proxy',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpsProxies.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpsProxies.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpsProxy Name of the TargetHttpsProxy resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targethttpsproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targethttpsproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targethttpsproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpsProxies.get
         * @desc Returns the specified TargetHttpsProxy resource. Gets a list of
         * available target HTTPS proxies by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpsProxy resource to return.
         *     targetHttpsProxy: 'my-target-https-proxy',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpsProxies.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpsProxies.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.targetHttpsProxy Name of the TargetHttpsProxy resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targethttpsproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxy>;
        get(params: Params$Resource$Targethttpsproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxy>, callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        get(params: Params$Resource$Targethttpsproxies$Get, callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        /**
         * compute.targetHttpsProxies.insert
         * @desc Creates a TargetHttpsProxy resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpsProxies.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpsProxies.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetHttpsProxy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targethttpsproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targethttpsproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targethttpsproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpsProxies.list
         * @desc Retrieves the list of TargetHttpsProxy resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetHttpsProxies.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetHttpsProxies.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpsProxies.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targethttpsproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxyList>;
        list(params: Params$Resource$Targethttpsproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxyList>, callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        list(params: Params$Resource$Targethttpsproxies$List, callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        /**
         * compute.targetHttpsProxies.setQuicOverride
         * @desc Sets the QUIC override policy for TargetHttpsProxy.
         * @alias compute.targetHttpsProxies.setQuicOverride
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpsProxy Name of the TargetHttpsProxy resource to set the QUIC override policy for. The name should conform to RFC1035.
         * @param {().TargetHttpsProxiesSetQuicOverrideRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setQuicOverride(params?: Params$Resource$Targethttpsproxies$Setquicoverride, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setQuicOverride(params: Params$Resource$Targethttpsproxies$Setquicoverride, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setQuicOverride(params: Params$Resource$Targethttpsproxies$Setquicoverride, callback: BodyResponseCallback<Schema$Operation>): void;
        setQuicOverride(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpsProxies.setSslCertificates
         * @desc Replaces SslCertificates for TargetHttpsProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpsProxy resource to set an SslCertificates
         * resource for. targetHttpsProxy: 'my-target-https-proxy',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpsProxies.setSslCertificates(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpsProxies.setSslCertificates
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpsProxy Name of the TargetHttpsProxy resource to set an SslCertificates resource for.
         * @param {().TargetHttpsProxiesSetSslCertificatesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setSslCertificates(params?: Params$Resource$Targethttpsproxies$Setsslcertificates, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslCertificates(params: Params$Resource$Targethttpsproxies$Setsslcertificates, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(params: Params$Resource$Targethttpsproxies$Setsslcertificates, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpsProxies.setSslPolicy
         * @desc Sets the SSL policy for TargetHttpsProxy. The SSL policy specifies
         * the server-side support for SSL features. This affects connections
         * between clients and the HTTPS proxy load balancer. They do not affect the
         * connection between the load balancer and the backends.
         * @alias compute.targetHttpsProxies.setSslPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpsProxy Name of the TargetHttpsProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.
         * @param {().SslPolicyReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setSslPolicy(params?: Params$Resource$Targethttpsproxies$Setsslpolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslPolicy(params: Params$Resource$Targethttpsproxies$Setsslpolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(params: Params$Resource$Targethttpsproxies$Setsslpolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetHttpsProxies.setUrlMap
         * @desc Changes the URL map for TargetHttpsProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetHttpsProxy resource whose URL map is to be set.
         *     targetHttpsProxy: 'my-target-https-proxy',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetHttpsProxies.setUrlMap(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetHttpsProxies.setUrlMap
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetHttpsProxy Name of the TargetHttpsProxy resource whose URL map is to be set.
         * @param {().UrlMapReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setUrlMap(params?: Params$Resource$Targethttpsproxies$Seturlmap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUrlMap(params: Params$Resource$Targethttpsproxies$Seturlmap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(params: Params$Resource$Targethttpsproxies$Seturlmap, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Targethttpsproxies$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to delete.
         */
        targetHttpsProxy?: string;
    }
    interface Params$Resource$Targethttpsproxies$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetHttpsProxy resource to return.
         */
        targetHttpsProxy?: string;
    }
    interface Params$Resource$Targethttpsproxies$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxy;
    }
    interface Params$Resource$Targethttpsproxies$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targethttpsproxies$Setquicoverride extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to set the QUIC override policy
         * for. The name should conform to RFC1035.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxiesSetQuicOverrideRequest;
    }
    interface Params$Resource$Targethttpsproxies$Setsslcertificates extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to set an SslCertificates resource
         * for.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxiesSetSslCertificatesRequest;
    }
    interface Params$Resource$Targethttpsproxies$Setsslpolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource whose SSL policy is to be set. The
         * name must be 1-63 characters long, and comply with RFC1035.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicyReference;
    }
    interface Params$Resource$Targethttpsproxies$Seturlmap extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource whose URL map is to be set.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapReference;
    }
    class Resource$Targetinstances {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetInstances.aggregatedList
         * @desc Retrieves an aggregated list of target instances.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetInstances.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetInstances.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetInstances.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Targetinstances$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetInstanceAggregatedList>;
        aggregatedList(params: Params$Resource$Targetinstances$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetInstanceAggregatedList>, callback: BodyResponseCallback<Schema$TargetInstanceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targetinstances$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetInstanceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetInstanceAggregatedList>): void;
        /**
         * compute.targetInstances.delete
         * @desc Deletes the specified TargetInstance resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone scoping this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetInstance resource to delete.
         *     targetInstance: 'my-target-instance',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetInstances.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetInstances.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetInstance Name of the TargetInstance resource to delete.
         * @param {string} params.zone Name of the zone scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targetinstances$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetinstances$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetinstances$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetInstances.get
         * @desc Returns the specified TargetInstance resource. Gets a list of
         * available target instances by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone scoping this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetInstance resource to return.
         *     targetInstance: 'my-target-instance',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetInstances.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetInstances.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.targetInstance Name of the TargetInstance resource to return.
         * @param {string} params.zone Name of the zone scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targetinstances$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetInstance>;
        get(params: Params$Resource$Targetinstances$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetInstance>, callback: BodyResponseCallback<Schema$TargetInstance>): void;
        get(params: Params$Resource$Targetinstances$Get, callback: BodyResponseCallback<Schema$TargetInstance>): void;
        get(callback: BodyResponseCallback<Schema$TargetInstance>): void;
        /**
         * compute.targetInstances.insert
         * @desc Creates a TargetInstance resource in the specified project and zone
         * using the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone scoping this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetInstances.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetInstances.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.zone Name of the zone scoping this request.
         * @param {().TargetInstance} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targetinstances$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetinstances$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetinstances$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetInstances.list
         * @desc Retrieves a list of TargetInstance resources available to the
         * specified project and zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone scoping this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetInstances.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetInstances.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetInstances.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targetinstances$List, options?: MethodOptions): GaxiosPromise<Schema$TargetInstanceList>;
        list(params: Params$Resource$Targetinstances$List, options: MethodOptions | BodyResponseCallback<Schema$TargetInstanceList>, callback: BodyResponseCallback<Schema$TargetInstanceList>): void;
        list(params: Params$Resource$Targetinstances$List, callback: BodyResponseCallback<Schema$TargetInstanceList>): void;
        list(callback: BodyResponseCallback<Schema$TargetInstanceList>): void;
    }
    interface Params$Resource$Targetinstances$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targetinstances$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetInstance resource to delete.
         */
        targetInstance?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
    }
    interface Params$Resource$Targetinstances$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetInstance resource to return.
         */
        targetInstance?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
    }
    interface Params$Resource$Targetinstances$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetInstance;
    }
    interface Params$Resource$Targetinstances$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
    }
    class Resource$Targetpools {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetPools.addHealthCheck
         * @desc Adds health check URLs to a target pool.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the target pool to add a health check to.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.addHealthCheck(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.addHealthCheck
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetPool Name of the target pool to add a health check to.
         * @param {().TargetPoolsAddHealthCheckRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addHealthCheck(params?: Params$Resource$Targetpools$Addhealthcheck, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addHealthCheck(params: Params$Resource$Targetpools$Addhealthcheck, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addHealthCheck(params: Params$Resource$Targetpools$Addhealthcheck, callback: BodyResponseCallback<Schema$Operation>): void;
        addHealthCheck(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetPools.addInstance
         * @desc Adds an instance to a target pool.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetPool resource to add instances to.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.addInstance(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.addInstance
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetPool Name of the TargetPool resource to add instances to.
         * @param {().TargetPoolsAddInstanceRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        addInstance(params?: Params$Resource$Targetpools$Addinstance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addInstance(params: Params$Resource$Targetpools$Addinstance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstance(params: Params$Resource$Targetpools$Addinstance, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetPools.aggregatedList
         * @desc Retrieves an aggregated list of target pools.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetPools.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetPools.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Targetpools$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetPoolAggregatedList>;
        aggregatedList(params: Params$Resource$Targetpools$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetPoolAggregatedList>, callback: BodyResponseCallback<Schema$TargetPoolAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targetpools$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetPoolAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetPoolAggregatedList>): void;
        /**
         * compute.targetPools.delete
         * @desc Deletes the specified target pool.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetPool resource to delete.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetPool Name of the TargetPool resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targetpools$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetpools$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetpools$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetPools.get
         * @desc Returns the specified target pool. Gets a list of available target
         * pools by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetPool resource to return.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string} params.targetPool Name of the TargetPool resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targetpools$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetPool>;
        get(params: Params$Resource$Targetpools$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetPool>, callback: BodyResponseCallback<Schema$TargetPool>): void;
        get(params: Params$Resource$Targetpools$Get, callback: BodyResponseCallback<Schema$TargetPool>): void;
        get(callback: BodyResponseCallback<Schema$TargetPool>): void;
        /**
         * compute.targetPools.getHealth
         * @desc Gets the most recent health check results for each IP for the
         * instance that is referenced by the given target pool.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetPool resource to which the queried instance
         * belongs. targetPool: 'my-target-pool',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.getHealth(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.getHealth
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string} params.targetPool Name of the TargetPool resource to which the queried instance belongs.
         * @param {().InstanceReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        getHealth(params?: Params$Resource$Targetpools$Gethealth, options?: MethodOptions): GaxiosPromise<Schema$TargetPoolInstanceHealth>;
        getHealth(params: Params$Resource$Targetpools$Gethealth, options: MethodOptions | BodyResponseCallback<Schema$TargetPoolInstanceHealth>, callback: BodyResponseCallback<Schema$TargetPoolInstanceHealth>): void;
        getHealth(params: Params$Resource$Targetpools$Gethealth, callback: BodyResponseCallback<Schema$TargetPoolInstanceHealth>): void;
        getHealth(callback: BodyResponseCallback<Schema$TargetPoolInstanceHealth>): void;
        /**
         * compute.targetPools.insert
         * @desc Creates a target pool in the specified project and region using the
         * data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetPool} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targetpools$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetpools$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetpools$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetPools.list
         * @desc Retrieves a list of target pools available to the specified project
         * and region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetPools.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetPools.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targetpools$List, options?: MethodOptions): GaxiosPromise<Schema$TargetPoolList>;
        list(params: Params$Resource$Targetpools$List, options: MethodOptions | BodyResponseCallback<Schema$TargetPoolList>, callback: BodyResponseCallback<Schema$TargetPoolList>): void;
        list(params: Params$Resource$Targetpools$List, callback: BodyResponseCallback<Schema$TargetPoolList>): void;
        list(callback: BodyResponseCallback<Schema$TargetPoolList>): void;
        /**
         * compute.targetPools.removeHealthCheck
         * @desc Removes health check URL from a target pool.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the target pool to remove health checks from.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.removeHealthCheck(request, function(err, response)
         * { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.removeHealthCheck
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetPool Name of the target pool to remove health checks from.
         * @param {().TargetPoolsRemoveHealthCheckRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        removeHealthCheck(params?: Params$Resource$Targetpools$Removehealthcheck, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeHealthCheck(params: Params$Resource$Targetpools$Removehealthcheck, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeHealthCheck(params: Params$Resource$Targetpools$Removehealthcheck, callback: BodyResponseCallback<Schema$Operation>): void;
        removeHealthCheck(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetPools.removeInstance
         * @desc Removes instance URL from a target pool.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetPool resource to remove instances from.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.removeInstance(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.removeInstance
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetPool Name of the TargetPool resource to remove instances from.
         * @param {().TargetPoolsRemoveInstanceRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        removeInstance(params?: Params$Resource$Targetpools$Removeinstance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeInstance(params: Params$Resource$Targetpools$Removeinstance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstance(params: Params$Resource$Targetpools$Removeinstance, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetPools.setBackup
         * @desc Changes a backup target pool's configurations.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region scoping this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetPool resource to set a backup pool for.
         *     targetPool: 'my-target-pool',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetPools.setBackup(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetPools.setBackup
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {number=} params.failoverRatio New failoverRatio value for the target pool.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region scoping this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetPool Name of the TargetPool resource to set a backup pool for.
         * @param {().TargetReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setBackup(params?: Params$Resource$Targetpools$Setbackup, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setBackup(params: Params$Resource$Targetpools$Setbackup, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackup(params: Params$Resource$Targetpools$Setbackup, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackup(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Targetpools$Addhealthcheck extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the target pool to add a health check to.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsAddHealthCheckRequest;
    }
    interface Params$Resource$Targetpools$Addinstance extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to add instances to.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsAddInstanceRequest;
    }
    interface Params$Resource$Targetpools$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targetpools$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to delete.
         */
        targetPool?: string;
    }
    interface Params$Resource$Targetpools$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetPool resource to return.
         */
        targetPool?: string;
    }
    interface Params$Resource$Targetpools$Gethealth extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetPool resource to which the queried instance belongs.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceReference;
    }
    interface Params$Resource$Targetpools$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPool;
    }
    interface Params$Resource$Targetpools$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    interface Params$Resource$Targetpools$Removehealthcheck extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the target pool to remove health checks from.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsRemoveHealthCheckRequest;
    }
    interface Params$Resource$Targetpools$Removeinstance extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to remove instances from.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsRemoveInstanceRequest;
    }
    interface Params$Resource$Targetpools$Setbackup extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * New failoverRatio value for the target pool.
         */
        failoverRatio?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to set a backup pool for.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetReference;
    }
    class Resource$Targetsslproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetSslProxies.delete
         * @desc Deletes the specified TargetSslProxy resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetSslProxy resource to delete.
         *     targetSslProxy: 'my-target-ssl-proxy',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetSslProxies.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetSslProxy Name of the TargetSslProxy resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targetsslproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetsslproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetsslproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetSslProxies.get
         * @desc Returns the specified TargetSslProxy resource. Gets a list of
         * available target SSL proxies by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetSslProxy resource to return.
         *     targetSslProxy: 'my-target-ssl-proxy',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetSslProxies.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.targetSslProxy Name of the TargetSslProxy resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targetsslproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetSslProxy>;
        get(params: Params$Resource$Targetsslproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetSslProxy>, callback: BodyResponseCallback<Schema$TargetSslProxy>): void;
        get(params: Params$Resource$Targetsslproxies$Get, callback: BodyResponseCallback<Schema$TargetSslProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetSslProxy>): void;
        /**
         * compute.targetSslProxies.insert
         * @desc Creates a TargetSslProxy resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetSslProxies.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetSslProxy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targetsslproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetsslproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetsslproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetSslProxies.list
         * @desc Retrieves the list of TargetSslProxy resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetSslProxies.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetSslProxies.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targetsslproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetSslProxyList>;
        list(params: Params$Resource$Targetsslproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetSslProxyList>, callback: BodyResponseCallback<Schema$TargetSslProxyList>): void;
        list(params: Params$Resource$Targetsslproxies$List, callback: BodyResponseCallback<Schema$TargetSslProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetSslProxyList>): void;
        /**
         * compute.targetSslProxies.setBackendService
         * @desc Changes the BackendService for TargetSslProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetSslProxy resource whose BackendService resource
         * is to be set. targetSslProxy: 'my-target-ssl-proxy',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetSslProxies.setBackendService(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.setBackendService
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetSslProxy Name of the TargetSslProxy resource whose BackendService resource is to be set.
         * @param {().TargetSslProxiesSetBackendServiceRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setBackendService(params?: Params$Resource$Targetsslproxies$Setbackendservice, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setBackendService(params: Params$Resource$Targetsslproxies$Setbackendservice, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(params: Params$Resource$Targetsslproxies$Setbackendservice, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetSslProxies.setProxyHeader
         * @desc Changes the ProxyHeaderType for TargetSslProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetSslProxy resource whose ProxyHeader is to be
         * set. targetSslProxy: 'my-target-ssl-proxy',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetSslProxies.setProxyHeader(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.setProxyHeader
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetSslProxy Name of the TargetSslProxy resource whose ProxyHeader is to be set.
         * @param {().TargetSslProxiesSetProxyHeaderRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setProxyHeader(params?: Params$Resource$Targetsslproxies$Setproxyheader, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setProxyHeader(params: Params$Resource$Targetsslproxies$Setproxyheader, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(params: Params$Resource$Targetsslproxies$Setproxyheader, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetSslProxies.setSslCertificates
         * @desc Changes SslCertificates for TargetSslProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetSslProxy resource whose SslCertificate resource
         * is to be set. targetSslProxy: 'my-target-ssl-proxy',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetSslProxies.setSslCertificates(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetSslProxies.setSslCertificates
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetSslProxy Name of the TargetSslProxy resource whose SslCertificate resource is to be set.
         * @param {().TargetSslProxiesSetSslCertificatesRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setSslCertificates(params?: Params$Resource$Targetsslproxies$Setsslcertificates, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslCertificates(params: Params$Resource$Targetsslproxies$Setsslcertificates, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(params: Params$Resource$Targetsslproxies$Setsslcertificates, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetSslProxies.setSslPolicy
         * @desc Sets the SSL policy for TargetSslProxy. The SSL policy specifies
         * the server-side support for SSL features. This affects connections
         * between clients and the SSL proxy load balancer. They do not affect the
         * connection between the load balancer and the backends.
         * @alias compute.targetSslProxies.setSslPolicy
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetSslProxy Name of the TargetSslProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.
         * @param {().SslPolicyReference} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setSslPolicy(params?: Params$Resource$Targetsslproxies$Setsslpolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslPolicy(params: Params$Resource$Targetsslproxies$Setsslpolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(params: Params$Resource$Targetsslproxies$Setsslpolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Targetsslproxies$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource to delete.
         */
        targetSslProxy?: string;
    }
    interface Params$Resource$Targetsslproxies$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetSslProxy resource to return.
         */
        targetSslProxy?: string;
    }
    interface Params$Resource$Targetsslproxies$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxy;
    }
    interface Params$Resource$Targetsslproxies$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targetsslproxies$Setbackendservice extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose BackendService resource is to
         * be set.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetBackendServiceRequest;
    }
    interface Params$Resource$Targetsslproxies$Setproxyheader extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose ProxyHeader is to be set.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetProxyHeaderRequest;
    }
    interface Params$Resource$Targetsslproxies$Setsslcertificates extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose SslCertificate resource is to
         * be set.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetSslCertificatesRequest;
    }
    interface Params$Resource$Targetsslproxies$Setsslpolicy extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose SSL policy is to be set. The
         * name must be 1-63 characters long, and comply with RFC1035.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicyReference;
    }
    class Resource$Targettcpproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetTcpProxies.delete
         * @desc Deletes the specified TargetTcpProxy resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetTcpProxy resource to delete.
         *     targetTcpProxy: 'my-target-tcp-proxy',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetTcpProxies.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetTcpProxies.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetTcpProxy Name of the TargetTcpProxy resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targettcpproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targettcpproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targettcpproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetTcpProxies.get
         * @desc Returns the specified TargetTcpProxy resource. Gets a list of
         * available target TCP proxies by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetTcpProxy resource to return.
         *     targetTcpProxy: 'my-target-tcp-proxy',  // TODO: Update placeholder
         * value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetTcpProxies.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetTcpProxies.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.targetTcpProxy Name of the TargetTcpProxy resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targettcpproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxy>;
        get(params: Params$Resource$Targettcpproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxy>, callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        get(params: Params$Resource$Targettcpproxies$Get, callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        /**
         * compute.targetTcpProxies.insert
         * @desc Creates a TargetTcpProxy resource in the specified project using
         * the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetTcpProxies.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetTcpProxies.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetTcpProxy} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targettcpproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targettcpproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targettcpproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetTcpProxies.list
         * @desc Retrieves the list of TargetTcpProxy resources available to the
         * specified project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetTcpProxies.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetTcpProxies.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetTcpProxies.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targettcpproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxyList>;
        list(params: Params$Resource$Targettcpproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxyList>, callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        list(params: Params$Resource$Targettcpproxies$List, callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        /**
         * compute.targetTcpProxies.setBackendService
         * @desc Changes the BackendService for TargetTcpProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetTcpProxy resource whose BackendService resource
         * is to be set. targetTcpProxy: 'my-target-tcp-proxy',  // TODO: Update
         * placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetTcpProxies.setBackendService(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetTcpProxies.setBackendService
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetTcpProxy Name of the TargetTcpProxy resource whose BackendService resource is to be set.
         * @param {().TargetTcpProxiesSetBackendServiceRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setBackendService(params?: Params$Resource$Targettcpproxies$Setbackendservice, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setBackendService(params: Params$Resource$Targettcpproxies$Setbackendservice, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(params: Params$Resource$Targettcpproxies$Setbackendservice, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetTcpProxies.setProxyHeader
         * @desc Changes the ProxyHeaderType for TargetTcpProxy.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the TargetTcpProxy resource whose ProxyHeader is to be
         * set. targetTcpProxy: 'my-target-tcp-proxy',  // TODO: Update placeholder
         * value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetTcpProxies.setProxyHeader(request, function(err,
         * response) { if (err) { console.error(err); return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetTcpProxies.setProxyHeader
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetTcpProxy Name of the TargetTcpProxy resource whose ProxyHeader is to be set.
         * @param {().TargetTcpProxiesSetProxyHeaderRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        setProxyHeader(params?: Params$Resource$Targettcpproxies$Setproxyheader, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setProxyHeader(params: Params$Resource$Targettcpproxies$Setproxyheader, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(params: Params$Resource$Targettcpproxies$Setproxyheader, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    interface Params$Resource$Targettcpproxies$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource to delete.
         */
        targetTcpProxy?: string;
    }
    interface Params$Resource$Targettcpproxies$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetTcpProxy resource to return.
         */
        targetTcpProxy?: string;
    }
    interface Params$Resource$Targettcpproxies$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxy;
    }
    interface Params$Resource$Targettcpproxies$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targettcpproxies$Setbackendservice extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource whose BackendService resource is to
         * be set.
         */
        targetTcpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxiesSetBackendServiceRequest;
    }
    interface Params$Resource$Targettcpproxies$Setproxyheader extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource whose ProxyHeader is to be set.
         */
        targetTcpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxiesSetProxyHeaderRequest;
    }
    class Resource$Targetvpngateways {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.targetVpnGateways.aggregatedList
         * @desc Retrieves an aggregated list of target VPN gateways.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetVpnGateways.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetVpnGateways.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetVpnGateways.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Targetvpngateways$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetVpnGatewayAggregatedList>;
        aggregatedList(params: Params$Resource$Targetvpngateways$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>, callback: BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targetvpngateways$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>): void;
        /**
         * compute.targetVpnGateways.delete
         * @desc Deletes the specified target VPN gateway.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the target VPN gateway to delete.
         *     targetVpnGateway: 'my-target-vpn-gateway',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetVpnGateways.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetVpnGateways.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.targetVpnGateway Name of the target VPN gateway to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Targetvpngateways$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetvpngateways$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetvpngateways$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetVpnGateways.get
         * @desc Returns the specified target VPN gateway. Gets a list of available
         * target VPN gateways by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the target VPN gateway to return.
         *     targetVpnGateway: 'my-target-vpn-gateway',  // TODO: Update
         * placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetVpnGateways.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetVpnGateways.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string} params.targetVpnGateway Name of the target VPN gateway to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Targetvpngateways$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetVpnGateway>;
        get(params: Params$Resource$Targetvpngateways$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetVpnGateway>, callback: BodyResponseCallback<Schema$TargetVpnGateway>): void;
        get(params: Params$Resource$Targetvpngateways$Get, callback: BodyResponseCallback<Schema$TargetVpnGateway>): void;
        get(callback: BodyResponseCallback<Schema$TargetVpnGateway>): void;
        /**
         * compute.targetVpnGateways.insert
         * @desc Creates a target VPN gateway in the specified project and region
         * using the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.targetVpnGateways.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetVpnGateways.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().TargetVpnGateway} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Targetvpngateways$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetvpngateways$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetvpngateways$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.targetVpnGateways.list
         * @desc Retrieves a list of target VPN gateways available to the specified
         * project and region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.targetVpnGateways.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.targetVpnGateways.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.targetVpnGateways.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Targetvpngateways$List, options?: MethodOptions): GaxiosPromise<Schema$TargetVpnGatewayList>;
        list(params: Params$Resource$Targetvpngateways$List, options: MethodOptions | BodyResponseCallback<Schema$TargetVpnGatewayList>, callback: BodyResponseCallback<Schema$TargetVpnGatewayList>): void;
        list(params: Params$Resource$Targetvpngateways$List, callback: BodyResponseCallback<Schema$TargetVpnGatewayList>): void;
        list(callback: BodyResponseCallback<Schema$TargetVpnGatewayList>): void;
    }
    interface Params$Resource$Targetvpngateways$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Targetvpngateways$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the target VPN gateway to delete.
         */
        targetVpnGateway?: string;
    }
    interface Params$Resource$Targetvpngateways$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the target VPN gateway to return.
         */
        targetVpnGateway?: string;
    }
    interface Params$Resource$Targetvpngateways$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetVpnGateway;
    }
    interface Params$Resource$Targetvpngateways$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    class Resource$Urlmaps {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.urlMaps.delete
         * @desc Deletes the specified UrlMap resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the UrlMap resource to delete.
         *     urlMap: 'my-url-map',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.urlMap Name of the UrlMap resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Urlmaps$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Urlmaps$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Urlmaps$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.urlMaps.get
         * @desc Returns the specified UrlMap resource. Gets a list of available URL
         * maps by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the UrlMap resource to return.
         *     urlMap: 'my-url-map',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.urlMap Name of the UrlMap resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Urlmaps$Get, options?: MethodOptions): GaxiosPromise<Schema$UrlMap>;
        get(params: Params$Resource$Urlmaps$Get, options: MethodOptions | BodyResponseCallback<Schema$UrlMap>, callback: BodyResponseCallback<Schema$UrlMap>): void;
        get(params: Params$Resource$Urlmaps$Get, callback: BodyResponseCallback<Schema$UrlMap>): void;
        get(callback: BodyResponseCallback<Schema$UrlMap>): void;
        /**
         * compute.urlMaps.insert
         * @desc Creates a UrlMap resource in the specified project using the data
         * included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().UrlMap} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Urlmaps$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Urlmaps$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Urlmaps$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.urlMaps.invalidateCache
         * @desc Initiates a cache invalidation operation, invalidating the
         * specified path, scoped to the specified UrlMap.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the UrlMap scoping this request.
         *     urlMap: 'my-url-map',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.invalidateCache(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.invalidateCache
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.urlMap Name of the UrlMap scoping this request.
         * @param {().CacheInvalidationRule} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        invalidateCache(params?: Params$Resource$Urlmaps$Invalidatecache, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        invalidateCache(params: Params$Resource$Urlmaps$Invalidatecache, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        invalidateCache(params: Params$Resource$Urlmaps$Invalidatecache, callback: BodyResponseCallback<Schema$Operation>): void;
        invalidateCache(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.urlMaps.list
         * @desc Retrieves the list of UrlMap resources available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.urlMaps.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.urlMaps.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Urlmaps$List, options?: MethodOptions): GaxiosPromise<Schema$UrlMapList>;
        list(params: Params$Resource$Urlmaps$List, options: MethodOptions | BodyResponseCallback<Schema$UrlMapList>, callback: BodyResponseCallback<Schema$UrlMapList>): void;
        list(params: Params$Resource$Urlmaps$List, callback: BodyResponseCallback<Schema$UrlMapList>): void;
        list(callback: BodyResponseCallback<Schema$UrlMapList>): void;
        /**
         * compute.urlMaps.patch
         * @desc Patches the specified UrlMap resource with the data included in the
         * request. This method supports PATCH semantics and uses the JSON merge
         * patch format and processing rules.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the UrlMap resource to patch.
         *     urlMap: 'my-url-map',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. Only these
         * properties
         *       // will be changed.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.patch(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.patch
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.urlMap Name of the UrlMap resource to patch.
         * @param {().UrlMap} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        patch(params?: Params$Resource$Urlmaps$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Urlmaps$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Urlmaps$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.urlMaps.update
         * @desc Updates the specified UrlMap resource with the data included in the
         * request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the UrlMap resource to update.
         *     urlMap: 'my-url-map',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body. All existing
         * properties
         *       // will be replaced.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.update(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.update
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.urlMap Name of the UrlMap resource to update.
         * @param {().UrlMap} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        update(params?: Params$Resource$Urlmaps$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Urlmaps$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Urlmaps$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.urlMaps.validate
         * @desc Runs static validation for the UrlMap. In particular, the tests of
         * the provided UrlMap will be run. Calling this method does NOT create the
         * UrlMap.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the UrlMap resource to be validated as.
         *     urlMap: 'my-url-map',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.urlMaps.validate(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.urlMaps.validate
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.urlMap Name of the UrlMap resource to be validated as.
         * @param {().UrlMapsValidateRequest} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        validate(params?: Params$Resource$Urlmaps$Validate, options?: MethodOptions): GaxiosPromise<Schema$UrlMapsValidateResponse>;
        validate(params: Params$Resource$Urlmaps$Validate, options: MethodOptions | BodyResponseCallback<Schema$UrlMapsValidateResponse>, callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
        validate(params: Params$Resource$Urlmaps$Validate, callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
        validate(callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
    }
    interface Params$Resource$Urlmaps$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to delete.
         */
        urlMap?: string;
    }
    interface Params$Resource$Urlmaps$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the UrlMap resource to return.
         */
        urlMap?: string;
    }
    interface Params$Resource$Urlmaps$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    interface Params$Resource$Urlmaps$Invalidatecache extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap scoping this request.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$CacheInvalidationRule;
    }
    interface Params$Resource$Urlmaps$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Urlmaps$Patch extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to patch.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    interface Params$Resource$Urlmaps$Update extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to update.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    interface Params$Resource$Urlmaps$Validate extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the UrlMap resource to be validated as.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapsValidateRequest;
    }
    class Resource$Vpntunnels {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.vpnTunnels.aggregatedList
         * @desc Retrieves an aggregated list of VPN tunnels.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     Object.keys(itemsPage).forEach(function(name) {
         *       // TODO: Change code below to process each `name` property:
         *       console.log(name + ': ' + JSON.stringify(itemsPage[name], null,
         * 2));
         *     });
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.vpnTunnels.aggregatedList(request, handlePage);
         *     }
         *   };
         *
         *   compute.vpnTunnels.aggregatedList(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.vpnTunnels.aggregatedList
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        aggregatedList(params?: Params$Resource$Vpntunnels$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$VpnTunnelAggregatedList>;
        aggregatedList(params: Params$Resource$Vpntunnels$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$VpnTunnelAggregatedList>, callback: BodyResponseCallback<Schema$VpnTunnelAggregatedList>): void;
        aggregatedList(params: Params$Resource$Vpntunnels$Aggregatedlist, callback: BodyResponseCallback<Schema$VpnTunnelAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$VpnTunnelAggregatedList>): void;
        /**
         * compute.vpnTunnels.delete
         * @desc Deletes the specified VpnTunnel resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the VpnTunnel resource to delete.
         *     vpnTunnel: 'my-vpn-tunnel',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.vpnTunnels.delete(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.vpnTunnels.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {string} params.vpnTunnel Name of the VpnTunnel resource to delete.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Vpntunnels$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Vpntunnels$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Vpntunnels$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.vpnTunnels.get
         * @desc Returns the specified VpnTunnel resource. Gets a list of available
         * VPN tunnels by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     // Name of the VpnTunnel resource to return.
         *     vpnTunnel: 'my-vpn-tunnel',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.vpnTunnels.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.vpnTunnels.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string} params.vpnTunnel Name of the VpnTunnel resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Vpntunnels$Get, options?: MethodOptions): GaxiosPromise<Schema$VpnTunnel>;
        get(params: Params$Resource$Vpntunnels$Get, options: MethodOptions | BodyResponseCallback<Schema$VpnTunnel>, callback: BodyResponseCallback<Schema$VpnTunnel>): void;
        get(params: Params$Resource$Vpntunnels$Get, callback: BodyResponseCallback<Schema$VpnTunnel>): void;
        get(callback: BodyResponseCallback<Schema$VpnTunnel>): void;
        /**
         * compute.vpnTunnels.insert
         * @desc Creates a VpnTunnel resource in the specified project and region
         * using the data included in the request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     resource: {
         *       // TODO: Add desired properties to the request body.
         *     },
         *
         *     auth: authClient,
         *   };
         *
         *   compute.vpnTunnels.insert(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.vpnTunnels.insert
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {string=} params.requestId An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.  For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.  The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
         * @param {().VpnTunnel} params.resource Request body data
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        insert(params?: Params$Resource$Vpntunnels$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Vpntunnels$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Vpntunnels$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.vpnTunnels.list
         * @desc Retrieves a list of VpnTunnel resources contained in the specified
         * project and region.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the region for this request.
         *     region: 'my-region',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.vpnTunnels.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.vpnTunnels.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.vpnTunnels.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.region Name of the region for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Vpntunnels$List, options?: MethodOptions): GaxiosPromise<Schema$VpnTunnelList>;
        list(params: Params$Resource$Vpntunnels$List, options: MethodOptions | BodyResponseCallback<Schema$VpnTunnelList>, callback: BodyResponseCallback<Schema$VpnTunnelList>): void;
        list(params: Params$Resource$Vpntunnels$List, callback: BodyResponseCallback<Schema$VpnTunnelList>): void;
        list(callback: BodyResponseCallback<Schema$VpnTunnelList>): void;
    }
    interface Params$Resource$Vpntunnels$Aggregatedlist extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    interface Params$Resource$Vpntunnels$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the VpnTunnel resource to delete.
         */
        vpnTunnel?: string;
    }
    interface Params$Resource$Vpntunnels$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the VpnTunnel resource to return.
         */
        vpnTunnel?: string;
    }
    interface Params$Resource$Vpntunnels$Insert extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID
         * so that if you must retry your request, the server will know to ignore
         * the request if it has already been completed.  For example, consider a
         * situation where you make an initial request and the request times out. If
         * you make the request again with the same request ID, the server can check
         * if original operation with the same request ID was received, and if so,
         * will ignore the second request. This prevents clients from accidentally
         * creating duplicate commitments.  The request ID must be a valid UUID with
         * the exception that zero UUID is not supported
         * (00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$VpnTunnel;
    }
    interface Params$Resource$Vpntunnels$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    class Resource$Zoneoperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.zoneOperations.delete
         * @desc Deletes the specified zone-specific Operations resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the Operations resource to delete.
         *     operation: 'my-operation',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.zoneOperations.delete(request, function(err) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.zoneOperations.delete
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.operation Name of the Operations resource to delete.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        delete(params?: Params$Resource$Zoneoperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Zoneoperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Zoneoperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * compute.zoneOperations.get
         * @desc Retrieves the specified zone-specific Operations resource.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for this request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     // Name of the Operations resource to return.
         *     operation: 'my-operation',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.zoneOperations.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.zoneOperations.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.operation Name of the Operations resource to return.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Zoneoperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Zoneoperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Zoneoperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * compute.zoneOperations.list
         * @desc Retrieves a list of Operation resources contained within the
         * specified zone.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone for request.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.zoneOperations.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.zoneOperations.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.zoneOperations.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone for request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Zoneoperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Zoneoperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Zoneoperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
    }
    interface Params$Resource$Zoneoperations$Delete extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Zoneoperations$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    interface Params$Resource$Zoneoperations$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for request.
         */
        zone?: string;
    }
    class Resource$Zones {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * compute.zones.get
         * @desc Returns the specified Zone resource. Gets a list of available zones
         * by making a list() request.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     // Name of the zone resource to return.
         *     zone: 'my-zone',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   compute.zones.get(request, function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     // TODO: Change code below to process the `response` object:
         *     console.log(JSON.stringify(response, null, 2));
         *   });
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.zones.get
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string} params.project Project ID for this request.
         * @param {string} params.zone Name of the zone resource to return.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        get(params?: Params$Resource$Zones$Get, options?: MethodOptions): GaxiosPromise<Schema$Zone>;
        get(params: Params$Resource$Zones$Get, options: MethodOptions | BodyResponseCallback<Schema$Zone>, callback: BodyResponseCallback<Schema$Zone>): void;
        get(params: Params$Resource$Zones$Get, callback: BodyResponseCallback<Schema$Zone>): void;
        get(callback: BodyResponseCallback<Schema$Zone>): void;
        /**
         * compute.zones.list
         * @desc Retrieves the list of Zone resources available to the specified
         * project.
         * @example
         * * // BEFORE RUNNING:
         * // ---------------
         * // 1. If not already done, enable the Compute Engine API
         * //    and check the quota for your project at
         * //    https://console.developers.google.com/apis/api/compute
         * // 2. This sample uses Application Default Credentials for
         * authentication.
         * //    If not already done, install the gcloud CLI from
         * //    https://cloud.google.com/sdk and run
         * //    `gcloud beta auth application-default login`.
         * //    For more information, see
         * //
         * https://developers.google.com/identity/protocols/application-default-credentials
         * // 3. Install the Node.js client library by running
         * //    `npm install googleapis --save`
         *
         * var google = require('googleapis');
         * var compute = google.compute('v1');
         *
         * authorize(function(authClient) {
         *   var request = {
         *     // Project ID for this request.
         *     project: 'my-project',  // TODO: Update placeholder value.
         *
         *     auth: authClient,
         *   };
         *
         *   var handlePage = function(err, response) {
         *     if (err) {
         *       console.error(err);
         *       return;
         *     }
         *
         *     var itemsPage = response['items'];
         *     if (!itemsPage) {
         *       return;
         *     }
         *     for (var i = 0; i < itemsPage.length; i++) {
         *       // TODO: Change code below to process each resource in `itemsPage`:
         *       console.log(JSON.stringify(itemsPage[i], null, 2));
         *     }
         *
         *     if (response.nextPageToken) {
         *       request.pageToken = response.nextPageToken;
         *       compute.zones.list(request, handlePage);
         *     }
         *   };
         *
         *   compute.zones.list(request, handlePage);
         * });
         *
         * function authorize(callback) {
         *   google.auth.getApplicationDefault(function(err, authClient) {
         *     if (err) {
         *       console.error('authentication failed: ', err);
         *       return;
         *     }
         *     if (authClient.createScopedRequired &&
         * authClient.createScopedRequired()) { var scopes =
         * ['https://www.googleapis.com/auth/cloud-platform']; authClient =
         * authClient.createScoped(scopes);
         *     }
         *     callback(authClient);
         *   });
         * }
         * @alias compute.zones.list
         * @memberOf! ()
         *
         * @param {object} params Parameters for request
         * @param {string=} params.filter A filter expression that filters resources listed in the response. The expression must specify the field name, a comparison operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The comparison operator must be either =, !=, >, or <.  For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.  You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels.  To filter on multiple expressions, provide each separate expression within parentheses. For example, (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake"). By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true).
         * @param {integer=} params.maxResults The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)
         * @param {string=} params.orderBy Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.  You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.  Currently, only sorting by name or creationTimestamp desc is supported.
         * @param {string=} params.pageToken Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.
         * @param {string} params.project Project ID for this request.
         * @param {object} [options] Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param {callback} callback The callback that handles the response.
         * @return {object} Request object
         */
        list(params?: Params$Resource$Zones$List, options?: MethodOptions): GaxiosPromise<Schema$ZoneList>;
        list(params: Params$Resource$Zones$List, options: MethodOptions | BodyResponseCallback<Schema$ZoneList>, callback: BodyResponseCallback<Schema$ZoneList>): void;
        list(params: Params$Resource$Zones$List, callback: BodyResponseCallback<Schema$ZoneList>): void;
        list(callback: BodyResponseCallback<Schema$ZoneList>): void;
    }
    interface Params$Resource$Zones$Get extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone resource to return.
         */
        zone?: string;
    }
    interface Params$Resource$Zones$List extends StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient;
        /**
         * A filter expression that filters resources listed in the response. The
         * expression must specify the field name, a comparison operator, and the
         * value that you want to use for filtering. The value must be a string, a
         * number, or a boolean. The comparison operator must be either =, !=, >, or
         * <.  For example, if you are filtering Compute Engine instances, you can
         * exclude instances named example-instance by specifying name !=
         * example-instance.  You can also filter nested fields. For example, you
         * could specify scheduling.automaticRestart = false to include instances
         * only if they are not scheduled for automatic restarts. You can use
         * filtering on nested fields to filter based on resource labels.  To filter
         * on multiple expressions, provide each separate expression within
         * parentheses. For example, (scheduling.automaticRestart = true)
         * (cpuPlatform = "Intel Skylake"). By default, each expression is an AND
         * expression. However, you can include AND and OR expressions explicitly.
         * For example, (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel
         * Broadwell") AND (scheduling.automaticRestart = true).
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the
         * number of available results is larger than maxResults, Compute Engine
         * returns a nextPageToken that can be used to get the next page of results
         * in subsequent list requests. Acceptable values are 0 to 500, inclusive.
         * (Default: 500)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned
         * in alphanumerical order based on the resource name.  You can also sort
         * results in descending order based on the creation timestamp using
         * orderBy="creationTimestamp desc". This sorts results based on the
         * creationTimestamp field in reverse chronological order (newest result
         * first). Use this to sort resources like operations so that the newest
         * operation is returned first.  Currently, only sorting by name or
         * creationTimestamp desc is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set pageToken to the nextPageToken
         * returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
}
